core/extensions/raymath/matrix/abbr_dart
library
Functions
-
MatrixAdd(MatrixD left, MatrixD right)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixAdd.
-
MatrixCompose(Vector3D translation, QuaternionD rotation, Vector3D scale)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixCompose.
-
MatrixDecompose(MatrixD mat)
→ (Vector3D, QuaternionD, Vector3D)
-
See RaylibMatrixExtDart.MatrixDecompose.
-
MatrixDeterminant(MatrixD mat)
→ double
-
See RaylibMatrixExtDart.MatrixDeterminant.
-
MatrixFrustum(double left, double right, double bottom, double top, double nearPlane, double farPlane)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixFrustum.
-
MatrixIdentity()
→ MatrixD
-
See RaylibMatrixExtDart.MatrixIdentity.
-
MatrixInvert(MatrixD mat)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixInvert.
-
MatrixLookAt(Vector3D eye, Vector3D target, Vector3D up)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixLookAt.
-
MatrixMultiply(MatrixD left, MatrixD right)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixMultiply.
-
MatrixMultiplyValue(MatrixD left, double value)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixMultiplyValue.
-
MatrixOrtho(double left, double right, double bottom, double top, double nearPlane, double farPlane)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixOrtho.
-
MatrixPerspective(double fovY, double aspect, double nearPlane, double farPlane)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixPerspective.
-
MatrixRotate(Vector3D axis, double angle)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixRotate.
-
MatrixRotateX(double angle)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixRotateX.
-
MatrixRotateXYZ(Vector3D angle)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixRotateXYZ.
-
MatrixRotateY(double angle)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixRotateY.
-
MatrixRotateZ(double angle)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixRotateZ.
-
MatrixRotateZYX(Vector3D angle)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixRotateZYX.
-
MatrixScale(double x, double y, double z)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixScale.
-
MatrixSubtract(MatrixD left, MatrixD right)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixSubtract.
-
MatrixToFloatV(MatrixD mat)
→ float16D
-
See RaylibMatrixExtDart.MatrixToFloatV.
-
MatrixTrace(MatrixD mat)
→ double
-
See RaylibMatrixExtDart.MatrixTrace.
-
MatrixTranslate(double x, double y, double z)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixTranslate.
-
MatrixTranspose(MatrixD mat)
→ MatrixD
-
See RaylibMatrixExtDart.MatrixTranspose.