core/modules/core/abbr_flat library

Functions

BeginBlendMode(int mode) → void
See RaylibCoreFlatModule.BeginBlendMode.
BeginDrawing() → void
See RaylibCoreFlatModule.BeginDrawing.
BeginMode2D(Camera2DD camera) → void
See RaylibCoreFlatModule.BeginMode2D.
BeginMode3D(Camera3DD camera) → void
See RaylibCoreFlatModule.BeginMode3D.
BeginScissorMode(int x, int y, int width, int height) → void
See RaylibCoreFlatModule.BeginScissorMode.
BeginShaderMode(ShaderD shader) → void
See RaylibCoreFlatModule.BeginShaderMode.
BeginTextureMode(RenderTextureD target) → void
See RaylibCoreFlatModule.BeginTextureMode.
BeginVrStereoMode(VrStereoConfigD config) → void
See RaylibCoreFlatModule.BeginVrStereoMode.
ChangeDirectory(MemoryPointer<RChar> dir) → bool
See RaylibCoreFlatModule.ChangeDirectory.
CheckCollisionBoxes(BoundingBoxD box1, BoundingBoxD box2) → bool
See RaylibCoreFlatModule.CheckCollisionBoxes.
CheckCollisionBoxSphere(BoundingBoxD box, Vector3D center, double radius) → bool
See RaylibCoreFlatModule.CheckCollisionBoxSphere.
CheckCollisionCircleLine(Vector2D center, double radius, Vector2D p1, Vector2D p2) → bool
See RaylibCoreFlatModule.CheckCollisionCircleLine.
CheckCollisionCircleRec(Vector2D center, double radius, RectangleD rec) → bool
See RaylibCoreFlatModule.CheckCollisionCircleRec.
CheckCollisionCircles(Vector2D center1, double radius1, Vector2D center2, double radius2) → bool
See RaylibCoreFlatModule.CheckCollisionCircles.
CheckCollisionLines(Vector2D startPos1, Vector2D endPos1, Vector2D startPos2, Vector2D endPos2, StructPointer<Vector2D> collisionPoint) → bool
See RaylibCoreFlatModule.CheckCollisionLines.
CheckCollisionPointCircle(Vector2D point, Vector2D center, double radius) → bool
See RaylibCoreFlatModule.CheckCollisionPointCircle.
CheckCollisionPointLine(Vector2D point, Vector2D p1, Vector2D p2, int threshold) → bool
See RaylibCoreFlatModule.CheckCollisionPointLine.
CheckCollisionPointPoly(Vector2D point, StructPointer<Vector2D> points, int pointCount) → bool
See RaylibCoreFlatModule.CheckCollisionPointPoly.
CheckCollisionPointRec(Vector2D point, RectangleD rec) → bool
See RaylibCoreFlatModule.CheckCollisionPointRec.
CheckCollisionPointTriangle(Vector2D point, Vector2D p1, Vector2D p2, Vector2D p3) → bool
See RaylibCoreFlatModule.CheckCollisionPointTriangle.
CheckCollisionRecs(RectangleD rec1, RectangleD rec2) → bool
See RaylibCoreFlatModule.CheckCollisionRecs.
CheckCollisionSpheres(Vector3D center1, double radius1, Vector3D center2, double radius2) → bool
See RaylibCoreFlatModule.CheckCollisionSpheres.
ClearBackground(ColorD color) → void
See RaylibCoreFlatModule.ClearBackground.
ClearWindowState(int flags) → void
See RaylibCoreFlatModule.ClearWindowState.
CloseWindow() → void
See RaylibCoreFlatModule.CloseWindow.
CodepointToUTF8(int codepoint, MemoryPointer<RInt> utf8Size) → MemoryPointer<RChar>
See RaylibCoreFlatModule.CodepointToUTF8.
ColorAlpha(ColorD color, double alpha) → ColorD
See RaylibCoreFlatModule.ColorAlpha.
ColorAlphaBlend(ColorD dst, ColorD src, ColorD tint) → ColorD
See RaylibCoreFlatModule.ColorAlphaBlend.
ColorBrightness(ColorD color, double factor) → ColorD
See RaylibCoreFlatModule.ColorBrightness.
ColorContrast(ColorD color, double contrast) → ColorD
See RaylibCoreFlatModule.ColorContrast.
ColorFromHSV(double hue, double saturation, double value) → ColorD
See RaylibCoreFlatModule.ColorFromHSV.
ColorFromNormalized(Vector4D normalized) → ColorD
See RaylibCoreFlatModule.ColorFromNormalized.
ColorIsEqual(ColorD col1, ColorD col2) → bool
See RaylibCoreFlatModule.ColorIsEqual.
ColorLerp(ColorD color1, ColorD color2, double factor) → ColorD
See RaylibCoreFlatModule.ColorLerp.
ColorNormalize(ColorD color) → Vector4D
See RaylibCoreFlatModule.ColorNormalize.
ColorTint(ColorD color, ColorD tint) → ColorD
See RaylibCoreFlatModule.ColorTint.
ColorToHSV(ColorD color) → Vector3D
See RaylibCoreFlatModule.ColorToHSV.
ColorToInt(ColorD color) → int
See RaylibCoreFlatModule.ColorToInt.
CompressData(MemoryPointer<RUnsignedChar> data, int dataSize, MemoryPointer<RInt> compDataSize) → MemoryPointer<RUnsignedChar>
See RaylibCoreFlatModule.CompressData.
ComputeCRC32(MemoryPointer<RUnsignedChar> data, int dataSize) → int
See RaylibCoreFlatModule.ComputeCRC32.
ComputeMD5(MemoryPointer<RUnsignedChar> data, int dataSize) → MemoryPointer<RUnsignedInt>
See RaylibCoreFlatModule.ComputeMD5.
ComputeSHA1(MemoryPointer<RUnsignedChar> data, int dataSize) → MemoryPointer<RUnsignedInt>
See RaylibCoreFlatModule.ComputeSHA1.
ComputeSHA256(MemoryPointer<RUnsignedChar> data, int dataSize) → MemoryPointer<RUnsignedInt>
See RaylibCoreFlatModule.ComputeSHA256.
DecodeDataBase64(MemoryPointer<RChar> data, MemoryPointer<RInt> outputSize) → MemoryPointer<RUnsignedChar>
See RaylibCoreFlatModule.DecodeDataBase64.
DecompressData(MemoryPointer<RUnsignedChar> compData, int compDataSize, MemoryPointer<RInt> dataSize) → MemoryPointer<RUnsignedChar>
See RaylibCoreFlatModule.DecompressData.
DirectoryExists(MemoryPointer<RChar> dirPath) → bool
See RaylibCoreFlatModule.DirectoryExists.
DisableCursor() → void
See RaylibCoreFlatModule.DisableCursor.
DisableEventWaiting() → void
See RaylibCoreFlatModule.DisableEventWaiting.
DrawBillboard(Camera3DD camera, TextureD texture, Vector3D position, double scale, ColorD tint) → void
See RaylibCoreFlatModule.DrawBillboard.
DrawBillboardPro(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector3D up, Vector2D size, Vector2D origin, double rotation, ColorD tint) → void
See RaylibCoreFlatModule.DrawBillboardPro.
DrawBillboardRec(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector2D size, ColorD tint) → void
See RaylibCoreFlatModule.DrawBillboardRec.
DrawBoundingBox(BoundingBoxD box, ColorD color) → void
See RaylibCoreFlatModule.DrawBoundingBox.
DrawCapsule(Vector3D startPos, Vector3D endPos, double radius, int slices, int rings, ColorD color) → void
See RaylibCoreFlatModule.DrawCapsule.
DrawCapsuleWires(Vector3D startPos, Vector3D endPos, double radius, int slices, int rings, ColorD color) → void
See RaylibCoreFlatModule.DrawCapsuleWires.
DrawCircle(int centerX, int centerY, double radius, ColorD color) → void
See RaylibCoreFlatModule.DrawCircle.
DrawCircle3D(Vector3D center, double radius, Vector3D rotationAxis, double rotationAngle, ColorD color) → void
See RaylibCoreFlatModule.DrawCircle3D.
DrawCircleGradient(Vector2D center, double radius, ColorD inner, ColorD outer) → void
See RaylibCoreFlatModule.DrawCircleGradient.
DrawCircleLines(int centerX, int centerY, double radius, ColorD color) → void
See RaylibCoreFlatModule.DrawCircleLines.
DrawCircleLinesV(Vector2D center, double radius, ColorD color) → void
See RaylibCoreFlatModule.DrawCircleLinesV.
DrawCircleSector(Vector2D center, double radius, double startAngle, double endAngle, int segments, ColorD color) → void
See RaylibCoreFlatModule.DrawCircleSector.
DrawCircleSectorLines(Vector2D center, double radius, double startAngle, double endAngle, int segments, ColorD color) → void
See RaylibCoreFlatModule.DrawCircleSectorLines.
DrawCircleV(Vector2D center, double radius, ColorD color) → void
See RaylibCoreFlatModule.DrawCircleV.
DrawCube(Vector3D position, double width, double height, double length, ColorD color) → void
See RaylibCoreFlatModule.DrawCube.
DrawCubeV(Vector3D position, Vector3D size, ColorD color) → void
See RaylibCoreFlatModule.DrawCubeV.
DrawCubeWires(Vector3D position, double width, double height, double length, ColorD color) → void
See RaylibCoreFlatModule.DrawCubeWires.
DrawCubeWiresV(Vector3D position, Vector3D size, ColorD color) → void
See RaylibCoreFlatModule.DrawCubeWiresV.
DrawCylinder(Vector3D position, double radiusTop, double radiusBottom, double height, int slices, ColorD color) → void
See RaylibCoreFlatModule.DrawCylinder.
DrawCylinderEx(Vector3D startPos, Vector3D endPos, double startRadius, double endRadius, int sides, ColorD color) → void
See RaylibCoreFlatModule.DrawCylinderEx.
DrawCylinderWires(Vector3D position, double radiusTop, double radiusBottom, double height, int slices, ColorD color) → void
See RaylibCoreFlatModule.DrawCylinderWires.
DrawCylinderWiresEx(Vector3D startPos, Vector3D endPos, double startRadius, double endRadius, int sides, ColorD color) → void
See RaylibCoreFlatModule.DrawCylinderWiresEx.
DrawEllipse(int centerX, int centerY, double radiusH, double radiusV, ColorD color) → void
See RaylibCoreFlatModule.DrawEllipse.
DrawEllipseLines(int centerX, int centerY, double radiusH, double radiusV, ColorD color) → void
See RaylibCoreFlatModule.DrawEllipseLines.
DrawEllipseLinesV(Vector2D center, double radiusH, double radiusV, ColorD color) → void
See RaylibCoreFlatModule.DrawEllipseLinesV.
DrawEllipseV(Vector2D center, double radiusH, double radiusV, ColorD color) → void
See RaylibCoreFlatModule.DrawEllipseV.
DrawFPS(int posX, int posY) → void
See RaylibCoreFlatModule.DrawFPS.
DrawGrid(int slices, double spacing) → void
See RaylibCoreFlatModule.DrawGrid.
DrawLine(int startPosX, int startPosY, int endPosX, int endPosY, ColorD color) → void
See RaylibCoreFlatModule.DrawLine.
DrawLine3D(Vector3D startPos, Vector3D endPos, ColorD color) → void
See RaylibCoreFlatModule.DrawLine3D.
DrawLineBezier(Vector2D startPos, Vector2D endPos, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawLineBezier.
DrawLineDashed(Vector2D startPos, Vector2D endPos, int dashSize, int spaceSize, ColorD color) → void
See RaylibCoreFlatModule.DrawLineDashed.
DrawLineEx(Vector2D startPos, Vector2D endPos, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawLineEx.
DrawLineStrip(StructPointer<Vector2D> points, int pointCount, ColorD color) → void
See RaylibCoreFlatModule.DrawLineStrip.
DrawLineV(Vector2D startPos, Vector2D endPos, ColorD color) → void
See RaylibCoreFlatModule.DrawLineV.
DrawMesh(MeshD mesh, MaterialD material, MatrixD transform) → void
See RaylibCoreFlatModule.DrawMesh.
DrawMeshInstanced(MeshD mesh, MaterialD material, StructPointer<MatrixD> transforms, int instances) → void
See RaylibCoreFlatModule.DrawMeshInstanced.
DrawModel(ModelD model, Vector3D position, double scale, ColorD tint) → void
See RaylibCoreFlatModule.DrawModel.
DrawModelEx(ModelD model, Vector3D position, Vector3D rotationAxis, double rotationAngle, Vector3D scale, ColorD tint) → void
See RaylibCoreFlatModule.DrawModelEx.
DrawModelWires(ModelD model, Vector3D position, double scale, ColorD tint) → void
See RaylibCoreFlatModule.DrawModelWires.
DrawModelWiresEx(ModelD model, Vector3D position, Vector3D rotationAxis, double rotationAngle, Vector3D scale, ColorD tint) → void
See RaylibCoreFlatModule.DrawModelWiresEx.
DrawPixel(int posX, int posY, ColorD color) → void
See RaylibCoreFlatModule.DrawPixel.
DrawPixelV(Vector2D position, ColorD color) → void
See RaylibCoreFlatModule.DrawPixelV.
DrawPlane(Vector3D centerPos, Vector2D size, ColorD color) → void
See RaylibCoreFlatModule.DrawPlane.
DrawPoint3D(Vector3D position, ColorD color) → void
See RaylibCoreFlatModule.DrawPoint3D.
DrawPoly(Vector2D center, int sides, double radius, double rotation, ColorD color) → void
See RaylibCoreFlatModule.DrawPoly.
DrawPolyLines(Vector2D center, int sides, double radius, double rotation, ColorD color) → void
See RaylibCoreFlatModule.DrawPolyLines.
DrawPolyLinesEx(Vector2D center, int sides, double radius, double rotation, double lineThick, ColorD color) → void
See RaylibCoreFlatModule.DrawPolyLinesEx.
DrawRay(RayD ray, ColorD color) → void
See RaylibCoreFlatModule.DrawRay.
DrawRectangle(int posX, int posY, int width, int height, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangle.
DrawRectangleGradientEx(RectangleD rec, ColorD topLeft, ColorD bottomLeft, ColorD topRight, ColorD bottomRight) → void
See RaylibCoreFlatModule.DrawRectangleGradientEx.
DrawRectangleGradientH(int posX, int posY, int width, int height, ColorD left, ColorD right) → void
See RaylibCoreFlatModule.DrawRectangleGradientH.
DrawRectangleGradientV(int posX, int posY, int width, int height, ColorD top, ColorD bottom) → void
See RaylibCoreFlatModule.DrawRectangleGradientV.
DrawRectangleLines(int posX, int posY, int width, int height, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleLines.
DrawRectangleLinesEx(RectangleD rec, double lineThick, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleLinesEx.
DrawRectanglePro(RectangleD rec, Vector2D origin, double rotation, ColorD color) → void
See RaylibCoreFlatModule.DrawRectanglePro.
DrawRectangleRec(RectangleD rec, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleRec.
DrawRectangleRounded(RectangleD rec, double roundness, int segments, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleRounded.
DrawRectangleRoundedLines(RectangleD rec, double roundness, int segments, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleRoundedLines.
DrawRectangleRoundedLinesEx(RectangleD rec, double roundness, int segments, double lineThick, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleRoundedLinesEx.
DrawRectangleV(Vector2D position, Vector2D size, ColorD color) → void
See RaylibCoreFlatModule.DrawRectangleV.
DrawRing(Vector2D center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorD color) → void
See RaylibCoreFlatModule.DrawRing.
DrawRingLines(Vector2D center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorD color) → void
See RaylibCoreFlatModule.DrawRingLines.
DrawSphere(Vector3D centerPos, double radius, ColorD color) → void
See RaylibCoreFlatModule.DrawSphere.
DrawSphereEx(Vector3D centerPos, double radius, int rings, int slices, ColorD color) → void
See RaylibCoreFlatModule.DrawSphereEx.
DrawSphereWires(Vector3D centerPos, double radius, int rings, int slices, ColorD color) → void
See RaylibCoreFlatModule.DrawSphereWires.
DrawSplineBasis(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineBasis.
DrawSplineBezierCubic(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineBezierCubic.
DrawSplineBezierQuadratic(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineBezierQuadratic.
DrawSplineCatmullRom(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineCatmullRom.
DrawSplineLinear(StructPointer<Vector2D> points, int pointCount, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineLinear.
DrawSplineSegmentBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineSegmentBasis.
DrawSplineSegmentBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineSegmentBezierCubic.
DrawSplineSegmentBezierQuadratic(Vector2D p1, Vector2D c2, Vector2D p3, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineSegmentBezierQuadratic.
DrawSplineSegmentCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineSegmentCatmullRom.
DrawSplineSegmentLinear(Vector2D p1, Vector2D p2, double thick, ColorD color) → void
See RaylibCoreFlatModule.DrawSplineSegmentLinear.
DrawText(MemoryPointer<RChar> text, int posX, int posY, int fontSize, ColorD color) → void
See RaylibCoreFlatModule.DrawText.
DrawTextCodepoint(FontD font, int codepoint, Vector2D position, double fontSize, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextCodepoint.
DrawTextCodepoints(FontD font, MemoryPointer<RInt> codepoints, int codepointCount, Vector2D position, double fontSize, double spacing, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextCodepoints.
DrawTextEx(FontD font, MemoryPointer<RChar> text, Vector2D position, double fontSize, double spacing, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextEx.
DrawTextPro(FontD font, MemoryPointer<RChar> text, Vector2D position, Vector2D origin, double rotation, double fontSize, double spacing, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextPro.
DrawTexture(TextureD texture, int posX, int posY, ColorD tint) → void
See RaylibCoreFlatModule.DrawTexture.
DrawTextureEx(TextureD texture, Vector2D position, double rotation, double scale, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextureEx.
DrawTextureNPatch(TextureD texture, NPatchInfoD nPatchInfo, RectangleD dest, Vector2D origin, double rotation, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextureNPatch.
DrawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, double rotation, ColorD tint) → void
See RaylibCoreFlatModule.DrawTexturePro.
DrawTextureRec(TextureD texture, RectangleD source, Vector2D position, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextureRec.
DrawTextureV(TextureD texture, Vector2D position, ColorD tint) → void
See RaylibCoreFlatModule.DrawTextureV.
DrawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
See RaylibCoreFlatModule.DrawTriangle.
DrawTriangle3D(Vector3D v1, Vector3D v2, Vector3D v3, ColorD color) → void
See RaylibCoreFlatModule.DrawTriangle3D.
DrawTriangleFan(StructPointer<Vector2D> points, int pointCount, ColorD color) → void
See RaylibCoreFlatModule.DrawTriangleFan.
DrawTriangleLines(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
See RaylibCoreFlatModule.DrawTriangleLines.
DrawTriangleStrip(StructPointer<Vector2D> points, int pointCount, ColorD color) → void
See RaylibCoreFlatModule.DrawTriangleStrip.
DrawTriangleStrip3D(StructPointer<Vector3D> points, int pointCount, ColorD color) → void
See RaylibCoreFlatModule.DrawTriangleStrip3D.
EnableCursor() → void
See RaylibCoreFlatModule.EnableCursor.
EnableEventWaiting() → void
See RaylibCoreFlatModule.EnableEventWaiting.
EncodeDataBase64(MemoryPointer<RUnsignedChar> data, int dataSize, MemoryPointer<RInt> outputSize) → MemoryPointer<RChar>
See RaylibCoreFlatModule.EncodeDataBase64.
EndBlendMode() → void
See RaylibCoreFlatModule.EndBlendMode.
EndDrawing() → void
See RaylibCoreFlatModule.EndDrawing.
EndMode2D() → void
See RaylibCoreFlatModule.EndMode2D.
EndMode3D() → void
See RaylibCoreFlatModule.EndMode3D.
EndScissorMode() → void
See RaylibCoreFlatModule.EndScissorMode.
EndShaderMode() → void
See RaylibCoreFlatModule.EndShaderMode.
EndTextureMode() → void
See RaylibCoreFlatModule.EndTextureMode.
EndVrStereoMode() → void
See RaylibCoreFlatModule.EndVrStereoMode.
ExportAutomationEventList(AutomationEventListD list, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportAutomationEventList.
ExportDataAsCode(MemoryPointer<RUnsignedChar> data, int dataSize, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportDataAsCode.
ExportFontAsCode(FontD font, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportFontAsCode.
ExportImage(ImageD image, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportImage.
ExportImageAsCode(ImageD image, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportImageAsCode.
ExportImageToMemory(ImageD image, MemoryPointer<RChar> fileType, MemoryPointer<RInt> fileSize) → MemoryPointer<RUnsignedChar>
See RaylibCoreFlatModule.ExportImageToMemory.
ExportMesh(MeshD mesh, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportMesh.
ExportMeshAsCode(MeshD mesh, MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.ExportMeshAsCode.
Fade(ColorD color, double alpha) → ColorD
See RaylibCoreFlatModule.Fade.
FileCopy(MemoryPointer<RChar> srcPath, MemoryPointer<RChar> dstPath) → int
See RaylibCoreFlatModule.FileCopy.
FileExists(MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.FileExists.
FileMove(MemoryPointer<RChar> srcPath, MemoryPointer<RChar> dstPath) → int
See RaylibCoreFlatModule.FileMove.
FileRemove(MemoryPointer<RChar> fileName) → int
See RaylibCoreFlatModule.FileRemove.
FileRename(MemoryPointer<RChar> fileName, MemoryPointer<RChar> fileRename) → int
See RaylibCoreFlatModule.FileRename.
FileTextFindIndex(MemoryPointer<RChar> fileName, MemoryPointer<RChar> search) → int
See RaylibCoreFlatModule.FileTextFindIndex.
FileTextReplace(MemoryPointer<RChar> fileName, MemoryPointer<RChar> search, MemoryPointer<RChar> replacement) → int
See RaylibCoreFlatModule.FileTextReplace.
GenImageCellular(int width, int height, int tileSize) → ImageD
See RaylibCoreFlatModule.GenImageCellular.
GenImageChecked(int width, int height, int checksX, int checksY, ColorD col1, ColorD col2) → ImageD
See RaylibCoreFlatModule.GenImageChecked.
GenImageColor(int width, int height, ColorD color) → ImageD
See RaylibCoreFlatModule.GenImageColor.
GenImageFontAtlas(StructPointer<GlyphInfoD> glyphs, MemoryPointer<RPointer<RStruct>> glyphRecs, int glyphCount, int fontSize, int padding, int packMethod) → ImageD
See RaylibCoreFlatModule.GenImageFontAtlas.
GenImageGradientLinear(int width, int height, int direction, ColorD start, ColorD end) → ImageD
See RaylibCoreFlatModule.GenImageGradientLinear.
GenImageGradientRadial(int width, int height, double density, ColorD inner, ColorD outer) → ImageD
See RaylibCoreFlatModule.GenImageGradientRadial.
GenImageGradientSquare(int width, int height, double density, ColorD inner, ColorD outer) → ImageD
See RaylibCoreFlatModule.GenImageGradientSquare.
GenImagePerlinNoise(int width, int height, int offsetX, int offsetY, double scale) → ImageD
See RaylibCoreFlatModule.GenImagePerlinNoise.
GenImageText(int width, int height, MemoryPointer<RChar> text) → ImageD
See RaylibCoreFlatModule.GenImageText.
GenImageWhiteNoise(int width, int height, double factor) → ImageD
See RaylibCoreFlatModule.GenImageWhiteNoise.
GenMeshCone(double radius, double height, int slices) → MeshD
See RaylibCoreFlatModule.GenMeshCone.
GenMeshCube(double width, double height, double length) → MeshD
See RaylibCoreFlatModule.GenMeshCube.
GenMeshCubicmap(ImageD cubicmap, Vector3D cubeSize) → MeshD
See RaylibCoreFlatModule.GenMeshCubicmap.
GenMeshCylinder(double radius, double height, int slices) → MeshD
See RaylibCoreFlatModule.GenMeshCylinder.
GenMeshHeightmap(ImageD heightmap, Vector3D size) → MeshD
See RaylibCoreFlatModule.GenMeshHeightmap.
GenMeshHemiSphere(double radius, int rings, int slices) → MeshD
See RaylibCoreFlatModule.GenMeshHemiSphere.
GenMeshKnot(double radius, double size, int radSeg, int sides) → MeshD
See RaylibCoreFlatModule.GenMeshKnot.
GenMeshPlane(double width, double length, int resX, int resZ) → MeshD
See RaylibCoreFlatModule.GenMeshPlane.
GenMeshPoly(int sides, double radius) → MeshD
See RaylibCoreFlatModule.GenMeshPoly.
GenMeshSphere(double radius, int rings, int slices) → MeshD
See RaylibCoreFlatModule.GenMeshSphere.
GenMeshTangents(StructPointer<MeshD> mesh) → void
See RaylibCoreFlatModule.GenMeshTangents.
GenMeshTorus(double radius, double size, int radSeg, int sides) → MeshD
See RaylibCoreFlatModule.GenMeshTorus.
GenTextureMipmaps(StructPointer<TextureD> texture) → void
See RaylibCoreFlatModule.GenTextureMipmaps.
GetApplicationDirectory() → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetApplicationDirectory.
GetCameraMatrix(Camera3DD camera) → MatrixD
See RaylibCoreFlatModule.GetCameraMatrix.
GetCameraMatrix2D(Camera2DD camera) → MatrixD
See RaylibCoreFlatModule.GetCameraMatrix2D.
GetCharPressed() → int
See RaylibCoreFlatModule.GetCharPressed.
GetClipboardImage() → ImageD
See RaylibCoreFlatModule.GetClipboardImage.
GetClipboardText() → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetClipboardText.
GetCodepoint(MemoryPointer<RChar> text, MemoryPointer<RInt> codepointSize) → int
See RaylibCoreFlatModule.GetCodepoint.
GetCodepointCount(MemoryPointer<RChar> text) → int
See RaylibCoreFlatModule.GetCodepointCount.
GetCodepointNext(MemoryPointer<RChar> text, MemoryPointer<RInt> codepointSize) → int
See RaylibCoreFlatModule.GetCodepointNext.
GetCodepointPrevious(MemoryPointer<RChar> text, MemoryPointer<RInt> codepointSize) → int
See RaylibCoreFlatModule.GetCodepointPrevious.
GetCollisionRec(RectangleD rec1, RectangleD rec2) → RectangleD
See RaylibCoreFlatModule.GetCollisionRec.
GetColor(int hexValue) → ColorD
See RaylibCoreFlatModule.GetColor.
GetCurrentMonitor() → int
See RaylibCoreFlatModule.GetCurrentMonitor.
GetDirectoryFileCount(MemoryPointer<RChar> dirPath) → int
See RaylibCoreFlatModule.GetDirectoryFileCount.
GetDirectoryFileCountEx(MemoryPointer<RChar> basePath, MemoryPointer<RChar> filter, bool scanSubdirs) → int
See RaylibCoreFlatModule.GetDirectoryFileCountEx.
GetDirectoryPath(MemoryPointer<RChar> filePath) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetDirectoryPath.
GetFileExtension(MemoryPointer<RChar> fileName) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetFileExtension.
GetFileLength(MemoryPointer<RChar> fileName) → int
See RaylibCoreFlatModule.GetFileLength.
GetFileModTime(MemoryPointer<RChar> fileName) → int
See RaylibCoreFlatModule.GetFileModTime.
GetFileName(MemoryPointer<RChar> filePath) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetFileName.
GetFileNameWithoutExt(MemoryPointer<RChar> filePath) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetFileNameWithoutExt.
GetFontDefault() → FontD
See RaylibCoreFlatModule.GetFontDefault.
GetFPS() → int
See RaylibCoreFlatModule.GetFPS.
GetFrameTime() → double
See RaylibCoreFlatModule.GetFrameTime.
GetGamepadAxisCount(int gamepad) → int
See RaylibCoreFlatModule.GetGamepadAxisCount.
GetGamepadAxisMovement(int gamepad, int axis) → double
See RaylibCoreFlatModule.GetGamepadAxisMovement.
GetGamepadButtonPressed() → int
See RaylibCoreFlatModule.GetGamepadButtonPressed.
GetGamepadName(int gamepad) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetGamepadName.
GetGestureDetected() → int
See RaylibCoreFlatModule.GetGestureDetected.
GetGestureDragAngle() → double
See RaylibCoreFlatModule.GetGestureDragAngle.
GetGestureDragVector() → Vector2D
See RaylibCoreFlatModule.GetGestureDragVector.
GetGestureHoldDuration() → double
See RaylibCoreFlatModule.GetGestureHoldDuration.
GetGesturePinchAngle() → double
See RaylibCoreFlatModule.GetGesturePinchAngle.
GetGesturePinchVector() → Vector2D
See RaylibCoreFlatModule.GetGesturePinchVector.
GetGlyphAtlasRec(FontD font, int codepoint) → RectangleD
See RaylibCoreFlatModule.GetGlyphAtlasRec.
GetGlyphIndex(FontD font, int codepoint) → int
See RaylibCoreFlatModule.GetGlyphIndex.
GetGlyphInfo(FontD font, int codepoint) → GlyphInfoD
See RaylibCoreFlatModule.GetGlyphInfo.
GetImageAlphaBorder(ImageD image, double threshold) → RectangleD
See RaylibCoreFlatModule.GetImageAlphaBorder.
GetImageColor(ImageD image, int x, int y) → ColorD
See RaylibCoreFlatModule.GetImageColor.
GetKeyName(int key) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetKeyName.
GetKeyPressed() → int
See RaylibCoreFlatModule.GetKeyPressed.
GetMeshBoundingBox(MeshD mesh) → BoundingBoxD
See RaylibCoreFlatModule.GetMeshBoundingBox.
GetModelBoundingBox(ModelD model) → BoundingBoxD
See RaylibCoreFlatModule.GetModelBoundingBox.
GetMonitorCount() → int
See RaylibCoreFlatModule.GetMonitorCount.
GetMonitorHeight(int monitor) → int
See RaylibCoreFlatModule.GetMonitorHeight.
GetMonitorName(int monitor) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetMonitorName.
GetMonitorPhysicalHeight(int monitor) → int
See RaylibCoreFlatModule.GetMonitorPhysicalHeight.
GetMonitorPhysicalWidth(int monitor) → int
See RaylibCoreFlatModule.GetMonitorPhysicalWidth.
GetMonitorPosition(int monitor) → Vector2D
See RaylibCoreFlatModule.GetMonitorPosition.
GetMonitorRefreshRate(int monitor) → int
See RaylibCoreFlatModule.GetMonitorRefreshRate.
GetMonitorWidth(int monitor) → int
See RaylibCoreFlatModule.GetMonitorWidth.
GetMouseDelta() → Vector2D
See RaylibCoreFlatModule.GetMouseDelta.
GetMousePosition() → Vector2D
See RaylibCoreFlatModule.GetMousePosition.
GetMouseWheelMove() → double
See RaylibCoreFlatModule.GetMouseWheelMove.
GetMouseWheelMoveV() → Vector2D
See RaylibCoreFlatModule.GetMouseWheelMoveV.
GetMouseX() → int
See RaylibCoreFlatModule.GetMouseX.
GetMouseY() → int
See RaylibCoreFlatModule.GetMouseY.
GetPixelColor(MemoryPointer<RVoid> srcPtr, int format) → ColorD
See RaylibCoreFlatModule.GetPixelColor.
GetPixelDataSize(int width, int height, int format) → int
See RaylibCoreFlatModule.GetPixelDataSize.
GetPrevDirectoryPath(MemoryPointer<RChar> dirPath) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetPrevDirectoryPath.
GetRandomValue(int min, int max) → int
See RaylibCoreFlatModule.GetRandomValue.
GetRayCollisionBox(RayD ray, BoundingBoxD box) → RayCollisionD
See RaylibCoreFlatModule.GetRayCollisionBox.
GetRayCollisionMesh(RayD ray, MeshD mesh, MatrixD transform) → RayCollisionD
See RaylibCoreFlatModule.GetRayCollisionMesh.
GetRayCollisionQuad(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3, Vector3D p4) → RayCollisionD
See RaylibCoreFlatModule.GetRayCollisionQuad.
GetRayCollisionSphere(RayD ray, Vector3D center, double radius) → RayCollisionD
See RaylibCoreFlatModule.GetRayCollisionSphere.
GetRayCollisionTriangle(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3) → RayCollisionD
See RaylibCoreFlatModule.GetRayCollisionTriangle.
GetRenderHeight() → int
See RaylibCoreFlatModule.GetRenderHeight.
GetRenderWidth() → int
See RaylibCoreFlatModule.GetRenderWidth.
GetScreenHeight() → int
See RaylibCoreFlatModule.GetScreenHeight.
GetScreenToWorld2D(Vector2D position, Camera2DD camera) → Vector2D
See RaylibCoreFlatModule.GetScreenToWorld2D.
GetScreenToWorldRay(Vector2D position, Camera3DD camera) → RayD
See RaylibCoreFlatModule.GetScreenToWorldRay.
GetScreenToWorldRayEx(Vector2D position, Camera3DD camera, int width, int height) → RayD
See RaylibCoreFlatModule.GetScreenToWorldRayEx.
GetScreenWidth() → int
See RaylibCoreFlatModule.GetScreenWidth.
GetShaderLocation(ShaderD shader, MemoryPointer<RChar> uniformName) → int
See RaylibCoreFlatModule.GetShaderLocation.
GetShaderLocationAttrib(ShaderD shader, MemoryPointer<RChar> attribName) → int
See RaylibCoreFlatModule.GetShaderLocationAttrib.
GetShapesTexture() → TextureD
See RaylibCoreFlatModule.GetShapesTexture.
GetShapesTextureRectangle() → RectangleD
See RaylibCoreFlatModule.GetShapesTextureRectangle.
GetSplinePointBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double t) → Vector2D
See RaylibCoreFlatModule.GetSplinePointBasis.
GetSplinePointBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, double t) → Vector2D
See RaylibCoreFlatModule.GetSplinePointBezierCubic.
GetSplinePointBezierQuad(Vector2D p1, Vector2D c2, Vector2D p3, double t) → Vector2D
See RaylibCoreFlatModule.GetSplinePointBezierQuad.
GetSplinePointCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, double t) → Vector2D
See RaylibCoreFlatModule.GetSplinePointCatmullRom.
GetSplinePointLinear(Vector2D startPos, Vector2D endPos, double t) → Vector2D
See RaylibCoreFlatModule.GetSplinePointLinear.
GetTextBetween(MemoryPointer<RChar> text, MemoryPointer<RChar> begin, MemoryPointer<RChar> end) → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetTextBetween.
GetTime() → double
See RaylibCoreFlatModule.GetTime.
GetTouchPointCount() → int
See RaylibCoreFlatModule.GetTouchPointCount.
GetTouchPointId(int index) → int
See RaylibCoreFlatModule.GetTouchPointId.
GetTouchPosition(int index) → Vector2D
See RaylibCoreFlatModule.GetTouchPosition.
GetTouchX() → int
See RaylibCoreFlatModule.GetTouchX.
GetTouchY() → int
See RaylibCoreFlatModule.GetTouchY.
GetWindowHandle() → MemoryPointer<RVoid>
See RaylibCoreFlatModule.GetWindowHandle.
GetWindowPosition() → Vector2D
See RaylibCoreFlatModule.GetWindowPosition.
GetWindowScaleDPI() → Vector2D
See RaylibCoreFlatModule.GetWindowScaleDPI.
GetWorkingDirectory() → MemoryPointer<RChar>
See RaylibCoreFlatModule.GetWorkingDirectory.
GetWorldToScreen(Vector3D position, Camera3DD camera) → Vector2D
See RaylibCoreFlatModule.GetWorldToScreen.
GetWorldToScreen2D(Vector2D position, Camera2DD camera) → Vector2D
See RaylibCoreFlatModule.GetWorldToScreen2D.
GetWorldToScreenEx(Vector3D position, Camera3DD camera, int width, int height) → Vector2D
See RaylibCoreFlatModule.GetWorldToScreenEx.
HideCursor() → void
See RaylibCoreFlatModule.HideCursor.
ImageAlphaClear(StructPointer<ImageD> image, ColorD color, double threshold) → void
See RaylibCoreFlatModule.ImageAlphaClear.
ImageAlphaCrop(StructPointer<ImageD> image, double threshold) → void
See RaylibCoreFlatModule.ImageAlphaCrop.
ImageAlphaMask(StructPointer<ImageD> image, ImageD alphaMask) → void
See RaylibCoreFlatModule.ImageAlphaMask.
ImageAlphaPremultiply(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageAlphaPremultiply.
ImageBlurGaussian(StructPointer<ImageD> image, int blurSize) → void
See RaylibCoreFlatModule.ImageBlurGaussian.
ImageClearBackground(StructPointer<ImageD> dst, ColorD color) → void
See RaylibCoreFlatModule.ImageClearBackground.
ImageColorBrightness(StructPointer<ImageD> image, int brightness) → void
See RaylibCoreFlatModule.ImageColorBrightness.
ImageColorContrast(StructPointer<ImageD> image, double contrast) → void
See RaylibCoreFlatModule.ImageColorContrast.
ImageColorGrayscale(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageColorGrayscale.
ImageColorInvert(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageColorInvert.
ImageColorReplace(StructPointer<ImageD> image, ColorD color, ColorD replace) → void
See RaylibCoreFlatModule.ImageColorReplace.
ImageColorTint(StructPointer<ImageD> image, ColorD color) → void
See RaylibCoreFlatModule.ImageColorTint.
ImageCopy(ImageD image) → ImageD
See RaylibCoreFlatModule.ImageCopy.
ImageCrop(StructPointer<ImageD> image, RectangleD crop) → void
See RaylibCoreFlatModule.ImageCrop.
ImageDither(StructPointer<ImageD> image, int rBpp, int gBpp, int bBpp, int aBpp) → void
See RaylibCoreFlatModule.ImageDither.
ImageDraw(StructPointer<ImageD> dst, ImageD src, RectangleD srcRec, RectangleD dstRec, ColorD tint) → void
See RaylibCoreFlatModule.ImageDraw.
ImageDrawCircle(StructPointer<ImageD> dst, int centerX, int centerY, int radius, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawCircle.
ImageDrawCircleLines(StructPointer<ImageD> dst, int centerX, int centerY, int radius, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawCircleLines.
ImageDrawCircleLinesV(StructPointer<ImageD> dst, Vector2D center, int radius, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawCircleLinesV.
ImageDrawCircleV(StructPointer<ImageD> dst, Vector2D center, int radius, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawCircleV.
ImageDrawLine(StructPointer<ImageD> dst, int startPosX, int startPosY, int endPosX, int endPosY, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawLine.
ImageDrawLineEx(StructPointer<ImageD> dst, Vector2D start, Vector2D end, int thick, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawLineEx.
ImageDrawLineV(StructPointer<ImageD> dst, Vector2D start, Vector2D end, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawLineV.
ImageDrawPixel(StructPointer<ImageD> dst, int posX, int posY, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawPixel.
ImageDrawPixelV(StructPointer<ImageD> dst, Vector2D position, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawPixelV.
ImageDrawRectangle(StructPointer<ImageD> dst, int posX, int posY, int width, int height, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawRectangle.
ImageDrawRectangleLines(StructPointer<ImageD> dst, RectangleD rec, int thick, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawRectangleLines.
ImageDrawRectangleRec(StructPointer<ImageD> dst, RectangleD rec, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawRectangleRec.
ImageDrawRectangleV(StructPointer<ImageD> dst, Vector2D position, Vector2D size, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawRectangleV.
ImageDrawText(StructPointer<ImageD> dst, MemoryPointer<RChar> text, int posX, int posY, int fontSize, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawText.
ImageDrawTextEx(StructPointer<ImageD> dst, FontD font, MemoryPointer<RChar> text, Vector2D position, double fontSize, double spacing, ColorD tint) → void
See RaylibCoreFlatModule.ImageDrawTextEx.
ImageDrawTriangle(StructPointer<ImageD> dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawTriangle.
ImageDrawTriangleEx(StructPointer<ImageD> dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD c1, ColorD c2, ColorD c3) → void
See RaylibCoreFlatModule.ImageDrawTriangleEx.
ImageDrawTriangleFan(StructPointer<ImageD> dst, StructPointer<Vector2D> points, int pointCount, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawTriangleFan.
ImageDrawTriangleLines(StructPointer<ImageD> dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawTriangleLines.
ImageDrawTriangleStrip(StructPointer<ImageD> dst, StructPointer<Vector2D> points, int pointCount, ColorD color) → void
See RaylibCoreFlatModule.ImageDrawTriangleStrip.
ImageFlipHorizontal(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageFlipHorizontal.
ImageFlipVertical(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageFlipVertical.
ImageFormat(StructPointer<ImageD> image, int newFormat) → void
See RaylibCoreFlatModule.ImageFormat.
ImageFromChannel(ImageD image, int selectedChannel) → ImageD
See RaylibCoreFlatModule.ImageFromChannel.
ImageFromImage(ImageD image, RectangleD rec) → ImageD
See RaylibCoreFlatModule.ImageFromImage.
ImageKernelConvolution(StructPointer<ImageD> image, MemoryPointer<RFloat> kernel, int kernelSize) → void
See RaylibCoreFlatModule.ImageKernelConvolution.
ImageMipmaps(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageMipmaps.
ImageResize(StructPointer<ImageD> image, int newWidth, int newHeight) → void
See RaylibCoreFlatModule.ImageResize.
ImageResizeCanvas(StructPointer<ImageD> image, int newWidth, int newHeight, int offsetX, int offsetY, ColorD fill) → void
See RaylibCoreFlatModule.ImageResizeCanvas.
ImageResizeNN(StructPointer<ImageD> image, int newWidth, int newHeight) → void
See RaylibCoreFlatModule.ImageResizeNN.
ImageRotate(StructPointer<ImageD> image, int degrees) → void
See RaylibCoreFlatModule.ImageRotate.
ImageRotateCCW(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageRotateCCW.
ImageRotateCW(StructPointer<ImageD> image) → void
See RaylibCoreFlatModule.ImageRotateCW.
ImageText(MemoryPointer<RChar> text, int fontSize, ColorD color) → ImageD
See RaylibCoreFlatModule.ImageText.
ImageTextEx(FontD font, MemoryPointer<RChar> text, double fontSize, double spacing, ColorD tint) → ImageD
See RaylibCoreFlatModule.ImageTextEx.
ImageToPOT(StructPointer<ImageD> image, ColorD fill) → void
See RaylibCoreFlatModule.ImageToPOT.
InitWindow(int width, int height, MemoryPointer<RChar> title) → void
See RaylibCoreFlatModule.InitWindow.
IsCursorHidden() → bool
See RaylibCoreFlatModule.IsCursorHidden.
IsCursorOnScreen() → bool
See RaylibCoreFlatModule.IsCursorOnScreen.
IsFileDropped() → bool
See RaylibCoreFlatModule.IsFileDropped.
IsFileExtension(MemoryPointer<RChar> fileName, MemoryPointer<RChar> ext) → bool
See RaylibCoreFlatModule.IsFileExtension.
IsFileNameValid(MemoryPointer<RChar> fileName) → bool
See RaylibCoreFlatModule.IsFileNameValid.
IsFontValid(FontD font) → bool
See RaylibCoreFlatModule.IsFontValid.
IsGamepadAvailable(int gamepad) → bool
See RaylibCoreFlatModule.IsGamepadAvailable.
IsGamepadButtonDown(int gamepad, int button) → bool
See RaylibCoreFlatModule.IsGamepadButtonDown.
IsGamepadButtonPressed(int gamepad, int button) → bool
See RaylibCoreFlatModule.IsGamepadButtonPressed.
IsGamepadButtonReleased(int gamepad, int button) → bool
See RaylibCoreFlatModule.IsGamepadButtonReleased.
IsGamepadButtonUp(int gamepad, int button) → bool
See RaylibCoreFlatModule.IsGamepadButtonUp.
IsGestureDetected(int gesture) → bool
See RaylibCoreFlatModule.IsGestureDetected.
IsImageValid(ImageD image) → bool
See RaylibCoreFlatModule.IsImageValid.
IsKeyDown(int key) → bool
See RaylibCoreFlatModule.IsKeyDown.
IsKeyPressed(int key) → bool
See RaylibCoreFlatModule.IsKeyPressed.
IsKeyPressedRepeat(int key) → bool
See RaylibCoreFlatModule.IsKeyPressedRepeat.
IsKeyReleased(int key) → bool
See RaylibCoreFlatModule.IsKeyReleased.
IsKeyUp(int key) → bool
See RaylibCoreFlatModule.IsKeyUp.
IsMaterialValid(MaterialD material) → bool
See RaylibCoreFlatModule.IsMaterialValid.
IsModelAnimationValid(ModelD model, ModelAnimationD anim) → bool
See RaylibCoreFlatModule.IsModelAnimationValid.
IsModelValid(ModelD model) → bool
See RaylibCoreFlatModule.IsModelValid.
IsMouseButtonDown(int button) → bool
See RaylibCoreFlatModule.IsMouseButtonDown.
IsMouseButtonPressed(int button) → bool
See RaylibCoreFlatModule.IsMouseButtonPressed.
IsMouseButtonReleased(int button) → bool
See RaylibCoreFlatModule.IsMouseButtonReleased.
IsMouseButtonUp(int button) → bool
See RaylibCoreFlatModule.IsMouseButtonUp.
IsPathFile(MemoryPointer<RChar> path) → bool
See RaylibCoreFlatModule.IsPathFile.
IsRenderTextureValid(RenderTextureD target) → bool
See RaylibCoreFlatModule.IsRenderTextureValid.
IsShaderValid(ShaderD shader) → bool
See RaylibCoreFlatModule.IsShaderValid.
IsTextureValid(TextureD texture) → bool
See RaylibCoreFlatModule.IsTextureValid.
IsWindowFocused() → bool
See RaylibCoreFlatModule.IsWindowFocused.
IsWindowFullscreen() → bool
See RaylibCoreFlatModule.IsWindowFullscreen.
IsWindowHidden() → bool
See RaylibCoreFlatModule.IsWindowHidden.
IsWindowMaximized() → bool
See RaylibCoreFlatModule.IsWindowMaximized.
IsWindowMinimized() → bool
See RaylibCoreFlatModule.IsWindowMinimized.
IsWindowReady() → bool
See RaylibCoreFlatModule.IsWindowReady.
IsWindowResized() → bool
See RaylibCoreFlatModule.IsWindowResized.
IsWindowState(int flag) → bool
See RaylibCoreFlatModule.IsWindowState.
LoadAutomationEventList(MemoryPointer<RChar> fileName) → AutomationEventListD
See RaylibCoreFlatModule.LoadAutomationEventList.
LoadCodepoints(MemoryPointer<RChar> text, MemoryPointer<RInt> count) → MemoryPointer<RInt>
See RaylibCoreFlatModule.LoadCodepoints.
LoadDirectoryFiles(MemoryPointer<RChar> dirPath) → FilePathListD
See RaylibCoreFlatModule.LoadDirectoryFiles.
LoadDirectoryFilesEx(MemoryPointer<RChar> basePath, MemoryPointer<RChar> filter, bool scanSubdirs) → FilePathListD
See RaylibCoreFlatModule.LoadDirectoryFilesEx.
LoadDroppedFiles() → FilePathListD
See RaylibCoreFlatModule.LoadDroppedFiles.
LoadFileData(MemoryPointer<RChar> fileName, MemoryPointer<RInt> dataSize) → MemoryPointer<RUnsignedChar>
See RaylibCoreFlatModule.LoadFileData.
LoadFileText(MemoryPointer<RChar> fileName) → MemoryPointer<RChar>
See RaylibCoreFlatModule.LoadFileText.
LoadFont(MemoryPointer<RChar> fileName) → FontD
See RaylibCoreFlatModule.LoadFont.
LoadFontData(MemoryPointer<RUnsignedChar> fileData, int dataSize, int fontSize, MemoryPointer<RInt> codepoints, int codepointCount, int type, MemoryPointer<RInt> glyphCount) → StructPointer<GlyphInfoD>
See RaylibCoreFlatModule.LoadFontData.
LoadFontEx(MemoryPointer<RChar> fileName, int fontSize, MemoryPointer<RInt> codepoints, int codepointCount) → FontD
See RaylibCoreFlatModule.LoadFontEx.
LoadFontFromImage(ImageD image, ColorD key, int firstChar) → FontD
See RaylibCoreFlatModule.LoadFontFromImage.
LoadFontFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize, int fontSize, MemoryPointer<RInt> codepoints, int codepointCount) → FontD
See RaylibCoreFlatModule.LoadFontFromMemory.
LoadImage(MemoryPointer<RChar> fileName) → ImageD
See RaylibCoreFlatModule.LoadImage.
LoadImageAnim(MemoryPointer<RChar> fileName, MemoryPointer<RInt> frames) → ImageD
See RaylibCoreFlatModule.LoadImageAnim.
LoadImageAnimFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize, MemoryPointer<RInt> frames) → ImageD
See RaylibCoreFlatModule.LoadImageAnimFromMemory.
LoadImageColors(ImageD image) → StructPointer<ColorD>
See RaylibCoreFlatModule.LoadImageColors.
LoadImageFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize) → ImageD
See RaylibCoreFlatModule.LoadImageFromMemory.
LoadImageFromScreen() → ImageD
See RaylibCoreFlatModule.LoadImageFromScreen.
LoadImageFromTexture(TextureD texture) → ImageD
See RaylibCoreFlatModule.LoadImageFromTexture.
LoadImagePalette(ImageD image, int maxPaletteSize, MemoryPointer<RInt> colorCount) → StructPointer<ColorD>
See RaylibCoreFlatModule.LoadImagePalette.
LoadImageRaw(MemoryPointer<RChar> fileName, int width, int height, int format, int headerSize) → ImageD
See RaylibCoreFlatModule.LoadImageRaw.
LoadMaterialDefault() → MaterialD
See RaylibCoreFlatModule.LoadMaterialDefault.
LoadMaterials(MemoryPointer<RChar> fileName, MemoryPointer<RInt> materialCount) → StructPointer<MaterialD>
See RaylibCoreFlatModule.LoadMaterials.
LoadModel(MemoryPointer<RChar> fileName) → ModelD
See RaylibCoreFlatModule.LoadModel.
LoadModelAnimations(MemoryPointer<RChar> fileName, MemoryPointer<RInt> animCount) → StructPointer<ModelAnimationD>
See RaylibCoreFlatModule.LoadModelAnimations.
LoadModelFromMesh(MeshD mesh) → ModelD
See RaylibCoreFlatModule.LoadModelFromMesh.
LoadRandomSequence(int count, int min, int max) → MemoryPointer<RInt>
See RaylibCoreFlatModule.LoadRandomSequence.
LoadRenderTexture(int width, int height) → RenderTextureD
See RaylibCoreFlatModule.LoadRenderTexture.
LoadShader(MemoryPointer<RChar> vsFileName, MemoryPointer<RChar> fsFileName) → ShaderD
See RaylibCoreFlatModule.LoadShader.
LoadShaderFromMemory(MemoryPointer<RChar> vsCode, MemoryPointer<RChar> fsCode) → ShaderD
See RaylibCoreFlatModule.LoadShaderFromMemory.
LoadTextLines(MemoryPointer<RChar> text, MemoryPointer<RInt> count) → MemoryPointer<RPointer<RChar>>
See RaylibCoreFlatModule.LoadTextLines.
LoadTexture(MemoryPointer<RChar> fileName) → TextureD
See RaylibCoreFlatModule.LoadTexture.
LoadTextureCubemap(ImageD image, int layout) → TextureD
See RaylibCoreFlatModule.LoadTextureCubemap.
LoadTextureFromImage(ImageD image) → TextureD
See RaylibCoreFlatModule.LoadTextureFromImage.
LoadUTF8(MemoryPointer<RInt> codepoints, int length) → MemoryPointer<RChar>
See RaylibCoreFlatModule.LoadUTF8.
LoadVrStereoConfig(VrDeviceInfoD device) → VrStereoConfigD
See RaylibCoreFlatModule.LoadVrStereoConfig.
MakeDirectory(MemoryPointer<RChar> dirPath) → int
See RaylibCoreFlatModule.MakeDirectory.
MaximizeWindow() → void
See RaylibCoreFlatModule.MaximizeWindow.
MeasureText(MemoryPointer<RChar> text, int fontSize) → int
See RaylibCoreFlatModule.MeasureText.
MeasureTextCodepoints(FontD font, MemoryPointer<RInt> codepoints, int length, double fontSize, double spacing) → Vector2D
See RaylibCoreFlatModule.MeasureTextCodepoints.
MeasureTextEx(FontD font, MemoryPointer<RChar> text, double fontSize, double spacing) → Vector2D
See RaylibCoreFlatModule.MeasureTextEx.
MinimizeWindow() → void
See RaylibCoreFlatModule.MinimizeWindow.
OpenURL(MemoryPointer<RChar> url) → void
See RaylibCoreFlatModule.OpenURL.
PlayAutomationEvent(AutomationEventD event) → void
See RaylibCoreFlatModule.PlayAutomationEvent.
PollInputEvents() → void
See RaylibCoreFlatModule.PollInputEvents.
ProcessGestureEvent(GestureEventD event) → void
See RaylibCoreFlatModule.ProcessGestureEvent.
RestoreWindow() → void
See RaylibCoreFlatModule.RestoreWindow.
SaveFileData(MemoryPointer<RChar> fileName, MemoryPointer<RVoid> data, int dataSize) → bool
See RaylibCoreFlatModule.SaveFileData.
SaveFileText(MemoryPointer<RChar> fileName, MemoryPointer<RChar> text) → bool
See RaylibCoreFlatModule.SaveFileText.
SetAutomationEventBaseFrame(int frame) → void
See RaylibCoreFlatModule.SetAutomationEventBaseFrame.
SetAutomationEventList(StructPointer<AutomationEventListD> list) → void
See RaylibCoreFlatModule.SetAutomationEventList.
SetClipboardText(MemoryPointer<RChar> text) → void
See RaylibCoreFlatModule.SetClipboardText.
SetConfigFlags(int flags) → void
See RaylibCoreFlatModule.SetConfigFlags.
SetExitKey(int key) → void
See RaylibCoreFlatModule.SetExitKey.
SetGamepadMappings(MemoryPointer<RChar> mappings) → int
See RaylibCoreFlatModule.SetGamepadMappings.
SetGamepadVibration(int gamepad, double leftMotor, double rightMotor, double duration) → void
See RaylibCoreFlatModule.SetGamepadVibration.
SetGesturesEnabled(int flags) → void
See RaylibCoreFlatModule.SetGesturesEnabled.
SetLoadFileDataCallback(MemoryPointer<RFunction<LoadFileDataCallbackBase>> callback) → void
See RaylibCoreFlatModule.SetLoadFileDataCallback.
SetLoadFileTextCallback(MemoryPointer<RFunction<LoadFileTextCallbackBase>> callback) → void
See RaylibCoreFlatModule.SetLoadFileTextCallback.
SetMaterialTexture(StructPointer<MaterialD> material, int mapType, TextureD texture) → void
See RaylibCoreFlatModule.SetMaterialTexture.
SetModelMeshMaterial(StructPointer<ModelD> model, int meshId, int materialId) → void
See RaylibCoreFlatModule.SetModelMeshMaterial.
SetMouseCursor(int cursor) → void
See RaylibCoreFlatModule.SetMouseCursor.
SetMouseOffset(int offsetX, int offsetY) → void
See RaylibCoreFlatModule.SetMouseOffset.
SetMousePosition(int x, int y) → void
See RaylibCoreFlatModule.SetMousePosition.
SetMouseScale(double scaleX, double scaleY) → void
See RaylibCoreFlatModule.SetMouseScale.
SetPixelColor(MemoryPointer<RVoid> dstPtr, ColorD color, int format) → void
See RaylibCoreFlatModule.SetPixelColor.
SetRandomSeed(int seed) → void
See RaylibCoreFlatModule.SetRandomSeed.
SetSaveFileDataCallback(MemoryPointer<RFunction<SaveFileDataCallbackBase>> callback) → void
See RaylibCoreFlatModule.SetSaveFileDataCallback.
SetSaveFileTextCallback(MemoryPointer<RFunction<SaveFileTextCallbackBase>> callback) → void
See RaylibCoreFlatModule.SetSaveFileTextCallback.
SetShaderValueMatrix(ShaderD shader, int locIndex, MatrixD mat) → void
See RaylibCoreFlatModule.SetShaderValueMatrix.
SetShaderValueTexture(ShaderD shader, int locIndex, TextureD texture) → void
See RaylibCoreFlatModule.SetShaderValueTexture.
SetShaderValueV(ShaderD shader, int locIndex, MemoryPointer<RVoid> value, int uniformType, int count) → void
See RaylibCoreFlatModule.SetShaderValueV.
SetShapesTexture(TextureD texture, RectangleD source) → void
See RaylibCoreFlatModule.SetShapesTexture.
SetTargetFPS(int fps) → void
See RaylibCoreFlatModule.SetTargetFPS.
SetTextLineSpacing(int spacing) → void
See RaylibCoreFlatModule.SetTextLineSpacing.
SetTextureFilter(TextureD texture, int filter) → void
See RaylibCoreFlatModule.SetTextureFilter.
SetTextureWrap(TextureD texture, int wrap) → void
See RaylibCoreFlatModule.SetTextureWrap.
SetTraceLogCallback(MemoryPointer<RFunction<TraceLogCallbackBase>> callback) → void
See RaylibCoreFlatModule.SetTraceLogCallback.
SetTraceLogLevel(int logLevel) → void
See RaylibCoreFlatModule.SetTraceLogLevel.
SetWindowFocused() → void
See RaylibCoreFlatModule.SetWindowFocused.
SetWindowIcon(ImageD image) → void
See RaylibCoreFlatModule.SetWindowIcon.
SetWindowIcons(StructPointer<ImageD> images, int count) → void
See RaylibCoreFlatModule.SetWindowIcons.
SetWindowMaxSize(int width, int height) → void
See RaylibCoreFlatModule.SetWindowMaxSize.
SetWindowMinSize(int width, int height) → void
See RaylibCoreFlatModule.SetWindowMinSize.
SetWindowMonitor(int monitor) → void
See RaylibCoreFlatModule.SetWindowMonitor.
SetWindowOpacity(double opacity) → void
See RaylibCoreFlatModule.SetWindowOpacity.
SetWindowPosition(int x, int y) → void
See RaylibCoreFlatModule.SetWindowPosition.
SetWindowSize(int width, int height) → void
See RaylibCoreFlatModule.SetWindowSize.
SetWindowState(int flags) → void
See RaylibCoreFlatModule.SetWindowState.
SetWindowTitle(MemoryPointer<RChar> title) → void
See RaylibCoreFlatModule.SetWindowTitle.
ShowCursor() → void
See RaylibCoreFlatModule.ShowCursor.
StartAutomationEventRecording() → void
See RaylibCoreFlatModule.StartAutomationEventRecording.
StopAutomationEventRecording() → void
See RaylibCoreFlatModule.StopAutomationEventRecording.
SwapScreenBuffer() → void
See RaylibCoreFlatModule.SwapScreenBuffer.
TakeScreenshot(MemoryPointer<RChar> fileName) → void
See RaylibCoreFlatModule.TakeScreenshot.
TextAppend(MemoryPointer<RChar> text, MemoryPointer<RChar> append, MemoryPointer<RInt> position) → void
See RaylibCoreFlatModule.TextAppend.
TextCopy(MemoryPointer<RChar> dst, MemoryPointer<RChar> src) → int
See RaylibCoreFlatModule.TextCopy.
TextFindIndex(MemoryPointer<RChar> text, MemoryPointer<RChar> find) → int
See RaylibCoreFlatModule.TextFindIndex.
TextFormat(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextFormat.
TextInsert(MemoryPointer<RChar> text, MemoryPointer<RChar> insert, int position) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextInsert.
TextInsertAlloc(MemoryPointer<RChar> text, MemoryPointer<RChar> insert, int position) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextInsertAlloc.
TextIsEqual(MemoryPointer<RChar> text1, MemoryPointer<RChar> text2) → bool
See RaylibCoreFlatModule.TextIsEqual.
TextJoin(MemoryPointer<RPointer<RChar>> textList, int count, MemoryPointer<RChar> delimiter) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextJoin.
TextLength(MemoryPointer<RChar> text) → int
See RaylibCoreFlatModule.TextLength.
TextRemoveSpaces(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextRemoveSpaces.
TextReplace(MemoryPointer<RChar> text, MemoryPointer<RChar> replace, MemoryPointer<RChar> by) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextReplace.
TextReplaceAlloc(MemoryPointer<RChar> text, MemoryPointer<RChar> replace, MemoryPointer<RChar> by) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextReplaceAlloc.
TextReplaceBetween(MemoryPointer<RChar> text, MemoryPointer<RChar> begin, MemoryPointer<RChar> end, MemoryPointer<RChar> replacement) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextReplaceBetween.
TextReplaceBetweenAlloc(MemoryPointer<RChar> text, MemoryPointer<RChar> begin, MemoryPointer<RChar> end, MemoryPointer<RChar> replacement) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextReplaceBetweenAlloc.
TextSplit(MemoryPointer<RChar> text, int delimiter, MemoryPointer<RInt> count) → MemoryPointer<RPointer<RChar>>
See RaylibCoreFlatModule.TextSplit.
TextSubtext(MemoryPointer<RChar> text, int position, int length) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextSubtext.
TextToCamel(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextToCamel.
TextToFloat(MemoryPointer<RChar> text) → double
See RaylibCoreFlatModule.TextToFloat.
TextToInteger(MemoryPointer<RChar> text) → int
See RaylibCoreFlatModule.TextToInteger.
TextToLower(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextToLower.
TextToPascal(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextToPascal.
TextToSnake(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextToSnake.
TextToUpper(MemoryPointer<RChar> text) → MemoryPointer<RChar>
See RaylibCoreFlatModule.TextToUpper.
ToggleBorderlessWindowed() → void
See RaylibCoreFlatModule.ToggleBorderlessWindowed.
ToggleFullscreen() → void
See RaylibCoreFlatModule.ToggleFullscreen.
TraceLog(int logLevel, MemoryPointer<RChar> text) → void
See RaylibCoreFlatModule.TraceLog.
UnloadAutomationEventList(AutomationEventListD list) → void
See RaylibCoreFlatModule.UnloadAutomationEventList.
UnloadCodepoints(MemoryPointer<RInt> codepoints) → void
See RaylibCoreFlatModule.UnloadCodepoints.
UnloadDirectoryFiles(FilePathListD files) → void
See RaylibCoreFlatModule.UnloadDirectoryFiles.
UnloadDroppedFiles(FilePathListD files) → void
See RaylibCoreFlatModule.UnloadDroppedFiles.
UnloadFileData(MemoryPointer<RUnsignedChar> data) → void
See RaylibCoreFlatModule.UnloadFileData.
UnloadFileText(MemoryPointer<RChar> text) → void
See RaylibCoreFlatModule.UnloadFileText.
UnloadFont(FontD font) → void
See RaylibCoreFlatModule.UnloadFont.
UnloadFontData(StructPointer<GlyphInfoD> glyphs, int glyphCount) → void
See RaylibCoreFlatModule.UnloadFontData.
UnloadImage(ImageD image) → void
See RaylibCoreFlatModule.UnloadImage.
UnloadImageColors(StructPointer<ColorD> colors) → void
See RaylibCoreFlatModule.UnloadImageColors.
UnloadImagePalette(StructPointer<ColorD> colors) → void
See RaylibCoreFlatModule.UnloadImagePalette.
UnloadMaterial(MaterialD material) → void
See RaylibCoreFlatModule.UnloadMaterial.
UnloadMesh(MeshD mesh) → void
See RaylibCoreFlatModule.UnloadMesh.
UnloadModel(ModelD model) → void
See RaylibCoreFlatModule.UnloadModel.
UnloadModelAnimations(StructPointer<ModelAnimationD> animations, int animCount) → void
See RaylibCoreFlatModule.UnloadModelAnimations.
UnloadRandomSequence(MemoryPointer<RInt> sequence) → void
See RaylibCoreFlatModule.UnloadRandomSequence.
UnloadRenderTexture(RenderTextureD target) → void
See RaylibCoreFlatModule.UnloadRenderTexture.
UnloadShader(ShaderD shader) → void
See RaylibCoreFlatModule.UnloadShader.
UnloadTextLines(MemoryPointer<RPointer<RChar>> text, int lineCount) → void
See RaylibCoreFlatModule.UnloadTextLines.
UnloadTexture(TextureD texture) → void
See RaylibCoreFlatModule.UnloadTexture.
UnloadUTF8(MemoryPointer<RChar> text) → void
See RaylibCoreFlatModule.UnloadUTF8.
UnloadVrStereoConfig(VrStereoConfigD config) → void
See RaylibCoreFlatModule.UnloadVrStereoConfig.
UpdateCamera(StructPointer<Camera3DD> camera, int mode) → void
See RaylibCoreFlatModule.UpdateCamera.
UpdateCameraPro(StructPointer<Camera3DD> camera, Vector3D movement, Vector3D rotation, double zoom) → void
See RaylibCoreFlatModule.UpdateCameraPro.
UpdateGestures() → void
See RaylibCoreFlatModule.UpdateGestures.
UpdateMeshBuffer(MeshD mesh, int index, MemoryPointer<RVoid> data, int dataSize, int offset) → void
See RaylibCoreFlatModule.UpdateMeshBuffer.
UpdateModelAnimation(ModelD model, ModelAnimationD anim, double frame) → void
See RaylibCoreFlatModule.UpdateModelAnimation.
UpdateModelAnimationEx(ModelD model, ModelAnimationD animA, double frameA, ModelAnimationD animB, double frameB, double blend) → void
See RaylibCoreFlatModule.UpdateModelAnimationEx.
UpdateTexture(TextureD texture, MemoryPointer<RVoid> pixels) → void
See RaylibCoreFlatModule.UpdateTexture.
UpdateTextureRec(TextureD texture, RectangleD rec, MemoryPointer<RVoid> pixels) → void
See RaylibCoreFlatModule.UpdateTextureRec.
UploadMesh(StructPointer<MeshD> mesh, bool dynamic) → void
See RaylibCoreFlatModule.UploadMesh.
WaitTime(double seconds) → void
See RaylibCoreFlatModule.WaitTime.
WindowShouldClose() → bool
See RaylibCoreFlatModule.WindowShouldClose.