ArrayCodec<E, R extends RType> class

Inheritance
Mixed-in types

Constructors

ArrayCodec(RArray<R> type, ContiguousCodec<E, R> inner, int count)
const

Properties

count → int
final
hashCode → int
The hash code for this object.
no setterinherited
inner → ContiguousCodec<E, R>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RArray<R>
finalinherited

Methods

allocate(RaylibTemp<RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void
override
allocator(RaylibTemp<RaylibBase> temp) → RaylibTempAllocator<RType>?
override
elementPtr(MemoryPointer<RType> fieldPtr, int index) → MemoryPointer<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(MemoryPointer<RType> p) → List<E>
override
readArray(MemoryPointer<RType> p, int count) → List<List<E>>
override
readAt(MemoryPointer<RType> fieldPtr, int index) → E
toString() → String
A string representation of this object.
inherited
write(MemoryPointer<RType> p, List<E> values) → void
override
writeArray(MemoryPointer<RType> p, List<List<E>> values) → void
override
writeAt(MemoryPointer<RType> fieldPtr, int index, E value) → E

Operators

operator ==(Object other) → bool
The equality operator.
inherited