BlendMode enum

BlendMode

Inheritance
Mixed-in types
Available extensions

Values

BLEND_ALPHA → const BlendMode

BLEND_ALPHA

const BlendMode(0)
BLEND_ADDITIVE → const BlendMode

BLEND_ADDITIVE

const BlendMode(1)
BLEND_MULTIPLIED → const BlendMode

BLEND_MULTIPLIED

const BlendMode(2)
BLEND_ADD_COLORS → const BlendMode

BLEND_ADD_COLORS

const BlendMode(3)
BLEND_SUBTRACT_COLORS → const BlendMode

BLEND_SUBTRACT_COLORS

const BlendMode(4)
BLEND_ALPHA_PREMULTIPLY → const BlendMode

BLEND_ALPHA_PREMULTIPLY

const BlendMode(5)
BLEND_CUSTOM → const BlendMode

BLEND_CUSTOM

const BlendMode(6)
BLEND_CUSTOM_SEPARATE → const BlendMode

BLEND_CUSTOM_SEPARATE

const BlendMode(7)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → BlendMode
Returns the BlendMode for the given native value.

Constants

values → const List<BlendMode>
A constant List of the values in this enum, in order of their declaration.