struct property

StructType<Camera2DD> struct
final

Describes the raw memory layout, construction, and pointer representation of this struct type.

Implementation

static final StructType<Camera2DD> struct = .new(
  factory: Camera2DD.new,
  layout: .aligned<Camera2DField>({
    .offset:   RStruct(Vector2D.struct), // Camera offset (screen space offset from window origin)
    .target:   RStruct(Vector2D.struct), // Camera target (world space target point that is mapped to screen space offset)
    .rotation: RFloat(), // Camera rotation in degrees (pivots around target)
    .zoom:     RFloat(), // Camera zoom (scaling around target), must not be set to 0, set to 1.0f for no scale
  }),
);