struct property

StructType<Camera3DD> struct
final

Describes the raw memory layout, construction, and pointer representation of this struct type.

Implementation

static final StructType<Camera3DD> struct = .new(
  factory: Camera3DD.new,
  layout: .aligned<Camera3DField>({
    .position:   RStruct(Vector3D.struct), // Camera position
    .target:     RStruct(Vector3D.struct), // Camera target it looks-at
    .up:         RStruct(Vector3D.struct), // Camera up vector (rotation over its axis)
    .fovy:       RFloat(), // Camera field-of-view aperture in Y (degrees) in perspective, used as near plane height in world units in orthographic
    .projection: RInt(), // Camera projection: CAMERA_PERSPECTIVE or CAMERA_ORTHOGRAPHIC
  }),
);