CameraMode enum

CameraMode

Inheritance
Mixed-in types
Available extensions

Values

CAMERA_CUSTOM → const CameraMode

CAMERA_CUSTOM

const CameraMode(0)
CAMERA_FREE → const CameraMode

CAMERA_FREE

const CameraMode(1)
CAMERA_ORBITAL → const CameraMode

CAMERA_ORBITAL

const CameraMode(2)
CAMERA_FIRST_PERSON → const CameraMode

CAMERA_FIRST_PERSON

const CameraMode(3)
CAMERA_THIRD_PERSON → const CameraMode

CAMERA_THIRD_PERSON

const CameraMode(4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → CameraMode
Returns the CameraMode for the given native value.

Constants

values → const List<CameraMode>
A constant List of the values in this enum, in order of their declaration.