ElementCodec<E, R extends RType> class abstract

A codec for a single value of type E, stored at an R-typed region of memory (the field's own on-struct type, for a pointer field this is RPointer<Pointee>, not Pointee).

Implementers

Constructors

ElementCodec(R type)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → R
final

Methods

allocate(RaylibTemp<RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void
allocator(RaylibTemp<RaylibBase> temp) → RaylibTempAllocator<RType>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(MemoryPointer<RType> p) → E
toString() → String
A string representation of this object.
inherited
write(MemoryPointer<RType> p, E value) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited