GamepadButton enum
Raylib GamepadButton enum.
Values
- GAMEPAD_BUTTON_UNKNOWN → const GamepadButton
-
GAMEPAD_BUTTON_UNKNOWNconst GamepadButton(0) - GAMEPAD_BUTTON_LEFT_FACE_UP → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_FACE_UPconst GamepadButton(1) - GAMEPAD_BUTTON_LEFT_FACE_RIGHT → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_FACE_RIGHTconst GamepadButton(2) - GAMEPAD_BUTTON_LEFT_FACE_DOWN → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_FACE_DOWNconst GamepadButton(3) - GAMEPAD_BUTTON_LEFT_FACE_LEFT → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_FACE_LEFTconst GamepadButton(4) - GAMEPAD_BUTTON_RIGHT_FACE_UP → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_FACE_UPconst GamepadButton(5) - GAMEPAD_BUTTON_RIGHT_FACE_RIGHT → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_FACE_RIGHTconst GamepadButton(6) - GAMEPAD_BUTTON_RIGHT_FACE_DOWN → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_FACE_DOWNconst GamepadButton(7) - GAMEPAD_BUTTON_RIGHT_FACE_LEFT → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_FACE_LEFTconst GamepadButton(8) - GAMEPAD_BUTTON_LEFT_TRIGGER_1 → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_TRIGGER_1const GamepadButton(9) - GAMEPAD_BUTTON_LEFT_TRIGGER_2 → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_TRIGGER_2const GamepadButton(10) - GAMEPAD_BUTTON_RIGHT_TRIGGER_1 → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_TRIGGER_1const GamepadButton(11) - GAMEPAD_BUTTON_RIGHT_TRIGGER_2 → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_TRIGGER_2const GamepadButton(12) - GAMEPAD_BUTTON_MIDDLE_LEFT → const GamepadButton
-
GAMEPAD_BUTTON_MIDDLE_LEFTconst GamepadButton(13) - GAMEPAD_BUTTON_MIDDLE → const GamepadButton
-
GAMEPAD_BUTTON_MIDDLEconst GamepadButton(14) - GAMEPAD_BUTTON_MIDDLE_RIGHT → const GamepadButton
-
GAMEPAD_BUTTON_MIDDLE_RIGHTconst GamepadButton(15) - GAMEPAD_BUTTON_LEFT_THUMB → const GamepadButton
-
GAMEPAD_BUTTON_LEFT_THUMBconst GamepadButton(16) - GAMEPAD_BUTTON_RIGHT_THUMB → const GamepadButton
-
GAMEPAD_BUTTON_RIGHT_THUMBconst GamepadButton(17)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GamepadButton -
Returns the GamepadButton for the given native
value.
Constants
-
values
→ const List<
GamepadButton> - A constant List of the values in this enum, in order of their declaration.