Gesture enum

Raylib Gesture enum.

Inheritance
Mixed-in types
Available extensions

Values

GESTURE_NONE → const Gesture

GESTURE_NONE

const Gesture(0)
GESTURE_TAP → const Gesture

GESTURE_TAP

const Gesture(1)
GESTURE_DOUBLETAP → const Gesture

GESTURE_DOUBLETAP

const Gesture(2)
GESTURE_HOLD → const Gesture

GESTURE_HOLD

const Gesture(4)
GESTURE_DRAG → const Gesture

GESTURE_DRAG

const Gesture(8)
GESTURE_SWIPE_RIGHT → const Gesture

GESTURE_SWIPE_RIGHT

const Gesture(16)
GESTURE_SWIPE_LEFT → const Gesture

GESTURE_SWIPE_LEFT

const Gesture(32)
GESTURE_SWIPE_UP → const Gesture

GESTURE_SWIPE_UP

const Gesture(64)
GESTURE_SWIPE_DOWN → const Gesture

GESTURE_SWIPE_DOWN

const Gesture(128)
GESTURE_PINCH_IN → const Gesture

GESTURE_PINCH_IN

const Gesture(256)
GESTURE_PINCH_OUT → const Gesture

GESTURE_PINCH_OUT

const Gesture(512)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) bool
inherited
operator <=(RaylibEnum other) bool
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(RaylibEnum other) bool
inherited
operator >=(RaylibEnum other) bool
inherited

Static Methods

fromValue(int value) Gesture
Returns the Gesture for the given native value.

Constants

values → const List<Gesture>
A constant List of the values in this enum, in order of their declaration.