GuiComboBoxProperty enum

raygui GuiComboBoxProperty enum.

Inheritance
Mixed-in types
Available extensions

Values

COMBO_BUTTON_WIDTH → const GuiComboBoxProperty

COMBO_BUTTON_WIDTH

const GuiComboBoxProperty(16)
COMBO_BUTTON_SPACING → const GuiComboBoxProperty

COMBO_BUTTON_SPACING

const GuiComboBoxProperty(17)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiComboBoxProperty
Returns the GuiComboBoxProperty for the given native value.

Constants

values → const List<GuiComboBoxProperty>
A constant List of the values in this enum, in order of their declaration.