GuiResult class sealed

GuiResult

Gui control result

Implementers

Constructors

GuiResult.custom(int value)
Returns the custom GuiResult for the given native value.
factory
GuiResult.fromValue(int value)
Returns the GuiResult for the given native value.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The underlying name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(GuiResult other) → bool
operator <=(GuiResult other) → bool
operator ==(Object other) → bool
The equality operator.
inherited
operator >(GuiResult other) → bool
operator >=(GuiResult other) → bool

Constants

RESULT_CHANGED → const _GuiResultConst
RESULT_CHANGED
RESULT_NONE → const _GuiResultConst
RESULT_NONE
RESULT_PRESSED → const _GuiResultConst
RESULT_PRESSED
RESULT_TAB_CLOSE → const _GuiResultConst
RESULT_TAB_CLOSE