GuiResultCustom class

Inheritance

Constructors

GuiResultCustom(int value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The underlying name.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(GuiResult other) → bool
inherited
operator <=(GuiResult other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(GuiResult other) → bool
inherited
operator >=(GuiResult other) → bool
inherited