GuiTextAlignmentVertical enum

GuiTextAlignmentVertical

Gui control text alignment vertical

Inheritance
Mixed-in types
Available extensions

Values

TEXT_ALIGN_TOP → const GuiTextAlignmentVertical

TEXT_ALIGN_TOP

const GuiTextAlignmentVertical(0)
TEXT_ALIGN_MIDDLE → const GuiTextAlignmentVertical

TEXT_ALIGN_MIDDLE

const GuiTextAlignmentVertical(1)
TEXT_ALIGN_BOTTOM → const GuiTextAlignmentVertical

TEXT_ALIGN_BOTTOM

const GuiTextAlignmentVertical(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → GuiTextAlignmentVertical
Returns the GuiTextAlignmentVertical for the given native value.

Constants

values → const List<GuiTextAlignmentVertical>
A constant List of the values in this enum, in order of their declaration.