GuiTextWrapMode enum

raygui GuiTextWrapMode enum.

Inheritance
Available extensions

Values

TEXT_WRAP_NONE → const GuiTextWrapMode

TEXT_WRAP_NONE

const GuiTextWrapMode(0)
TEXT_WRAP_CHAR → const GuiTextWrapMode

TEXT_WRAP_CHAR

const GuiTextWrapMode(1)
TEXT_WRAP_WORD → const GuiTextWrapMode

TEXT_WRAP_WORD

const GuiTextWrapMode(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiTextWrapMode
Returns the GuiTextWrapMode for the given native value.

Constants

values → const List<GuiTextWrapMode>
A constant List of the values in this enum, in order of their declaration.