structUpdateFrameCount abstract method

void structUpdateFrameCount(
  1. int frameCount
)

Updates frameCount and resynchronizes frame-dependent memory state.

This must be used when native decoders determine the frame count after allocation/loading (for example animated GIF decoding), because changing frameCount affects derived memory layout such as dataLength.

This is separate from directly assigning frameCount because platform implementations may need to refresh internal views or buffers after the frame count changes.

Implementation

void structUpdateFrameCount(int frameCount);