frameCount property
Number of frames in the image.
Always 1 for static images. Greater than 1 for animated formats such as GIF.
Setting this value also updates the data according to dataLength.
Implementation
int frameCount = 1;
Number of frames in the image.
Always 1 for static images. Greater than 1 for animated formats such as GIF.
Setting this value also updates the data according to dataLength.
int frameCount = 1;