LivePointerSync<R extends RType> class

Constructors

LivePointerSync.pointerSync(MemoryPointer<RType>? ptrOf(), StructPointerValueField<dynamic, R> field)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

derefPtr<Y extends RType>() → MemoryPointer<Y>
fieldPtr() → MemoryPointer<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncFrom(MemoryPointer<RType> p, {bool borrow = true}) → void
syncInto(MemoryPointer<RType> p) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited