copy abstract method
X
copy()
inherited
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
Implementation
T copy();
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
T copy();