clone abstract method
M
clone()
inherited
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
Implementation
T clone();
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
T clone();