MeshBase<X extends MeshBase<X, M, V3, Q, V4> , M extends MatrixBase<M, V3, Q, V4> , V3 extends Vector3Base<V3, M, Q, V4> , Q extends QuaternionBase<Q, M, V3, V4> , V4 extends Vector4Base<V4, Q, M, V3> > mixin
Backend-agnostic contract for MeshBase structs.
Must be mixed into every concrete platform implementation of a Raylib type to ensure a unified API surface across different backends.
- Superclass constraints
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
animNormals
↔ RaylibLiveList<
double> -
getter/setter pair
- animNormalsCount → int
-
no setter
-
animVertices
↔ RaylibLiveList<
double> -
getter/setter pair
- animVerticesCount → int
-
no setter
- boneCount ↔ int
-
getter/setter pair
-
boneIds
↔ RaylibLiveList<
int> -
getter/setter pair
- boneIdsCount → int
-
no setter
-
boneMatrices
↔ RaylibLiveList<
M> -
getter/setter pair
- boneMatricesCount → int
-
no setter
-
boneWeights
↔ RaylibLiveList<
double> -
getter/setter pair
- boneWeightsCount → int
-
no setter
-
colors
↔ RaylibLiveList<
int> -
getter/setter pair
- colorsCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ RaylibLiveList<
int> -
getter/setter pair
- indicesCount → int
-
no setter
-
normals
↔ RaylibLiveList<
double> -
getter/setter pair
- normalsCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
-
tangents
↔ RaylibLiveList<
double> -
getter/setter pair
- tangentsCount → int
-
no setter
-
texcoords
↔ RaylibLiveList<
double> -
getter/setter pair
-
texcoords2
↔ RaylibLiveList<
double> -
getter/setter pair
- texcoords2Count → int
-
no setter
- texcoordsCount → int
-
no setter
- triangleCount ↔ int
-
getter/setter pair
- vaoId ↔ int
-
getter/setter pair
-
vboId
↔ RaylibLiveList<
int> -
getter/setter pair
- vboIdCount → int
-
no setter
- vertexCount ↔ int
-
getter/setter pair
-
vertices
↔ RaylibLiveList<
double> -
getter/setter pair
- verticesCount → int
-
no setter
Methods
-
clone(
) → X -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
inherited
-
copy(
) → X -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setD(
X o) → X -
Copies the fields of
ointo this instance and returnsthis.inherited -
signature(
) → String -
Returns a human-readable representation of this struct's current field values.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_vboIdCount → int
-
no setter
Static Methods
-
BASE_animNormalsCount(
int vertexCount) → int -
BASE_animVerticesCount(
int vertexCount) → int -
BASE_boneIdsCount(
int vertexCount) → int -
BASE_boneMatricesCount(
int boneCount) → int -
BASE_boneWeightsCount(
int vertexCount) → int -
BASE_colorsCount(
int vertexCount) → int -
BASE_indicesCount(
int triangleCount) → int -
BASE_normalsCount(
int vertexCount) → int -
BASE_tangentsCount(
int vertexCount) → int -
BASE_texcoords2Count(
int vertexCount) → int -
BASE_texcoordsCount(
int vertexCount) → int -
BASE_verticesCount(
int vertexCount) → int