nameLength property

int get nameLength

Compile-time ABI constant describing the capacity of the native name buffer.

This is not related to the Dart String length of name.

Exists only for memory layout / FFI compatibility.

Implementation

int get nameLength => BASE_nameLength;