ModelBase<X extends ModelBase<X, MeshType, MatrixType, V3, Q, V4, MaterialType, ShaderType, MaterialMapType, TextureType, ColorType, TransformType, BoneInfoType>, MeshType extends MeshBase<MeshType, MatrixType, V3, Q, V4>, MatrixType extends MatrixBase<MatrixType, V3, Q, V4>, V3 extends Vector3Base<V3, MatrixType, Q, V4>, Q extends QuaternionBase<Q, MatrixType, V3, V4>, V4 extends Vector4Base<V4, Q, MatrixType, V3>, MaterialType extends MaterialBase<MaterialType, ShaderType, MaterialMapType, TextureType, ColorType>, ShaderType extends ShaderBase<ShaderType>, MaterialMapType extends MaterialMapBase<MaterialMapType, TextureType, ColorType>, TextureType extends TextureBase<TextureType>, ColorType extends ColorBase<ColorType>, TransformType extends TransformBase<TransformType, V3, MatrixType, Q, V4>, BoneInfoType extends BoneInfoBase<BoneInfoType>> mixin

Backend-agnostic contract for ModelBase structs.

Must be mixed into every concrete platform implementation of a Raylib type to ensure a unified API surface across different backends.

Superclass constraints

Properties

$state RaylibTempStructState
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
bindPose RaylibLiveList<TransformType>
getter/setter pair
boneCount int
no setter
bones RaylibLiveList<BoneInfoType>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
materialCount int
no setter
materials RaylibLiveList<MaterialType>
getter/setter pair
meshCount int
no setter
meshes RaylibLiveList<MeshType>
getter/setter pair
meshMaterial RaylibLiveList<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
The Dart-side type name of this struct
no setterinherited
transform ↔ MatrixType
getter/setter pair

Methods

clone() → X
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
inherited
copy() → X
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setD(X o) → X
Copies the fields of o into this instance and returns this.
inherited
signature() String
Returns a human-readable representation of this struct's current field values.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited