MouseButton enum

MouseButton

Inheritance
Mixed-in types
Available extensions

Values

MOUSE_BUTTON_LEFT → const MouseButton

MOUSE_BUTTON_LEFT

const MouseButton(0)
MOUSE_BUTTON_RIGHT → const MouseButton

MOUSE_BUTTON_RIGHT

const MouseButton(1)
MOUSE_BUTTON_MIDDLE → const MouseButton

MOUSE_BUTTON_MIDDLE

const MouseButton(2)
MOUSE_BUTTON_SIDE → const MouseButton

MOUSE_BUTTON_SIDE

const MouseButton(3)
MOUSE_BUTTON_EXTRA → const MouseButton

MOUSE_BUTTON_EXTRA

const MouseButton(4)
MOUSE_BUTTON_FORWARD → const MouseButton

MOUSE_BUTTON_FORWARD

const MouseButton(5)
MOUSE_BUTTON_BACK → const MouseButton

MOUSE_BUTTON_BACK

const MouseButton(6)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → MouseButton
Returns the MouseButton for the given native value.

Constants

values → const List<MouseButton>
A constant List of the values in this enum, in order of their declaration.