MouseCursor enum

Raylib MouseCursor enum.

Inheritance
Available extensions

Values

MOUSE_CURSOR_DEFAULT → const MouseCursor

MOUSE_CURSOR_DEFAULT

const MouseCursor(0)
MOUSE_CURSOR_ARROW → const MouseCursor

MOUSE_CURSOR_ARROW

const MouseCursor(1)
MOUSE_CURSOR_IBEAM → const MouseCursor

MOUSE_CURSOR_IBEAM

const MouseCursor(2)
MOUSE_CURSOR_CROSSHAIR → const MouseCursor

MOUSE_CURSOR_CROSSHAIR

const MouseCursor(3)
MOUSE_CURSOR_POINTING_HAND → const MouseCursor

MOUSE_CURSOR_POINTING_HAND

const MouseCursor(4)
MOUSE_CURSOR_RESIZE_EW → const MouseCursor

MOUSE_CURSOR_RESIZE_EW

const MouseCursor(5)
MOUSE_CURSOR_RESIZE_NS → const MouseCursor

MOUSE_CURSOR_RESIZE_NS

const MouseCursor(6)
MOUSE_CURSOR_RESIZE_NWSE → const MouseCursor

MOUSE_CURSOR_RESIZE_NWSE

const MouseCursor(7)
MOUSE_CURSOR_RESIZE_NESW → const MouseCursor

MOUSE_CURSOR_RESIZE_NESW

const MouseCursor(8)
MOUSE_CURSOR_RESIZE_ALL → const MouseCursor

MOUSE_CURSOR_RESIZE_ALL

const MouseCursor(9)
MOUSE_CURSOR_NOT_ALLOWED → const MouseCursor

MOUSE_CURSOR_NOT_ALLOWED

const MouseCursor(10)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) MouseCursor
Returns the MouseCursor for the given native value.

Constants

values → const List<MouseCursor>
A constant List of the values in this enum, in order of their declaration.