clone method
Returns a deep copy of this instance, preserving op if present.
Implementation
@override
NPatchInfoD clone() => .new(
op: op,
source: source.clone(),
left: left,
top: top,
right: right,
bottom: bottom,
layout: layout,
);
Returns a deep copy of this instance, preserving op if present.
@override
NPatchInfoD clone() => .new(
op: op,
source: source.clone(),
left: left,
top: top,
right: right,
bottom: bottom,
layout: layout,
);