NPatchLayout enum

Raylib NPatchLayout enum.

Inheritance
Available extensions

Values

NPATCH_NINE_PATCH → const NPatchLayout

NPATCH_NINE_PATCH

const NPatchLayout(0)
NPATCH_THREE_PATCH_VERTICAL → const NPatchLayout

NPATCH_THREE_PATCH_VERTICAL

const NPatchLayout(1)
NPATCH_THREE_PATCH_HORIZONTAL → const NPatchLayout

NPATCH_THREE_PATCH_HORIZONTAL

const NPatchLayout(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) NPatchLayout
Returns the NPatchLayout for the given native value.

Constants

values → const List<NPatchLayout>
A constant List of the values in this enum, in order of their declaration.