max method
Returns a new quaternion with each component being the component-wise maximum of this and o.
Implementation
QuaternionD max(QuaternionD o) => .quat(
math.max(x, o.x),
math.max(y, o.y),
math.max(z, o.z),
math.max(w, o.w),
);
Returns a new quaternion with each component being the component-wise maximum of this and o.
QuaternionD max(QuaternionD o) => .quat(
math.max(x, o.x),
math.max(y, o.y),
math.max(z, o.z),
math.max(w, o.w),
);