LoadSoundAlias method

SoundD LoadSoundAlias(
  1. SoundD source
)

Create a new sound that shares the same sample data as the source sound, does not own the sound data

Implementation

SoundD LoadSoundAlias(
  SoundD source,
) => run(
  () => _debugLabels.LoadSoundAlias(source),
  () => _flat.LoadSoundAlias(
    source,
  ),
);