LoadSoundAlias abstract method

SoundStructType LoadSoundAlias(
  1. SoundStructType source
)

Create a new sound that shares the same sample data as the source sound, does not own the sound data

Implementation

SoundStructType LoadSoundAlias(
  SoundStructType source,
);