GetCameraProjectionMatrix abstract method
Returns the projection matrix for camera with the given aspect ratio.
Implementation
MatrixD GetCameraProjectionMatrix(
StructPointer<Camera3DD> camera,
double aspect,
);
Returns the projection matrix for camera with the given aspect ratio.
MatrixD GetCameraProjectionMatrix(
StructPointer<Camera3DD> camera,
double aspect,
);