GetCameraUp abstract method
Returns the up vector (normalized) of camera.
The up vector might not be perpendicular to the forward vector.
Implementation
Vector3D GetCameraUp(
StructPointer<Camera3DD> camera,
);
Returns the up vector (normalized) of camera.
The up vector might not be perpendicular to the forward vector.
Vector3D GetCameraUp(
StructPointer<Camera3DD> camera,
);