CameraMoveRight abstract method

void CameraMoveRight(
  1. Camera3DStructType camera,
  2. num distance,
  3. bool moveInWorldPlane
)

Moves the camera target in its current right direction by distance.

If moveInWorldPlane is true, movement is constrained to the XZ plane regardless of the camera's pitch.

Implementation

void CameraMoveRight(
  Camera3DStructType camera,
  num distance,
  bool moveInWorldPlane,
);