CameraRoll abstract method

void CameraRoll(
  1. Camera3DStructType camera,
  2. num angle
)

Rotates camera around its forward vector by angle radians.

Roll is "turning your head sideways to the left or right"

Implementation

void CameraRoll(
  Camera3DStructType camera,
  num angle,
);