GetCameraProjectionMatrix abstract method
Returns the projection matrix for camera with the given aspect ratio.
Implementation
MatrixStructType GetCameraProjectionMatrix(
Camera3DStructType camera,
num aspect,
);
Returns the projection matrix for camera with the given aspect ratio.
MatrixStructType GetCameraProjectionMatrix(
Camera3DStructType camera,
num aspect,
);