maxTrackedAllocations property

int maxTrackedAllocations
getter/setter pair

Maximum number of simultaneously tracked temporary allocations per temporary allocator.

Defaults to 1024. This acts as a safety limit against accidentally creating an unbounded number of temporary allocation slots.

Increase this before initializing Raylib if a legitimate use case requires more tracked allocations.

Implementation

static int maxTrackedAllocations = 1024;