RaylibConstants class

Dart-side mirror of Raylib's compile-time constants (RAYLIB_VERSION, PI, etc.), kept in the base package so both backends share a single source of truth.

Constructors

RaylibConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

DEG2RAD double
final
EPSILON double
final
M_1_PI double
final
M_2_PI double
final
M_2_SQRTPI double
final
M_E double
final
M_LN10 double
final
M_LN2 double
final
M_LOG10E double
final
M_LOG2E double
final
M_PI double
final
M_PI_2 double
final
M_PI_4 double
final
M_SQRT1_2 double
final
M_SQRT2 double
final
MATERIAL_MAP_DIFFUSE MaterialMapIndex
final
MATERIAL_MAP_SPECULAR MaterialMapIndex
final
MAX_MATERIAL_MAPS int
final
PI double
final
RAD2DEG double
final
RAND_MAX int
final
RAYLIB_VERSION String
final
RAYLIB_VERSION_MAJOR int
final
RAYLIB_VERSION_MINOR int
final
RAYLIB_VERSION_PATCH int
final
SHADER_LOC_MAP_DIFFUSE int
final
SHADER_LOC_MAP_SPECULAR int
final