RaylibCoreModuleBase<R extends RaylibBase, UnsignedCharPointerType, AutomationEventListStructType extends AutomationEventListBase<AutomationEventListStructType, AutomationEventStructType> , AutomationEventStructType extends AutomationEventBase<AutomationEventStructType> , BoneInfoStructType extends BoneInfoBase<BoneInfoStructType> , BoundingBoxStructType extends BoundingBoxBase<BoundingBoxStructType, Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , Camera2DStructType extends Camera2DBase<Camera2DStructType, Vector2StructType, MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType> , Camera3DStructType extends Camera3DBase<Camera3DStructType, Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , ColorStructType extends ColorBase<ColorStructType> , FilePathListStructType extends FilePathListBase<FilePathListStructType> , FontStructType extends FontBase<FontStructType, TextureStructType, RectangleStructType, GlyphInfoStructType, ImageStructType> , GlyphInfoStructType extends GlyphInfoBase<GlyphInfoStructType, ImageStructType> , ImageStructType extends ImageBase<ImageStructType> , MaterialStructType extends MaterialBase<MaterialStructType, ShaderStructType, MaterialMapStructType, TextureStructType, ColorStructType> , MaterialMapStructType extends MaterialMapBase<MaterialMapStructType, TextureStructType, ColorStructType> , MatrixStructType extends MatrixBase<MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType> , MeshStructType extends MeshBase<MeshStructType, MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType> , ModelStructType extends ModelBase<ModelStructType, MeshStructType, MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType, MaterialStructType, ShaderStructType, MaterialMapStructType, TextureStructType, ColorStructType, TransformStructType, BoneInfoStructType> , ModelAnimationStructType extends ModelAnimationBase<ModelAnimationStructType, BoneInfoStructType, TransformStructType, Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , NPatchInfoStructType extends NPatchInfoBase<NPatchInfoStructType, RectangleStructType> , QuaternionStructType extends QuaternionBase<QuaternionStructType, MatrixStructType, Vector3StructType, Vector4StructType> , RayStructType extends RayBase<RayStructType, Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , RayCollisionStructType extends RayCollisionBase<RayCollisionStructType, Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , RectangleStructType extends RectangleBase<RectangleStructType> , RenderTextureStructType extends RenderTextureBase<RenderTextureStructType, TextureStructType> , ShaderStructType extends ShaderBase<ShaderStructType> , TextureStructType extends TextureBase<TextureStructType> , TransformStructType extends TransformBase<TransformStructType, Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , Vector2StructType extends Vector2Base<Vector2StructType, MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType> , Vector3StructType extends Vector3Base<Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType> , Vector4StructType extends Vector4Base<Vector4StructType, QuaternionStructType, MatrixStructType, Vector3StructType> , VrDeviceInfoStructType extends VrDeviceInfoBase<VrDeviceInfoStructType> , VrStereoConfigStructType extends VrStereoConfigBase<VrStereoConfigStructType, MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType> , LoadFileDataCallbackType extends LoadFileDataCallbackBase, SaveFileDataCallbackType extends SaveFileDataCallbackBase, LoadFileTextCallbackType extends LoadFileTextCallbackBase, SaveFileTextCallbackType extends SaveFileTextCallbackBase> class
abstract
Backend-agnostic contract for the Raylib Core module.
Concrete platform implementations mix in or extend this to provide the full Core API surface across different backends.
- Inheritance
-
- Object
- RaylibModule<
R> - RaylibCoreModuleBase
Constructors
- RaylibCoreModuleBase(R rl)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- RaylibCaptureIds → RaylibCoreModuleCaptureIds
-
Capture ID generator for pointer slots allocated by this module.
final
- RaylibDebugLabels → RaylibCoreModuleDebugLabels
-
Debug label generator for this module's function calls.
final
- rl → R
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
BeginBlendMode(
BlendMode mode) → void -
BeginDrawing(
) → void -
BeginMode2D(
Camera2DStructType camera) → void -
BeginMode3D(
Camera3DStructType camera) → void -
BeginScissorMode(
num x, num y, num width, num height) → void -
BeginShaderMode(
ShaderStructType shader) → void -
BeginTextureMode(
RenderTextureStructType target) → void -
BeginVrStereoMode(
VrStereoConfigStructType config) → void -
ChangeDirectory(
String dir) → bool -
CheckCollisionBoxes(
BoundingBoxStructType box1, BoundingBoxStructType box2) → bool -
CheckCollisionBoxSphere(
BoundingBoxStructType box, Vector3StructType center, num radius) → bool -
CheckCollisionCircleLine(
Vector2StructType center, num radius, Vector2StructType p1, Vector2StructType p2) → bool -
CheckCollisionCircleRec(
Vector2StructType center, num radius, RectangleStructType rec) → bool -
CheckCollisionCircles(
Vector2StructType center1, num radius1, Vector2StructType center2, num radius2) → bool -
CheckCollisionLines(
Vector2StructType startPos1, Vector2StructType endPos1, Vector2StructType startPos2, Vector2StructType endPos2) → (bool, Vector2StructType) -
CheckCollisionPointCircle(
Vector2StructType point, Vector2StructType center, num radius) → bool -
CheckCollisionPointLine(
Vector2StructType point, Vector2StructType p1, Vector2StructType p2, num threshold) → bool -
CheckCollisionPointPoly(
Vector2StructType point, List< Vector2StructType> points) → bool -
CheckCollisionPointRec(
Vector2StructType point, RectangleStructType rec) → bool -
CheckCollisionPointTriangle(
Vector2StructType point, Vector2StructType p1, Vector2StructType p2, Vector2StructType p3) → bool -
CheckCollisionRecs(
RectangleStructType rec1, RectangleStructType rec2) → bool -
CheckCollisionSpheres(
Vector3StructType center1, num radius1, Vector3StructType center2, num radius2) → bool -
ClearBackground(
ColorStructType color) → void -
ClearWindowState(
Iterable< ConfigFlags> flags) → void -
CloseWindow(
) → void -
CodepointToUTF8(
num codepoint) → (String, int) -
ColorAlpha(
ColorStructType color, num alpha) → ColorStructType -
ColorAlphaBlend(
ColorStructType dst, ColorStructType src, ColorStructType tint) → ColorStructType -
ColorBrightness(
ColorStructType color, num factor) → ColorStructType -
ColorContrast(
ColorStructType color, num contrast) → ColorStructType -
ColorFromHSV(
num hue, num saturation, num value) → ColorStructType -
ColorFromNormalized(
Vector4StructType normalized) → ColorStructType -
ColorIsEqual(
ColorStructType col1, ColorStructType col2) → bool -
ColorLerp(
ColorStructType color1, ColorStructType color2, num factor) → ColorStructType -
ColorNormalize(
ColorStructType color) → Vector4StructType -
ColorTint(
ColorStructType color, ColorStructType tint) → ColorStructType -
ColorToHSV(
ColorStructType color) → Vector3StructType -
ColorToInt(
ColorStructType color) → int -
CompressData(
Uint8List data) → Uint8List -
ComputeCRC32(
Uint8List data) → int -
ComputeMD5(
Uint8List data) → Uint8List -
ComputeSHA1(
Uint8List data) → Uint8List -
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
DecodeDataBase64(
Uint8List data) → Uint8List -
DecompressData(
Uint8List compData) → Uint8List -
DirectoryExists(
String dirPath) → bool -
DisableCursor(
) → void -
DisableEventWaiting(
) → void -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
doLoad(
) → void -
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
-
DrawBillboard(
Camera3DStructType camera, TextureStructType texture, Vector3StructType position, num scale, ColorStructType tint) → void -
DrawBillboardPro(
Camera3DStructType camera, TextureStructType texture, RectangleStructType source, Vector3StructType position, Vector3StructType up, Vector2StructType size, Vector2StructType origin, num rotation, ColorStructType tint) → void -
DrawBillboardRec(
Camera3DStructType camera, TextureStructType texture, RectangleStructType source, Vector3StructType position, Vector2StructType size, ColorStructType tint) → void -
DrawBoundingBox(
BoundingBoxStructType box, ColorStructType color) → void -
DrawCapsule(
Vector3StructType startPos, Vector3StructType endPos, num radius, num slices, num rings, ColorStructType color) → void -
DrawCapsuleWires(
Vector3StructType startPos, Vector3StructType endPos, num radius, num slices, num rings, ColorStructType color) → void -
DrawCircle(
num centerX, num centerY, num radius, ColorStructType color) → void -
DrawCircle3D(
Vector3StructType center, num radius, Vector3StructType rotationAxis, num rotationAngle, ColorStructType color) → void -
DrawCircleGradient(
num centerX, num centerY, num radius, ColorStructType inner, ColorStructType outer) → void -
DrawCircleLines(
num centerX, num centerY, num radius, ColorStructType color) → void -
DrawCircleLinesV(
Vector2StructType center, num radius, ColorStructType color) → void -
DrawCircleSector(
Vector2StructType center, num radius, num startAngle, num endAngle, num segments, ColorStructType color) → void -
DrawCircleSectorLines(
Vector2StructType center, num radius, num startAngle, num endAngle, num segments, ColorStructType color) → void -
DrawCircleV(
Vector2StructType center, num radius, ColorStructType color) → void -
DrawCube(
Vector3StructType position, num width, num height, num length, ColorStructType color) → void -
DrawCubeV(
Vector3StructType position, Vector3StructType size, ColorStructType color) → void -
DrawCubeWires(
Vector3StructType position, num width, num height, num length, ColorStructType color) → void -
DrawCubeWiresV(
Vector3StructType position, Vector3StructType size, ColorStructType color) → void -
DrawCylinder(
Vector3StructType position, num radiusTop, num radiusBottom, num height, num slices, ColorStructType color) → void -
DrawCylinderEx(
Vector3StructType startPos, Vector3StructType endPos, num startRadius, num endRadius, num sides, ColorStructType color) → void -
DrawCylinderWires(
Vector3StructType position, num radiusTop, num radiusBottom, num height, num slices, ColorStructType color) → void -
DrawCylinderWiresEx(
Vector3StructType startPos, Vector3StructType endPos, num startRadius, num endRadius, num sides, ColorStructType color) → void -
DrawEllipse(
num centerX, num centerY, num radiusH, num radiusV, ColorStructType color) → void -
DrawEllipseLines(
num centerX, num centerY, num radiusH, num radiusV, ColorStructType color) → void -
DrawFPS(
num posX, num posY) → void -
DrawGrid(
num slices, num spacing) → void -
DrawLine(
num startPosX, num startPosY, num endPosX, num endPosY, ColorStructType color) → void -
DrawLine3D(
Vector3StructType startPos, Vector3StructType endPos, ColorStructType color) → void -
DrawLineBezier(
Vector2StructType startPos, Vector2StructType endPos, num thick, ColorStructType color) → void -
DrawLineEx(
Vector2StructType startPos, Vector2StructType endPos, num thick, ColorStructType color) → void -
DrawLineStrip(
List< Vector2StructType> points, ColorStructType color) → void -
DrawLineV(
Vector2StructType startPos, Vector2StructType endPos, ColorStructType color) → void -
DrawMesh(
MeshStructType mesh, MaterialStructType material, MatrixStructType transform) → void -
DrawMeshInstanced(
MeshStructType mesh, MaterialStructType material, List< MatrixStructType> transforms) → void -
DrawModel(
ModelStructType model, Vector3StructType position, num scale, ColorStructType tint) → void -
DrawModelEx(
ModelStructType model, Vector3StructType position, Vector3StructType rotationAxis, num rotationAngle, Vector3StructType scale, ColorStructType tint) → void -
DrawModelPoints(
ModelStructType model, Vector3StructType position, num scale, ColorStructType tint) → void -
DrawModelPointsEx(
ModelStructType model, Vector3StructType position, Vector3StructType rotationAxis, num rotationAngle, Vector3StructType scale, ColorStructType tint) → void -
DrawModelWires(
ModelStructType model, Vector3StructType position, num scale, ColorStructType tint) → void -
DrawModelWiresEx(
ModelStructType model, Vector3StructType position, Vector3StructType rotationAxis, num rotationAngle, Vector3StructType scale, ColorStructType tint) → void -
DrawPixel(
num posX, num posY, ColorStructType color) → void -
DrawPixelV(
Vector2StructType position, ColorStructType color) → void -
DrawPlane(
Vector3StructType centerPos, Vector2StructType size, ColorStructType color) → void -
DrawPoint3D(
Vector3StructType position, ColorStructType color) → void -
DrawPoly(
Vector2StructType center, num sides, num radius, num rotation, ColorStructType color) → void -
DrawPolyLines(
Vector2StructType center, num sides, num radius, num rotation, ColorStructType color) → void -
DrawPolyLinesEx(
Vector2StructType center, num sides, num radius, num rotation, num lineThick, ColorStructType color) → void -
DrawRay(
RayStructType ray, ColorStructType color) → void -
DrawRectangle(
num posX, num posY, num width, num height, ColorStructType color) → void -
DrawRectangleGradientEx(
RectangleStructType rec, ColorStructType topLeft, ColorStructType bottomLeft, ColorStructType topRight, ColorStructType bottomRight) → void -
DrawRectangleGradientH(
num posX, num posY, num width, num height, ColorStructType left, ColorStructType right) → void -
DrawRectangleGradientV(
num posX, num posY, num width, num height, ColorStructType top, ColorStructType bottom) → void -
DrawRectangleLines(
num posX, num posY, num width, num height, ColorStructType color) → void -
DrawRectangleLinesEx(
RectangleStructType rec, num lineThick, ColorStructType color) → void -
DrawRectanglePro(
RectangleStructType rec, Vector2StructType origin, num rotation, ColorStructType color) → void -
DrawRectangleRec(
RectangleStructType rec, ColorStructType color) → void -
DrawRectangleRounded(
RectangleStructType rec, num roundness, num segments, ColorStructType color) → void -
DrawRectangleRoundedLines(
RectangleStructType rec, num roundness, num segments, ColorStructType color) → void -
DrawRectangleRoundedLinesEx(
RectangleStructType rec, num roundness, num segments, num lineThick, ColorStructType color) → void -
DrawRectangleV(
Vector2StructType position, Vector2StructType size, ColorStructType color) → void -
DrawRing(
Vector2StructType center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorStructType color) → void -
DrawRingLines(
Vector2StructType center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorStructType color) → void -
DrawSphere(
Vector3StructType centerPos, num radius, ColorStructType color) → void -
DrawSphereEx(
Vector3StructType centerPos, num radius, num rings, num slices, ColorStructType color) → void -
DrawSphereWires(
Vector3StructType centerPos, num radius, num rings, num slices, ColorStructType color) → void -
DrawSplineBasis(
List< Vector2StructType> points, num thick, ColorStructType color) → void -
DrawSplineBezierCubic(
List< Vector2StructType> points, num thick, ColorStructType color) → void -
DrawSplineBezierQuadratic(
List< Vector2StructType> points, num thick, ColorStructType color) → void -
DrawSplineCatmullRom(
List< Vector2StructType> points, num thick, ColorStructType color) → void -
DrawSplineLinear(
List< Vector2StructType> points, num thick, ColorStructType color) → void -
DrawSplineSegmentBasis(
Vector2StructType p1, Vector2StructType p2, Vector2StructType p3, Vector2StructType p4, num thick, ColorStructType color) → void -
DrawSplineSegmentBezierCubic(
Vector2StructType p1, Vector2StructType c2, Vector2StructType c3, Vector2StructType p4, num thick, ColorStructType color) → void -
DrawSplineSegmentBezierQuadratic(
Vector2StructType p1, Vector2StructType c2, Vector2StructType p3, num thick, ColorStructType color) → void -
DrawSplineSegmentCatmullRom(
Vector2StructType p1, Vector2StructType p2, Vector2StructType p3, Vector2StructType p4, num thick, ColorStructType color) → void -
DrawSplineSegmentLinear(
Vector2StructType p1, Vector2StructType p2, num thick, ColorStructType color) → void -
DrawText(
String text, num posX, num posY, num fontSize, ColorStructType color) → void -
DrawTextCodepoint(
FontStructType font, num codepoint, Vector2StructType position, num fontSize, ColorStructType tint) → void -
DrawTextCodepoints(
FontStructType font, Int32List codepoints, Vector2StructType position, num fontSize, num spacing, ColorStructType tint) → void -
DrawTextEx(
FontStructType font, String text, Vector2StructType position, num fontSize, num spacing, ColorStructType tint) → void -
DrawTextPro(
FontStructType font, String text, Vector2StructType position, Vector2StructType origin, num rotation, num fontSize, num spacing, ColorStructType tint) → void -
DrawTexture(
TextureStructType texture, num posX, num posY, ColorStructType tint) → void -
DrawTextureEx(
TextureStructType texture, Vector2StructType position, num rotation, num scale, ColorStructType tint) → void -
DrawTextureNPatch(
TextureStructType texture, NPatchInfoStructType nPatchInfo, RectangleStructType dest, Vector2StructType origin, num rotation, ColorStructType tint) → void -
DrawTexturePro(
TextureStructType texture, RectangleStructType source, RectangleStructType dest, Vector2StructType origin, num rotation, ColorStructType tint) → void -
DrawTextureRec(
TextureStructType texture, RectangleStructType source, Vector2StructType position, ColorStructType tint) → void -
DrawTextureV(
TextureStructType texture, Vector2StructType position, ColorStructType tint) → void -
DrawTriangle(
Vector2StructType v1, Vector2StructType v2, Vector2StructType v3, ColorStructType color) → void -
DrawTriangle3D(
Vector3StructType v1, Vector3StructType v2, Vector3StructType v3, ColorStructType color) → void -
DrawTriangleFan(
List< Vector2StructType> points, ColorStructType color) → void -
DrawTriangleLines(
Vector2StructType v1, Vector2StructType v2, Vector2StructType v3, ColorStructType color) → void -
DrawTriangleStrip(
List< Vector2StructType> points, ColorStructType color) → void -
DrawTriangleStrip3D(
List< Vector3StructType> points, ColorStructType color) → void -
EnableCursor(
) → void -
EnableEventWaiting(
) → void -
EncodeDataBase64(
Uint8List data) → Uint8List -
EndBlendMode(
) → void -
EndDrawing(
) → void -
EndMode2D(
) → void -
EndMode3D(
) → void -
EndScissorMode(
) → void -
EndShaderMode(
) → void -
EndTextureMode(
) → void -
EndVrStereoMode(
) → void -
ExportAutomationEventList(
AutomationEventListStructType list, String fileName) → bool -
ExportDataAsCode(
Uint8List data, String fileName) → bool -
ExportFontAsCode(
FontStructType font, String fileName) → bool -
ExportImage(
ImageStructType image, String fileName) → bool -
ExportImageAsCode(
ImageStructType image, String fileName) → bool -
ExportImageToMemory(
ImageStructType image, String fileType) → (UnsignedCharPointerType, int) -
ExportMesh(
MeshStructType mesh, String fileName) → bool -
ExportMeshAsCode(
MeshStructType mesh, String fileName) → bool -
Fade(
ColorStructType color, num alpha) → ColorStructType -
FileExists(
String fileName) → bool -
GenImageCellular(
num width, num height, num tileSize) → ImageStructType -
GenImageChecked(
num width, num height, num checksX, num checksY, ColorStructType col1, ColorStructType col2) → ImageStructType -
GenImageColor(
num width, num height, ColorStructType color) → ImageStructType -
GenImageFontAtlas(
List< GlyphInfoStructType> glyphs, num fontSize, num padding, num packMethod) → (ImageStructType, List<RectangleStructType> ) -
GenImageGradientLinear(
num width, num height, num direction, ColorStructType start, ColorStructType end) → ImageStructType -
GenImageGradientRadial(
num width, num height, num density, ColorStructType inner, ColorStructType outer) → ImageStructType -
GenImageGradientSquare(
num width, num height, num density, ColorStructType inner, ColorStructType outer) → ImageStructType -
GenImagePerlinNoise(
num width, num height, num offsetX, num offsetY, num scale) → ImageStructType -
GenImageText(
num width, num height, String text) → ImageStructType -
GenImageWhiteNoise(
num width, num height, num factor) → ImageStructType -
GenMeshCone(
num radius, num height, num slices) → MeshStructType -
GenMeshCube(
num width, num height, num length) → MeshStructType -
GenMeshCubicmap(
ImageStructType cubicmap, Vector3StructType cubeSize) → MeshStructType -
GenMeshCylinder(
num radius, num height, num slices) → MeshStructType -
GenMeshHeightmap(
ImageStructType heightmap, Vector3StructType size) → MeshStructType -
GenMeshHemiSphere(
num radius, num rings, num slices) → MeshStructType -
GenMeshKnot(
num radius, num size, num radSeg, num sides) → MeshStructType -
GenMeshPlane(
num width, num length, num resX, num resZ) → MeshStructType -
GenMeshPoly(
num sides, num radius) → MeshStructType -
GenMeshSphere(
num radius, num rings, num slices) → MeshStructType -
GenMeshTangents(
MeshStructType mesh) → void -
GenMeshTorus(
num radius, num size, num radSeg, num sides) → MeshStructType -
GenTextureMipmaps(
TextureStructType texture) → void -
GetApplicationDirectory(
) → String -
GetCameraMatrix(
Camera3DStructType camera) → MatrixStructType -
GetCameraMatrix2D(
Camera2DStructType camera) → MatrixStructType -
GetCharPressed(
) → int -
GetClipboardImage(
) → ImageStructType -
GetClipboardText(
) → String -
GetCodepoint(
String text) → (int, int) -
GetCodepointCount(
String text) → int -
GetCodepointNext(
String text) → (int, int) -
GetCodepointPrevious(
String text) → (int, int) -
GetCollisionRec(
RectangleStructType rec1, RectangleStructType rec2) → RectangleStructType -
GetColor(
num hexValue) → ColorStructType -
GetCurrentMonitor(
) → int -
GetDirectoryPath(
String filePath) → String -
GetFileExtension(
String fileName) → String -
GetFileLength(
String fileName) → int -
GetFileModTime(
String fileName) → int -
GetFileName(
String filePath) → String -
GetFileNameWithoutExt(
String filePath) → String -
GetFontDefault(
) → FontStructType -
GetFPS(
) → int -
GetFrameTime(
) → double -
GetGamepadAxisCount(
num gamepad) → int -
GetGamepadAxisMovement(
num gamepad, GamepadAxis axis) → double -
GetGamepadButtonPressed(
) → GamepadButton -
GetGamepadName(
num gamepad) → String -
GetGestureDetected(
) → Gesture -
GetGestureDragAngle(
) → double -
GetGestureDragVector(
) → Vector2StructType -
GetGestureHoldDuration(
) → double -
GetGesturePinchAngle(
) → double -
GetGesturePinchVector(
) → Vector2StructType -
GetGlyphAtlasRec(
FontStructType font, num codepoint) → RectangleStructType -
GetGlyphIndex(
FontStructType font, num codepoint) → int -
GetGlyphInfo(
FontStructType font, num codepoint) → GlyphInfoStructType -
GetImageAlphaBorder(
ImageStructType image, num threshold) → RectangleStructType -
GetImageColor(
ImageStructType image, num x, num y) → ColorStructType -
GetKeyPressed(
) → int -
GetMeshBoundingBox(
MeshStructType mesh) → BoundingBoxStructType -
GetModelBoundingBox(
ModelStructType model) → BoundingBoxStructType -
GetMonitorCount(
) → int -
GetMonitorHeight(
num monitor) → int -
GetMonitorName(
num monitor) → String -
GetMonitorPhysicalHeight(
num monitor) → int -
GetMonitorPhysicalWidth(
num monitor) → int -
GetMonitorPosition(
num monitor) → Vector2StructType -
GetMonitorRefreshRate(
num monitor) → int -
GetMonitorWidth(
num monitor) → int -
GetMouseButtonInfo(
MouseButton button) → MouseButtonInfo -
GetMouseDelta(
) → Vector2StructType -
GetMouseInfo(
) → MouseInfo< Vector2StructType> -
GetMousePosition(
) → Vector2StructType -
GetMouseWheelMove(
) → double -
GetMouseWheelMoveV(
) → Vector2StructType -
GetMouseX(
) → int -
GetMouseY(
) → int -
GetPixelDataSize(
num width, num height, PixelFormat format) → int -
GetPrevDirectoryPath(
String dirPath) → String -
GetRandomValue(
num min, num max) → int -
GetRayCollisionBox(
RayStructType ray, BoundingBoxStructType box) → RayCollisionStructType -
GetRayCollisionMesh(
RayStructType ray, MeshStructType mesh, MatrixStructType transform) → RayCollisionStructType -
GetRayCollisionQuad(
RayStructType ray, Vector3StructType p1, Vector3StructType p2, Vector3StructType p3, Vector3StructType p4) → RayCollisionStructType -
GetRayCollisionSphere(
RayStructType ray, Vector3StructType center, num radius) → RayCollisionStructType -
GetRayCollisionTriangle(
RayStructType ray, Vector3StructType p1, Vector3StructType p2, Vector3StructType p3) → RayCollisionStructType -
GetRenderHeight(
) → int -
GetRenderWidth(
) → int -
GetScreenHeight(
) → int -
GetScreenToWorld2D(
Vector2StructType position, Camera2DStructType camera) → Vector2StructType -
GetScreenToWorldRay(
Vector2StructType position, Camera3DStructType camera) → RayStructType -
GetScreenToWorldRayEx(
Vector2StructType position, Camera3DStructType camera, num width, num height) → RayStructType -
GetScreenWidth(
) → int -
GetShaderLocation(
ShaderStructType shader, String uniformName) → int -
GetShaderLocationAttrib(
ShaderStructType shader, String attribName) → int -
GetShapesTexture(
) → TextureStructType -
GetShapesTextureRectangle(
) → RectangleStructType -
GetSplinePointBasis(
Vector2StructType p1, Vector2StructType p2, Vector2StructType p3, Vector2StructType p4, num t) → Vector2StructType -
GetSplinePointBezierCubic(
Vector2StructType p1, Vector2StructType c2, Vector2StructType c3, Vector2StructType p4, num t) → Vector2StructType -
GetSplinePointBezierQuad(
Vector2StructType p1, Vector2StructType c2, Vector2StructType p3, num t) → Vector2StructType -
GetSplinePointCatmullRom(
Vector2StructType p1, Vector2StructType p2, Vector2StructType p3, Vector2StructType p4, num t) → Vector2StructType -
GetSplinePointLinear(
Vector2StructType startPos, Vector2StructType endPos, num t) → Vector2StructType -
GetTime(
) → double -
GetTouchPointCount(
) → int -
GetTouchPointId(
num index) → int -
GetTouchPosition(
num index) → Vector2StructType -
GetTouchX(
) → int -
GetTouchY(
) → int -
GetWindowPosition(
) → Vector2StructType -
GetWindowScaleDPI(
) → Vector2StructType -
GetWorkingDirectory(
) → String -
GetWorldToScreen(
Vector3StructType position, Camera3DStructType camera) → Vector2StructType -
GetWorldToScreen2D(
Vector2StructType position, Camera2DStructType camera) → Vector2StructType -
GetWorldToScreenEx(
Vector3StructType position, Camera3DStructType camera, num width, num height) → Vector2StructType -
HideCursor(
) → void -
ImageAlphaClear(
ImageStructType image, ColorStructType color, num threshold) → void -
ImageAlphaCrop(
ImageStructType image, num threshold) → void -
ImageAlphaMask(
ImageStructType image, ImageStructType alphaMask) → void -
ImageAlphaPremultiply(
ImageStructType image) → void -
ImageBlurGaussian(
ImageStructType image, num blurSize) → void -
ImageClearBackground(
ImageStructType dst, ColorStructType color) → void -
ImageColorBrightness(
ImageStructType image, num brightness) → void -
ImageColorContrast(
ImageStructType image, num contrast) → void -
ImageColorGrayscale(
ImageStructType image) → void -
ImageColorInvert(
ImageStructType image) → void -
ImageColorReplace(
ImageStructType image, ColorStructType color, ColorStructType replace) → void -
ImageColorTint(
ImageStructType image, ColorStructType color) → void -
ImageCopy(
ImageStructType image) → ImageStructType -
ImageCrop(
ImageStructType image, RectangleStructType crop) → void -
ImageDither(
ImageStructType image, num rBpp, num gBpp, num bBpp, num aBpp) → void -
ImageDraw(
ImageStructType dst, ImageStructType src, RectangleStructType srcRec, RectangleStructType dstRec, ColorStructType tint) → void -
ImageDrawCircle(
ImageStructType dst, num centerX, num centerY, num radius, ColorStructType color) → void -
ImageDrawCircleLines(
ImageStructType dst, num centerX, num centerY, num radius, ColorStructType color) → void -
ImageDrawCircleLinesV(
ImageStructType dst, Vector2StructType center, num radius, ColorStructType color) → void -
ImageDrawCircleV(
ImageStructType dst, Vector2StructType center, num radius, ColorStructType color) → void -
ImageDrawLine(
ImageStructType dst, num startPosX, num startPosY, num endPosX, num endPosY, ColorStructType color) → void -
ImageDrawLineEx(
ImageStructType dst, Vector2StructType start, Vector2StructType end, num thick, ColorStructType color) → void -
ImageDrawLineV(
ImageStructType dst, Vector2StructType start, Vector2StructType end, ColorStructType color) → void -
ImageDrawPixel(
ImageStructType dst, num posX, num posY, ColorStructType color) → void -
ImageDrawPixelV(
ImageStructType dst, Vector2StructType position, ColorStructType color) → void -
ImageDrawRectangle(
ImageStructType dst, num posX, num posY, num width, num height, ColorStructType color) → void -
ImageDrawRectangleLines(
ImageStructType dst, RectangleStructType rec, num thick, ColorStructType color) → void -
ImageDrawRectangleRec(
ImageStructType dst, RectangleStructType rec, ColorStructType color) → void -
ImageDrawRectangleV(
ImageStructType dst, Vector2StructType position, Vector2StructType size, ColorStructType color) → void -
ImageDrawText(
ImageStructType dst, String text, num posX, num posY, num fontSize, ColorStructType color) → void -
ImageDrawTextEx(
ImageStructType dst, FontStructType font, String text, Vector2StructType position, num fontSize, num spacing, ColorStructType tint) → void -
ImageDrawTriangle(
ImageStructType dst, Vector2StructType v1, Vector2StructType v2, Vector2StructType v3, ColorStructType color) → void -
ImageDrawTriangleEx(
ImageStructType dst, Vector2StructType v1, Vector2StructType v2, Vector2StructType v3, ColorStructType c1, ColorStructType c2, ColorStructType c3) → void -
ImageDrawTriangleFan(
ImageStructType dst, List< Vector2StructType> points, ColorStructType color) → void -
ImageDrawTriangleLines(
ImageStructType dst, Vector2StructType v1, Vector2StructType v2, Vector2StructType v3, ColorStructType color) → void -
ImageDrawTriangleStrip(
ImageStructType dst, List< Vector2StructType> points, ColorStructType color) → void -
ImageFlipHorizontal(
ImageStructType image) → void -
ImageFlipVertical(
ImageStructType image) → void -
ImageFormat(
ImageStructType image, PixelFormat newFormat) → void -
ImageFromChannel(
ImageStructType image, num selectedChannel) → ImageStructType -
ImageFromImage(
ImageStructType image, RectangleStructType rec) → ImageStructType -
ImageKernelConvolution(
ImageStructType image, List< double> kernel) → void -
ImageMipmaps(
ImageStructType image) → void -
ImageResize(
ImageStructType image, num newWidth, num newHeight) → void -
ImageResizeCanvas(
ImageStructType image, num newWidth, num newHeight, num offsetX, num offsetY, ColorStructType fill) → void -
ImageResizeNN(
ImageStructType image, num newWidth, num newHeight) → void -
ImageRotate(
ImageStructType image, num degrees) → void -
ImageRotateCCW(
ImageStructType image) → void -
ImageRotateCW(
ImageStructType image) → void -
ImageText(
String text, num fontSize, ColorStructType color) → ImageStructType -
ImageTextEx(
FontStructType font, String text, num fontSize, num spacing, ColorStructType tint) → ImageStructType -
ImageToPOT(
ImageStructType image, ColorStructType fill) → void -
InitWindow(
num width, num height, String title) → void -
IsCursorHidden(
) → bool -
IsCursorOnScreen(
) → bool -
IsFileDropped(
) → bool -
IsFileExtension(
String fileName, String ext) → bool -
IsFileNameValid(
String fileName) → bool -
IsFontValid(
FontStructType font) → bool -
IsGamepadAvailable(
num gamepad) → bool -
IsGamepadButtonDown(
num gamepad, GamepadButton button) → bool -
IsGamepadButtonPressed(
num gamepad, GamepadButton button) → bool -
IsGamepadButtonReleased(
num gamepad, GamepadButton button) → bool -
IsGamepadButtonUp(
num gamepad, GamepadButton button) → bool -
IsGestureDetected(
Gesture key) → bool -
IsImageValid(
ImageStructType image) → bool -
IsKeyDown(
KeyboardKey key) → bool -
IsKeyPressed(
KeyboardKey key) → bool -
IsKeyPressedRepeat(
KeyboardKey key) → bool -
IsKeyReleased(
KeyboardKey key) → bool -
IsKeyUp(
KeyboardKey key) → bool -
IsMaterialValid(
MaterialStructType material) → bool -
IsModelAnimationValid(
ModelStructType model, ModelAnimationStructType anim) → bool -
IsModelValid(
ModelStructType model) → bool -
IsMouseButtonDown(
MouseButton button) → bool -
IsMouseButtonPressed(
MouseButton button) → bool -
IsMouseButtonReleased(
MouseButton button) → bool -
IsMouseButtonUp(
MouseButton button) → bool -
IsPathFile(
String path) → bool -
IsRenderTextureValid(
RenderTextureStructType target) → bool -
IsShaderValid(
ShaderStructType shader) → bool -
IsTextureValid(
TextureStructType texture) → bool -
IsWindowFocused(
) → bool -
IsWindowFullscreen(
) → bool -
IsWindowHidden(
) → bool -
IsWindowMaximized(
) → bool -
IsWindowMinimized(
) → bool -
IsWindowReady(
) → bool -
IsWindowResized(
) → bool -
IsWindowState(
ConfigFlags flag) → bool -
load(
) → void -
Override to perform one-time module initialization. Called by doLoad.
inherited
-
LoadAutomationEventList(
String? fileName) → AutomationEventListStructType -
LoadCodepoints(
String text) → Int32List -
LoadDirectoryFiles(
String dirPath) → FilePathListStructType -
LoadDirectoryFilesEx(
String basePath, String filter, bool scanSubdirs) → FilePathListStructType -
LoadDroppedFiles(
) → FilePathListStructType -
LoadFileData(
String fileName) → Uint8List -
LoadFileText(
String fileName) → String -
LoadFont(
String fileName) → FontStructType -
LoadFontData(
Uint8List fileData, num fontSize, Int32List? codepoints, num? codepointCount, FontType type) → List< GlyphInfoStructType> -
LoadFontEx(
String fileName, num fontSize, [Int32List? codepoints, num? codePointCount]) → FontStructType -
LoadFontFromImage(
ImageStructType image, ColorStructType key, num firstChar) → FontStructType -
LoadFontFromMemory(
String fileType, Uint8List fileData, num fontSize, Int32List codepoints) → FontStructType -
LoadImage(
String fileName) → ImageStructType -
LoadImageAnim(
String fileName) → ImageStructType -
LoadImageAnimFromMemory(
String fileType, Uint8List fileData) → ImageStructType -
LoadImageColors(
ImageStructType image) → List< ColorStructType> -
LoadImageFromMemory(
String fileType, Uint8List fileData) → ImageStructType -
LoadImageFromScreen(
) → ImageStructType -
LoadImageFromTexture(
TextureStructType texture) → ImageStructType -
LoadImagePalette(
ImageStructType image, num maxPaletteSize) → List< ColorStructType> -
LoadImageRaw(
String fileName, num width, num height, PixelFormat format, num headerSize) → ImageStructType -
LoadMaterialDefault(
) → MaterialStructType -
LoadMaterials(
String fileName) → List< MaterialStructType> -
LoadModel(
String fileName) → ModelStructType -
LoadModelAnimations(
String fileName) → List< ModelAnimationStructType> -
LoadModelFromMesh(
MeshStructType mesh) → ModelStructType -
LoadRandomSequence(
int count, int min, int max, [int? seed]) → List< int> -
LoadRenderTexture(
num width, num height) → RenderTextureStructType -
LoadShader(
String? vsFileName, String? fsFileName) → ShaderStructType -
LoadShaderFromMemory(
String? vsCode, String? fsCode) → ShaderStructType -
LoadTexture(
String fileName) → TextureStructType -
LoadTextureCubemap(
ImageStructType image, CubemapLayout layout) → TextureStructType -
LoadTextureFromImage(
ImageStructType image) → TextureStructType -
LoadUTF8(
Int32List codepoints) → String -
LoadVrStereoConfig(
VrDeviceInfoStructType device) → VrStereoConfigStructType -
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
MakeDirectory(
String dirPath) → int -
MaximizeWindow(
) → void -
MeasureText(
String text, num fontSize) → int -
MeasureTextEx(
FontStructType font, String text, num fontSize, num spacing) → Vector2StructType -
MinimizeWindow(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
OpenURL(
String url) → void -
PlayAutomationEvent(
AutomationEventStructType event) → void -
PollInputEvents(
) → void -
RestoreWindow(
) → void -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
SaveFileData(
String fileName, Uint8List data) → bool -
SaveFileText(
String fileName, String text) → bool -
SetAutomationEventBaseFrame(
int frame) → void -
SetAutomationEventList(
AutomationEventListStructType list) → void -
SetClipboardText(
String text) → void -
SetConfigFlags(
Iterable< ConfigFlags> flags) → void -
SetExitKey(
KeyboardKey key) → void -
SetGamepadMappings(
String mappings) → int -
SetGamepadVibration(
num gamepad, num leftMotor, num rightMotor, num duration) → void -
SetGesturesEnabled(
Iterable< Gesture> flags) → void -
SetLoadFileDataCallback(
LoadFileDataCallbackType? callback) → void -
SetLoadFileTextCallback(
LoadFileTextCallbackType? callback) → void -
SetMaterialTexture(
MaterialStructType material, MaterialMapIndex mapType, TextureStructType texture) → void -
SetModelMeshMaterial(
ModelStructType model, num meshId, num materialId) → void -
SetMouseCursor(
MouseCursor cursor) → void -
SetMouseOffset(
num offsetX, num offsetY) → void -
SetMousePosition(
num x, num y) → void -
SetMouseScale(
num scaleX, num scaleY) → void -
SetRandomSeed(
num seed) → void -
SetSaveFileDataCallback(
SaveFileDataCallbackType? callback) → void -
SetSaveFileTextCallback(
SaveFileTextCallbackType? callback) → void -
SetShaderValue(
ShaderStructType shader, num locIndex, List< num> value, ShaderUniformDataType uniformType) → void -
SetShaderValueMatrix(
ShaderStructType shader, num locIndex, MatrixStructType mat) → void -
SetShaderValueTexture(
ShaderStructType shader, num locIndex, TextureStructType texture) → void -
SetShaderValueV(
ShaderStructType shader, num locIndex, List< num> value, ShaderUniformDataType uniformType, num count) → void -
SetShapesTexture(
TextureStructType texture, RectangleStructType source) → void -
SetTargetFPS(
num fps) → void -
SetTextLineSpacing(
num spacing) → void -
SetTextureFilter(
TextureStructType texture, TextureFilter filter) → void -
SetTextureWrap(
TextureStructType texture, TextureWrap wrap) → void -
SetTraceLogLevel(
TraceLogLevel logLevel) → void -
SetWindowFocused(
) → void -
SetWindowIcon(
ImageStructType image) → void -
SetWindowIcons(
List< ImageStructType> images) → void -
SetWindowMaxSize(
num width, num height) → void -
SetWindowMinSize(
num width, num height) → void -
SetWindowMonitor(
num monitor) → void -
SetWindowOpacity(
num opacity) → void -
SetWindowPosition(
num x, num y) → void -
SetWindowSize(
num width, num height) → void -
SetWindowState(
Iterable< ConfigFlags> flags) → void -
SetWindowTitle(
String title) → void -
ShowCursor(
) → void -
StartAutomationEventRecording(
) → void -
StopAutomationEventRecording(
) → void -
SwapScreenBuffer(
) → void -
TakeScreenshot(
String fileName) → void -
ToggleBorderlessWindowed(
) → void -
ToggleFullscreen(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
TraceLog(
TraceLogLevel logLevel, String text) → void -
UnloadAutomationEventList(
AutomationEventListStructType list) → void -
UnloadDroppedFiles(
FilePathListStructType files) → void -
UnloadFont(
FontStructType font) → void -
UnloadFontData(
List< GlyphInfoStructType> glyphs) → void -
UnloadImage(
ImageStructType image) → void -
UnloadMaterial(
MaterialStructType material) → void -
UnloadMesh(
MeshStructType mesh) → void -
UnloadModel(
ModelStructType model) → void -
UnloadModelAnimation(
ModelAnimationStructType anim) → void -
UnloadModelAnimations(
List< ModelAnimationStructType> animations) → void -
UnloadRenderTexture(
RenderTextureStructType target) → void -
UnloadShader(
ShaderStructType shader) → void -
UnloadTexture(
TextureStructType texture) → void -
UnloadVrStereoConfig(
VrStereoConfigStructType config) → void -
UpdateCamera(
Camera3DStructType camera, CameraMode mode) → void -
UpdateCameraPro(
Camera3DStructType camera, Vector3StructType movement, Vector3StructType rotation, num zoom) → void -
UpdateMeshBuffer(
MeshStructType mesh, num index, TypedDataList data, num offset) → void -
UpdateModelAnimation(
ModelStructType model, ModelAnimationStructType anim, num frame) → void -
UpdateModelAnimationBones(
ModelStructType model, ModelAnimationStructType anim, num frame) → void -
UpdateTexture(
TextureStructType texture, Uint8List pixels) → void -
UpdateTextureRec(
TextureStructType texture, RectangleStructType rec, Uint8List pixels) → void -
UploadMesh(
MeshStructType mesh, bool dynamic) → void -
WaitTime(
num seconds) → void -
WindowShouldClose(
) → bool
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited