FloatEquals static method
Returns true if x and y are approximately equal.
Uses epsilon-based comparison scaled to the magnitude of the compared values.
Implementation
static bool FloatEquals(double x, double y) {
return ((x - y).abs()) <= (RaylibConstants.EPSILON*math.max(1.0, math.max(x.abs(), y.abs())));
}