init abstract method
void
init(
- R rl
Called once before the game loop starts.
Use this to initialize game state and open the window via RaylibCoreModuleBase.InitWindow.
Implementation
void init(R rl);
Called once before the game loop starts.
Use this to initialize game state and open the window via RaylibCoreModuleBase.InitWindow.
void init(R rl);