RaylibGuiConstants class
Dart-side mirror of raygui's compile-time constants (RAYGUI_VERSION, RAYGUI_ICONS, etc.),
kept in the base package so both backends share a single source of truth.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- RAYGUI_COLORBARALPHA_CHECKED_SIZE → int
-
final
- RAYGUI_GRID_ALPHA → double
-
final
- RAYGUI_GROUPBOX_LINE_THICK → int
-
final
- RAYGUI_ICON_DATA_ELEMENTS → int
-
final
- RAYGUI_ICON_MAX_ICONS → int
-
final
- RAYGUI_ICON_MAX_NAME_LENGTH → int
-
final
- RAYGUI_ICON_SIZE → int
-
final
- RAYGUI_ICON_TEXT_PADDING → int
-
final
-
RAYGUI_ICONS
→ List<
int> -
final
- RAYGUI_LINE_MARGIN_TEXT → int
-
final
- RAYGUI_LINE_TEXT_PADDING → int
-
final
- RAYGUI_MAX_CONTROLS → int
-
final
- RAYGUI_MAX_LINE_BUFFER_SIZE → int
-
final
- RAYGUI_MAX_PROPS_BASE → int
-
final
- RAYGUI_MAX_PROPS_EXTENDED → int
-
final
- RAYGUI_MAX_TEXT_LINES → int
-
final
- RAYGUI_MESSAGEBOX_BUTTON_HEIGHT → int
-
final
- RAYGUI_MESSAGEBOX_BUTTON_PADDING → int
-
final
- RAYGUI_MIN_MOUSE_WHEEL_SPEED → int
-
final
- RAYGUI_MIN_SCROLLBAR_HEIGHT → int
-
final
- RAYGUI_MIN_SCROLLBAR_WIDTH → int
-
final
- RAYGUI_PANEL_BORDER_WIDTH → int
-
final
- RAYGUI_SCROLLBAR_LEFT_SIDE → int
-
final
- RAYGUI_SCROLLBAR_RIGHT_SIDE → int
-
final
- RAYGUI_TABBAR_ITEM_WIDTH → int
-
final
- RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN → int
-
final
- RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY → int
-
final
- RAYGUI_TEXTFORMAT_MAX_SIZE → int
-
final
- RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT → int
-
final
- RAYGUI_TEXTINPUTBOX_BUTTON_PADDING → int
-
final
- RAYGUI_TEXTINPUTBOX_HEIGHT → int
-
final
- RAYGUI_TEXTSPLIT_MAX_ITEMS → int
-
final
- RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE → int
-
final
- RAYGUI_TOGGLEGROUP_MAX_ITEMS → int
-
final
- RAYGUI_VALUEBOX_MAX_CHARS → int
-
final
- RAYGUI_VERSION → String
-
final
- RAYGUI_VERSION_MAJOR → int
-
final
- RAYGUI_VERSION_MINOR → int
-
final
- RAYGUI_VERSION_PATCH → int
-
final
- RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT → int
-
final