RaylibGuiFlatModule<R extends RaylibBase> class
abstract
Backend-agnostic contract for the Raygui module.
Concrete platform implementations mix in or extend this to provide the full API surface across different backends.
- Inheritance
-
- Object
- RaylibModule<
R> - RaylibGuiFlatModule
- Mixed-in types
Constructors
- RaylibGuiFlatModule(R rl)
Properties
-
$
→ RaylibTemp<
RaylibBase> -
See RaylibTemp.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- RAYGUI_COLORBARALPHA_CHECKED_SIZE → int
-
See RaylibGuiConstants.RAYGUI_COLORBARALPHA_CHECKED_SIZE.
no setterinherited
- RAYGUI_GRID_ALPHA → double
-
See RaylibGuiConstants.RAYGUI_GRID_ALPHA.
no setterinherited
- RAYGUI_GROUPBOX_LINE_THICK → int
-
See RaylibGuiConstants.RAYGUI_GROUPBOX_LINE_THICK.
no setterinherited
- RAYGUI_ICON_DATA_ELEMENTS → int
-
See RaylibGuiConstants.RAYGUI_ICON_DATA_ELEMENTS.
no setterinherited
- RAYGUI_ICON_FONT_ATLAS_PADDING → int
-
See RaylibGuiConstants.RAYGUI_ICON_FONT_ATLAS_PADDING.
no setterinherited
- RAYGUI_ICON_MAX_FONT_BACKED → int
-
See RaylibGuiConstants.RAYGUI_ICON_MAX_FONT_BACKED.
no setterinherited
- RAYGUI_ICON_MAX_ICONS → int
-
See RaylibGuiConstants.RAYGUI_ICON_MAX_ICONS.
no setterinherited
- RAYGUI_ICON_MAX_NAME_LENGTH → int
-
See RaylibGuiConstants.RAYGUI_ICON_MAX_NAME_LENGTH.
no setterinherited
- RAYGUI_ICON_SIZE → int
-
See RaylibGuiConstants.RAYGUI_ICON_SIZE.
no setterinherited
- RAYGUI_ICON_TEXT_PADDING → int
-
See RaylibGuiConstants.RAYGUI_ICON_TEXT_PADDING.
no setterinherited
-
RAYGUI_ICONS
→ List<
int> -
See RaylibGuiConstants.RAYGUI_ICONS.
no setterinherited
- RAYGUI_LINE_MARGIN_TEXT → int
-
See RaylibGuiConstants.RAYGUI_LINE_MARGIN_TEXT.
no setterinherited
- RAYGUI_LINE_TEXT_PADDING → int
-
See RaylibGuiConstants.RAYGUI_LINE_TEXT_PADDING.
no setterinherited
- RAYGUI_MAX_CONTROLS → int
-
See RaylibGuiConstants.RAYGUI_MAX_CONTROLS.
no setterinherited
- RAYGUI_MAX_PROPS_BASE → int
-
See RaylibGuiConstants.RAYGUI_MAX_PROPS_BASE.
no setterinherited
- RAYGUI_MAX_PROPS_EXTENDED → int
-
See RaylibGuiConstants.RAYGUI_MAX_PROPS_EXTENDED.
no setterinherited
- RAYGUI_MAX_TEXT_LINES → int
-
See RaylibGuiConstants.RAYGUI_MAX_TEXT_LINES.
no setterinherited
- RAYGUI_MESSAGEBOX_BUTTON_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_HEIGHT.
no setterinherited
- RAYGUI_MESSAGEBOX_BUTTON_PADDING → int
-
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_PADDING.
no setterinherited
- RAYGUI_MIN_MOUSE_WHEEL_SPEED → int
-
See RaylibGuiConstants.RAYGUI_MIN_MOUSE_WHEEL_SPEED.
no setterinherited
- RAYGUI_MIN_SCROLLBAR_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_HEIGHT.
no setterinherited
- RAYGUI_MIN_SCROLLBAR_WIDTH → int
-
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_WIDTH.
no setterinherited
- RAYGUI_PANEL_BORDER_WIDTH → int
-
See RaylibGuiConstants.RAYGUI_PANEL_BORDER_WIDTH.
no setterinherited
- RAYGUI_SCROLLBAR_LEFT_SIDE → int
-
See RaylibGuiConstants.RAYGUI_SCROLLBAR_LEFT_SIDE.
no setterinherited
- RAYGUI_SCROLLBAR_RIGHT_SIDE → int
-
See RaylibGuiConstants.RAYGUI_SCROLLBAR_RIGHT_SIDE.
no setterinherited
- RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN → int
-
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN.
no setterinherited
- RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY → int
-
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY.
no setterinherited
- RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT.
no setterinherited
- RAYGUI_TEXTINPUTBOX_BUTTON_PADDING → int
-
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_PADDING.
no setterinherited
- RAYGUI_TEXTINPUTBOX_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_HEIGHT.
no setterinherited
- RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE → int
-
See RaylibGuiConstants.RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE.
no setterinherited
- RAYGUI_VALUEBOX_MAX_CHARS → int
-
See RaylibGuiConstants.RAYGUI_VALUEBOX_MAX_CHARS.
no setterinherited
- RAYGUI_VERSION → String
-
See RaylibGuiConstants.RAYGUI_VERSION.
no setterinherited
- RAYGUI_VERSION_MAJOR → int
-
See RaylibGuiConstants.RAYGUI_VERSION_MAJOR.
no setterinherited
- RAYGUI_VERSION_MINOR → int
-
See RaylibGuiConstants.RAYGUI_VERSION_MINOR.
no setterinherited
- RAYGUI_VERSION_PATCH → int
-
See RaylibGuiConstants.RAYGUI_VERSION_PATCH.
no setterinherited
- RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT.
no setterinherited
- RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT.
no setterinherited
- RaylibCaptureIds → _RaylibGuiDartCaptureIds
-
Capture ID generator for pointer slots allocated by this module.
final
- rl → R
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
disposeStructWithOpFreed<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then frees the temporary allocation backing the pointer, if any.inherited -
disposeStructWithOpUnslotted<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.inherited -
GuiButton(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Button control, returns true when clicked
-
GuiCheckBox(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RBool> checked) → int - Check Box control, returns true when active
-
GuiColorBarAlpha(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RFloat32> alpha) → int - Color Bar Alpha control
-
GuiColorBarHue(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RFloat32> value) → int - Color Bar Hue control
-
GuiColorPanel(
RectangleD bounds, MemoryPointer< RInt8> text, StructPointer<ColorD> color) → int - Color Panel control
-
GuiColorPanelHSV(
RectangleD bounds, MemoryPointer< RInt8> text, StructPointer<Vector3D> colorHsv) → int - Color Panel control, using Hue-Saturation-Value color data
-
GuiColorPicker(
RectangleD bounds, MemoryPointer< RInt8> text, StructPointer<ColorD> color) → int - Color Picker control, includes Color bar controls
-
GuiColorPickerHSV(
RectangleD bounds, MemoryPointer< RInt8> text, StructPointer<Vector3D> colorHsv) → int - Color Picker control, using Hue-Saturation-Value color data, includes Color bar controls
-
GuiComboBox(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> active) → int - Combo Box control
-
GuiDisable(
) → void - Disable gui controls (global state)
-
GuiDisableTooltip(
) → void - Disable gui tooltips (global state)
-
GuiDrawIcon(
int iconId, int posX, int posY, int pixelSize, ColorD color) → void - Draw icon using pixel size at specified position
-
GuiDropdownBox(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> active, bool editMode) → int - Dropdown Box control
-
GuiDummyRec(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Dummy control for placeholders
-
GuiEnable(
) → void - Enable gui controls (global state)
-
GuiEnableTooltip(
) → void - Enable gui tooltips (global state)
-
GuiGetFont(
) → FontD - Get gui custom font (global state)
-
GuiGetIcons(
) → MemoryPointer< RUint32> - Get raygui icons data
-
GuiGetState(
) → int - Get gui state (global state)
-
GuiGetStyle(
int control, int property) → int - Get one style property
-
GuiGetTextWidth(
MemoryPointer< RInt8> text) → int - Get text width considering gui style and icon size (if required)
-
GuiGrid(
RectangleD bounds, MemoryPointer< RInt8> text, double spacing, int subdivs, StructPointer<Vector2D> mouseCell) → int - Grid control
-
GuiGroupBox(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Group Box control with text name
-
GuiIconText(
int iconId, MemoryPointer< RInt8> text) → MemoryPointer<RInt8> - Get text with icon id prepended (if supported)
-
GuiIsLocked(
) → bool - Check if gui is locked (global state)
-
GuiLabel(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Label control
-
GuiLabelButton(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Label button control, returns true when clicked
-
GuiLine(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Line separator control, could contain text
-
GuiListView(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> scrollIndex, MemoryPointer<RInt32> active) → int - List View control
-
GuiListViewEx(
RectangleD bounds, MemoryPointer< RPointer< text, int count, MemoryPointer<RChar> >RInt32> scrollIndex, MemoryPointer<RInt32> active, MemoryPointer<RInt32> focus) → int - List View control, using text entries list and returning focus entry
-
GuiLoadIcons(
MemoryPointer< RInt8> fileName, bool loadIconsName) → MemoryPointer<RPointer< RChar> > - Load raygui icons file (.rgi) into internal icons data
-
GuiLoadIconsFromMemory(
MemoryPointer< RUint8> fileData, int dataSize, bool loadIconsName) → MemoryPointer<RPointer< RChar> > - Load raygui icons file (.rgi) from memory into internal icons data
-
GuiLoadStyle(
MemoryPointer< RInt8> fileName) → void - Load style file over global style variable (.rgs)
-
GuiLoadStyleDefault(
) → void - Load style default over global style
-
GuiLoadStyleFromMemory(
MemoryPointer< RUint8> fileData, int dataSize) → void - Load style from memory (binary only)
-
GuiLock(
) → void - Lock gui controls (global state)
-
GuiMessageBox(
RectangleD bounds, MemoryPointer< RInt8> title, MemoryPointer<RInt8> message, MemoryPointer<RInt8> btnText, MemoryPointer<RInt32> btnActive) → int - Message Box control, displays a message
-
GuiPanel(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Panel control, useful to group controls
-
GuiProgressBar(
RectangleD bounds, MemoryPointer< RInt8> textLeft, MemoryPointer<RInt8> textRight, MemoryPointer<RFloat32> value, double minValue, double maxValue) → int - Progress Bar control
-
GuiScrollPanel(
RectangleD bounds, MemoryPointer< RInt8> text, RectangleD content, StructPointer<Vector2D> scroll, StructPointer<RectangleD> view) → int - Scroll Panel control
-
GuiSetAlpha(
double alpha) → void - Set gui controls alpha (global state), alpha goes from 0.0 to 1.0
-
GuiSetFont(
FontD font) → void - Set gui custom font (global state)
-
GuiSetIconScale(
int scale) → void - Set default icon drawing size
-
GuiSetState(
int state) → void - Set gui state (global state)
-
GuiSetStyle(
int control, int property, int value) → void - Set one style property
-
GuiSetTooltip(
MemoryPointer< RInt8> tooltip) → void - Set tooltip string
-
GuiSlider(
RectangleD bounds, MemoryPointer< RInt8> textLeft, MemoryPointer<RInt8> textRight, MemoryPointer<RFloat32> value, double minValue, double maxValue) → int - Slider control
-
GuiSliderBar(
RectangleD bounds, MemoryPointer< RInt8> textLeft, MemoryPointer<RInt8> textRight, MemoryPointer<RFloat32> value, double minValue, double maxValue) → int - Slider Bar control
-
GuiSpinner(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> value, int minValue, int maxValue, bool editMode) → int - Spinner control
-
GuiStatusBar(
RectangleD bounds, MemoryPointer< RInt8> text) → int - Status Bar control, shows info text
-
GuiTabBar(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> hscroll, MemoryPointer<RInt32> active) → int - Tab Bar control
-
GuiTabBarEx(
RectangleD bounds, MemoryPointer< RPointer< text, int count, MemoryPointer<RChar> >RInt32> hscroll, MemoryPointer<RInt32> active, MemoryPointer<RInt32> focus) → int - Tab Bar control, using text entries list and returning focus entry
-
GuiTextBox(
RectangleD bounds, MemoryPointer< RInt8> text, int textSize, bool editMode) → int - Text Box control, updates input text
-
GuiTextInputBox(
RectangleD bounds, MemoryPointer< RInt8> title, MemoryPointer<RInt8> message, MemoryPointer<RInt8> text, int textSize, MemoryPointer<RInt8> btnText, MemoryPointer<RInt32> btnActive, MemoryPointer<RBool> secretViewActive) → int - Text Input Box control, ask for text, supports secret
-
GuiToggle(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RBool> active) → int - Toggle Button control
-
GuiToggleGroup(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> active) → int - Toggle Group control
-
GuiToggleSlider(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> active) → int - Toggle Slider control
-
GuiUnlock(
) → void - Unlock gui controls (global state)
-
GuiValueBox(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt32> value, int minValue, int maxValue, bool editMode) → int - Value Box control, updates input text with numbers
-
GuiValueBoxFloat(
RectangleD bounds, MemoryPointer< RInt8> text, MemoryPointer<RInt8> textValue, MemoryPointer<RFloat32> value, bool editMode) → int - Value box control for float values
-
GuiWindowBox(
RectangleD bounds, MemoryPointer< RInt8> title) → int - Window Box control, shows a window that can be closed
-
load(
) → void -
Override to perform one-time module initialization.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited