GuiWindowBox abstract method
Window Box control, shows a window that can be closed
Implementation
int GuiWindowBox(
RectangleD bounds,
MemoryPointer<RChar> title,
);
Window Box control, shows a window that can be closed
int GuiWindowBox(
RectangleD bounds,
MemoryPointer<RChar> title,
);