GuiWindowBox abstract method
Window Box control, shows a window that can be closed
Implementation
int GuiWindowBox(
RectangleStructType bounds,
String? title,
);
Window Box control, shows a window that can be closed
int GuiWindowBox(
RectangleStructType bounds,
String? title,
);