RaylibGuiModuleCaptureIds class

Produces stable slot key strings identifying the allocation origin of each Gui module function's captured Struct.

Constructors

RaylibGuiModuleCaptureIds()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

GuiGetFont() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited