RaylibLightModuleDebugLabels class

Produces human-readable debug strings for each Light module function call, logged to the console when debug output is enabled.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

CreateLight(LightType type, Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> position, Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> target, ColorBase<ColorBase> color, ShaderBase<ShaderBase> shader) String
EnumsAsFlagsOr(Iterable<RaylibEnum> flags) String
Formats flags as a |-separated string of enum names, mirroring C bitflag notation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
UpdateLightValues(ShaderBase<ShaderBase> shader, LightBase<LightBase<dynamic, Vector3Base, MatrixBase, QuaternionBase, Vector4Base, ColorBase>, Vector3Base, MatrixBase, QuaternionBase, Vector4Base, ColorBase> light) String

Operators

operator ==(Object other) bool
The equality operator.
inherited