MatrixCompose abstract method
Compose a transformation matrix from rotational, translational and scaling components
Implementation
MatrixD MatrixCompose(
Vector3D translation,
QuaternionD rotation,
Vector3D scale,
);
Compose a transformation matrix from rotational, translational and scaling components
MatrixD MatrixCompose(
Vector3D translation,
QuaternionD rotation,
Vector3D scale,
);