rlSetTexture method
Set current texture for render batch and check buffers limits
Implementation
void rlSetTexture(
num id,
) => run(
() => _debugLabels.rlSetTexture(id),
() => _flat.rlSetTexture(
id.toInt(),
),
);
Set current texture for render batch and check buffers limits
void rlSetTexture(
num id,
) => run(
() => _debugLabels.rlSetTexture(id),
() => _flat.rlSetTexture(
id.toInt(),
),
);