RaylibRlglFlatModule<R extends RaylibBase> class
abstract
Backend-agnostic contract for the Raylib Rlgl module.
Concrete platform implementations mix in or extend this to provide the full API surface across different backends.
- Inheritance
-
- Object
- RaylibModule<
R> - RaylibRlglFlatModule
- Mixed-in types
Constructors
- RaylibRlglFlatModule(R rl)
Properties
-
$
→ RaylibTemp<
RaylibBase> -
See RaylibTemp.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- RaylibCaptureIds → _RaylibRlglDartCaptureIds
-
Capture ID generator for pointer slots allocated by this module.
final
- rl → R
-
finalinherited
- RL_BLEND_COLOR → int
-
See RaylibRlglConstants.RL_BLEND_COLOR.
no setterinherited
- RL_BLEND_DST_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_DST_ALPHA.
no setterinherited
- RL_BLEND_DST_RGB → int
-
See RaylibRlglConstants.RL_BLEND_DST_RGB.
no setterinherited
- RL_BLEND_EQUATION → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION.
no setterinherited
- RL_BLEND_EQUATION_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION_ALPHA.
no setterinherited
- RL_BLEND_EQUATION_RGB → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION_RGB.
no setterinherited
- RL_BLEND_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_SRC_ALPHA.
no setterinherited
- RL_BLEND_SRC_RGB → int
-
See RaylibRlglConstants.RL_BLEND_SRC_RGB.
no setterinherited
- RL_COMPUTE_SHADER → int
-
See RaylibRlglConstants.RL_COMPUTE_SHADER.
no setterinherited
- RL_CONSTANT_ALPHA → int
-
See RaylibRlglConstants.RL_CONSTANT_ALPHA.
no setterinherited
- RL_CONSTANT_COLOR → int
-
See RaylibRlglConstants.RL_CONSTANT_COLOR.
no setterinherited
- RL_CULL_DISTANCE_FAR → double
-
See RaylibRlglConstants.RL_CULL_DISTANCE_FAR.
no setterinherited
- RL_CULL_DISTANCE_NEAR → double
-
See RaylibRlglConstants.RL_CULL_DISTANCE_NEAR.
no setterinherited
- RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFER_ELEMENTS.
no setterinherited
- RL_DEFAULT_BATCH_BUFFERS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFERS.
no setterinherited
- RL_DEFAULT_BATCH_DRAWCALLS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_DRAWCALLS.
no setterinherited
- RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS.
no setterinherited
- RL_DRAW_FRAMEBUFFER → int
-
See RaylibRlglConstants.RL_DRAW_FRAMEBUFFER.
no setterinherited
- RL_DST_ALPHA → int
-
See RaylibRlglConstants.RL_DST_ALPHA.
no setterinherited
- RL_DST_COLOR → int
-
See RaylibRlglConstants.RL_DST_COLOR.
no setterinherited
- RL_DYNAMIC_COPY → int
-
See RaylibRlglConstants.RL_DYNAMIC_COPY.
no setterinherited
- RL_DYNAMIC_DRAW → int
-
See RaylibRlglConstants.RL_DYNAMIC_DRAW.
no setterinherited
- RL_DYNAMIC_READ → int
-
See RaylibRlglConstants.RL_DYNAMIC_READ.
no setterinherited
- RL_FLOAT → int
-
See RaylibRlglConstants.RL_FLOAT.
no setterinherited
- RL_FRAGMENT_SHADER → int
-
See RaylibRlglConstants.RL_FRAGMENT_SHADER.
no setterinherited
- RL_FUNC_ADD → int
-
See RaylibRlglConstants.RL_FUNC_ADD.
no setterinherited
- RL_FUNC_REVERSE_SUBTRACT → int
-
See RaylibRlglConstants.RL_FUNC_REVERSE_SUBTRACT.
no setterinherited
- RL_FUNC_SUBTRACT → int
-
See RaylibRlglConstants.RL_FUNC_SUBTRACT.
no setterinherited
- RL_LINES → int
-
See RaylibRlglConstants.RL_LINES.
no setterinherited
- RL_MAX → int
-
See RaylibRlglConstants.RL_MAX.
no setterinherited
- RL_MAX_MATRIX_STACK_SIZE → int
-
See RaylibRlglConstants.RL_MAX_MATRIX_STACK_SIZE.
no setterinherited
- RL_MAX_SHADER_LOCATIONS → int
-
See RaylibRlglConstants.RL_MAX_SHADER_LOCATIONS.
no setterinherited
- RL_MIN → int
-
See RaylibRlglConstants.RL_MIN.
no setterinherited
- RL_MODELVIEW → int
-
See RaylibRlglConstants.RL_MODELVIEW.
no setterinherited
- RL_ONE → int
-
See RaylibRlglConstants.RL_ONE.
no setterinherited
- RL_ONE_MINUS_CONSTANT_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_ALPHA.
no setterinherited
- RL_ONE_MINUS_CONSTANT_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_COLOR.
no setterinherited
- RL_ONE_MINUS_DST_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_DST_ALPHA.
no setterinherited
- RL_ONE_MINUS_DST_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_DST_COLOR.
no setterinherited
- RL_ONE_MINUS_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_SRC_ALPHA.
no setterinherited
- RL_ONE_MINUS_SRC_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_SRC_COLOR.
no setterinherited
- RL_PROJECTION → int
-
See RaylibRlglConstants.RL_PROJECTION.
no setterinherited
- RL_QUADS → int
-
See RaylibRlglConstants.RL_QUADS.
no setterinherited
- RL_READ_FRAMEBUFFER → int
-
See RaylibRlglConstants.RL_READ_FRAMEBUFFER.
no setterinherited
- RL_SHADER_LOC_MAP_DIFFUSE → int
-
See RaylibRlglConstants.RL_SHADER_LOC_MAP_DIFFUSE.
no setterinherited
- RL_SHADER_LOC_MAP_SPECULAR → int
-
See RaylibRlglConstants.RL_SHADER_LOC_MAP_SPECULAR.
no setterinherited
- RL_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_SRC_ALPHA.
no setterinherited
- RL_SRC_ALPHA_SATURATE → int
-
See RaylibRlglConstants.RL_SRC_ALPHA_SATURATE.
no setterinherited
- RL_SRC_COLOR → int
-
See RaylibRlglConstants.RL_SRC_COLOR.
no setterinherited
- RL_STATIC_COPY → int
-
See RaylibRlglConstants.RL_STATIC_COPY.
no setterinherited
- RL_STATIC_DRAW → int
-
See RaylibRlglConstants.RL_STATIC_DRAW.
no setterinherited
- RL_STATIC_READ → int
-
See RaylibRlglConstants.RL_STATIC_READ.
no setterinherited
- RL_STREAM_COPY → int
-
See RaylibRlglConstants.RL_STREAM_COPY.
no setterinherited
- RL_STREAM_DRAW → int
-
See RaylibRlglConstants.RL_STREAM_DRAW.
no setterinherited
- RL_STREAM_READ → int
-
See RaylibRlglConstants.RL_STREAM_READ.
no setterinherited
- RL_TEXTURE → int
-
See RaylibRlglConstants.RL_TEXTURE.
no setterinherited
- RL_TEXTURE_FILTER_ANISOTROPIC → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_ANISOTROPIC.
no setterinherited
- RL_TEXTURE_FILTER_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR.
no setterinherited
- RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_MIP_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_LINEAR.
no setterinherited
- RL_TEXTURE_FILTER_MIP_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR.
no setterinherited
- RL_TEXTURE_MAG_FILTER → int
-
See RaylibRlglConstants.RL_TEXTURE_MAG_FILTER.
no setterinherited
- RL_TEXTURE_MIN_FILTER → int
-
See RaylibRlglConstants.RL_TEXTURE_MIN_FILTER.
no setterinherited
- RL_TEXTURE_MIPMAP_BIAS_RATIO → int
-
See RaylibRlglConstants.RL_TEXTURE_MIPMAP_BIAS_RATIO.
no setterinherited
- RL_TEXTURE_WRAP_CLAMP → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_CLAMP.
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_CLAMP → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_CLAMP.
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_REPEAT → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_REPEAT.
no setterinherited
- RL_TEXTURE_WRAP_REPEAT → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_REPEAT.
no setterinherited
- RL_TEXTURE_WRAP_S → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_S.
no setterinherited
- RL_TEXTURE_WRAP_T → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_T.
no setterinherited
- RL_TRIANGLES → int
-
See RaylibRlglConstants.RL_TRIANGLES.
no setterinherited
- RL_UNSIGNED_BYTE → int
-
See RaylibRlglConstants.RL_UNSIGNED_BYTE.
no setterinherited
- RL_VERTEX_SHADER → int
-
See RaylibRlglConstants.RL_VERTEX_SHADER.
no setterinherited
- RL_ZERO → int
-
See RaylibRlglConstants.RL_ZERO.
no setterinherited
- RLGL_VERSION → String
-
See RaylibRlglConstants.RLGL_VERSION.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
disposeStructWithOpFreed<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then frees the temporary allocation backing the pointer, if any.inherited -
disposeStructWithOpUnslotted<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.inherited -
load(
) → void -
Override to perform one-time module initialization.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
rlActiveDrawBuffers(
int count) → void - Activate multiple draw color buffers
-
rlActiveTextureSlot(
int slot) → void - Select and active a texture slot
-
rlBegin(
int mode) → void - Initialize drawing mode (how to organize vertex)
-
rlBindFramebuffer(
int target, int framebuffer) → void - Bind framebuffer (FBO)
-
rlBindImageTexture(
int id, int index, int format, bool readonly) → void - Bind image texture
-
rlBindShaderBuffer(
int id, int index) → void - Bind SSBO buffer
-
rlBlitFramebuffer(
int srcX, int srcY, int srcWidth, int srcHeight, int dstX, int dstY, int dstWidth, int dstHeight, int bufferMask) → void - Blit active framebuffer to main framebuffer
-
rlCheckErrors(
) → void - Check and log OpenGL error codes
-
rlCheckRenderBatchLimit(
int vCount) → bool - Check internal buffer overflow for a given number of vertex
-
rlClearColor(
int r, int g, int b, int a) → void - Clear color buffer with color
-
rlClearScreenBuffers(
) → void - Clear used screen buffers (color and depth)
-
rlColor3f(
double x, double y, double z) → void - Define one vertex (color) - 3 float
-
rlColor4f(
double x, double y, double z, double w) → void - Define one vertex (color) - 4 float
-
rlColor4ub(
int r, int g, int b, int a) → void - Define one vertex (color) - 4 byte
-
rlColorMask(
bool r, bool g, bool b, bool a) → void - Color mask control
-
rlComputeShaderDispatch(
int groupX, int groupY, int groupZ) → void - Dispatch compute shader (equivalent to draw for graphics pipeline)
-
rlCopyFramebuffer(
int x, int y, int width, int height, int format, MemoryPointer< RVoid> pixels) → void - Copy framebuffer pixel data to internal buffer
-
rlCopyShaderBuffer(
int destId, int srcId, int destOffset, int srcOffset, int count) → void - Copy SSBO data between buffers
-
rlCubemapParameters(
int id, int param, int value) → void - Set cubemap parameters (filter, wrap)
-
rlDisableBackfaceCulling(
) → void - Disable backface culling
-
rlDisableColorBlend(
) → void - Disable color blending
-
rlDisableDepthMask(
) → void - Disable depth write
-
rlDisableDepthTest(
) → void - Disable depth test
-
rlDisableFramebuffer(
) → void - Disable render texture (fbo), return to default framebuffer
-
rlDisablePointMode(
) → void - Disable point mode
-
rlDisableScissorTest(
) → void - Disable scissor test
-
rlDisableShader(
) → void - Disable shader program
-
rlDisableSmoothLines(
) → void - Disable line aliasing
-
rlDisableStatePointer(
int vertexAttribType) → void - Disable attribute state pointer
-
rlDisableStereoRender(
) → void - Disable stereo rendering
-
rlDisableTexture(
) → void - Disable texture
-
rlDisableTextureCubemap(
) → void - Disable texture cubemap
-
rlDisableVertexArray(
) → void - Disable vertex array (VAO, if supported)
-
rlDisableVertexAttribute(
int index) → void - Disable vertex attribute index
-
rlDisableVertexBuffer(
) → void - Disable vertex buffer (VBO)
-
rlDisableVertexBufferElement(
) → void - Disable vertex buffer element (VBO element)
-
rlDisableWireMode(
) → void - Disable wire mode
-
rlDrawRenderBatch(
StructPointer< RlRenderBatchD> batch) → void - Draw render batch data (Update->Draw->Reset)
-
rlDrawRenderBatchActive(
) → void - Update and draw internal render batch
-
rlDrawVertexArray(
int offset, int count) → void - Draw vertex array (currently active vao)
-
rlDrawVertexArrayElements(
int offset, int count, MemoryPointer< RVoid> buffer) → void - Draw vertex array elements
-
rlDrawVertexArrayElementsInstanced(
int offset, int count, MemoryPointer< RVoid> buffer, int instances) → void - Draw vertex array elements with instancing
-
rlDrawVertexArrayInstanced(
int offset, int count, int instances) → void - Draw vertex array (currently active vao) with instancing
-
rlEnableBackfaceCulling(
) → void - Enable backface culling
-
rlEnableColorBlend(
) → void - Enable color blending
-
rlEnableDepthMask(
) → void - Enable depth write
-
rlEnableDepthTest(
) → void - Enable depth test
-
rlEnableFramebuffer(
int id) → void - Enable render texture (fbo)
-
rlEnablePointMode(
) → void - Enable point mode
-
rlEnableScissorTest(
) → void - Enable scissor test
-
rlEnableShader(
int id) → void - Enable shader program
-
rlEnableSmoothLines(
) → void - Enable line aliasing
-
rlEnableStatePointer(
int vertexAttribType, MemoryPointer< RVoid> buffer) → void - Enable attribute state pointer
-
rlEnableStereoRender(
) → void - Enable stereo rendering
-
rlEnableTexture(
int id) → void - Enable texture
-
rlEnableTextureCubemap(
int id) → void - Enable texture cubemap
-
rlEnableVertexArray(
int vaoId) → bool - Enable vertex array (VAO, if supported)
-
rlEnableVertexAttribute(
int index) → void - Enable vertex attribute index
-
rlEnableVertexBuffer(
int id) → void - Enable vertex buffer (VBO)
-
rlEnableVertexBufferElement(
int id) → void - Enable vertex buffer element (VBO element)
-
rlEnableWireMode(
) → void - Enable wire mode
-
rlEnd(
) → void - Finish vertex providing
-
rlFramebufferAttach(
int fboId, int texId, int attachType, int texType, int mipLevel) → void - Attach texture/renderbuffer to a framebuffer
-
rlFramebufferComplete(
int id) → bool - Verify framebuffer is complete
-
rlFrustum(
double left, double right, double bottom, double top, double znear, double zfar) → void - Multiply the current matrix by a perspective matrix generated by parameters
-
rlGenTextureMipmaps(
int id, int width, int height, int format, MemoryPointer< RInt32> mipmaps) → void - Generate mipmap data for selected texture
-
rlGetActiveFramebuffer(
) → int - Get the currently active render texture (fbo), 0 for default framebuffer
-
rlGetCullDistanceFar(
) → double - Get cull plane distance far
-
rlGetCullDistanceNear(
) → double - Get cull plane distance near
-
rlGetFramebufferHeight(
) → int - Get default framebuffer height
-
rlGetFramebufferWidth(
) → int - Get default framebuffer width
-
rlGetGlTextureFormats(
int format, MemoryPointer< RUint32> glInternalFormat, MemoryPointer<RUint32> glFormat, MemoryPointer<RUint32> glType) → void - Get OpenGL internal formats
-
rlGetLineWidth(
) → double - Get the line drawing width
-
rlGetLocationAttrib(
int shaderId, MemoryPointer< RInt8> attribName) → int - Get shader location attribute, requires shader program id
-
rlGetLocationUniform(
int shaderId, MemoryPointer< RInt8> uniformName) → int - Get shader location uniform, requires shader program id
-
rlGetMatrixModelview(
) → MatrixD - Get internal modelview matrix
-
rlGetMatrixProjection(
) → MatrixD - Get internal projection matrix
-
rlGetMatrixProjectionStereo(
int eye) → MatrixD - Get internal projection matrix for stereo render (selected eye)
-
rlGetMatrixTransform(
) → MatrixD - Get internal accumulated transform matrix
-
rlGetMatrixViewOffsetStereo(
int eye) → MatrixD - Get internal view offset matrix for stereo render (selected eye)
-
rlGetPixelFormatName(
int format) → MemoryPointer< RInt8> - Get name string for pixel format
-
rlGetPointSize(
) → double - Get the point drawing size
-
rlGetProcAddress(
MemoryPointer< RInt8> procName) → MemoryPointer<RVoid> - Get OpenGL procedure address
-
rlGetShaderBufferSize(
int id) → int - Get SSBO buffer size
-
rlGetShaderIdDefault(
) → int - Get default shader id
-
rlGetShaderLocsDefault(
) → MemoryPointer< RInt32> - Get default shader locations
-
rlGetTextureIdDefault(
) → int - Get default texture id
-
rlGetVersion(
) → int - Get current OpenGL version
-
rlglClose(
) → void - De-initialize rlgl (buffers, shaders, textures)
-
rlglInit(
int width, int height) → void - Initialize rlgl (buffers, shaders, textures, states)
-
rlIsStereoRenderEnabled(
) → bool - Check if stereo render is enabled
-
rlLoadDrawCube(
) → void - Load and draw a cube
-
rlLoadDrawQuad(
) → void - Load and draw a quad
-
rlLoadExtensions(
MemoryPointer< RVoid> loader) → void - Load OpenGL extensions (loader function required)
-
rlLoadFramebuffer(
) → int - Load an empty framebuffer
-
rlLoadIdentity(
) → void - Reset current matrix to identity matrix
-
rlLoadRenderBatch(
int numBuffers, int bufferElements) → RlRenderBatchD - Load a render batch system
-
rlLoadShader(
MemoryPointer< RInt8> code, int type) → int - Load (compile) shader and return shader id
-
rlLoadShaderBuffer(
int size, MemoryPointer< RVoid> data, int usageHint) → int - Load shader storage buffer object (SSBO)
-
rlLoadShaderProgram(
MemoryPointer< RInt8> vsCode, MemoryPointer<RInt8> fsCode) → int - Load shader from code strings
-
rlLoadShaderProgramCompute(
int csId) → int - Load compute shader program
-
rlLoadShaderProgramEx(
int vsId, int fsId) → int - Load shader program, using already loaded shader ids
-
rlLoadTexture(
MemoryPointer< RVoid> data, int width, int height, int format, int mipmapCount) → int - Load texture data
-
rlLoadTextureCubemap(
MemoryPointer< RVoid> data, int size, int format, int mipmapCount) → int - Load texture cubemap data
-
rlLoadTextureDepth(
int width, int height, bool useRenderBuffer) → int - Load depth texture/renderbuffer (to be attached to fbo)
-
rlLoadVertexArray(
) → int - Load vertex array (vao) if supported
-
rlLoadVertexBuffer(
MemoryPointer< RVoid> buffer, int size, bool dynamic) → int - Load a vertex buffer object
-
rlLoadVertexBufferElement(
MemoryPointer< RVoid> buffer, int size, bool dynamic) → int - Load vertex buffer elements object
-
rlMatrixMode(
int mode) → void - Choose the current matrix to be transformed
-
rlMultMatrixf(
MemoryPointer< RFloat32> matf) → void - Multiply the current matrix by another matrix
-
rlNormal3f(
double x, double y, double z) → void - Define one vertex (normal) - 3 float
-
rlOrtho(
double left, double right, double bottom, double top, double znear, double zfar) → void - Multiply the current matrix by an orthographic matrix generated by parameters
-
rlPopMatrix(
) → void - Pop latest inserted matrix from stack
-
rlPushMatrix(
) → void - Push the current matrix to stack
-
rlReadScreenPixels(
int width, int height) → MemoryPointer< RUint8> - Read screen pixel data (color buffer)
-
rlReadShaderBuffer(
int id, MemoryPointer< RVoid> dest, int count, int offset) → void - Read SSBO buffer data (GPU->CPU)
-
rlReadTexturePixels(
int id, int width, int height, int format) → MemoryPointer< RVoid> - Read texture pixel data
-
rlResizeFramebuffer(
int width, int height) → void - Resize internal framebuffer
-
rlRotatef(
double angle, double x, double y, double z) → void - Multiply the current matrix by a rotation matrix
-
rlScalef(
double x, double y, double z) → void - Multiply the current matrix by a scaling matrix
-
rlScissor(
int x, int y, int width, int height) → void - Scissor test
-
rlSetBlendFactors(
int glSrcFactor, int glDstFactor, int glEquation) → void - Set blending mode factor and equation (using OpenGL factors)
-
rlSetBlendFactorsSeparate(
int glSrcRGB, int glDstRGB, int glSrcAlpha, int glDstAlpha, int glEqRGB, int glEqAlpha) → void - Set blending mode factors and equations separately (using OpenGL factors)
-
rlSetBlendMode(
int mode) → void - Set blending mode
-
rlSetClipPlanes(
double nearPlane, double farPlane) → void - Set clip planes distances
-
rlSetCullFace(
int mode) → void - Set face culling mode
-
rlSetFramebufferHeight(
int height) → void - Set current framebuffer height
-
rlSetFramebufferWidth(
int width) → void - Set current framebuffer width
-
rlSetLineWidth(
double width) → void - Set the line drawing width
-
rlSetMatrixModelview(
MatrixD view) → void - Set a custom modelview matrix (replaces internal modelview matrix)
-
rlSetMatrixProjection(
MatrixD proj) → void - Set a custom projection matrix (replaces internal projection matrix)
-
rlSetMatrixProjectionStereo(
MatrixD right, MatrixD left) → void - Set eyes projection matrices for stereo rendering
-
rlSetMatrixViewOffsetStereo(
MatrixD right, MatrixD left) → void - Set eyes view offsets matrices for stereo rendering
-
rlSetPointSize(
double size) → void - Set the point drawing size
-
rlSetRenderBatchActive(
StructPointer< RlRenderBatchD> batch) → void - Set the active render batch for rlgl (NULL for default internal)
-
rlSetShader(
int id, MemoryPointer< RInt32> locs) → void - Set shader currently active (id and locations)
-
rlSetTexture(
int id) → void - Set current texture for render batch and check buffers limits
-
rlSetUniform(
int locIndex, MemoryPointer< RVoid> value, int uniformType, int count) → void - Set shader value uniform
-
rlSetUniformMatrices(
int locIndex, StructPointer< MatrixD> mat, int count) → void - Set shader value matrices
-
rlSetUniformMatrix(
int locIndex, MatrixD mat) → void - Set shader value matrix
-
rlSetUniformSampler(
int locIndex, int textureId) → void - Set shader value sampler
-
rlSetVertexAttribute(
int index, int compSize, int type, bool normalized, int stride, int offset) → void - Set vertex attribute data configuration
-
rlSetVertexAttributeDefault(
int locIndex, MemoryPointer< RVoid> value, int attribType, int count) → void - Set vertex attribute default value, when attribute to provided
-
rlSetVertexAttributeDivisor(
int index, int divisor) → void - Set vertex attribute data divisor
-
rlTexCoord2f(
double x, double y) → void - Define one vertex (texture coordinate) - 2 float
-
rlTextureParameters(
int id, int param, int value) → void - Set texture parameters (filter, wrap)
-
rlTranslatef(
double x, double y, double z) → void - Multiply the current matrix by a translation matrix
-
rlUnloadFramebuffer(
int id) → void - Delete framebuffer from GPU
-
rlUnloadRenderBatch(
RlRenderBatchD batch) → void - Unload render batch system
-
rlUnloadShader(
int id) → void - Unload shader, loaded with rlLoadShader();
-
rlUnloadShaderBuffer(
int ssboId) → void - Unload shader storage buffer object (SSBO)
-
rlUnloadShaderProgram(
int id) → void - Unload shader program
-
rlUnloadTexture(
int id) → void - Unload texture from GPU memory
-
rlUnloadVertexArray(
int vaoId) → void - Unload vertex array (vao)
-
rlUnloadVertexBuffer(
int vboId) → void - Unload vertex buffer object
-
rlUpdateShaderBuffer(
int id, MemoryPointer< RVoid> data, int dataSize, int offset) → void - Update SSBO buffer data
-
rlUpdateTexture(
int id, int offsetX, int offsetY, int width, int height, int format, MemoryPointer< RVoid> data) → void - Update texture with new data on GPU
-
rlUpdateVertexBuffer(
int bufferId, MemoryPointer< RVoid> data, int dataSize, int offset) → void - Update vertex buffer object data on GPU buffer
-
rlUpdateVertexBufferElements(
int id, MemoryPointer< RVoid> data, int dataSize, int offset) → void - Update vertex buffer elements data on GPU buffer
-
rlVertex2f(
double x, double y) → void - Define one vertex (position) - 2 float
-
rlVertex2i(
int x, int y) → void - Define one vertex (position) - 2 int
-
rlVertex3f(
double x, double y, double z) → void - Define one vertex (position) - 3 float
-
rlViewport(
int x, int y, int width, int height) → void - Set the viewport area
-
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited