RaylibRlglModuleDebugLabels class

Produces human-readable debug strings for each Rlgl module function call, logged to the console when debug output is enabled.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

EnumsAsFlagsOr(Iterable<RaylibEnum> flags) String
Formats flags as a |-separated string of enum names, mirroring C bitflag notation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rlActiveDrawBuffers(num count) String
Label for RaylibRlglModuleBase.rlActiveDrawBuffers.
rlActiveTextureSlot(num slot) String
Label for RaylibRlglModuleBase.rlActiveTextureSlot.
rlBegin(RlDrawMode mode) String
Label for RaylibRlglModuleBase.rlBegin.
rlBindFramebuffer(num target, num framebuffer) String
Label for RaylibRlglModuleBase.rlBindFramebuffer.
rlBindImageTexture(num id, num index, PixelFormat format, bool readonly) String
Label for RaylibRlglModuleBase.rlBindImageTexture.
rlBindShaderBuffer(num id, num index) String
Label for RaylibRlglModuleBase.rlBindShaderBuffer.
rlBlitFramebuffer(num srcX, num srcY, num srcWidth, num srcHeight, num dstX, num dstY, num dstWidth, num dstHeight, num bufferMask) String
Label for RaylibRlglModuleBase.rlBlitFramebuffer.
rlCheckErrors() String
Label for RaylibRlglModuleBase.rlCheckErrors.
rlCheckRenderBatchLimit(num vCount) String
Label for RaylibRlglModuleBase.rlCheckRenderBatchLimit.
rlClearColor(num r, num g, num b, num a) String
Label for RaylibRlglModuleBase.rlClearColor.
rlClearScreenBuffers() String
Label for RaylibRlglModuleBase.rlClearScreenBuffers.
rlColor3f(num x, num y, num z) String
Label for RaylibRlglModuleBase.rlColor3f.
rlColor4f(num x, num y, num z, num w) String
Label for RaylibRlglModuleBase.rlColor4f.
rlColor4ub(num r, num g, num b, num a) String
Label for RaylibRlglModuleBase.rlColor4ub.
rlColorMask(bool r, bool g, bool b, bool a) String
Label for RaylibRlglModuleBase.rlColorMask.
rlCompileShader(String shaderCode, RlShaderType type) String
Label for RaylibRlglModuleBase.rlCompileShader.
rlComputeShaderDispatch(num groupX, num groupY, num groupZ) String
Label for RaylibRlglModuleBase.rlComputeShaderDispatch.
rlCopyShaderBuffer(num destId, num srcId, num destOffset, num srcOffset, num count) String
Label for RaylibRlglModuleBase.rlCopyShaderBuffer.
rlCubemapParameters(num id, num param, num value) String
Label for RaylibRlglModuleBase.rlCubemapParameters.
rlDisableBackfaceCulling() String
Label for RaylibRlglModuleBase.rlDisableBackfaceCulling.
rlDisableColorBlend() String
Label for RaylibRlglModuleBase.rlDisableColorBlend.
rlDisableDepthMask() String
Label for RaylibRlglModuleBase.rlDisableDepthMask.
rlDisableDepthTest() String
Label for RaylibRlglModuleBase.rlDisableDepthTest.
rlDisableFramebuffer() String
Label for RaylibRlglModuleBase.rlDisableFramebuffer.
rlDisableScissorTest() String
Label for RaylibRlglModuleBase.rlDisableScissorTest.
rlDisableShader() String
Label for RaylibRlglModuleBase.rlDisableShader.
rlDisableSmoothLines() String
Label for RaylibRlglModuleBase.rlDisableSmoothLines.
rlDisableStereoRender() String
Label for RaylibRlglModuleBase.rlDisableStereoRender.
rlDisableTexture() String
Label for RaylibRlglModuleBase.rlDisableTexture.
rlDisableTextureCubemap() String
Label for RaylibRlglModuleBase.rlDisableTextureCubemap.
rlDisableVertexArray() String
Label for RaylibRlglModuleBase.rlDisableVertexArray.
rlDisableVertexAttribute(num index) String
Label for RaylibRlglModuleBase.rlDisableVertexAttribute.
rlDisableVertexBuffer() String
Label for RaylibRlglModuleBase.rlDisableVertexBuffer.
rlDisableVertexBufferElement() String
Label for RaylibRlglModuleBase.rlDisableVertexBufferElement.
rlDisableWireMode() String
Label for RaylibRlglModuleBase.rlDisableWireMode.
rlDrawRenderBatch(RlRenderBatchBase<RlRenderBatchBase<dynamic, RlVertexBufferBase, RlDrawCallBase>, RlVertexBufferBase, RlDrawCallBase> batch) String
Label for RaylibRlglModuleBase.rlDrawRenderBatch.
rlDrawRenderBatchActive() String
Label for RaylibRlglModuleBase.rlDrawRenderBatchActive.
rlDrawVertexArray(num offset, num count) String
Label for RaylibRlglModuleBase.rlDrawVertexArray.
rlDrawVertexArrayElements(num offset, num count, Uint16List buffer) String
Label for RaylibRlglModuleBase.rlDrawVertexArrayElements.
rlDrawVertexArrayElementsInstanced(num offset, num count, Uint16List buffer, num instances) String
Label for RaylibRlglModuleBase.rlDrawVertexArrayElementsInstanced.
rlDrawVertexArrayInstanced(num offset, num count, num instances) String
Label for RaylibRlglModuleBase.rlDrawVertexArrayInstanced.
rlEnableBackfaceCulling() String
Label for RaylibRlglModuleBase.rlEnableBackfaceCulling.
rlEnableColorBlend() String
Label for RaylibRlglModuleBase.rlEnableColorBlend.
rlEnableDepthMask() String
Label for RaylibRlglModuleBase.rlEnableDepthMask.
rlEnableDepthTest() String
Label for RaylibRlglModuleBase.rlEnableDepthTest.
rlEnableFramebuffer(num id) String
Label for RaylibRlglModuleBase.rlEnableFramebuffer.
rlEnablePointMode() String
Label for RaylibRlglModuleBase.rlEnablePointMode.
rlEnableScissorTest() String
Label for RaylibRlglModuleBase.rlEnableScissorTest.
rlEnableShader(num id) String
Label for RaylibRlglModuleBase.rlEnableShader.
rlEnableSmoothLines() String
Label for RaylibRlglModuleBase.rlEnableSmoothLines.
rlEnableStereoRender() String
Label for RaylibRlglModuleBase.rlEnableStereoRender.
rlEnableTexture(num id) String
Label for RaylibRlglModuleBase.rlEnableTexture.
rlEnableTextureCubemap(num id) String
Label for RaylibRlglModuleBase.rlEnableTextureCubemap.
rlEnableVertexArray(num vaoId) String
Label for RaylibRlglModuleBase.rlEnableVertexArray.
rlEnableVertexAttribute(num index) String
Label for RaylibRlglModuleBase.rlEnableVertexAttribute.
rlEnableVertexBuffer(num id) String
Label for RaylibRlglModuleBase.rlEnableVertexBuffer.
rlEnableVertexBufferElement(num id) String
Label for RaylibRlglModuleBase.rlEnableVertexBufferElement.
rlEnableWireMode() String
Label for RaylibRlglModuleBase.rlEnableWireMode.
rlEnd() String
Label for RaylibRlglModuleBase.rlEnd.
rlFramebufferAttach(num fboId, num texId, RlFramebufferAttachType attachType, RlFramebufferAttachTextureType texType, num mipLevel) String
Label for RaylibRlglModuleBase.rlFramebufferAttach.
rlFramebufferComplete(num id) String
Label for RaylibRlglModuleBase.rlFramebufferComplete.
rlFrustum(num left, num right, num bottom, num top, num znear, num zfar) String
Label for RaylibRlglModuleBase.rlFrustum.
rlGenTextureMipmaps(num id, num width, num height, PixelFormat format) String
Label for RaylibRlglModuleBase.rlGenTextureMipmaps.
rlGetActiveFramebuffer() String
Label for RaylibRlglModuleBase.rlGetActiveFramebuffer.
rlGetCullDistanceFar() String
Label for RaylibRlglModuleBase.rlGetCullDistanceFar.
rlGetCullDistanceNear() String
Label for RaylibRlglModuleBase.rlGetCullDistanceNear.
rlGetFramebufferHeight() String
Label for RaylibRlglModuleBase.rlGetFramebufferHeight.
rlGetFramebufferWidth() String
Label for RaylibRlglModuleBase.rlGetFramebufferWidth.
rlGetGlTextureFormats(PixelFormat format) String
Label for RaylibRlglModuleBase.rlGetGlTextureFormats.
rlGetLineWidth() String
Label for RaylibRlglModuleBase.rlGetLineWidth.
rlGetLocationAttrib(num shaderId, String attribName) String
Label for RaylibRlglModuleBase.rlGetLocationAttrib.
rlGetLocationUniform(num shaderId, String uniformName) String
Label for RaylibRlglModuleBase.rlGetLocationUniform.
rlGetMatrixModelview() String
Label for RaylibRlglModuleBase.rlGetMatrixModelview.
rlGetMatrixProjection() String
Label for RaylibRlglModuleBase.rlGetMatrixProjection.
rlGetMatrixProjectionStereo(num eye) String
Label for RaylibRlglModuleBase.rlGetMatrixProjectionStereo.
rlGetMatrixTransform() String
Label for RaylibRlglModuleBase.rlGetMatrixTransform.
rlGetMatrixViewOffsetStereo(num eye) String
Label for RaylibRlglModuleBase.rlGetMatrixViewOffsetStereo.
rlGetPixelFormatName(PixelFormat format) String
Label for RaylibRlglModuleBase.rlGetPixelFormatName.
rlGetShaderBufferSize(num id) String
Label for RaylibRlglModuleBase.rlGetShaderBufferSize.
rlGetShaderIdDefault() String
Label for RaylibRlglModuleBase.rlGetShaderIdDefault.
rlGetShaderLocsDefault() String
Label for RaylibRlglModuleBase.rlGetShaderLocsDefault.
rlGetTextureIdDefault() String
Label for RaylibRlglModuleBase.rlGetTextureIdDefault.
rlGetVersion() String
Label for RaylibRlglModuleBase.rlGetVersion.
rlglClose() String
Label for RaylibRlglModuleBase.rlglClose.
rlglInit(num width, num height) String
Label for RaylibRlglModuleBase.rlglInit.
rlIsStereoRenderEnabled() String
Label for RaylibRlglModuleBase.rlIsStereoRenderEnabled.
rlLoadComputeShaderProgram(num shaderId) String
Label for RaylibRlglModuleBase.rlLoadComputeShaderProgram.
rlLoadDrawCube() String
Label for RaylibRlglModuleBase.rlLoadDrawCube.
rlLoadDrawQuad() String
Label for RaylibRlglModuleBase.rlLoadDrawQuad.
rlLoadFramebuffer() String
Label for RaylibRlglModuleBase.rlLoadFramebuffer.
rlLoadIdentity() String
Label for RaylibRlglModuleBase.rlLoadIdentity.
rlLoadRenderBatch(num numBuffers, num bufferElements) String
Label for RaylibRlglModuleBase.rlLoadRenderBatch.
rlLoadShaderBuffer(num size, TypedDataList? data, RlUsageHint? usageHint) String
Label for RaylibRlglModuleBase.rlLoadShaderBuffer.
rlLoadShaderCode(String? vsCode, String? fsCode) String
Label for RaylibRlglModuleBase.rlLoadShaderCode.
rlLoadShaderProgram(num vShaderId, num fShaderId) String
Label for RaylibRlglModuleBase.rlLoadShaderProgram.
rlLoadTexture(Uint8List? data, num width, num height, PixelFormat format, num mipmapCount) String
Label for RaylibRlglModuleBase.rlLoadTexture.
rlLoadTextureCubemap(Uint8List? data, num size, PixelFormat format, num mipmapCount) String
Label for RaylibRlglModuleBase.rlLoadTextureCubemap.
rlLoadTextureDepth(num width, num height, bool useRenderBuffer) String
Label for RaylibRlglModuleBase.rlLoadTextureDepth.
rlLoadVertexArray() String
Label for RaylibRlglModuleBase.rlLoadVertexArray.
rlLoadVertexBuffer(TypedDataList buffer, bool dynamic) String
Label for RaylibRlglModuleBase.rlLoadVertexBuffer.
rlLoadVertexBufferElement(TypedDataList buffer, bool dynamic) String
Label for RaylibRlglModuleBase.rlLoadVertexBufferElement.
rlMatrixMode(RlMatrixMode mode) String
Label for RaylibRlglModuleBase.rlMatrixMode.
rlMultMatrixf(List<double> matf) String
Label for RaylibRlglModuleBase.rlMultMatrixf.
rlNormal3f(num x, num y, num z) String
Label for RaylibRlglModuleBase.rlNormal3f.
rlOrtho(num left, num right, num bottom, num top, num znear, num zfar) String
Label for RaylibRlglModuleBase.rlOrtho.
rlPopMatrix() String
Label for RaylibRlglModuleBase.rlPopMatrix.
rlPushMatrix() String
Label for RaylibRlglModuleBase.rlPushMatrix.
rlReadScreenPixels(num width, num height) String
Label for RaylibRlglModuleBase.rlReadScreenPixels.
rlReadShaderBuffer(num id, num count, num offset) String
Label for RaylibRlglModuleBase.rlReadShaderBuffer.
rlReadTexturePixels(num id, num width, num height, PixelFormat format) String
Label for RaylibRlglModuleBase.rlReadTexturePixels.
rlRotatef(num angle, num x, num y, num z) String
Label for RaylibRlglModuleBase.rlRotatef.
rlScalef(num x, num y, num z) String
Label for RaylibRlglModuleBase.rlScalef.
rlScissor(num x, num y, num width, num height) String
Label for RaylibRlglModuleBase.rlScissor.
rlSetBlendFactors(num glSrcFactor, num glDstFactor, num glEquation) String
Label for RaylibRlglModuleBase.rlSetBlendFactors.
rlSetBlendFactorsSeparate(num glSrcRGB, num glDstRGB, num glSrcAlpha, num glDstAlpha, num glEqRGB, num glEqAlpha) String
Label for RaylibRlglModuleBase.rlSetBlendFactorsSeparate.
rlSetBlendMode(BlendMode mode) String
Label for RaylibRlglModuleBase.rlSetBlendMode.
rlSetClipPlanes(num nearPlane, num farPlane) String
Label for RaylibRlglModuleBase.rlSetClipPlanes.
rlSetCullFace(RlCullMode mode) String
Label for RaylibRlglModuleBase.rlSetCullFace.
rlSetFramebufferHeight(num height) String
Label for RaylibRlglModuleBase.rlSetFramebufferHeight.
rlSetFramebufferWidth(num width) String
Label for RaylibRlglModuleBase.rlSetFramebufferWidth.
rlSetLineWidth(num width) String
Label for RaylibRlglModuleBase.rlSetLineWidth.
rlSetMatrixModelview(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> view) String
Label for RaylibRlglModuleBase.rlSetMatrixModelview.
rlSetMatrixProjection(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> proj) String
Label for RaylibRlglModuleBase.rlSetMatrixProjection.
rlSetMatrixProjectionStereo(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> right, MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> left) String
Label for RaylibRlglModuleBase.rlSetMatrixProjectionStereo.
rlSetMatrixViewOffsetStereo(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> right, MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> left) String
Label for RaylibRlglModuleBase.rlSetMatrixViewOffsetStereo.
rlSetRenderBatchActive(RlRenderBatchBase<RlRenderBatchBase<dynamic, RlVertexBufferBase, RlDrawCallBase>, RlVertexBufferBase, RlDrawCallBase> batch) String
Label for RaylibRlglModuleBase.rlSetRenderBatchActive.
rlSetShader(num id, List<int> locs) String
Label for RaylibRlglModuleBase.rlSetShader.
rlSetTexture(num id) String
Label for RaylibRlglModuleBase.rlSetTexture.
rlSetUniform(num locIndex, TypedDataList value, RlShaderUniformDataType uniformType, num count) String
Label for RaylibRlglModuleBase.rlSetUniform.
rlSetUniformMatrices(num locIndex, List<MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base>> mat) String
Label for RaylibRlglModuleBase.rlSetUniformMatrices.
rlSetUniformMatrix(num locIndex, MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> mat) String
Label for RaylibRlglModuleBase.rlSetUniformMatrix.
rlSetUniformSampler(num locIndex, num textureId) String
Label for RaylibRlglModuleBase.rlSetUniformSampler.
rlSetVertexAttribute(num index, num compSize, num type, bool normalized, num stride, num offset) String
Label for RaylibRlglModuleBase.rlSetVertexAttribute.
rlSetVertexAttributeDefault(num locIndex, Float32List value, RlShaderAttributeDataType attribType) String
Label for RaylibRlglModuleBase.rlSetVertexAttributeDefault.
rlSetVertexAttributeDivisor(num index, num divisor) String
Label for RaylibRlglModuleBase.rlSetVertexAttributeDivisor.
rlTexCoord2f(num x, num y) String
Label for RaylibRlglModuleBase.rlTexCoord2f.
rlTextureParameters(num id, num param, num value) String
Label for RaylibRlglModuleBase.rlTextureParameters.
rlTranslatef(num x, num y, num z) String
Label for RaylibRlglModuleBase.rlTranslatef.
rlUnloadFramebuffer(num id) String
Label for RaylibRlglModuleBase.rlUnloadFramebuffer.
rlUnloadRenderBatch(RlRenderBatchBase<RlRenderBatchBase<dynamic, RlVertexBufferBase, RlDrawCallBase>, RlVertexBufferBase, RlDrawCallBase> batch) String
Label for RaylibRlglModuleBase.rlUnloadRenderBatch.
rlUnloadShaderBuffer(num ssboId) String
Label for RaylibRlglModuleBase.rlUnloadShaderBuffer.
rlUnloadShaderProgram(num id) String
Label for RaylibRlglModuleBase.rlUnloadShaderProgram.
rlUnloadTexture(num id) String
Label for RaylibRlglModuleBase.rlUnloadTexture.
rlUnloadVertexArray(num vaoId) String
Label for RaylibRlglModuleBase.rlUnloadVertexArray.
rlUnloadVertexBuffer(num vboId) String
Label for RaylibRlglModuleBase.rlUnloadVertexBuffer.
rlUpdateShaderBuffer(num id, TypedDataList data, num offset) String
Label for RaylibRlglModuleBase.rlUpdateShaderBuffer.
rlUpdateTexture(num id, num offsetX, num offsetY, num width, num height, PixelFormat format, Uint8List data) String
Label for RaylibRlglModuleBase.rlUpdateTexture.
rlUpdateVertexBuffer(num bufferId, TypedDataList data, num offset) String
Label for RaylibRlglModuleBase.rlUpdateVertexBuffer.
rlUpdateVertexBufferElements(num id, TypedDataList data, num offset) String
Label for RaylibRlglModuleBase.rlUpdateVertexBufferElements.
rlVertex2f(num x, num y) String
Label for RaylibRlglModuleBase.rlVertex2f.
rlVertex2i(num x, num y) String
Label for RaylibRlglModuleBase.rlVertex2i.
rlVertex3f(num x, num y, num z) String
Label for RaylibRlglModuleBase.rlVertex3f.
rlViewport(num x, num y, num width, num height) String
Label for RaylibRlglModuleBase.rlViewport.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited