RaylibRlglModuleExtras<R extends RaylibBase> mixin

Re-exports RaylibRlglConstants values as instance members, so constants are accessible directly on the module without a class qualifier.

Superclass constraints
Mixin applications

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rl → R
finalinherited
RL_BLEND_COLOR → int
See RaylibRlglConstants.RL_BLEND_COLOR.
no setter
RL_BLEND_DST_ALPHA → int
See RaylibRlglConstants.RL_BLEND_DST_ALPHA.
no setter
RL_BLEND_DST_RGB → int
See RaylibRlglConstants.RL_BLEND_DST_RGB.
no setter
RL_BLEND_EQUATION → int
See RaylibRlglConstants.RL_BLEND_EQUATION.
no setter
RL_BLEND_EQUATION_ALPHA → int
See RaylibRlglConstants.RL_BLEND_EQUATION_ALPHA.
no setter
RL_BLEND_EQUATION_RGB → int
See RaylibRlglConstants.RL_BLEND_EQUATION_RGB.
no setter
RL_BLEND_SRC_ALPHA → int
See RaylibRlglConstants.RL_BLEND_SRC_ALPHA.
no setter
RL_BLEND_SRC_RGB → int
See RaylibRlglConstants.RL_BLEND_SRC_RGB.
no setter
RL_COMPUTE_SHADER → int
See RaylibRlglConstants.RL_COMPUTE_SHADER.
no setter
RL_CONSTANT_ALPHA → int
See RaylibRlglConstants.RL_CONSTANT_ALPHA.
no setter
RL_CONSTANT_COLOR → int
See RaylibRlglConstants.RL_CONSTANT_COLOR.
no setter
RL_CULL_DISTANCE_FAR → double
See RaylibRlglConstants.RL_CULL_DISTANCE_FAR.
no setter
RL_CULL_DISTANCE_NEAR → double
See RaylibRlglConstants.RL_CULL_DISTANCE_NEAR.
no setter
RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFER_ELEMENTS.
no setter
RL_DEFAULT_BATCH_BUFFERS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFERS.
no setter
RL_DEFAULT_BATCH_DRAWCALLS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_DRAWCALLS.
no setter
RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
See RaylibRlglConstants.RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS.
no setter
RL_DRAW_FRAMEBUFFER → int
See RaylibRlglConstants.RL_DRAW_FRAMEBUFFER.
no setter
RL_DST_ALPHA → int
See RaylibRlglConstants.RL_DST_ALPHA.
no setter
RL_DST_COLOR → int
See RaylibRlglConstants.RL_DST_COLOR.
no setter
RL_DYNAMIC_COPY → int
See RaylibRlglConstants.RL_DYNAMIC_COPY.
no setter
RL_DYNAMIC_DRAW → int
See RaylibRlglConstants.RL_DYNAMIC_DRAW.
no setter
RL_DYNAMIC_READ → int
See RaylibRlglConstants.RL_DYNAMIC_READ.
no setter
RL_FLOAT → int
See RaylibRlglConstants.RL_FLOAT.
no setter
RL_FRAGMENT_SHADER → int
See RaylibRlglConstants.RL_FRAGMENT_SHADER.
no setter
RL_FUNC_ADD → int
See RaylibRlglConstants.RL_FUNC_ADD.
no setter
RL_FUNC_REVERSE_SUBTRACT → int
See RaylibRlglConstants.RL_FUNC_REVERSE_SUBTRACT.
no setter
RL_FUNC_SUBTRACT → int
See RaylibRlglConstants.RL_FUNC_SUBTRACT.
no setter
RL_LINES → int
See RaylibRlglConstants.RL_LINES.
no setter
RL_MAX → int
See RaylibRlglConstants.RL_MAX.
no setter
RL_MAX_MATRIX_STACK_SIZE → int
See RaylibRlglConstants.RL_MAX_MATRIX_STACK_SIZE.
no setter
RL_MAX_SHADER_LOCATIONS → int
See RaylibRlglConstants.RL_MAX_SHADER_LOCATIONS.
no setter
RL_MIN → int
See RaylibRlglConstants.RL_MIN.
no setter
RL_MODELVIEW → int
See RaylibRlglConstants.RL_MODELVIEW.
no setter
RL_ONE → int
See RaylibRlglConstants.RL_ONE.
no setter
RL_ONE_MINUS_CONSTANT_ALPHA → int
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_ALPHA.
no setter
RL_ONE_MINUS_CONSTANT_COLOR → int
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_COLOR.
no setter
RL_ONE_MINUS_DST_ALPHA → int
See RaylibRlglConstants.RL_ONE_MINUS_DST_ALPHA.
no setter
RL_ONE_MINUS_DST_COLOR → int
See RaylibRlglConstants.RL_ONE_MINUS_DST_COLOR.
no setter
RL_ONE_MINUS_SRC_ALPHA → int
See RaylibRlglConstants.RL_ONE_MINUS_SRC_ALPHA.
no setter
RL_ONE_MINUS_SRC_COLOR → int
See RaylibRlglConstants.RL_ONE_MINUS_SRC_COLOR.
no setter
RL_PROJECTION → int
See RaylibRlglConstants.RL_PROJECTION.
no setter
RL_QUADS → int
See RaylibRlglConstants.RL_QUADS.
no setter
RL_READ_FRAMEBUFFER → int
See RaylibRlglConstants.RL_READ_FRAMEBUFFER.
no setter
RL_SHADER_LOC_MAP_DIFFUSE → int
See RaylibRlglConstants.RL_SHADER_LOC_MAP_DIFFUSE.
no setter
RL_SHADER_LOC_MAP_SPECULAR → int
See RaylibRlglConstants.RL_SHADER_LOC_MAP_SPECULAR.
no setter
RL_SRC_ALPHA → int
See RaylibRlglConstants.RL_SRC_ALPHA.
no setter
RL_SRC_ALPHA_SATURATE → int
See RaylibRlglConstants.RL_SRC_ALPHA_SATURATE.
no setter
RL_SRC_COLOR → int
See RaylibRlglConstants.RL_SRC_COLOR.
no setter
RL_STATIC_COPY → int
See RaylibRlglConstants.RL_STATIC_COPY.
no setter
RL_STATIC_DRAW → int
See RaylibRlglConstants.RL_STATIC_DRAW.
no setter
RL_STATIC_READ → int
See RaylibRlglConstants.RL_STATIC_READ.
no setter
RL_STREAM_COPY → int
See RaylibRlglConstants.RL_STREAM_COPY.
no setter
RL_STREAM_DRAW → int
See RaylibRlglConstants.RL_STREAM_DRAW.
no setter
RL_STREAM_READ → int
See RaylibRlglConstants.RL_STREAM_READ.
no setter
RL_TEXTURE → int
See RaylibRlglConstants.RL_TEXTURE.
no setter
RL_TEXTURE_FILTER_ANISOTROPIC → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_ANISOTROPIC.
no setter
RL_TEXTURE_FILTER_LINEAR → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR.
no setter
RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST.
no setter
RL_TEXTURE_FILTER_MIP_LINEAR → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_LINEAR.
no setter
RL_TEXTURE_FILTER_MIP_NEAREST → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_NEAREST.
no setter
RL_TEXTURE_FILTER_NEAREST → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST.
no setter
RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR.
no setter
RL_TEXTURE_MAG_FILTER → int
See RaylibRlglConstants.RL_TEXTURE_MAG_FILTER.
no setter
RL_TEXTURE_MIN_FILTER → int
See RaylibRlglConstants.RL_TEXTURE_MIN_FILTER.
no setter
RL_TEXTURE_MIPMAP_BIAS_RATIO → int
See RaylibRlglConstants.RL_TEXTURE_MIPMAP_BIAS_RATIO.
no setter
RL_TEXTURE_WRAP_CLAMP → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_CLAMP.
no setter
RL_TEXTURE_WRAP_MIRROR_CLAMP → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_CLAMP.
no setter
RL_TEXTURE_WRAP_MIRROR_REPEAT → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_REPEAT.
no setter
RL_TEXTURE_WRAP_REPEAT → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_REPEAT.
no setter
RL_TEXTURE_WRAP_S → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_S.
no setter
RL_TEXTURE_WRAP_T → int
See RaylibRlglConstants.RL_TEXTURE_WRAP_T.
no setter
RL_TRIANGLES → int
See RaylibRlglConstants.RL_TRIANGLES.
no setter
RL_UNSIGNED_BYTE → int
See RaylibRlglConstants.RL_UNSIGNED_BYTE.
no setter
RL_VERTEX_SHADER → int
See RaylibRlglConstants.RL_VERTEX_SHADER.
no setter
RL_ZERO → int
See RaylibRlglConstants.RL_ZERO.
no setter
RLGL_VERSION → String
See RaylibRlglConstants.RLGL_VERSION.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited