copy method

D copy()

Returns a deep copy of this instance without op.

Useful when you need an independent value that should not accidentally sync back into owned memory.

Implementation

D copy() {
  final clone = this.clone();
  clone.op = null;
  return clone;
}