copy method

  1. @override
D copy()
override

Returns a deep copy of this instance without originalPointer.

Useful when you need an independent value that should not accidentally sync back into raylib-owned memory.

Implementation

@override
D copy() {
  final clone = this.clone();
  clone.originalPointer = null;
  return clone;
}