copy method

  1. @override
  2. @nonVirtual
D copy()
override

Returns a deep copy of this instance without op.

Useful when you need an independent value that should not accidentally sync back into owned memory.

Implementation

@override
@nonVirtual
D copy() => clone();