internalId property

int? internalId
getter/setter pair

A stable numeric ID assigned on first RaylibTempStructAllocatorBase.PointerTo call for pointer-owning structs.

Incorporated into slot keys to prevent collisions between distinct instances of the same struct type sharing the same tag.

Implementation

int? internalId;