isFirstSync property
Used to full sync once to push pre-promotion Dart state to memory on the first RaylibTempStructAllocator.Allocate allocation.
Implementation
bool isFirstSync = true;
Used to full sync once to push pre-promotion Dart state to memory on the first RaylibTempStructAllocator.Allocate allocation.
bool isFirstSync = true;