clone method
Returns a deep copy of this instance, preserving op if present.
Implementation
@override
RenderTextureD clone() => .new(
op: op,
id: id,
texture: texture.clone(),
depth: depth.clone(),
);
Returns a deep copy of this instance, preserving op if present.
@override
RenderTextureD clone() => .new(
op: op,
id: id,
texture: texture.clone(),
depth: depth.clone(),
);