pointer property
Scratch memory for this claim, cast to Y. Contents are short-lived
and undefined once release is called or a nested MemoryScratch.acquire
invalidates the stack ordering guarantee.
Implementation
final MemoryPointer<Y> pointer;
Scratch memory for this claim, cast to Y. Contents are short-lived
and undefined once release is called or a nested MemoryScratch.acquire
invalidates the stack ordering guarantee.
final MemoryPointer<Y> pointer;