StructCodec<E extends RaylibStruct<E>> class

Inheritance
Mixed-in types

Constructors

StructCodec(RStruct type)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pointer → StructPointerFactory<E>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RStruct
finalinherited

Methods

allocate(RaylibTemp<RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void
inherited
allocator(RaylibTemp<RaylibBase> temp) → RaylibTempAllocator<RType>?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(MemoryPointer<RType> p) → E
override
readArray(MemoryPointer<RType> p, int count) → List<E>
override
toString() → String
A string representation of this object.
inherited
write(MemoryPointer<RType> p, E value) → void
override
writeArray(MemoryPointer<RType> p, List<E> values) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited