StructFieldBase<E> class abstract

Implementers

Constructors

StructFieldBase(int offset)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
offset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate(RaylibTemp<RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(MemoryPointer<RType> p) → E
readOr(MemoryPointer<RType>? p, E fallback) → E
toString() → String
A string representation of this object.
inherited
write(MemoryPointer<RType> p, E value) → E
writeOr(MemoryPointer<RType>? p, E value) → E

Operators

operator ==(Object other) → bool
The equality operator.
inherited