offset method
Returns the byte offset of field within the struct.
Implementation
int offset(F field) {
_checkField(field);
return offsets[field]!;
}
Returns the byte offset of field within the struct.
int offset(F field) {
_checkField(field);
return offsets[field]!;
}