pointerPointerStructArray<T extends RaylibStruct<T>> method

StructPointerArrayField<T, RPointer<RStruct>> pointerPointerStructArray<T extends RaylibStruct<T>>(
  1. F f
)

Creates a pointer-to-pointer struct array field for f.

The field represents a C-style T**: an outer pointer points to pointers, and each inner pointer points to a nested struct.

pointerFactory creates the Dart wrapper used to access each target struct.

Implementation

StructPointerArrayField<T, RPointer<RStruct>> pointerPointerStructArray<T extends RaylibStruct<T>>(F f) {
  _checkField(f);
  final type = _getFieldAs<RPointer<RPointer<RStruct>>>(f);
  final structCodec = StructCodec<T>(type.target.target);
  final innerPointerCodec = PointerCodec(type.target, structCodec);
  final pointerCodec = PointerCodec(type, innerPointerCodec);
  return .new(offset(f), pointerCodec);
}