allocationKey property

  1. @override
String? get allocationKey
override

The key of the temporary allocation backing this pointer.

null when this pointer is not associated with a tracked temporary allocation.

Implementation

@override
String? get allocationKey => ptr.allocationKey;