StructValueField<E, R extends RType> class

Inheritance
Available extensions

Constructors

StructValueField(int offset, ElementCodec<E, R> codec)
const

Properties

codec → ElementCodec<E, R>
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate(RaylibTemp<RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void
override
live(MemoryPointer<RType>? ptrOf(), List<E> initial) → StructLiveList<E, R>

Available on StructValueField<List<E>, RArray<R>>, provided by the LiveArrayFieldX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(MemoryPointer<RType> p) → E
override
readOr(MemoryPointer<RType>? p, E fallback) → E
inherited
toString() → String
A string representation of this object.
inherited
write(MemoryPointer<RType> p, E value) → E
override
writeOr(MemoryPointer<RType>? p, E value) → E
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited