TraceLogLevel enum

Raylib TraceLogLevel enum.

Inheritance
Available extensions

Values

LOG_ALL → const TraceLogLevel

LOG_ALL

const TraceLogLevel(0)
LOG_TRACE → const TraceLogLevel

LOG_TRACE

const TraceLogLevel(1)
LOG_DEBUG → const TraceLogLevel

LOG_DEBUG

const TraceLogLevel(2)
LOG_INFO → const TraceLogLevel

LOG_INFO

const TraceLogLevel(3)
LOG_WARNING → const TraceLogLevel

LOG_WARNING

const TraceLogLevel(4)
LOG_ERROR → const TraceLogLevel

LOG_ERROR

const TraceLogLevel(5)
LOG_FATAL → const TraceLogLevel

LOG_FATAL

const TraceLogLevel(6)
LOG_NONE → const TraceLogLevel

LOG_NONE

const TraceLogLevel(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) TraceLogLevel
Returns the TraceLogLevel for the given native value.

Constants

values → const List<TraceLogLevel>
A constant List of the values in this enum, in order of their declaration.