Vector3Base<V3 extends Vector3Base<V3, M, Q, V4> , M extends MatrixBase<M, V3, Q, V4> , Q extends QuaternionBase<Q, M, V3, V4> , V4 extends Vector4Base<V4, Q, M, V3> > mixin
Backend-agnostic contract for Vector3Base structs.
Must be mixed into every concrete platform implementation of a Raylib type to ensure a unified API surface across different backends.
- Superclass constraints
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → double
-
no setter
- lengthSqr → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
- z ↔ double
-
getter/setter pair
Methods
-
add(
V3 o) → V3 -
addValue(
num value) → V3 -
angle(
V3 o) → double -
clamp(
V3 min, V3 max) → V3 -
clampValue(
double min, double max) → V3 -
clone(
) → V3 -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
inherited
-
copy(
) → V3 -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
crossProduct(
V3 o) → V3 -
cubicHermite(
V3 tangent1, V3 v2, V3 tangent2, double amount) → V3 -
distance(
V3 o) → double -
distanceSqr(
V3 o) → double -
div(
V3 o) → V3 -
divideBy(
num o) → V3 -
dotProduct(
V3 o) → double -
equals(
V3 o) → bool -
format(
[int x0 = 0, int? y0, int? z0]) → String -
invert(
) → V3 -
lerp(
V3 o, double amount) → V3 -
max(
V3 o) → V3 -
min(
V3 o) → V3 -
moveTowards(
V3 target, double maxDistance) → V3 -
mul(
V3 o) → V3 -
negate(
) → V3 -
normalize(
) → V3 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orthoNormalize(
V3 o) → V3 -
project(
V3 o) → V3 -
reflect(
V3 normal) → V3 -
refract(
V3 n, double r) → V3 -
reject(
V3 o) → V3 -
rotateByAxisAngle(
V3 axis, double angle) → V3 -
rotateByQuaternion(
Q q) → V3 -
scale(
num o) → V3 -
set(
num x, num y, num z) → V3 -
setD(
V3 o) → V3 -
Copies the fields of
ointo this instance and returnsthis.inherited -
signature(
) → String -
Returns a human-readable representation of this struct's current field values.
override
-
sub(
V3 o) → V3 -
subValue(
num value) → V3 -
toArray(
) → List< double> -
toString(
) → String -
A string representation of this object.
inherited
-
transform(
M o) → V3 -
unproject(
M projection, M view) → V3
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited