VrStereoConfigD class
VrStereoConfig, VR stereo rendering configuration for simulator
- Inheritance
-
- Object
- RaylibStruct<
VrStereoConfigD> - VrStereoConfigD
Constructors
-
VrStereoConfigD({StructPointer<
VrStereoConfigD> ? op, List<MatrixD> ? projection, List<MatrixD> ? viewOffset, List<double> ? leftLensCenter, List<double> ? rightLensCenter, List<double> ? leftScreenCenter, List<double> ? rightScreenCenter, List<double> ? scale, List<double> ? scaleIn}) - VrStereoConfigD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leftLensCenter
↔ StructLiveList<
double, RFloat> -
VR left lens center
getter/setter pair
-
leftScreenCenter
↔ StructLiveList<
double, RFloat> -
VR left screen center
getter/setter pair
-
op
↔ StructPointer<
VrStereoConfigD> ? -
The C-owned or RaylibTemp-owned typed pointer for this struct, if any.
getter/setter pairinherited
- paramsCount → int
-
Number of components in the projection, viewOffset, leftLensCenter, rightLensCenter, leftScreenCenter, rightScreenCenter, scale and scaleIn arrays.
no setter
-
projection
↔ StructLiveListStruct<
MatrixD> -
VR projection matrices (per eye)
getter/setter pair
-
rightLensCenter
↔ StructLiveList<
double, RFloat> -
VR right lens center
getter/setter pair
-
rightScreenCenter
↔ StructLiveList<
double, RFloat> -
VR right screen center
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scale
↔ StructLiveList<
double, RFloat> -
VR distortion scale
getter/setter pair
-
scaleIn
↔ StructLiveList<
double, RFloat> -
VR distortion scale in
getter/setter pair
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
-
viewOffset
↔ StructLiveListStruct<
MatrixD> -
VR view offset matrices (per eye)
getter/setter pair
Methods
-
clone(
) → VrStereoConfigD -
Returns a deep copy of this instance, preserving op if present.
override
-
copy(
) → VrStereoConfigD -
Returns a deep copy of this instance without op.
inherited
-
getOp(
) → StructPointer< VrStereoConfigD> -
Returns op, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOpAndDispose(
) → StructPointer< VrStereoConfigD> -
Returns op and immediately disposes this struct.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDart(
VrStereoConfigD o) → VrStereoConfigD -
Copies the fields of
ointo this instance.override -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
structAllocateInto(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.inherited -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears op.
inherited
-
structOnOp(
void callback(StructPointer< VrStereoConfigD> p)) → void -
Calls
callbackwith op if it is set, otherwise no-ops.inherited -
structReadFrom(
MemoryPointer< RType> p) → void -
override
-
structSetTag(
String newTag) → VrStereoConfigD -
Sets RaylibTempStructState.tag to
newTag.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires op.
inherited
-
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires op.
inherited
-
structWriteInto(
MemoryPointer< RType> p) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_paramsCount → int
-
Number of components in the projection, viewOffset, leftLensCenter, rightLensCenter, leftScreenCenter, rightScreenCenter, scale and scaleIn arrays.
no setter
-
field_leftLensCenter
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for leftLensCenter.
final
-
field_leftScreenCenter
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for leftScreenCenter.
final
-
field_projection
→ StructValueField<
List< MatrixD> , RArray<RStruct> > -
Field descriptor for projection.
final
-
field_rightLensCenter
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for rightLensCenter.
final
-
field_rightScreenCenter
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for rightScreenCenter.
final
-
field_scale
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for scale.
final
-
field_scaleIn
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for scaleIn.
final
-
field_viewOffset
→ StructValueField<
List< MatrixD> , RArray<RStruct> > -
Field descriptor for viewOffset.
final
-
struct
→ StructType<
VrStereoConfigD> -
Describes the raw memory layout, construction, and pointer representation
of this struct type.
final
-
structLayout
→ StructLayout<
VrStereoConfigField> -
Raw memory layout of this object.
final