core/modules/core/abbr_dart
library
Functions
-
BeginBlendMode(BlendMode mode)
→ void
-
See RaylibCoreDart.BeginBlendMode.
-
BeginDrawing()
→ void
-
See RaylibCoreDart.BeginDrawing.
-
BeginMode2D(Camera2DD camera)
→ void
-
See RaylibCoreDart.BeginMode2D.
-
BeginMode3D(Camera3DD camera)
→ void
-
See RaylibCoreDart.BeginMode3D.
-
BeginScissorMode(num x, num y, num width, num height)
→ void
-
See RaylibCoreDart.BeginScissorMode.
-
BeginShaderMode(ShaderD shader)
→ void
-
See RaylibCoreDart.BeginShaderMode.
-
BeginTextureMode(RenderTextureD target)
→ void
-
See RaylibCoreDart.BeginTextureMode.
-
BeginVrStereoMode(VrStereoConfigD config)
→ void
-
See RaylibCoreDart.BeginVrStereoMode.
-
ChangeDirectory(String dir)
→ bool
-
See RaylibCoreDart.ChangeDirectory.
-
CheckCollisionBoxes(BoundingBoxD box1, BoundingBoxD box2)
→ bool
-
See RaylibCoreDart.CheckCollisionBoxes.
-
CheckCollisionBoxSphere(BoundingBoxD box, Vector3D center, num radius)
→ bool
-
See RaylibCoreDart.CheckCollisionBoxSphere.
-
CheckCollisionCircleLine(Vector2D center, num radius, Vector2D p1, Vector2D p2)
→ bool
-
See RaylibCoreDart.CheckCollisionCircleLine.
-
CheckCollisionCircleRec(Vector2D center, num radius, RectangleD rec)
→ bool
-
See RaylibCoreDart.CheckCollisionCircleRec.
-
CheckCollisionCircles(Vector2D center1, num radius1, Vector2D center2, num radius2)
→ bool
-
See RaylibCoreDart.CheckCollisionCircles.
-
CheckCollisionLines(Vector2D startPos1, Vector2D endPos1, Vector2D startPos2, Vector2D endPos2)
→ (bool, Vector2D)
-
See RaylibCoreDart.CheckCollisionLines.
-
CheckCollisionPointCircle(Vector2D point, Vector2D center, num radius)
→ bool
-
See RaylibCoreDart.CheckCollisionPointCircle.
-
CheckCollisionPointLine(Vector2D point, Vector2D p1, Vector2D p2, num threshold)
→ bool
-
See RaylibCoreDart.CheckCollisionPointLine.
-
CheckCollisionPointPoly(Vector2D point, List<Vector2D> points)
→ bool
-
See RaylibCoreDart.CheckCollisionPointPoly.
-
CheckCollisionPointRec(Vector2D point, RectangleD rec)
→ bool
-
See RaylibCoreDart.CheckCollisionPointRec.
-
CheckCollisionPointTriangle(Vector2D point, Vector2D p1, Vector2D p2, Vector2D p3)
→ bool
-
See RaylibCoreDart.CheckCollisionPointTriangle.
-
CheckCollisionRecs(RectangleD rec1, RectangleD rec2)
→ bool
-
See RaylibCoreDart.CheckCollisionRecs.
-
CheckCollisionSpheres(Vector3D center1, num radius1, Vector3D center2, num radius2)
→ bool
-
See RaylibCoreDart.CheckCollisionSpheres.
-
ClearBackground(ColorD color)
→ void
-
See RaylibCoreDart.ClearBackground.
-
ClearWindowState(Iterable<ConfigFlags> flags)
→ void
-
See RaylibCoreDart.ClearWindowState.
-
CloseWindow()
→ void
-
See RaylibCoreDart.CloseWindow.
-
CodepointToUTF8(num codepoint)
→ (String, int)
-
See RaylibCoreDart.CodepointToUTF8.
-
ColorAlpha(ColorD color, num alpha)
→ ColorD
-
See RaylibCoreDart.ColorAlpha.
-
ColorAlphaBlend(ColorD dst, ColorD src, ColorD tint)
→ ColorD
-
See RaylibCoreDart.ColorAlphaBlend.
-
ColorBrightness(ColorD color, num factor)
→ ColorD
-
See RaylibCoreDart.ColorBrightness.
-
ColorContrast(ColorD color, num contrast)
→ ColorD
-
See RaylibCoreDart.ColorContrast.
-
ColorFromHSV(num hue, num saturation, num value)
→ ColorD
-
See RaylibCoreDart.ColorFromHSV.
-
ColorFromNormalized(Vector4D normalized)
→ ColorD
-
See RaylibCoreDart.ColorFromNormalized.
-
ColorIsEqual(ColorD col1, ColorD col2)
→ bool
-
See RaylibCoreDart.ColorIsEqual.
-
ColorLerp(ColorD color1, ColorD color2, num factor)
→ ColorD
-
See RaylibCoreDart.ColorLerp.
-
ColorNormalize(ColorD color)
→ Vector4D
-
See RaylibCoreDart.ColorNormalize.
-
ColorTint(ColorD color, ColorD tint)
→ ColorD
-
See RaylibCoreDart.ColorTint.
-
ColorToHSV(ColorD color)
→ Vector3D
-
See RaylibCoreDart.ColorToHSV.
-
ColorToInt(ColorD color)
→ int
-
See RaylibCoreDart.ColorToInt.
-
CompressData(Uint8List data)
→ Uint8List
-
See RaylibCoreDart.CompressData.
-
ComputeCRC32(Uint8List data)
→ int
-
See RaylibCoreDart.ComputeCRC32.
-
ComputeMD5(Uint8List data)
→ Uint8List
-
See RaylibCoreDart.ComputeMD5.
-
ComputeSHA1(Uint8List data)
→ Uint8List
-
See RaylibCoreDart.ComputeSHA1.
-
ComputeSHA256(Uint8List data)
→ Uint8List
-
See RaylibCoreDart.ComputeSHA256.
-
DecodeDataBase64(Uint8List data)
→ Uint8List
-
See RaylibCoreDart.DecodeDataBase64.
-
DecompressData(Uint8List compData)
→ Uint8List
-
See RaylibCoreDart.DecompressData.
-
DirectoryExists(String dirPath)
→ bool
-
See RaylibCoreDart.DirectoryExists.
-
DisableCursor()
→ void
-
See RaylibCoreDart.DisableCursor.
-
DisableEventWaiting()
→ void
-
See RaylibCoreDart.DisableEventWaiting.
-
DrawBillboard(Camera3DD camera, TextureD texture, Vector3D position, num scale, ColorD tint)
→ void
-
See RaylibCoreDart.DrawBillboard.
-
DrawBillboardPro(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector3D up, Vector2D size, Vector2D origin, num rotation, ColorD tint)
→ void
-
See RaylibCoreDart.DrawBillboardPro.
-
DrawBillboardRec(Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector2D size, ColorD tint)
→ void
-
See RaylibCoreDart.DrawBillboardRec.
-
DrawBoundingBox(BoundingBoxD box, ColorD color)
→ void
-
See RaylibCoreDart.DrawBoundingBox.
-
DrawCapsule(Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color)
→ void
-
See RaylibCoreDart.DrawCapsule.
-
DrawCapsuleWires(Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color)
→ void
-
See RaylibCoreDart.DrawCapsuleWires.
-
DrawCircle(num centerX, num centerY, num radius, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircle.
-
DrawCircle3D(Vector3D center, num radius, Vector3D rotationAxis, num rotationAngle, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircle3D.
-
DrawCircleGradient(Vector2D center, num radius, ColorD inner, ColorD outer)
→ void
-
See RaylibCoreDart.DrawCircleGradient.
-
DrawCircleLines(num centerX, num centerY, num radius, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircleLines.
-
DrawCircleLinesV(Vector2D center, num radius, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircleLinesV.
-
DrawCircleSector(Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircleSector.
-
DrawCircleSectorLines(Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircleSectorLines.
-
DrawCircleV(Vector2D center, num radius, ColorD color)
→ void
-
See RaylibCoreDart.DrawCircleV.
-
DrawCube(Vector3D position, num width, num height, num length, ColorD color)
→ void
-
See RaylibCoreDart.DrawCube.
-
DrawCubeV(Vector3D position, Vector3D size, ColorD color)
→ void
-
See RaylibCoreDart.DrawCubeV.
-
DrawCubeWires(Vector3D position, num width, num height, num length, ColorD color)
→ void
-
See RaylibCoreDart.DrawCubeWires.
-
DrawCubeWiresV(Vector3D position, Vector3D size, ColorD color)
→ void
-
See RaylibCoreDart.DrawCubeWiresV.
-
DrawCylinder(Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color)
→ void
-
See RaylibCoreDart.DrawCylinder.
-
DrawCylinderEx(Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color)
→ void
-
See RaylibCoreDart.DrawCylinderEx.
-
DrawCylinderWires(Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color)
→ void
-
See RaylibCoreDart.DrawCylinderWires.
-
DrawCylinderWiresEx(Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color)
→ void
-
See RaylibCoreDart.DrawCylinderWiresEx.
-
DrawEllipse(num centerX, num centerY, num radiusH, num radiusV, ColorD color)
→ void
-
See RaylibCoreDart.DrawEllipse.
-
DrawEllipseLines(num centerX, num centerY, num radiusH, num radiusV, ColorD color)
→ void
-
See RaylibCoreDart.DrawEllipseLines.
-
DrawEllipseLinesV(Vector2D center, num radiusH, num radiusV, ColorD color)
→ void
-
See RaylibCoreDart.DrawEllipseLinesV.
-
DrawEllipseV(Vector2D center, num radiusH, num radiusV, ColorD color)
→ void
-
See RaylibCoreDart.DrawEllipseV.
-
DrawFPS(num posX, num posY)
→ void
-
See RaylibCoreDart.DrawFPS.
-
DrawGrid(num slices, num spacing)
→ void
-
See RaylibCoreDart.DrawGrid.
-
DrawLine(num startPosX, num startPosY, num endPosX, num endPosY, ColorD color)
→ void
-
See RaylibCoreDart.DrawLine.
-
DrawLine3D(Vector3D startPos, Vector3D endPos, ColorD color)
→ void
-
See RaylibCoreDart.DrawLine3D.
-
DrawLineBezier(Vector2D startPos, Vector2D endPos, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawLineBezier.
-
DrawLineDashed(Vector2D startPos, Vector2D endPos, num dashSize, num spaceSize, ColorD color)
→ void
-
See RaylibCoreDart.DrawLineDashed.
-
DrawLineEx(Vector2D startPos, Vector2D endPos, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawLineEx.
-
DrawLineStrip(List<Vector2D> points, ColorD color)
→ void
-
See RaylibCoreDart.DrawLineStrip.
-
DrawLineV(Vector2D startPos, Vector2D endPos, ColorD color)
→ void
-
See RaylibCoreDart.DrawLineV.
-
DrawMesh(MeshD mesh, MaterialD material, MatrixD transform)
→ void
-
See RaylibCoreDart.DrawMesh.
-
DrawMeshInstanced(MeshD mesh, MaterialD material, List<MatrixD> transforms)
→ void
-
See RaylibCoreDart.DrawMeshInstanced.
-
DrawModel(ModelD model, Vector3D position, num scale, ColorD tint)
→ void
-
See RaylibCoreDart.DrawModel.
-
DrawModelEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint)
→ void
-
See RaylibCoreDart.DrawModelEx.
-
DrawModelWires(ModelD model, Vector3D position, num scale, ColorD tint)
→ void
-
See RaylibCoreDart.DrawModelWires.
-
DrawModelWiresEx(ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint)
→ void
-
See RaylibCoreDart.DrawModelWiresEx.
-
DrawPixel(num posX, num posY, ColorD color)
→ void
-
See RaylibCoreDart.DrawPixel.
-
DrawPixelV(Vector2D position, ColorD color)
→ void
-
See RaylibCoreDart.DrawPixelV.
-
DrawPlane(Vector3D centerPos, Vector2D size, ColorD color)
→ void
-
See RaylibCoreDart.DrawPlane.
-
DrawPoint3D(Vector3D position, ColorD color)
→ void
-
See RaylibCoreDart.DrawPoint3D.
-
DrawPoly(Vector2D center, num sides, num radius, num rotation, ColorD color)
→ void
-
See RaylibCoreDart.DrawPoly.
-
DrawPolyLines(Vector2D center, num sides, num radius, num rotation, ColorD color)
→ void
-
See RaylibCoreDart.DrawPolyLines.
-
DrawPolyLinesEx(Vector2D center, num sides, num radius, num rotation, num lineThick, ColorD color)
→ void
-
See RaylibCoreDart.DrawPolyLinesEx.
-
DrawRay(RayD ray, ColorD color)
→ void
-
See RaylibCoreDart.DrawRay.
-
DrawRectangle(num posX, num posY, num width, num height, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangle.
-
DrawRectangleGradientEx(RectangleD rec, ColorD topLeft, ColorD bottomLeft, ColorD topRight, ColorD bottomRight)
→ void
-
See RaylibCoreDart.DrawRectangleGradientEx.
-
DrawRectangleGradientH(num posX, num posY, num width, num height, ColorD left, ColorD right)
→ void
-
See RaylibCoreDart.DrawRectangleGradientH.
-
DrawRectangleGradientV(num posX, num posY, num width, num height, ColorD top, ColorD bottom)
→ void
-
See RaylibCoreDart.DrawRectangleGradientV.
-
DrawRectangleLines(num posX, num posY, num width, num height, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleLines.
-
DrawRectangleLinesEx(RectangleD rec, num lineThick, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleLinesEx.
-
DrawRectanglePro(RectangleD rec, Vector2D origin, num rotation, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectanglePro.
-
DrawRectangleRec(RectangleD rec, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleRec.
-
DrawRectangleRounded(RectangleD rec, num roundness, num segments, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleRounded.
-
DrawRectangleRoundedLines(RectangleD rec, num roundness, num segments, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleRoundedLines.
-
DrawRectangleRoundedLinesEx(RectangleD rec, num roundness, num segments, num lineThick, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleRoundedLinesEx.
-
DrawRectangleV(Vector2D position, Vector2D size, ColorD color)
→ void
-
See RaylibCoreDart.DrawRectangleV.
-
DrawRing(Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color)
→ void
-
See RaylibCoreDart.DrawRing.
-
DrawRingLines(Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color)
→ void
-
See RaylibCoreDart.DrawRingLines.
-
DrawSphere(Vector3D centerPos, num radius, ColorD color)
→ void
-
See RaylibCoreDart.DrawSphere.
-
DrawSphereEx(Vector3D centerPos, num radius, num rings, num slices, ColorD color)
→ void
-
See RaylibCoreDart.DrawSphereEx.
-
DrawSphereWires(Vector3D centerPos, num radius, num rings, num slices, ColorD color)
→ void
-
See RaylibCoreDart.DrawSphereWires.
-
DrawSplineBasis(List<Vector2D> points, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineBasis.
-
DrawSplineBezierCubic(List<Vector2D> points, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineBezierCubic.
-
DrawSplineBezierQuadratic(List<Vector2D> points, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineBezierQuadratic.
-
DrawSplineCatmullRom(List<Vector2D> points, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineCatmullRom.
-
DrawSplineLinear(List<Vector2D> points, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineLinear.
-
DrawSplineSegmentBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineSegmentBasis.
-
DrawSplineSegmentBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineSegmentBezierCubic.
-
DrawSplineSegmentBezierQuadratic(Vector2D p1, Vector2D c2, Vector2D p3, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineSegmentBezierQuadratic.
-
DrawSplineSegmentCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineSegmentCatmullRom.
-
DrawSplineSegmentLinear(Vector2D p1, Vector2D p2, num thick, ColorD color)
→ void
-
See RaylibCoreDart.DrawSplineSegmentLinear.
-
DrawText(String text, num posX, num posY, num fontSize, ColorD color)
→ void
-
See RaylibCoreDart.DrawText.
-
DrawTextCodepoint(FontD font, num codepoint, Vector2D position, num fontSize, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextCodepoint.
-
DrawTextCodepoints(FontD font, Int32List codepoints, Vector2D position, num fontSize, num spacing, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextCodepoints.
-
DrawTextEx(FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextEx.
-
DrawTextPro(FontD font, String text, Vector2D position, Vector2D origin, num rotation, num fontSize, num spacing, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextPro.
-
DrawTexture(TextureD texture, num posX, num posY, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTexture.
-
DrawTextureEx(TextureD texture, Vector2D position, num rotation, num scale, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextureEx.
-
DrawTextureNPatch(TextureD texture, NPatchInfoD nPatchInfo, RectangleD dest, Vector2D origin, num rotation, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextureNPatch.
-
DrawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, num rotation, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTexturePro.
-
DrawTextureRec(TextureD texture, RectangleD source, Vector2D position, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextureRec.
-
DrawTextureV(TextureD texture, Vector2D position, ColorD tint)
→ void
-
See RaylibCoreDart.DrawTextureV.
-
DrawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
See RaylibCoreDart.DrawTriangle.
-
DrawTriangle3D(Vector3D v1, Vector3D v2, Vector3D v3, ColorD color)
→ void
-
See RaylibCoreDart.DrawTriangle3D.
-
DrawTriangleFan(List<Vector2D> points, ColorD color)
→ void
-
See RaylibCoreDart.DrawTriangleFan.
-
DrawTriangleLines(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
See RaylibCoreDart.DrawTriangleLines.
-
DrawTriangleStrip(List<Vector2D> points, ColorD color)
→ void
-
See RaylibCoreDart.DrawTriangleStrip.
-
DrawTriangleStrip3D(List<Vector3D> points, ColorD color)
→ void
-
See RaylibCoreDart.DrawTriangleStrip3D.
-
EnableCursor()
→ void
-
See RaylibCoreDart.EnableCursor.
-
EnableEventWaiting()
→ void
-
See RaylibCoreDart.EnableEventWaiting.
-
EncodeDataBase64(Uint8List data)
→ Uint8List
-
See RaylibCoreDart.EncodeDataBase64.
-
EndBlendMode()
→ void
-
See RaylibCoreDart.EndBlendMode.
-
EndDrawing()
→ void
-
See RaylibCoreDart.EndDrawing.
-
EndMode2D()
→ void
-
See RaylibCoreDart.EndMode2D.
-
EndMode3D()
→ void
-
See RaylibCoreDart.EndMode3D.
-
EndScissorMode()
→ void
-
See RaylibCoreDart.EndScissorMode.
-
EndShaderMode()
→ void
-
See RaylibCoreDart.EndShaderMode.
-
EndTextureMode()
→ void
-
See RaylibCoreDart.EndTextureMode.
-
EndVrStereoMode()
→ void
-
See RaylibCoreDart.EndVrStereoMode.
-
ExportAutomationEventList(AutomationEventListD list, String fileName)
→ bool
-
See RaylibCoreDart.ExportAutomationEventList.
-
ExportDataAsCode(Uint8List data, String fileName)
→ bool
-
See RaylibCoreDart.ExportDataAsCode.
-
ExportFontAsCode(FontD font, String fileName)
→ bool
-
See RaylibCoreDart.ExportFontAsCode.
-
ExportImage(ImageD image, String fileName)
→ bool
-
See RaylibCoreDart.ExportImage.
-
ExportImageAsCode(ImageD image, String fileName)
→ bool
-
See RaylibCoreDart.ExportImageAsCode.
-
ExportImageToMemory(ImageD image, String fileType)
→ (MemoryPointer<RUint8>, int)
-
See RaylibCoreDart.ExportImageToMemory.
-
ExportMesh(MeshD mesh, String fileName)
→ bool
-
See RaylibCoreDart.ExportMesh.
-
ExportMeshAsCode(MeshD mesh, String fileName)
→ bool
-
See RaylibCoreDart.ExportMeshAsCode.
-
Fade(ColorD color, num alpha)
→ ColorD
-
See RaylibCoreDart.Fade.
-
FileCopy(String srcPath, String dstPath)
→ int
-
See RaylibCoreDart.FileCopy.
-
FileExists(String fileName)
→ bool
-
See RaylibCoreDart.FileExists.
-
FileMove(String srcPath, String dstPath)
→ int
-
See RaylibCoreDart.FileMove.
-
FileRemove(String fileName)
→ int
-
See RaylibCoreDart.FileRemove.
-
FileRename(String fileName, String fileRename)
→ int
-
See RaylibCoreDart.FileRename.
-
FileTextFindIndex(String fileName, String search)
→ int
-
See RaylibCoreDart.FileTextFindIndex.
-
FileTextReplace(String fileName, String search, String replacement)
→ int
-
See RaylibCoreDart.FileTextReplace.
-
GenImageCellular(num width, num height, num tileSize)
→ ImageD
-
See RaylibCoreDart.GenImageCellular.
-
GenImageChecked(num width, num height, num checksX, num checksY, ColorD col1, ColorD col2)
→ ImageD
-
See RaylibCoreDart.GenImageChecked.
-
GenImageColor(num width, num height, ColorD color)
→ ImageD
-
See RaylibCoreDart.GenImageColor.
-
GenImageFontAtlas(List<GlyphInfoD> glyphs, num fontSize, num padding, num packMethod)
→ (ImageD, List<RectangleD>)
-
See RaylibCoreDart.GenImageFontAtlas.
-
GenImageGradientLinear(num width, num height, num direction, ColorD start, ColorD end)
→ ImageD
-
See RaylibCoreDart.GenImageGradientLinear.
-
GenImageGradientRadial(num width, num height, num density, ColorD inner, ColorD outer)
→ ImageD
-
See RaylibCoreDart.GenImageGradientRadial.
-
GenImageGradientSquare(num width, num height, num density, ColorD inner, ColorD outer)
→ ImageD
-
See RaylibCoreDart.GenImageGradientSquare.
-
GenImagePerlinNoise(num width, num height, num offsetX, num offsetY, num scale)
→ ImageD
-
See RaylibCoreDart.GenImagePerlinNoise.
-
GenImageText(num width, num height, String text)
→ ImageD
-
See RaylibCoreDart.GenImageText.
-
GenImageWhiteNoise(num width, num height, num factor)
→ ImageD
-
See RaylibCoreDart.GenImageWhiteNoise.
-
GenMeshCone(num radius, num height, num slices)
→ MeshD
-
See RaylibCoreDart.GenMeshCone.
-
GenMeshCube(num width, num height, num length)
→ MeshD
-
See RaylibCoreDart.GenMeshCube.
-
GenMeshCubicmap(ImageD cubicmap, Vector3D cubeSize)
→ MeshD
-
See RaylibCoreDart.GenMeshCubicmap.
-
GenMeshCylinder(num radius, num height, num slices)
→ MeshD
-
See RaylibCoreDart.GenMeshCylinder.
-
GenMeshHeightmap(ImageD heightmap, Vector3D size)
→ MeshD
-
See RaylibCoreDart.GenMeshHeightmap.
-
GenMeshHemiSphere(num radius, num rings, num slices)
→ MeshD
-
See RaylibCoreDart.GenMeshHemiSphere.
-
GenMeshKnot(num radius, num size, num radSeg, num sides)
→ MeshD
-
See RaylibCoreDart.GenMeshKnot.
-
GenMeshPlane(num width, num length, num resX, num resZ)
→ MeshD
-
See RaylibCoreDart.GenMeshPlane.
-
GenMeshPoly(num sides, num radius)
→ MeshD
-
See RaylibCoreDart.GenMeshPoly.
-
GenMeshSphere(num radius, num rings, num slices)
→ MeshD
-
See RaylibCoreDart.GenMeshSphere.
-
GenMeshTangents(MeshD mesh)
→ void
-
See RaylibCoreDart.GenMeshTangents.
-
GenMeshTorus(num radius, num size, num radSeg, num sides)
→ MeshD
-
See RaylibCoreDart.GenMeshTorus.
-
GenTextureMipmaps(TextureD texture)
→ void
-
See RaylibCoreDart.GenTextureMipmaps.
-
GetApplicationDirectory()
→ String
-
See RaylibCoreDart.GetApplicationDirectory.
-
GetCameraMatrix(Camera3DD camera)
→ MatrixD
-
See RaylibCoreDart.GetCameraMatrix.
-
GetCameraMatrix2D(Camera2DD camera)
→ MatrixD
-
See RaylibCoreDart.GetCameraMatrix2D.
-
GetCharPressed()
→ int
-
See RaylibCoreDart.GetCharPressed.
-
GetClipboardImage()
→ ImageD
-
See RaylibCoreDart.GetClipboardImage.
-
GetClipboardText()
→ String
-
See RaylibCoreDart.GetClipboardText.
-
GetCodepoint(String text)
→ (int, int)
-
See RaylibCoreDart.GetCodepoint.
-
GetCodepointCount(String text)
→ int
-
See RaylibCoreDart.GetCodepointCount.
-
GetCodepointNext(String text)
→ (int, int)
-
See RaylibCoreDart.GetCodepointNext.
-
GetCodepointPrevious(String text)
→ (int, int)
-
See RaylibCoreDart.GetCodepointPrevious.
-
GetCollisionRec(RectangleD rec1, RectangleD rec2)
→ RectangleD
-
See RaylibCoreDart.GetCollisionRec.
-
GetColor(num hexValue)
→ ColorD
-
See RaylibCoreDart.GetColor.
-
GetCurrentMonitor()
→ int
-
See RaylibCoreDart.GetCurrentMonitor.
-
GetDirectoryFileCount(String dirPath)
→ int
-
See RaylibCoreDart.GetDirectoryFileCount.
-
GetDirectoryFileCountEx(String basePath, String filter, bool scanSubdirs)
→ int
-
See RaylibCoreDart.GetDirectoryFileCountEx.
-
GetDirectoryPath(String filePath)
→ String
-
See RaylibCoreDart.GetDirectoryPath.
-
GetFileExtension(String fileName)
→ String
-
See RaylibCoreDart.GetFileExtension.
-
GetFileLength(String fileName)
→ int
-
See RaylibCoreDart.GetFileLength.
-
GetFileModTime(String fileName)
→ int
-
See RaylibCoreDart.GetFileModTime.
-
GetFileName(String filePath)
→ String
-
See RaylibCoreDart.GetFileName.
-
GetFileNameWithoutExt(String filePath)
→ String
-
See RaylibCoreDart.GetFileNameWithoutExt.
-
GetFontDefault()
→ FontD
-
See RaylibCoreDart.GetFontDefault.
-
GetFPS()
→ int
-
See RaylibCoreDart.GetFPS.
-
GetFrameTime()
→ double
-
See RaylibCoreDart.GetFrameTime.
-
GetGamepadAxisCount(num gamepad)
→ int
-
See RaylibCoreDart.GetGamepadAxisCount.
-
GetGamepadAxisMovement(num gamepad, GamepadAxis axis)
→ double
-
See RaylibCoreDart.GetGamepadAxisMovement.
-
GetGamepadButtonPressed()
→ GamepadButton
-
See RaylibCoreDart.GetGamepadButtonPressed.
-
GetGamepadName(num gamepad)
→ String
-
See RaylibCoreDart.GetGamepadName.
-
GetGestureDetected()
→ Gesture
-
See RaylibCoreDart.GetGestureDetected.
-
GetGestureDragAngle()
→ double
-
See RaylibCoreDart.GetGestureDragAngle.
-
GetGestureDragVector()
→ Vector2D
-
See RaylibCoreDart.GetGestureDragVector.
-
GetGestureHoldDuration()
→ double
-
See RaylibCoreDart.GetGestureHoldDuration.
-
GetGesturePinchAngle()
→ double
-
See RaylibCoreDart.GetGesturePinchAngle.
-
GetGesturePinchVector()
→ Vector2D
-
See RaylibCoreDart.GetGesturePinchVector.
-
GetGlyphAtlasRec(FontD font, num codepoint)
→ RectangleD
-
See RaylibCoreDart.GetGlyphAtlasRec.
-
GetGlyphIndex(FontD font, num codepoint)
→ int
-
See RaylibCoreDart.GetGlyphIndex.
-
GetGlyphInfo(FontD font, num codepoint)
→ GlyphInfoD
-
See RaylibCoreDart.GetGlyphInfo.
-
GetImageAlphaBorder(ImageD image, num threshold)
→ RectangleD
-
See RaylibCoreDart.GetImageAlphaBorder.
-
GetImageColor(ImageD image, num x, num y)
→ ColorD
-
See RaylibCoreDart.GetImageColor.
-
GetKeyName(KeyboardKey key)
→ String
-
See RaylibCoreDart.GetKeyName.
-
GetKeyPressed()
→ int
-
See RaylibCoreDart.GetKeyPressed.
-
GetMeshBoundingBox(MeshD mesh)
→ BoundingBoxD
-
See RaylibCoreDart.GetMeshBoundingBox.
-
GetModelBoundingBox(ModelD model)
→ BoundingBoxD
-
See RaylibCoreDart.GetModelBoundingBox.
-
GetMonitorCount()
→ int
-
See RaylibCoreDart.GetMonitorCount.
-
GetMonitorHeight(num monitor)
→ int
-
See RaylibCoreDart.GetMonitorHeight.
-
GetMonitorName(num monitor)
→ String
-
See RaylibCoreDart.GetMonitorName.
-
GetMonitorPhysicalHeight(num monitor)
→ int
-
See RaylibCoreDart.GetMonitorPhysicalHeight.
-
GetMonitorPhysicalWidth(num monitor)
→ int
-
See RaylibCoreDart.GetMonitorPhysicalWidth.
-
GetMonitorPosition(num monitor)
→ Vector2D
-
See RaylibCoreDart.GetMonitorPosition.
-
GetMonitorRefreshRate(num monitor)
→ int
-
See RaylibCoreDart.GetMonitorRefreshRate.
-
GetMonitorWidth(num monitor)
→ int
-
See RaylibCoreDart.GetMonitorWidth.
-
GetMouseDelta()
→ Vector2D
-
See RaylibCoreDart.GetMouseDelta.
-
GetMousePosition()
→ Vector2D
-
See RaylibCoreDart.GetMousePosition.
-
GetMouseWheelMove()
→ double
-
See RaylibCoreDart.GetMouseWheelMove.
-
GetMouseWheelMoveV()
→ Vector2D
-
See RaylibCoreDart.GetMouseWheelMoveV.
-
GetMouseX()
→ int
-
See RaylibCoreDart.GetMouseX.
-
GetMouseY()
→ int
-
See RaylibCoreDart.GetMouseY.
-
GetPixelDataSize(num width, num height, PixelFormat format)
→ int
-
See RaylibCoreDart.GetPixelDataSize.
-
GetPrevDirectoryPath(String dirPath)
→ String
-
See RaylibCoreDart.GetPrevDirectoryPath.
-
GetRandomValue(num min, num max)
→ int
-
See RaylibCoreDart.GetRandomValue.
-
GetRayCollisionBox(RayD ray, BoundingBoxD box)
→ RayCollisionD
-
See RaylibCoreDart.GetRayCollisionBox.
-
GetRayCollisionMesh(RayD ray, MeshD mesh, MatrixD transform)
→ RayCollisionD
-
See RaylibCoreDart.GetRayCollisionMesh.
-
GetRayCollisionQuad(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3, Vector3D p4)
→ RayCollisionD
-
See RaylibCoreDart.GetRayCollisionQuad.
-
GetRayCollisionSphere(RayD ray, Vector3D center, num radius)
→ RayCollisionD
-
See RaylibCoreDart.GetRayCollisionSphere.
-
GetRayCollisionTriangle(RayD ray, Vector3D p1, Vector3D p2, Vector3D p3)
→ RayCollisionD
-
See RaylibCoreDart.GetRayCollisionTriangle.
-
GetRenderHeight()
→ int
-
See RaylibCoreDart.GetRenderHeight.
-
GetRenderWidth()
→ int
-
See RaylibCoreDart.GetRenderWidth.
-
GetScreenHeight()
→ int
-
See RaylibCoreDart.GetScreenHeight.
-
GetScreenToWorld2D(Vector2D position, Camera2DD camera)
→ Vector2D
-
See RaylibCoreDart.GetScreenToWorld2D.
-
GetScreenToWorldRay(Vector2D position, Camera3DD camera)
→ RayD
-
See RaylibCoreDart.GetScreenToWorldRay.
-
GetScreenToWorldRayEx(Vector2D position, Camera3DD camera, num width, num height)
→ RayD
-
See RaylibCoreDart.GetScreenToWorldRayEx.
-
GetScreenWidth()
→ int
-
See RaylibCoreDart.GetScreenWidth.
-
GetShaderLocation(ShaderD shader, String uniformName)
→ int
-
See RaylibCoreDart.GetShaderLocation.
-
GetShaderLocationAttrib(ShaderD shader, String attribName)
→ int
-
See RaylibCoreDart.GetShaderLocationAttrib.
-
GetShapesTexture()
→ TextureD
-
See RaylibCoreDart.GetShapesTexture.
-
GetShapesTextureRectangle()
→ RectangleD
-
See RaylibCoreDart.GetShapesTextureRectangle.
-
GetSplinePointBasis(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t)
→ Vector2D
-
See RaylibCoreDart.GetSplinePointBasis.
-
GetSplinePointBezierCubic(Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num t)
→ Vector2D
-
See RaylibCoreDart.GetSplinePointBezierCubic.
-
GetSplinePointBezierQuad(Vector2D p1, Vector2D c2, Vector2D p3, num t)
→ Vector2D
-
See RaylibCoreDart.GetSplinePointBezierQuad.
-
GetSplinePointCatmullRom(Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t)
→ Vector2D
-
See RaylibCoreDart.GetSplinePointCatmullRom.
-
GetSplinePointLinear(Vector2D startPos, Vector2D endPos, num t)
→ Vector2D
-
See RaylibCoreDart.GetSplinePointLinear.
-
GetTextBetween(String text, String begin, String end)
→ String
-
See RaylibCoreDart.GetTextBetween.
-
GetTime()
→ double
-
See RaylibCoreDart.GetTime.
-
GetTouchPointCount()
→ int
-
See RaylibCoreDart.GetTouchPointCount.
-
GetTouchPointId(num index)
→ int
-
See RaylibCoreDart.GetTouchPointId.
-
GetTouchPosition(num index)
→ Vector2D
-
See RaylibCoreDart.GetTouchPosition.
-
GetTouchX()
→ int
-
See RaylibCoreDart.GetTouchX.
-
GetTouchY()
→ int
-
See RaylibCoreDart.GetTouchY.
-
GetWindowPosition()
→ Vector2D
-
See RaylibCoreDart.GetWindowPosition.
-
GetWindowScaleDPI()
→ Vector2D
-
See RaylibCoreDart.GetWindowScaleDPI.
-
GetWorkingDirectory()
→ String
-
See RaylibCoreDart.GetWorkingDirectory.
-
GetWorldToScreen(Vector3D position, Camera3DD camera)
→ Vector2D
-
See RaylibCoreDart.GetWorldToScreen.
-
GetWorldToScreen2D(Vector2D position, Camera2DD camera)
→ Vector2D
-
See RaylibCoreDart.GetWorldToScreen2D.
-
GetWorldToScreenEx(Vector3D position, Camera3DD camera, num width, num height)
→ Vector2D
-
See RaylibCoreDart.GetWorldToScreenEx.
-
HideCursor()
→ void
-
See RaylibCoreDart.HideCursor.
-
ImageAlphaClear(ImageD image, ColorD color, num threshold)
→ void
-
See RaylibCoreDart.ImageAlphaClear.
-
ImageAlphaCrop(ImageD image, num threshold)
→ void
-
See RaylibCoreDart.ImageAlphaCrop.
-
ImageAlphaMask(ImageD image, ImageD alphaMask)
→ void
-
See RaylibCoreDart.ImageAlphaMask.
-
ImageAlphaPremultiply(ImageD image)
→ void
-
See RaylibCoreDart.ImageAlphaPremultiply.
-
ImageBlurGaussian(ImageD image, num blurSize)
→ void
-
See RaylibCoreDart.ImageBlurGaussian.
-
ImageClearBackground(ImageD dst, ColorD color)
→ void
-
See RaylibCoreDart.ImageClearBackground.
-
ImageColorBrightness(ImageD image, num brightness)
→ void
-
See RaylibCoreDart.ImageColorBrightness.
-
ImageColorContrast(ImageD image, num contrast)
→ void
-
See RaylibCoreDart.ImageColorContrast.
-
ImageColorGrayscale(ImageD image)
→ void
-
See RaylibCoreDart.ImageColorGrayscale.
-
ImageColorInvert(ImageD image)
→ void
-
See RaylibCoreDart.ImageColorInvert.
-
ImageColorReplace(ImageD image, ColorD color, ColorD replace)
→ void
-
See RaylibCoreDart.ImageColorReplace.
-
ImageColorTint(ImageD image, ColorD color)
→ void
-
See RaylibCoreDart.ImageColorTint.
-
ImageCopy(ImageD image)
→ ImageD
-
See RaylibCoreDart.ImageCopy.
-
ImageCrop(ImageD image, RectangleD crop)
→ void
-
See RaylibCoreDart.ImageCrop.
-
ImageDither(ImageD image, num rBpp, num gBpp, num bBpp, num aBpp)
→ void
-
See RaylibCoreDart.ImageDither.
-
ImageDraw(ImageD dst, ImageD src, RectangleD srcRec, RectangleD dstRec, ColorD tint)
→ void
-
See RaylibCoreDart.ImageDraw.
-
ImageDrawCircle(ImageD dst, num centerX, num centerY, num radius, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawCircle.
-
ImageDrawCircleLines(ImageD dst, num centerX, num centerY, num radius, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawCircleLines.
-
ImageDrawCircleLinesV(ImageD dst, Vector2D center, num radius, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawCircleLinesV.
-
ImageDrawCircleV(ImageD dst, Vector2D center, num radius, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawCircleV.
-
ImageDrawLine(ImageD dst, num startPosX, num startPosY, num endPosX, num endPosY, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawLine.
-
ImageDrawLineEx(ImageD dst, Vector2D start, Vector2D end, num thick, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawLineEx.
-
ImageDrawLineV(ImageD dst, Vector2D start, Vector2D end, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawLineV.
-
ImageDrawPixel(ImageD dst, num posX, num posY, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawPixel.
-
ImageDrawPixelV(ImageD dst, Vector2D position, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawPixelV.
-
ImageDrawRectangle(ImageD dst, num posX, num posY, num width, num height, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawRectangle.
-
ImageDrawRectangleLines(ImageD dst, RectangleD rec, num thick, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawRectangleLines.
-
ImageDrawRectangleRec(ImageD dst, RectangleD rec, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawRectangleRec.
-
ImageDrawRectangleV(ImageD dst, Vector2D position, Vector2D size, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawRectangleV.
-
ImageDrawText(ImageD dst, String text, num posX, num posY, num fontSize, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawText.
-
ImageDrawTextEx(ImageD dst, FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint)
→ void
-
See RaylibCoreDart.ImageDrawTextEx.
-
ImageDrawTriangle(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawTriangle.
-
ImageDrawTriangleEx(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD c1, ColorD c2, ColorD c3)
→ void
-
See RaylibCoreDart.ImageDrawTriangleEx.
-
ImageDrawTriangleFan(ImageD dst, List<Vector2D> points, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawTriangleFan.
-
ImageDrawTriangleLines(ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawTriangleLines.
-
ImageDrawTriangleStrip(ImageD dst, List<Vector2D> points, ColorD color)
→ void
-
See RaylibCoreDart.ImageDrawTriangleStrip.
-
ImageFlipHorizontal(ImageD image)
→ void
-
See RaylibCoreDart.ImageFlipHorizontal.
-
ImageFlipVertical(ImageD image)
→ void
-
See RaylibCoreDart.ImageFlipVertical.
-
ImageFormat(ImageD image, PixelFormat newFormat)
→ void
-
See RaylibCoreDart.ImageFormat.
-
ImageFromChannel(ImageD image, num selectedChannel)
→ ImageD
-
See RaylibCoreDart.ImageFromChannel.
-
ImageFromImage(ImageD image, RectangleD rec)
→ ImageD
-
See RaylibCoreDart.ImageFromImage.
-
ImageKernelConvolution(ImageD image, List<double> kernel)
→ void
-
See RaylibCoreDart.ImageKernelConvolution.
-
ImageMipmaps(ImageD image)
→ void
-
See RaylibCoreDart.ImageMipmaps.
-
ImageResize(ImageD image, num newWidth, num newHeight)
→ void
-
See RaylibCoreDart.ImageResize.
-
ImageResizeCanvas(ImageD image, num newWidth, num newHeight, num offsetX, num offsetY, ColorD fill)
→ void
-
See RaylibCoreDart.ImageResizeCanvas.
-
ImageResizeNN(ImageD image, num newWidth, num newHeight)
→ void
-
See RaylibCoreDart.ImageResizeNN.
-
ImageRotate(ImageD image, num degrees)
→ void
-
See RaylibCoreDart.ImageRotate.
-
ImageRotateCCW(ImageD image)
→ void
-
See RaylibCoreDart.ImageRotateCCW.
-
ImageRotateCW(ImageD image)
→ void
-
See RaylibCoreDart.ImageRotateCW.
-
ImageText(String text, num fontSize, ColorD color)
→ ImageD
-
See RaylibCoreDart.ImageText.
-
ImageTextEx(FontD font, String text, num fontSize, num spacing, ColorD tint)
→ ImageD
-
See RaylibCoreDart.ImageTextEx.
-
ImageToPOT(ImageD image, ColorD fill)
→ void
-
See RaylibCoreDart.ImageToPOT.
-
InitWindow(num width, num height, String title)
→ void
-
See RaylibCoreDart.InitWindow.
-
IsCursorHidden()
→ bool
-
See RaylibCoreDart.IsCursorHidden.
-
IsCursorOnScreen()
→ bool
-
See RaylibCoreDart.IsCursorOnScreen.
-
IsFileDropped()
→ bool
-
See RaylibCoreDart.IsFileDropped.
-
IsFileExtension(String fileName, String ext)
→ bool
-
See RaylibCoreDart.IsFileExtension.
-
IsFileNameValid(String fileName)
→ bool
-
See RaylibCoreDart.IsFileNameValid.
-
IsFontValid(FontD font)
→ bool
-
See RaylibCoreDart.IsFontValid.
-
IsGamepadAvailable(num gamepad)
→ bool
-
See RaylibCoreDart.IsGamepadAvailable.
-
IsGamepadButtonDown(num gamepad, GamepadButton button)
→ bool
-
See RaylibCoreDart.IsGamepadButtonDown.
-
IsGamepadButtonPressed(num gamepad, GamepadButton button)
→ bool
-
See RaylibCoreDart.IsGamepadButtonPressed.
-
IsGamepadButtonReleased(num gamepad, GamepadButton button)
→ bool
-
See RaylibCoreDart.IsGamepadButtonReleased.
-
IsGamepadButtonUp(num gamepad, GamepadButton button)
→ bool
-
See RaylibCoreDart.IsGamepadButtonUp.
-
IsGestureDetected(Gesture key)
→ bool
-
See RaylibCoreDart.IsGestureDetected.
-
IsImageValid(ImageD image)
→ bool
-
See RaylibCoreDart.IsImageValid.
-
IsKeyDown(KeyboardKey key)
→ bool
-
See RaylibCoreDart.IsKeyDown.
-
IsKeyPressed(KeyboardKey key)
→ bool
-
See RaylibCoreDart.IsKeyPressed.
-
IsKeyPressedRepeat(KeyboardKey key)
→ bool
-
See RaylibCoreDart.IsKeyPressedRepeat.
-
IsKeyReleased(KeyboardKey key)
→ bool
-
See RaylibCoreDart.IsKeyReleased.
-
IsKeyUp(KeyboardKey key)
→ bool
-
See RaylibCoreDart.IsKeyUp.
-
IsMaterialValid(MaterialD material)
→ bool
-
See RaylibCoreDart.IsMaterialValid.
-
IsModelAnimationValid(ModelD model, ModelAnimationD anim)
→ bool
-
See RaylibCoreDart.IsModelAnimationValid.
-
IsModelValid(ModelD model)
→ bool
-
See RaylibCoreDart.IsModelValid.
-
IsMouseButtonDown(MouseButton button)
→ bool
-
See RaylibCoreDart.IsMouseButtonDown.
-
IsMouseButtonPressed(MouseButton button)
→ bool
-
See RaylibCoreDart.IsMouseButtonPressed.
-
IsMouseButtonReleased(MouseButton button)
→ bool
-
See RaylibCoreDart.IsMouseButtonReleased.
-
IsMouseButtonUp(MouseButton button)
→ bool
-
See RaylibCoreDart.IsMouseButtonUp.
-
IsPathFile(String path)
→ bool
-
See RaylibCoreDart.IsPathFile.
-
IsRenderTextureValid(RenderTextureD target)
→ bool
-
See RaylibCoreDart.IsRenderTextureValid.
-
IsShaderValid(ShaderD shader)
→ bool
-
See RaylibCoreDart.IsShaderValid.
-
IsTextureValid(TextureD texture)
→ bool
-
See RaylibCoreDart.IsTextureValid.
-
IsWindowFocused()
→ bool
-
See RaylibCoreDart.IsWindowFocused.
-
IsWindowFullscreen()
→ bool
-
See RaylibCoreDart.IsWindowFullscreen.
-
IsWindowHidden()
→ bool
-
See RaylibCoreDart.IsWindowHidden.
-
IsWindowMaximized()
→ bool
-
See RaylibCoreDart.IsWindowMaximized.
-
IsWindowMinimized()
→ bool
-
See RaylibCoreDart.IsWindowMinimized.
-
IsWindowReady()
→ bool
-
See RaylibCoreDart.IsWindowReady.
-
IsWindowResized()
→ bool
-
See RaylibCoreDart.IsWindowResized.
-
IsWindowState(ConfigFlags flag)
→ bool
-
See RaylibCoreDart.IsWindowState.
-
LoadAutomationEventList(String? fileName)
→ AutomationEventListD
-
See RaylibCoreDart.LoadAutomationEventList.
-
LoadCodepoints(String text)
→ Int32List
-
See RaylibCoreDart.LoadCodepoints.
-
LoadDirectoryFiles(String dirPath)
→ FilePathListD
-
See RaylibCoreDart.LoadDirectoryFiles.
-
LoadDirectoryFilesEx(String basePath, String filter, bool scanSubdirs)
→ FilePathListD
-
See RaylibCoreDart.LoadDirectoryFilesEx.
-
LoadDroppedFiles()
→ FilePathListD
-
See RaylibCoreDart.LoadDroppedFiles.
-
LoadFileData(String fileName)
→ Uint8List
-
See RaylibCoreDart.LoadFileData.
-
LoadFileText(String fileName)
→ String
-
See RaylibCoreDart.LoadFileText.
-
LoadFont(String fileName)
→ FontD
-
See RaylibCoreDart.LoadFont.
-
LoadFontData(Uint8List fileData, num fontSize, Int32List? codepoints, num? codepointCount, FontType type)
→ List<GlyphInfoD>
-
See RaylibCoreDart.LoadFontData.
-
LoadFontEx(String fileName, num fontSize, [Int32List? codepoints, num? codepointCount])
→ FontD
-
See RaylibCoreDart.LoadFontEx.
-
LoadFontFromImage(ImageD image, ColorD key, num firstChar)
→ FontD
-
See RaylibCoreDart.LoadFontFromImage.
-
LoadFontFromMemory(String fileType, Uint8List fileData, num fontSize, Int32List codepoints)
→ FontD
-
See RaylibCoreDart.LoadFontFromMemory.
-
LoadImage(String fileName)
→ ImageD
-
See RaylibCoreDart.LoadImage.
-
LoadImageAnim(String fileName)
→ ImageD
-
See RaylibCoreDart.LoadImageAnim.
-
LoadImageAnimFromMemory(String fileType, Uint8List fileData)
→ ImageD
-
See RaylibCoreDart.LoadImageAnimFromMemory.
-
LoadImageColors(ImageD image)
→ List<ColorD>
-
See RaylibCoreDart.LoadImageColors.
-
LoadImageFromMemory(String fileType, Uint8List fileData)
→ ImageD
-
See RaylibCoreDart.LoadImageFromMemory.
-
LoadImageFromScreen()
→ ImageD
-
See RaylibCoreDart.LoadImageFromScreen.
-
LoadImageFromTexture(TextureD texture)
→ ImageD
-
See RaylibCoreDart.LoadImageFromTexture.
-
LoadImagePalette(ImageD image, num maxPaletteSize)
→ List<ColorD>
-
See RaylibCoreDart.LoadImagePalette.
-
LoadImageRaw(String fileName, num width, num height, PixelFormat format, )
→ ImageD
-
See RaylibCoreDart.LoadImageRaw.
-
LoadMaterialDefault()
→ MaterialD
-
See RaylibCoreDart.LoadMaterialDefault.
-
LoadMaterials(String fileName)
→ List<MaterialD>
-
See RaylibCoreDart.LoadMaterials.
-
LoadModel(String fileName)
→ ModelD
-
See RaylibCoreDart.LoadModel.
-
LoadModelAnimations(String fileName)
→ List<ModelAnimationD>
-
See RaylibCoreDart.LoadModelAnimations.
-
LoadModelFromMesh(MeshD mesh)
→ ModelD
-
See RaylibCoreDart.LoadModelFromMesh.
-
LoadRandomSequence(num count, num min, num max)
→ List<int>
-
See RaylibCoreDart.LoadRandomSequence.
-
LoadRenderTexture(num width, num height)
→ RenderTextureD
-
See RaylibCoreDart.LoadRenderTexture.
-
LoadShader(String? vsFileName, String? fsFileName)
→ ShaderD
-
See RaylibCoreDart.LoadShader.
-
LoadShaderFromMemory(String? vsCode, String? fsCode)
→ ShaderD
-
See RaylibCoreDart.LoadShaderFromMemory.
-
LoadTextLines(String text)
→ List<String>
-
See RaylibCoreDart.LoadTextLines.
-
LoadTexture(String fileName)
→ TextureD
-
See RaylibCoreDart.LoadTexture.
-
LoadTextureCubemap(ImageD image, CubemapLayout layout)
→ TextureD
-
See RaylibCoreDart.LoadTextureCubemap.
-
LoadTextureFromImage(ImageD image)
→ TextureD
-
See RaylibCoreDart.LoadTextureFromImage.
-
LoadUTF8(Int32List codepoints)
→ String
-
See RaylibCoreDart.LoadUTF8.
-
LoadVrStereoConfig(VrDeviceInfoD device)
→ VrStereoConfigD
-
See RaylibCoreDart.LoadVrStereoConfig.
-
MakeDirectory(String dirPath)
→ int
-
See RaylibCoreDart.MakeDirectory.
-
MaximizeWindow()
→ void
-
See RaylibCoreDart.MaximizeWindow.
-
MeasureText(String text, num fontSize)
→ int
-
See RaylibCoreDart.MeasureText.
-
MeasureTextCodepoints(FontD font, Int32List codepoints, num fontSize, num spacing)
→ Vector2D
-
See RaylibCoreDart.MeasureTextCodepoints.
-
MeasureTextEx(FontD font, String text, num fontSize, num spacing)
→ Vector2D
-
See RaylibCoreDart.MeasureTextEx.
-
MinimizeWindow()
→ void
-
See RaylibCoreDart.MinimizeWindow.
-
OpenURL(String url)
→ void
-
See RaylibCoreDart.OpenURL.
-
PlayAutomationEvent(AutomationEventD event)
→ void
-
See RaylibCoreDart.PlayAutomationEvent.
-
PollInputEvents()
→ void
-
See RaylibCoreDart.PollInputEvents.
-
ProcessGestureEvent(GestureEventD event)
→ void
-
See RaylibCoreDart.ProcessGestureEvent.
-
RestoreWindow()
→ void
-
See RaylibCoreDart.RestoreWindow.
-
SaveFileData(String fileName, Uint8List data)
→ bool
-
See RaylibCoreDart.SaveFileData.
-
SaveFileText(String fileName, String text)
→ bool
-
See RaylibCoreDart.SaveFileText.
-
SetAutomationEventBaseFrame(int frame)
→ void
-
See RaylibCoreDart.SetAutomationEventBaseFrame.
-
SetAutomationEventList(AutomationEventListD list)
→ void
-
See RaylibCoreDart.SetAutomationEventList.
-
SetClipboardText(String text)
→ void
-
See RaylibCoreDart.SetClipboardText.
-
SetConfigFlags(Iterable<ConfigFlags> flags)
→ void
-
See RaylibCoreDart.SetConfigFlags.
-
SetExitKey(KeyboardKey key)
→ void
-
See RaylibCoreDart.SetExitKey.
-
SetGamepadMappings(String mappings)
→ int
-
See RaylibCoreDart.SetGamepadMappings.
-
SetGamepadVibration(num gamepad, num leftMotor, num rightMotor, num duration)
→ void
-
See RaylibCoreDart.SetGamepadVibration.
-
SetGesturesEnabled(Iterable<Gesture> flags)
→ void
-
See RaylibCoreDart.SetGesturesEnabled.
-
SetLoadFileDataCallback(LoadFileDataCallbackBase? callback)
→ void
-
See RaylibCoreDart.SetLoadFileDataCallback.
-
SetLoadFileTextCallback(LoadFileTextCallbackBase? callback)
→ void
-
See RaylibCoreDart.SetLoadFileTextCallback.
-
SetMaterialTexture(MaterialD material, MaterialMapIndex mapType, TextureD texture)
→ void
-
See RaylibCoreDart.SetMaterialTexture.
-
SetModelMeshMaterial(ModelD model, num meshId, num materialId)
→ void
-
See RaylibCoreDart.SetModelMeshMaterial.
-
SetMouseCursor(MouseCursor cursor)
→ void
-
See RaylibCoreDart.SetMouseCursor.
-
SetMouseOffset(num offsetX, num offsetY)
→ void
-
See RaylibCoreDart.SetMouseOffset.
-
SetMousePosition(num x, num y)
→ void
-
See RaylibCoreDart.SetMousePosition.
-
SetMouseScale(num scaleX, num scaleY)
→ void
-
See RaylibCoreDart.SetMouseScale.
-
SetRandomSeed(num seed)
→ void
-
See RaylibCoreDart.SetRandomSeed.
-
SetSaveFileDataCallback(SaveFileDataCallbackBase? callback)
→ void
-
See RaylibCoreDart.SetSaveFileDataCallback.
-
SetSaveFileTextCallback(SaveFileTextCallbackBase? callback)
→ void
-
See RaylibCoreDart.SetSaveFileTextCallback.
-
SetShaderValue(ShaderD shader, num locIndex, List<num> value, ShaderUniformDataType uniformType)
→ void
-
See RaylibCoreDart.SetShaderValue.
-
SetShaderValueMatrix(ShaderD shader, num locIndex, MatrixD mat)
→ void
-
See RaylibCoreDart.SetShaderValueMatrix.
-
SetShaderValueTexture(ShaderD shader, num locIndex, TextureD texture)
→ void
-
See RaylibCoreDart.SetShaderValueTexture.
-
SetShaderValueV(ShaderD shader, num locIndex, List<num> value, ShaderUniformDataType uniformType, num count)
→ void
-
See RaylibCoreDart.SetShaderValueV.
-
SetShapesTexture(TextureD texture, RectangleD source)
→ void
-
See RaylibCoreDart.SetShapesTexture.
-
SetTargetFPS(num fps)
→ void
-
See RaylibCoreDart.SetTargetFPS.
-
SetTextLineSpacing(num spacing)
→ void
-
See RaylibCoreDart.SetTextLineSpacing.
-
SetTextureFilter(TextureD texture, TextureFilter filter)
→ void
-
See RaylibCoreDart.SetTextureFilter.
-
SetTextureWrap(TextureD texture, TextureWrap wrap)
→ void
-
See RaylibCoreDart.SetTextureWrap.
-
SetTraceLogCallback(TraceLogCallbackBase callback)
→ void
-
See RaylibCoreDart.SetTraceLogCallback.
-
SetTraceLogLevel(TraceLogLevel logLevel)
→ void
-
See RaylibCoreDart.SetTraceLogLevel.
-
SetWindowFocused()
→ void
-
See RaylibCoreDart.SetWindowFocused.
-
SetWindowIcon(ImageD image)
→ void
-
See RaylibCoreDart.SetWindowIcon.
-
SetWindowIcons(List<ImageD> images)
→ void
-
See RaylibCoreDart.SetWindowIcons.
-
SetWindowMaxSize(num width, num height)
→ void
-
See RaylibCoreDart.SetWindowMaxSize.
-
SetWindowMinSize(num width, num height)
→ void
-
See RaylibCoreDart.SetWindowMinSize.
-
SetWindowMonitor(num monitor)
→ void
-
See RaylibCoreDart.SetWindowMonitor.
-
SetWindowOpacity(num opacity)
→ void
-
See RaylibCoreDart.SetWindowOpacity.
-
SetWindowPosition(num x, num y)
→ void
-
See RaylibCoreDart.SetWindowPosition.
-
SetWindowSize(num width, num height)
→ void
-
See RaylibCoreDart.SetWindowSize.
-
SetWindowState(Iterable<ConfigFlags> flags)
→ void
-
See RaylibCoreDart.SetWindowState.
-
SetWindowTitle(String title)
→ void
-
See RaylibCoreDart.SetWindowTitle.
-
ShowCursor()
→ void
-
See RaylibCoreDart.ShowCursor.
-
StartAutomationEventRecording()
→ void
-
See RaylibCoreDart.StartAutomationEventRecording.
-
StopAutomationEventRecording()
→ void
-
See RaylibCoreDart.StopAutomationEventRecording.
-
SwapScreenBuffer()
→ void
-
See RaylibCoreDart.SwapScreenBuffer.
-
TakeScreenshot(String fileName)
→ void
-
See RaylibCoreDart.TakeScreenshot.
-
TextAppend(String text, String append)
→ String
-
See RaylibCoreDart.TextAppend.
-
TextFindIndex(String text, String search)
→ int
-
See RaylibCoreDart.TextFindIndex.
-
TextFormat(String text, [List<Object?> args = const []])
→ String
-
See RaylibCoreDart.TextFormat.
-
TextInsert(String text, String insert, int position)
→ String
-
See RaylibCoreDart.TextInsert.
-
TextIsEqual(String text1, String text2)
→ bool
-
See RaylibCoreDart.TextIsEqual.
-
TextJoin(List<String> textList, String delimiter)
→ String
-
See RaylibCoreDart.TextJoin.
-
TextLength(String text)
→ int
-
See RaylibCoreDart.TextLength.
-
TextRemoveSpaces(String text)
→ String
-
See RaylibCoreDart.TextRemoveSpaces.
-
TextReplace(String text, String search, String replacement)
→ String
-
See RaylibCoreDart.TextReplace.
-
TextReplaceBetween(String text, String begin, String end, String replacement)
→ String
-
See RaylibCoreDart.TextReplaceBetween.
-
TextSplit(String text, String delimiter)
→ List<String>
-
See RaylibCoreDart.TextSplit.
-
TextSubtext(String text, int position, int length)
→ String
-
See RaylibCoreDart.TextSubtext.
-
TextToCamel(String text)
→ String
-
See RaylibCoreDart.TextToCamel.
-
TextToFloat(String text)
→ double
-
See RaylibCoreDart.TextToFloat.
-
TextToInteger(String text)
→ int
-
See RaylibCoreDart.TextToInteger.
-
TextToLower(String text)
→ String
-
See RaylibCoreDart.TextToLower.
-
TextToPascal(String text)
→ String
-
See RaylibCoreDart.TextToPascal.
-
TextToSnake(String text)
→ String
-
See RaylibCoreDart.TextToSnake.
-
TextToUpper(String text)
→ String
-
See RaylibCoreDart.TextToUpper.
-
ToggleBorderlessWindowed()
→ void
-
See RaylibCoreDart.ToggleBorderlessWindowed.
-
ToggleFullscreen()
→ void
-
See RaylibCoreDart.ToggleFullscreen.
-
TraceLog(TraceLogLevel logLevel, String text)
→ void
-
See RaylibCoreDart.TraceLog.
-
UnloadAutomationEventList(AutomationEventListD list)
→ void
-
See RaylibCoreDart.UnloadAutomationEventList.
-
UnloadDirectoryFiles(FilePathListD files)
→ void
-
See RaylibCoreDart.UnloadDirectoryFiles.
-
UnloadDroppedFiles(FilePathListD files)
→ void
-
See RaylibCoreDart.UnloadDroppedFiles.
-
UnloadFont(FontD font)
→ void
-
See RaylibCoreDart.UnloadFont.
-
UnloadFontData(List<GlyphInfoD> glyphs)
→ void
-
See RaylibCoreDart.UnloadFontData.
-
UnloadImage(ImageD image)
→ void
-
See RaylibCoreDart.UnloadImage.
-
UnloadMaterial(MaterialD material)
→ void
-
See RaylibCoreDart.UnloadMaterial.
-
UnloadMesh(MeshD mesh)
→ void
-
See RaylibCoreDart.UnloadMesh.
-
UnloadModel(ModelD model)
→ void
-
See RaylibCoreDart.UnloadModel.
-
UnloadModelAnimations(List<ModelAnimationD> animations)
→ void
-
See RaylibCoreDart.UnloadModelAnimations.
-
UnloadRenderTexture(RenderTextureD target)
→ void
-
See RaylibCoreDart.UnloadRenderTexture.
-
UnloadShader(ShaderD shader)
→ void
-
See RaylibCoreDart.UnloadShader.
-
UnloadTexture(TextureD texture)
→ void
-
See RaylibCoreDart.UnloadTexture.
-
UnloadVrStereoConfig(VrStereoConfigD config)
→ void
-
See RaylibCoreDart.UnloadVrStereoConfig.
-
UpdateCamera(Camera3DD camera, CameraMode mode)
→ void
-
See RaylibCoreDart.UpdateCamera.
-
UpdateCameraPro(Camera3DD camera, Vector3D movement, Vector3D rotation, num zoom)
→ void
-
See RaylibCoreDart.UpdateCameraPro.
-
UpdateGestures()
→ void
-
See RaylibCoreDart.UpdateGestures.
-
UpdateMeshBuffer(MeshD mesh, num index, TypedDataList data, num offset)
→ void
-
See RaylibCoreDart.UpdateMeshBuffer.
-
UpdateModelAnimation(ModelD model, ModelAnimationD anim, num frame)
→ void
-
See RaylibCoreDart.UpdateModelAnimation.
-
UpdateModelAnimationEx(ModelD model, ModelAnimationD animA, num frameA, ModelAnimationD animB, num frameB, num blend)
→ void
-
See RaylibCoreDart.UpdateModelAnimationEx.
-
UpdateTexture(TextureD texture, Uint8List pixels)
→ void
-
See RaylibCoreDart.UpdateTexture.
-
UpdateTextureRec(TextureD texture, RectangleD rec, Uint8List pixels)
→ void
-
See RaylibCoreDart.UpdateTextureRec.
-
UploadMesh(MeshD mesh, bool dynamic)
→ void
-
See RaylibCoreDart.UploadMesh.
-
WaitTime(num seconds)
→ void
-
See RaylibCoreDart.WaitTime.
-
WindowShouldClose()
→ bool
-
See RaylibCoreDart.WindowShouldClose.