GuiControl enum

raygui GuiControl enum.

Inheritance
Available extensions

Values

DEFAULT → const GuiControl

DEFAULT

const GuiControl(0)
LABEL → const GuiControl

LABEL

const GuiControl(1)
BUTTON → const GuiControl

BUTTON

const GuiControl(2)
TOGGLE → const GuiControl

TOGGLE

const GuiControl(3)
SLIDER → const GuiControl

SLIDER

const GuiControl(4)
PROGRESSBAR → const GuiControl

PROGRESSBAR

const GuiControl(5)
CHECKBOX → const GuiControl

CHECKBOX

const GuiControl(6)
COMBOBOX → const GuiControl

COMBOBOX

const GuiControl(7)

DROPDOWNBOX

const GuiControl(8)
TEXTBOX → const GuiControl

TEXTBOX

const GuiControl(9)
VALUEBOX → const GuiControl

VALUEBOX

const GuiControl(10)
CONTROL11 → const GuiControl

CONTROL11

const GuiControl(11)
LISTVIEW → const GuiControl

LISTVIEW

const GuiControl(12)
COLORPICKER → const GuiControl

COLORPICKER

const GuiControl(13)
SCROLLBAR → const GuiControl

SCROLLBAR

const GuiControl(14)
STATUSBAR → const GuiControl

STATUSBAR

const GuiControl(15)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiControl
Returns the GuiControl for the given native value.

Constants

values → const List<GuiControl>
A constant List of the values in this enum, in order of their declaration.