GuiControl enum
raygui GuiControl enum.
Values
- DEFAULT → const GuiControl
-
DEFAULTconst GuiControl(0) - LABEL → const GuiControl
-
LABELconst GuiControl(1) - BUTTON → const GuiControl
-
BUTTONconst GuiControl(2) - TOGGLE → const GuiControl
-
TOGGLEconst GuiControl(3) - SLIDER → const GuiControl
-
SLIDERconst GuiControl(4) - PROGRESSBAR → const GuiControl
-
PROGRESSBARconst GuiControl(5) - CHECKBOX → const GuiControl
-
CHECKBOXconst GuiControl(6) - COMBOBOX → const GuiControl
-
COMBOBOXconst GuiControl(7) - DROPDOWNBOX → const GuiControl
-
DROPDOWNBOXconst GuiControl(8) - TEXTBOX → const GuiControl
-
TEXTBOXconst GuiControl(9) - VALUEBOX → const GuiControl
-
VALUEBOXconst GuiControl(10) - CONTROL11 → const GuiControl
-
CONTROL11const GuiControl(11) - LISTVIEW → const GuiControl
-
LISTVIEWconst GuiControl(12) - COLORPICKER → const GuiControl
-
COLORPICKERconst GuiControl(13) - SCROLLBAR → const GuiControl
-
SCROLLBARconst GuiControl(14) - STATUSBAR → const GuiControl
-
STATUSBARconst GuiControl(15)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GuiControl -
Returns the GuiControl for the given native
value.
Constants
-
values
→ const List<
GuiControl> - A constant List of the values in this enum, in order of their declaration.