MeshBase<X extends MeshBase<X, M, V3, Q, V4> , M extends MatrixBase<M, V3, Q, V4> , V3 extends Vector3Base<V3, M, Q, V4> , Q extends QuaternionBase<Q, M, V3, V4> , V4 extends Vector4Base<V4, Q, M, V3> > mixin
Backend-agnostic contract for MeshBase structs.
Must be mixed into every concrete platform implementation of a Raylib type to ensure a unified API surface across different backends.
Vertex data and vao/vbo.
- Superclass constraints
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
animNormals
↔ RaylibLiveList<
double> -
Animated normals (after bones transformations)
getter/setter pair
- animNormalsCount → int
-
Expected length of animNormals.
no setter
-
animVertices
↔ RaylibLiveList<
double> -
Animated vertex positions (after bones transformations)
getter/setter pair
- animVerticesCount → int
-
Expected length of animVertices.
no setter
- boneCount ↔ int
-
Number of bones
getter/setter pair
-
boneIds
↔ RaylibLiveList<
int> -
Vertex bone ids, max 255 bone ids, up to 4 bones influence by vertex (skinning) (shader-location = 6)
getter/setter pair
- boneIdsCount → int
-
Expected length of boneIds.
no setter
-
boneMatrices
↔ RaylibLiveList<
M> -
Bones animated transformation matrices
getter/setter pair
- boneMatricesCount → int
-
Expected length of boneMatrices.
no setter
-
boneWeights
↔ RaylibLiveList<
double> -
Vertex bone weight, up to 4 bones influence by vertex (skinning) (shader-location = 7)
getter/setter pair
- boneWeightsCount → int
-
Expected length of boneWeights.
no setter
-
colors
↔ RaylibLiveList<
int> -
Vertex colors (RGBA - 4 components per vertex) (shader-location = 3)
getter/setter pair
- colorsCount → int
-
Expected length of colors.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ RaylibLiveList<
int> -
Vertex indices (in case vertex data comes indexed)
getter/setter pair
- indicesCount → int
-
Expected length of indices.
no setter
-
normals
↔ RaylibLiveList<
double> -
Vertex normals (XYZ - 3 components per vertex) (shader-location = 2)
getter/setter pair
- normalsCount → int
-
Expected length of normals.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
-
tangents
↔ RaylibLiveList<
double> -
Vertex tangents (XYZW - 4 components per vertex) (shader-location = 4)
getter/setter pair
- tangentsCount → int
-
Expected length of tangents.
no setter
-
texcoords
↔ RaylibLiveList<
double> -
Vertex texture coordinates (UV - 2 components per vertex) (shader-location = 1)
getter/setter pair
-
texcoords2
↔ RaylibLiveList<
double> -
Vertex texture second coordinates (UV - 2 components per vertex) (shader-location = 5)
getter/setter pair
- texcoords2Count → int
-
Expected length of texcoords2.
no setter
- texcoordsCount → int
-
Expected length of texcoords.
no setter
- triangleCount ↔ int
-
Number of triangles stored (indexed or not)
getter/setter pair
- vaoId ↔ int
-
OpenGL Vertex Array Object id
getter/setter pair
-
vboId
↔ RaylibLiveList<
int> -
OpenGL Vertex Buffer Objects id (default vertex data)
getter/setter pair
- vboIdCount → int
-
Expected length of vboId.
no setter
- vertexCount ↔ int
-
Number of vertices stored in arrays
getter/setter pair
-
vertices
↔ RaylibLiveList<
double> -
Vertex position (XYZ - 3 components per vertex) (shader-location = 0)
getter/setter pair
- verticesCount → int
-
Expected length of vertices.
no setter
Methods
-
clone(
) → X -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
inherited
-
copy(
) → X -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setD(
X o) → X -
Copies the fields of
ointo this instance and returnsthis.inherited -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_vboIdCount → int
-
Number of components in the
vboIdbuffer.no setter
Static Methods
-
BASE_animNormalsCount(
int vertexCount) → int -
Number of components in the
animNormalsbuffer. -
BASE_animVerticesCount(
int vertexCount) → int -
Number of components in the
animVerticesbuffer. -
BASE_boneIdsCount(
int vertexCount) → int -
Number of components in the
boneIdsbuffer. -
BASE_boneMatricesCount(
int boneCount) → int -
Number of components in the
boneMatricesbuffer. -
BASE_boneWeightsCount(
int vertexCount) → int -
Number of components in the
boneWeightsbuffer. -
BASE_colorsCount(
int vertexCount) → int -
Number of components in the
colorsbuffer. -
BASE_indicesCount(
int triangleCount) → int -
Number of components in the
indicesbuffer. -
BASE_normalsCount(
int vertexCount) → int -
Number of components in the
normalsbuffer. -
BASE_tangentsCount(
int vertexCount) → int -
Number of components in the
tangentsbuffer. -
BASE_texcoords2Count(
int vertexCount) → int -
Number of components in the
texcoords2buffer. -
BASE_texcoordsCount(
int vertexCount) → int -
Number of components in the
texcoordsbuffer. -
BASE_verticesCount(
int vertexCount) → int -
Number of components in the
verticesbuffer.