MeshD class
Mesh, vertex data and vao/vbo
- Inheritance
-
- Object
- RaylibStruct<
MeshD> - MeshD
Constructors
-
MeshD({StructPointer<
MeshD> ? op, int vertexCount = 0, int triangleCount = 0, int boneCount = 0, List<double> ? vertices, List<double> ? texcoords, List<double> ? texcoords2, List<double> ? normals, List<double> ? tangents, List<int> ? colors, List<int> ? indices, List<int> ? boneIndices, List<double> ? boneWeights, List<double> ? animVertices, List<double> ? animNormals, int vaoId = 0, List<int> ? vboId}) - MeshD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
animNormals
↔ StructLiveList<
double, RFloat> -
Animated normals (after bones transformations)
getter/setter pair
- animNormalsCount → int
-
Number of components in the animNormals buffer.
no setter
-
animVertices
↔ StructLiveList<
double, RFloat> -
Animated vertex positions (after bones transformations)
getter/setter pair
- animVerticesCount → int
-
Number of components in the animVertices buffer.
no setter
- boneCount ↔ int
-
getter/setter pair
-
boneIndices
↔ StructLiveList<
int, RUnsignedChar> -
Vertex bone indices, up to 4 bones influence by vertex (skinning) (shader-location = 6)
getter/setter pair
- boneIndicesCount → int
-
Number of components in the boneIndices buffer.
no setter
-
boneWeights
↔ StructLiveList<
double, RFloat> -
Vertex bone weight, up to 4 bones influence by vertex (skinning) (shader-location = 7)
getter/setter pair
- boneWeightsCount → int
-
Number of components in the boneWeights buffer.
no setter
-
colors
↔ StructLiveList<
int, RUnsignedChar> -
Vertex colors (RGBA - 4 components per vertex) (shader-location = 3)
getter/setter pair
- colorsCount → int
-
Number of components in the colors buffer.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ StructLiveList<
int, RUnsignedShort> -
Vertex indices (in case vertex data comes indexed)
getter/setter pair
- indicesCount → int
-
Number of components in the indices buffer.
no setter
-
normals
↔ StructLiveList<
double, RFloat> -
Vertex normals (XYZ - 3 components per vertex) (shader-location = 2)
getter/setter pair
- normalsCount → int
-
Number of components in the normals buffer.
no setter
-
op
↔ StructPointer<
MeshD> ? -
The C-owned or RaylibTemp-owned typed pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
-
tangents
↔ StructLiveList<
double, RFloat> -
Vertex tangents (XYZW - 4 components per vertex) (shader-location = 4)
getter/setter pair
- tangentsCount → int
-
Number of components in the tangents buffer.
no setter
-
texcoords
↔ StructLiveList<
double, RFloat> -
Vertex texture coordinates (UV - 2 components per vertex) (shader-location = 1)
getter/setter pair
-
texcoords2
↔ StructLiveList<
double, RFloat> -
Vertex texture second coordinates (UV - 2 components per vertex) (shader-location = 5)
getter/setter pair
- texcoords2Count → int
-
Number of components in the texcoords2 buffer.
no setter
- texcoordsCount → int
-
Number of components in the texcoords buffer.
no setter
- triangleCount ↔ int
-
Number of triangles stored (indexed or not)
getter/setter pair
- vaoId ↔ int
-
OpenGL Vertex Array Object id
getter/setter pair
-
vboId
↔ StructLiveList<
int, RUnsignedInt> -
OpenGL Vertex Buffer Objects id (default vertex data)
getter/setter pair
- vboIdCount → int
-
Number of components in the vboId buffer.
no setter
- vertexCount ↔ int
-
Number of vertices stored in arrays
getter/setter pair
-
vertices
↔ StructLiveList<
double, RFloat> -
Vertex position (XYZ - 3 components per vertex) (shader-location = 0)
getter/setter pair
- verticesCount → int
-
Number of components in the vertices buffer.
no setter
Methods
-
clone(
) → MeshD -
Returns a deep copy of this instance, preserving op if present.
override
-
copy(
) → MeshD -
Returns a deep copy of this instance without op.
inherited
-
getOp(
) → StructPointer< MeshD> -
Returns op, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOpAndDispose(
) → StructPointer< MeshD> -
Returns op and immediately disposes this struct.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDart(
MeshD o) → MeshD -
Copies the fields of
ointo this instance.override -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
structAllocateInto(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.override -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears op.
inherited
-
structOnOp(
void callback(StructPointer< MeshD> mesh)) → void -
Calls
callbackwith op if it is set, otherwise no-ops.inherited -
structReadFrom(
MemoryPointer< RType> p) → void -
override
-
structSetTag(
String newTag) → MeshD -
Sets RaylibTempStructState.tag to
newTag.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires op.
inherited
-
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires op.
inherited
-
structWriteInto(
MemoryPointer< RType> p) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_vboIdCount → int
-
Number of components in the vboId buffer.
no setter
-
field_animNormals
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for animNormals.
final
-
field_animVertices
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for animVertices.
final
-
field_boneCount
→ StructValueField<
int, RInt> -
Field descriptor for boneCount.
final
-
field_boneIndices
→ StructPointerArrayField<
int, RUnsignedChar> -
Field descriptor for boneIndices.
final
-
field_boneWeights
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for boneWeights.
final
-
field_colors
→ StructPointerArrayField<
int, RUnsignedChar> -
Field descriptor for colors.
final
-
field_indices
→ StructPointerArrayField<
int, RUnsignedShort> -
Field descriptor for indices.
final
-
field_normals
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for normals.
final
-
field_tangents
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for tangents.
final
-
field_texcoords
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for texcoords.
final
-
field_texcoords2
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for texcoords2.
final
-
field_triangleCount
→ StructValueField<
int, RInt> -
Field descriptor for triangleCount.
final
-
field_vaoId
→ StructValueField<
int, RUnsignedInt> -
Field descriptor for vaoId.
final
-
field_vboId
→ StructPointerArrayField<
int, RUnsignedInt> -
Field descriptor for vboId.
final
-
field_vertexCount
→ StructValueField<
int, RInt> -
Field descriptor for vertexCount.
final
-
field_vertices
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for vertices.
final
-
struct
→ StructType<
MeshD> -
Describes the raw memory layout, construction, and pointer representation
of this struct type.
final
-
structLayout
→ StructLayout<
MeshField> -
Raw memory layout of this object.
final
Static Methods
-
BASE_animNormalsCount(
int vertexCount) → int - Number of components in the animNormals buffer.
-
BASE_animVerticesCount(
int vertexCount) → int - Number of components in the animVertices buffer.
-
BASE_boneIndicesCount(
int vertexCount) → int - Number of components in the boneIndices buffer.
-
BASE_boneWeightsCount(
int vertexCount) → int - Number of components in the boneWeights buffer.
-
BASE_colorsCount(
int vertexCount) → int - Number of components in the colors buffer.
-
BASE_indicesCount(
int triangleCount) → int - Number of components in the indices buffer.
-
BASE_normalsCount(
int vertexCount) → int - Number of components in the normals buffer.
-
BASE_tangentsCount(
int vertexCount) → int - Number of components in the tangents buffer.
-
BASE_texcoords2Count(
int vertexCount) → int - Number of components in the texcoords2 buffer.
-
BASE_texcoordsCount(
int vertexCount) → int - Number of components in the texcoords buffer.
-
BASE_verticesCount(
int vertexCount) → int - Number of components in the vertices buffer.