MeshField enum
- Inheritance
- Mixed-in types
- Available extensions
Values
- vertexCount → const MeshField
- triangleCount → const MeshField
- vertices → const MeshField
- texcoords → const MeshField
- texcoords2 → const MeshField
- normals → const MeshField
- tangents → const MeshField
- colors → const MeshField
- indices → const MeshField
- boneCount → const MeshField
- boneIndices → const MeshField
- boneWeights → const MeshField
- animVertices → const MeshField
- animNormals → const MeshField
- vaoId → const MeshField
- vboId → const MeshField
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited