MouseButtonInfo class final
Snapshot of a single mouse button's state for the current frame.
All fields default to false; only the relevant flags are set to true
when constructing via RaylibCoreModuleBase.GetMouseInfo.
Constructors
- MouseButtonInfo({bool up = false, bool down = false, bool pressed = false, bool released = false})
-
const
Properties
- down → bool
-
trueif the button is held down this frame.final - hashCode → int
-
The hash code for this object.
no setterinherited
- pressed → bool
-
trueif the button was just pressed this frame.final - released → bool
-
trueif the button was just released this frame.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- up → bool
-
trueif the button is not held down this frame.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited