MouseInfo<Vector2StructType> class final

Constructors

MouseInfo({Vector2StructType? position, Vector2StructType? delta, Vector2StructType? wheel, MouseButtonInfo? btnLeft, MouseButtonInfo? btnMiddle, MouseButtonInfo? btnRight, MouseButtonInfo? btnSide, MouseButtonInfo? btnExtra, MouseButtonInfo? btnForward, MouseButtonInfo? btnBack})

Properties

btnBack MouseButtonInfo
final
btnExtra MouseButtonInfo
final
btnForward MouseButtonInfo
final
btnLeft MouseButtonInfo
final
btnMiddle MouseButtonInfo
final
btnRight MouseButtonInfo
final
btnSide MouseButtonInfo
final
delta → Vector2StructType
final
hashCode int
The hash code for this object.
no setterinherited
position → Vector2StructType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wheel → Vector2StructType
final

Methods

getButtonInfo(MouseButton button) MouseButtonInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited