RArray<E extends RType> class
final
Properties
- alignment → int
-
Natural alignment for this field, per C rules,
arrays align to their element size, not their total size.
no setteroverride
- byteSize → int
-
Size of a single element.
no setteroverride
- count → int
-
final
- element → E
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
V> (MemoryPointer< RType> p, int offset) → V? -
Read this RType from a
pat givenoffset.override -
toString(
) → String -
A string representation of this object.
inherited
-
write<
V> (MemoryPointer< RType> p, int offset, V? value) → void -
Write a
valueof RType into apat givenoffset.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited