RaylibAudioModuleCaptureIds class

Produces stable slot key strings identifying the allocation origin of each Audio module function's captured Struct.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

LoadAudioStream(num sampleRate, num sampleSize, num channels) String
Capture ID for RaylibAudioModuleBase.LoadAudioStream.
LoadMusicStream(String fileName) String
Capture ID for RaylibAudioModuleBase.LoadMusicStream.
LoadMusicStreamFromMemory(String fileType, Uint8List data) String
Capture ID for RaylibAudioModuleBase.LoadMusicStreamFromMemory.
LoadSound(String fileName) String
Capture ID for RaylibAudioModuleBase.LoadSound.
LoadSoundAlias(SoundBase<SoundBase<dynamic, AudioStreamBase>, AudioStreamBase> source) String
Capture ID for RaylibAudioModuleBase.LoadSoundAlias.
LoadSoundFromWave(WaveBase<WaveBase> wave) String
Capture ID for RaylibAudioModuleBase.LoadSoundFromWave.
LoadWave(String fileName) String
Capture ID for RaylibAudioModuleBase.LoadWave.
LoadWaveFromMemory(String fileType, Uint8List fileData) String
Capture ID for RaylibAudioModuleBase.LoadWaveFromMemory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
WaveCopy(WaveBase<WaveBase> wave) String
Capture ID for RaylibAudioModuleBase.WaveCopy.

Operators

operator ==(Object other) bool
The equality operator.
inherited