CameraRoll abstract method
Rotates camera around its forward vector by angle radians.
Roll is "turning your head sideways to the left or right"
Implementation
void CameraRoll(
StructPointer<Camera3DD> camera,
double angle,
);
Rotates camera around its forward vector by angle radians.
Roll is "turning your head sideways to the left or right"
void CameraRoll(
StructPointer<Camera3DD> camera,
double angle,
);