CameraMoveRight abstract method
Moves the camera target in its current right direction by distance.
If moveInWorldPlane is true, movement is constrained to the XZ plane
regardless of the camera's pitch.
Implementation
void CameraMoveRight(
Camera3DStructType camera,
num distance,
bool moveInWorldPlane,
);