CameraPitch abstract method
void
CameraPitch()
Rotates camera around its right vector by angle radians.
Pitch is "looking up and down".
If lockView is true, pitch is clamped to prevent flipping.
If rotateAroundTarget is true, the camera orbits its target;
otherwise it rotates in place.
If rotateUp is true, the up vector is rotated as well (typically useful in CameraMode.CAMERA_FREE).
Implementation
void CameraPitch(
Camera3DStructType camera,
num angle,
bool lockView,
bool rotateAroundTarget,
bool rotateUp,
);