RaylibConstants class

Dart-side mirror of compile-time constants.

Constructors

RaylibConstants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

DEG2RAD ↔ double
DEG2RAD
getter/setter pair
EPSILON ↔ double
EPSILON
getter/setter pair
M_1_PI ↔ double
M_1_PI
getter/setter pair
M_2_PI ↔ double
M_2_PI
getter/setter pair
M_2_SQRTPI ↔ double
M_2_SQRTPI
getter/setter pair
M_E ↔ double
M_E
getter/setter pair
M_LN10 ↔ double
M_LN10
getter/setter pair
M_LN2 ↔ double
M_LN2
getter/setter pair
M_LOG10E ↔ double
M_LOG10E
getter/setter pair
M_LOG2E ↔ double
M_LOG2E
getter/setter pair
M_PI ↔ double
M_PI
getter/setter pair
M_PI_2 ↔ double
M_PI_2
getter/setter pair
M_PI_4 ↔ double
M_PI_4
getter/setter pair
M_SQRT1_2 ↔ double
M_SQRT1_2
getter/setter pair
M_SQRT2 ↔ double
M_SQRT2
getter/setter pair
MATERIAL_MAP_DIFFUSE ↔ MaterialMapIndex
MATERIAL_MAP_DIFFUSE
getter/setter pair
MATERIAL_MAP_SPECULAR ↔ MaterialMapIndex
MATERIAL_MAP_SPECULAR
getter/setter pair
MAX_MATERIAL_MAPS ↔ int
MAX_MATERIAL_MAPS
getter/setter pair
MAX_TOUCH_POINTS ↔ int
MAX_TOUCH_POINTS
getter/setter pair
PI ↔ double
PI
getter/setter pair
RAD2DEG ↔ double
RAD2DEG
getter/setter pair
RAND_MAX ↔ int
M_SQRT1_2
getter/setter pair
RAYLIB_VERSION ↔ String
RAYLIB_VERSION
getter/setter pair
RAYLIB_VERSION_MAJOR ↔ int
RAYLIB_VERSION_MAJOR
getter/setter pair
RAYLIB_VERSION_MINOR ↔ int
RAYLIB_VERSION_MINOR
getter/setter pair
RAYLIB_VERSION_PATCH ↔ int
RAYLIB_VERSION_PATCH
getter/setter pair
SHADER_LOC_MAP_DIFFUSE ↔ ShaderLocationIndex
SHADER_LOC_MAP_DIFFUSE
getter/setter pair
SHADER_LOC_MAP_SPECULAR ↔ ShaderLocationIndex
SHADER_LOC_MAP_SPECULAR
getter/setter pair