RaylibConstants class

Dart-side mirror of Raylib's compile-time constants (RAYLIB_VERSION, PI, etc.), kept in the base package so all backends share a single source of truth.

Constructors

RaylibConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

DEG2RAD double
Predefined constant DEG2RAD.
final
EPSILON double
Predefined constant EPSILON.
final
M_1_PI double
Predefined constant M_1_PI.
final
M_2_PI double
Predefined constant M_2_PI.
final
M_2_SQRTPI double
Predefined constant M_2_SQRTPI.
final
M_E double
Predefined constant M_E.
final
M_LN10 double
Predefined constant M_LN10.
final
M_LN2 double
Predefined constant M_LN2.
final
M_LOG10E double
Predefined constant M_LOG10E.
final
M_LOG2E double
Predefined constant M_LOG2E.
final
M_PI double
Predefined constant M_PI.
final
M_PI_2 double
Predefined constant M_PI_2.
final
M_PI_4 double
Predefined constant M_PI_4.
final
M_SQRT1_2 double
Predefined constant M_SQRT1_2.
final
M_SQRT2 double
Predefined constant M_SQRT2.
final
MATERIAL_MAP_DIFFUSE MaterialMapIndex
Predefined constant MATERIAL_MAP_DIFFUSE.
final
MATERIAL_MAP_SPECULAR MaterialMapIndex
Predefined constant MATERIAL_MAP_SPECULAR.
final
MAX_MATERIAL_MAPS int
Predefined constant MAX_MATERIAL_MAPS.
final
PI double
Predefined constant PI.
final
RAD2DEG double
Predefined constant RAD2DEG.
final
RAND_MAX int
Predefined constant M_SQRT1_2.
final
RAYLIB_VERSION String
Predefined constant RAYLIB_VERSION.
final
RAYLIB_VERSION_MAJOR int
Predefined constant RAYLIB_VERSION_MAJOR.
final
RAYLIB_VERSION_MINOR int
Predefined constant RAYLIB_VERSION_MINOR.
final
RAYLIB_VERSION_PATCH int
Predefined constant RAYLIB_VERSION_PATCH.
final
SHADER_LOC_MAP_DIFFUSE int
Predefined constant SHADER_LOC_MAP_DIFFUSE.
final
SHADER_LOC_MAP_SPECULAR int
Predefined constant SHADER_LOC_MAP_SPECULAR.
final