RaylibCoreDart<R extends RaylibBase> class
final
Backend-agnostic Raylib Core module.
- Inheritance
-
- Object
- RaylibModule<
R> - RaylibCoreDart
Constructors
- RaylibCoreDart(R rl)
Properties
-
$
→ RaylibTemp<
RaylibBase> -
See RaylibTemp.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- rl → R
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
BeginBlendMode(
BlendMode mode) → void - Begin blending mode (alpha, additive, multiplied, subtract, custom)
-
BeginDrawing(
) → void - Setup canvas (framebuffer) to start drawing
-
BeginMode2D(
Camera2DD camera) → void - Begin 2D mode with custom camera (2D)
-
BeginMode3D(
Camera3DD camera) → void - Begin 3D mode with custom camera (3D)
-
BeginScissorMode(
num x, num y, num width, num height) → void - Begin scissor mode (define screen area for following drawing)
-
BeginShaderMode(
ShaderD shader) → void - Begin custom shader drawing
-
BeginTextureMode(
RenderTextureD target) → void - Begin drawing to render texture
-
BeginVrStereoMode(
VrStereoConfigD config) → void - Begin stereo rendering (requires VR simulator)
-
ChangeDirectory(
String dir) → bool - Change working directory, return true on success
-
CheckCollisionBoxes(
BoundingBoxD box1, BoundingBoxD box2) → bool - Check collision between two bounding boxes
-
CheckCollisionBoxSphere(
BoundingBoxD box, Vector3D center, num radius) → bool - Check collision between box and sphere
-
CheckCollisionCircleLine(
Vector2D center, num radius, Vector2D p1, Vector2D p2) → bool -
Check if circle collides with a line created betweeen two points
p1andp2 -
CheckCollisionCircleRec(
Vector2D center, num radius, RectangleD rec) → bool - Check collision between circle and rectangle
-
CheckCollisionCircles(
Vector2D center1, num radius1, Vector2D center2, num radius2) → bool - Check collision between two circles
-
CheckCollisionLines(
Vector2D startPos1, Vector2D endPos1, Vector2D startPos2, Vector2D endPos2) → (bool, Vector2D) - Check the collision between two lines defined by two points each, returns collision point by reference
-
CheckCollisionPointCircle(
Vector2D point, Vector2D center, num radius) → bool - Check if point is inside circle
-
CheckCollisionPointLine(
Vector2D point, Vector2D p1, Vector2D p2, num threshold) → bool -
Check if point belongs to line created between two points
p1andp2with defined margin in pixelsthreshold -
CheckCollisionPointPoly(
Vector2D point, List< Vector2D> points) → bool - Check if point is within a polygon described by array of vertices
-
CheckCollisionPointRec(
Vector2D point, RectangleD rec) → bool - Check if point is inside rectangle
-
CheckCollisionPointTriangle(
Vector2D point, Vector2D p1, Vector2D p2, Vector2D p3) → bool - Check if point is inside a triangle
-
CheckCollisionRecs(
RectangleD rec1, RectangleD rec2) → bool - Check collision between two rectangles
-
CheckCollisionSpheres(
Vector3D center1, num radius1, Vector3D center2, num radius2) → bool - Check collision between two spheres
-
ClearBackground(
ColorD color) → void - Set background color (framebuffer clear color)
-
ClearWindowState(
Iterable< ConfigFlags> flags) → void - Clear window configuration state flags
-
CloseWindow(
) → void - Close window and unload OpenGL context
-
CodepointToUTF8(
num codepoint) → (String, int) - Encode one codepoint into UTF-8 byte array (array length returned as parameter)
-
ColorAlpha(
ColorD color, num alpha) → ColorD - Get color with alpha applied, alpha goes from 0.0 to 1.0
-
ColorAlphaBlend(
ColorD dst, ColorD src, ColorD tint) → ColorD - Get src alpha-blended into dst color with tint
-
ColorBrightness(
ColorD color, num factor) → ColorD - Get color with brightness correction, brightness factor goes from -1.0 to 1.0
-
ColorContrast(
ColorD color, num contrast) → ColorD - Get color with contrast correction, contrast values between -1.0 and 1.0
-
ColorFromHSV(
num hue, num saturation, num value) → ColorD -
Get a Color from HSV values, hue
0..360, saturation/value0..1 -
ColorFromNormalized(
Vector4D normalized) → ColorD -
Get Color from normalized values
0..1 -
ColorIsEqual(
ColorD col1, ColorD col2) → bool - Check if two colors are equal
-
ColorLerp(
ColorD color1, ColorD color2, num factor) → ColorD -
Get color lerp interpolation between two colors, factor
0.0..1.0 -
ColorNormalize(
ColorD color) → Vector4D -
Get Color normalized as float
0..1 -
ColorTint(
ColorD color, ColorD tint) → ColorD - Get color multiplied with another color
-
ColorToHSV(
ColorD color) → Vector3D -
Get HSV values for a Color, hue
0..360, saturation/value0..1 -
ColorToInt(
ColorD color) → int - Get hexadecimal value for a Color (0xRRGGBBAA)
-
CompressData(
Uint8List data) → Uint8List - Compress data (DEFLATE algorithm)
-
ComputeCRC32(
Uint8List data) → int - Compute CRC32 hash code
-
ComputeMD5(
Uint8List data) → Uint8List - Compute MD5 hash code
-
ComputeSHA1(
Uint8List data) → Uint8List - Compute SHA1 hash code
-
ComputeSHA256(
Uint8List data) → Uint8List - Compute SHA256 hash code
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
DecodeDataBase64(
Uint8List data) → Uint8List - Decode Base64 string data
-
DecompressData(
Uint8List compData) → Uint8List - Decompress data (DEFLATE algorithm)
-
DirectoryExists(
String dirPath) → bool - Check if a directory path exists
-
DisableCursor(
) → void - Disables cursor (lock cursor)
-
DisableEventWaiting(
) → void - Disable waiting for events on EndDrawing(), automatic events polling
-
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
disposeStructWithOpFreed<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then frees the temporary allocation backing the pointer, if any.inherited -
disposeStructWithOpUnslotted<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.inherited -
DrawBillboard(
Camera3DD camera, TextureD texture, Vector3D position, num scale, ColorD tint) → void - Draw a billboard texture
-
DrawBillboardPro(
Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector3D up, Vector2D size, Vector2D origin, num rotation, ColorD tint) → void - Draw a billboard texture defined by source and rotation
-
DrawBillboardRec(
Camera3DD camera, TextureD texture, RectangleD source, Vector3D position, Vector2D size, ColorD tint) → void - Draw a billboard texture defined by source
-
DrawBoundingBox(
BoundingBoxD box, ColorD color) → void - Draw bounding box (wires)
-
DrawCapsule(
Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color) → void - Draw a capsule with the center of its sphere caps at startPos and endPos
-
DrawCapsuleWires(
Vector3D startPos, Vector3D endPos, num radius, num slices, num rings, ColorD color) → void - Draw capsule wireframe with the center of its sphere caps at startPos and endPos
-
DrawCircle(
num centerX, num centerY, num radius, ColorD color) → void - Draw a color-filled circle
-
DrawCircle3D(
Vector3D center, num radius, Vector3D rotationAxis, num rotationAngle, ColorD color) → void - Draw a circle in 3D world space
-
DrawCircleGradient(
Vector2D center, num radius, ColorD inner, ColorD outer) → void - Draw a gradient-filled circle
-
DrawCircleLines(
num centerX, num centerY, num radius, ColorD color) → void - Draw circle outline
-
DrawCircleLinesV(
Vector2D center, num radius, ColorD color) → void - Draw circle outline (Vector version)
-
DrawCircleSector(
Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color) → void - Draw a piece of a circle
-
DrawCircleSectorLines(
Vector2D center, num radius, num startAngle, num endAngle, num segments, ColorD color) → void - Draw circle sector outline
-
DrawCircleV(
Vector2D center, num radius, ColorD color) → void - Draw a color-filled circle (Vector version)
-
DrawCube(
Vector3D position, num width, num height, num length, ColorD color) → void - Draw cube
-
DrawCubeV(
Vector3D position, Vector3D size, ColorD color) → void - Draw cube (Vector version)
-
DrawCubeWires(
Vector3D position, num width, num height, num length, ColorD color) → void - Draw cube wires
-
DrawCubeWiresV(
Vector3D position, Vector3D size, ColorD color) → void - Draw cube wires (Vector version)
-
DrawCylinder(
Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color) → void - Draw a cylinder/cone
-
DrawCylinderEx(
Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color) → void - Draw a cylinder with base at startPos and top at endPos
-
DrawCylinderWires(
Vector3D position, num radiusTop, num radiusBottom, num height, num slices, ColorD color) → void - Draw a cylinder/cone wires
-
DrawCylinderWiresEx(
Vector3D startPos, Vector3D endPos, num startRadius, num endRadius, num sides, ColorD color) → void - Draw a cylinder wires with base at startPos and top at endPos
-
DrawEllipse(
num centerX, num centerY, num radiusH, num radiusV, ColorD color) → void - Draw ellipse
-
DrawEllipseLines(
num centerX, num centerY, num radiusH, num radiusV, ColorD color) → void - Draw ellipse outline
-
DrawEllipseLinesV(
Vector2D center, num radiusH, num radiusV, ColorD color) → void - Draw ellipse outline (Vector version)
-
DrawEllipseV(
Vector2D center, num radiusH, num radiusV, ColorD color) → void - Draw ellipse (Vector version)
-
DrawFPS(
num posX, num posY) → void - Draw current FPS
-
DrawGrid(
num slices, num spacing) → void - Draw a grid (centered at (0, 0, 0))
-
DrawLine(
num startPosX, num startPosY, num endPosX, num endPosY, ColorD color) → void - Draw a line
-
DrawLine3D(
Vector3D startPos, Vector3D endPos, ColorD color) → void - Draw a line in 3D world space
-
DrawLineBezier(
Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void - Draw line segment cubic-bezier in-out interpolation
-
DrawLineDashed(
Vector2D startPos, Vector2D endPos, num dashSize, num spaceSize, ColorD color) → void - Draw a dashed line
-
DrawLineEx(
Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void - Draw a line (using triangles/quads)
-
DrawLineStrip(
List< Vector2D> points, ColorD color) → void - Draw lines sequence (using gl lines)
-
DrawLineV(
Vector2D startPos, Vector2D endPos, ColorD color) → void - Draw a line (using gl lines)
-
DrawMesh(
MeshD mesh, MaterialD material, MatrixD transform) → void - Draw a 3d mesh with material and transform
-
DrawMeshInstanced(
MeshD mesh, MaterialD material, List< MatrixD> transforms) → void - Draw multiple mesh instances with material and different transforms
-
DrawModel(
ModelD model, Vector3D position, num scale, ColorD tint) → void - Draw a model (with texture if set)
-
DrawModelEx(
ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void - Draw a model with extended parameters
-
DrawModelWires(
ModelD model, Vector3D position, num scale, ColorD tint) → void - Draw a model wires (with texture if set)
-
DrawModelWiresEx(
ModelD model, Vector3D position, Vector3D rotationAxis, num rotationAngle, Vector3D scale, ColorD tint) → void - Draw a model wires (with texture if set) with extended parameters
-
DrawPixel(
num posX, num posY, ColorD color) → void -
Draw a pixel using geometry
Can be slow, use with care -
DrawPixelV(
Vector2D position, ColorD color) → void -
Draw a pixel using geometry (Vector version)
Can be slow, use with care -
DrawPlane(
Vector3D centerPos, Vector2D size, ColorD color) → void - Draw a plane XZ
-
DrawPoint3D(
Vector3D position, ColorD color) → void - Draw a point in 3D space, actually a small line
-
DrawPoly(
Vector2D center, num sides, num radius, num rotation, ColorD color) → void - Draw a regular polygon (Vector version)
-
DrawPolyLines(
Vector2D center, num sides, num radius, num rotation, ColorD color) → void - Draw a polygon outline of n sides
-
DrawPolyLinesEx(
Vector2D center, num sides, num radius, num rotation, num lineThick, ColorD color) → void - Draw a polygon outline of n sides with extended parameters
-
DrawRay(
RayD ray, ColorD color) → void - Draw a ray line
-
DrawRectangle(
num posX, num posY, num width, num height, ColorD color) → void - Draw a color-filled rectangle
-
DrawRectangleGradientEx(
RectangleD rec, ColorD topLeft, ColorD bottomLeft, ColorD topRight, ColorD bottomRight) → void - Draw a gradient-filled rectangle with custom vertex colors
-
DrawRectangleGradientH(
num posX, num posY, num width, num height, ColorD left, ColorD right) → void - Draw a horizontal-gradient-filled rectangle
-
DrawRectangleGradientV(
num posX, num posY, num width, num height, ColorD top, ColorD bottom) → void - Draw a vertical-gradient-filled rectangle
-
DrawRectangleLines(
num posX, num posY, num width, num height, ColorD color) → void - Draw rectangle outline
-
DrawRectangleLinesEx(
RectangleD rec, num lineThick, ColorD color) → void - Draw rectangle outline with extended parameters
-
DrawRectanglePro(
RectangleD rec, Vector2D origin, num rotation, ColorD color) → void - Draw a color-filled rectangle with pro parameters
-
DrawRectangleRec(
RectangleD rec, ColorD color) → void - Draw a color-filled rectangle
-
DrawRectangleRounded(
RectangleD rec, num roundness, num segments, ColorD color) → void - Draw rectangle with rounded edges
-
DrawRectangleRoundedLines(
RectangleD rec, num roundness, num segments, ColorD color) → void - Draw rectangle lines with rounded edges
-
DrawRectangleRoundedLinesEx(
RectangleD rec, num roundness, num segments, num lineThick, ColorD color) → void - Draw rectangle with rounded edges outline
-
DrawRectangleV(
Vector2D position, Vector2D size, ColorD color) → void - Draw a color-filled rectangle (Vector version)
-
DrawRing(
Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color) → void - Draw ring
-
DrawRingLines(
Vector2D center, num innerRadius, num outerRadius, num startAngle, num endAngle, num segments, ColorD color) → void - Draw ring outline
-
DrawSphere(
Vector3D centerPos, num radius, ColorD color) → void - Draw sphere
-
DrawSphereEx(
Vector3D centerPos, num radius, num rings, num slices, ColorD color) → void - Draw sphere with extended parameters
-
DrawSphereWires(
Vector3D centerPos, num radius, num rings, num slices, ColorD color) → void - Draw sphere wires
-
DrawSplineBasis(
List< Vector2D> points, num thick, ColorD color) → void - Draw spline: B-Spline, minimum 4 points
-
DrawSplineBezierCubic(
List< Vector2D> points, num thick, ColorD color) → void -
Draw spline: Cubic Bezier, minimum 4 points (2 control points):
p1, c2, c3, p4, c5, c6... -
DrawSplineBezierQuadratic(
List< Vector2D> points, num thick, ColorD color) → void -
Draw spline: Quadratic Bezier, minimum 3 points (1 control point):
p1, c2, p3, c4... -
DrawSplineCatmullRom(
List< Vector2D> points, num thick, ColorD color) → void - Draw spline: Catmull-Rom, minimum 4 points
-
DrawSplineLinear(
List< Vector2D> points, num thick, ColorD color) → void - Draw spline: Linear, minimum 2 points
-
DrawSplineSegmentBasis(
Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color) → void - Draw spline segment: B-Spline, 4 points
-
DrawSplineSegmentBezierCubic(
Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num thick, ColorD color) → void - Draw spline segment: Cubic Bezier, 2 points, 2 control points
-
DrawSplineSegmentBezierQuadratic(
Vector2D p1, Vector2D c2, Vector2D p3, num thick, ColorD color) → void - Draw spline segment: Quadratic Bezier, 2 points, 1 control point
-
DrawSplineSegmentCatmullRom(
Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num thick, ColorD color) → void - Draw spline segment: Catmull-Rom, 4 points
-
DrawSplineSegmentLinear(
Vector2D p1, Vector2D p2, num thick, ColorD color) → void - Draw spline segment: Linear, 2 points
-
DrawText(
String text, num posX, num posY, num fontSize, ColorD color) → void - Draw text (using default font)
-
DrawTextCodepoint(
FontD font, num codepoint, Vector2D position, num fontSize, ColorD tint) → void - Draw one character (codepoint)
-
DrawTextCodepoints(
FontD font, Int32List codepoints, Vector2D position, num fontSize, num spacing, ColorD tint) → void - Draw multiple character (codepoint)
-
DrawTextEx(
FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void - Draw text using font and additional parameters
-
DrawTextPro(
FontD font, String text, Vector2D position, Vector2D origin, num rotation, num fontSize, num spacing, ColorD tint) → void - Draw text using Font and pro parameters (rotation)
-
DrawTexture(
TextureD texture, num posX, num posY, ColorD tint) → void - Draw a Texture2D
-
DrawTextureEx(
TextureD texture, Vector2D position, num rotation, num scale, ColorD tint) → void - Draw a Texture2D with extended parameters
-
DrawTextureNPatch(
TextureD texture, NPatchInfoD nPatchInfo, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void - Draws a texture (or part of it) that stretches or shrinks nicely
-
DrawTexturePro(
TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void - Draw a part of a texture defined by a rectangle with 'pro' parameters
-
DrawTextureRec(
TextureD texture, RectangleD source, Vector2D position, ColorD tint) → void - Draw a part of a texture defined by a rectangle
-
DrawTextureV(
TextureD texture, Vector2D position, ColorD tint) → void - Draw a Texture2D with position defined as Vector2
-
DrawTriangle(
Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void - Draw a color-filled triangle (vertex in counter-clockwise order!)
-
DrawTriangle3D(
Vector3D v1, Vector3D v2, Vector3D v3, ColorD color) → void - Draw a color-filled triangle (vertex in counter-clockwise order!)
-
DrawTriangleFan(
List< Vector2D> points, ColorD color) → void - Draw a triangle fan defined by points (first vertex is the center)
-
DrawTriangleLines(
Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void - Draw triangle outline (vertex in counter-clockwise order!)
-
DrawTriangleStrip(
List< Vector2D> points, ColorD color) → void - Draw a triangle strip defined by points
-
DrawTriangleStrip3D(
List< Vector3D> points, ColorD color) → void - Draw a triangle strip defined by points
-
EnableCursor(
) → void - Enables cursor (unlock cursor)
-
EnableEventWaiting(
) → void - Enable waiting for events on EndDrawing(), no automatic event polling
-
EncodeDataBase64(
Uint8List data) → Uint8List - Encode data to Base64 string
-
EndBlendMode(
) → void - End blending mode (reset to default: alpha blending)
-
EndDrawing(
) → void - End canvas drawing and swap buffers (double buffering)
-
EndMode2D(
) → void - Ends 2D mode with custom camera
-
EndMode3D(
) → void - Ends 3D mode and returns to default 2D orthographic mode
-
EndScissorMode(
) → void - End scissor mode
-
EndShaderMode(
) → void - End custom shader drawing (use default shader)
-
EndTextureMode(
) → void - Ends drawing to render texture
-
EndVrStereoMode(
) → void - End stereo rendering (requires VR simulator)
-
ExportAutomationEventList(
AutomationEventListD list, String fileName) → bool - Export automation events list as text file
-
ExportDataAsCode(
Uint8List data, String fileName) → bool - Export data to code (.h), returns true on success
-
ExportFontAsCode(
FontD font, String fileName) → bool - Export font as code file, returns true on success
-
ExportImage(
ImageD image, String fileName) → bool - Export image data to file, returns true on success
-
ExportImageAsCode(
ImageD image, String fileName) → bool - Export image as code file defining an array of bytes, returns true on success
-
ExportImageToMemory(
ImageD image, String fileType) → (MemoryPointer< RUint8> , int) - Export image to memory buffer
-
ExportMesh(
MeshD mesh, String fileName) → bool - Export mesh data to file, returns true on success
-
ExportMeshAsCode(
MeshD mesh, String fileName) → bool - Export mesh as code file (.h) defining multiple arrays of vertex attributes
-
Fade(
ColorD color, num alpha) → ColorD - Get color with alpha applied, alpha goes from 0.0 to 1.0
-
FileCopy(
String srcPath, String dstPath) → int - Copy file from one path to another, dstPath created if it doesn't exist
-
FileExists(
String fileName) → bool - Check if file exists
-
FileMove(
String srcPath, String dstPath) → int - Move file from one directory to another, dstPath created if it doesn't exist
-
FileRemove(
String fileName) → int - Remove file (if exists)
-
FileRename(
String fileName, String fileRename) → int - Rename file (if exists)
-
FileTextFindIndex(
String fileName, String search) → int - Find text in existing file
-
FileTextReplace(
String fileName, String search, String replacement) → int - Replace text in an existing file
-
GenImageCellular(
num width, num height, num tileSize) → ImageD - Generate image: cellular algorithm, bigger tileSize means bigger cells
-
GenImageChecked(
num width, num height, num checksX, num checksY, ColorD col1, ColorD col2) → ImageD - Generate image: checked
-
GenImageColor(
num width, num height, ColorD color) → ImageD - Generate image: plain color
-
GenImageFontAtlas(
List< GlyphInfoD> glyphs, num fontSize, num padding, num packMethod) → (ImageD, List<RectangleD> ) - Generate image font atlas using chars info
-
GenImageGradientLinear(
num width, num height, num direction, ColorD start, ColorD end) → ImageD -
Generate image: linear gradient, direction in degrees
0..360, 0=Vertical gradient -
GenImageGradientRadial(
num width, num height, num density, ColorD inner, ColorD outer) → ImageD - Generate image: radial gradient
-
GenImageGradientSquare(
num width, num height, num density, ColorD inner, ColorD outer) → ImageD - Generate image: square gradient
-
GenImagePerlinNoise(
num width, num height, num offsetX, num offsetY, num scale) → ImageD - Generate image: perlin noise
-
GenImageText(
num width, num height, String text) → ImageD - Generate image: grayscale image from text data
-
GenImageWhiteNoise(
num width, num height, num factor) → ImageD - Generate image: white noise
-
GenMeshCone(
num radius, num height, num slices) → MeshD - Generate cone/pyramid mesh
-
GenMeshCube(
num width, num height, num length) → MeshD - Generate cuboid mesh
-
GenMeshCubicmap(
ImageD cubicmap, Vector3D cubeSize) → MeshD - Generate cubes-based map mesh from image data
-
GenMeshCylinder(
num radius, num height, num slices) → MeshD - Generate cylinder mesh
-
GenMeshHeightmap(
ImageD heightmap, Vector3D size) → MeshD - Generate heightmap mesh from image data
-
GenMeshHemiSphere(
num radius, num rings, num slices) → MeshD - Generate half-sphere mesh (no bottom cap)
-
GenMeshKnot(
num radius, num size, num radSeg, num sides) → MeshD - Generate trefoil knot mesh
-
GenMeshPlane(
num width, num length, num resX, num resZ) → MeshD - Generate plane mesh (with subdivisions)
-
GenMeshPoly(
num sides, num radius) → MeshD - Generate polygonal mesh
-
GenMeshSphere(
num radius, num rings, num slices) → MeshD - Generate sphere mesh (standard sphere)
-
GenMeshTangents(
MeshD mesh) → void - Compute mesh tangents
-
GenMeshTorus(
num radius, num size, num radSeg, num sides) → MeshD - Generate torus mesh
-
GenTextureMipmaps(
TextureD texture) → void - Generate GPU mipmaps for a texture
-
GetApplicationDirectory(
) → String - Get the directory of the running application
-
GetCameraMatrix(
Camera3DD camera) → MatrixD - Get camera transform matrix (view matrix)
-
GetCameraMatrix2D(
Camera2DD camera) → MatrixD - Get camera 2d transform matrix
-
GetCharPressed(
) → int - Get char pressed (unicode), call it multiple times for chars queued, returns 0 when the queue is empty
-
GetClipboardImage(
) → ImageD - Get clipboard image content
-
GetClipboardText(
) → String - Get clipboard text content
-
GetCodepoint(
String text) → (int, int) - Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
-
GetCodepointCount(
String text) → int - Get total number of codepoints in a UTF-8 encoded string
-
GetCodepointNext(
String text) → (int, int) - Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
-
GetCodepointPrevious(
String text) → (int, int) - Get previous codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
-
GetCollisionRec(
RectangleD rec1, RectangleD rec2) → RectangleD - Get collision rectangle for two rectangles collision
-
GetColor(
num hexValue) → ColorD - Get Color structure from hexadecimal value
-
GetCurrentMonitor(
) → int - Get current monitor where window is placed
-
GetDirectoryFileCount(
String dirPath) → int - Get the file count in a directory
-
GetDirectoryFileCountEx(
String basePath, String filter, bool scanSubdirs) → int - Get the file count in a directory with extension filtering and recursive directory scan.
-
GetDirectoryPath(
String filePath) → String - Get full path for a given fileName with path
-
GetFileExtension(
String fileName) → String - Get extension for a filename (includes dot: '.png')
-
GetFileLength(
String fileName) → int - Get file length in bytes
-
GetFileModTime(
String fileName) → int - Get file modification time (last write time)
-
GetFileName(
String filePath) → String - Get filename for a path string
-
GetFileNameWithoutExt(
String filePath) → String - Get filename without extension
-
GetFontDefault(
) → FontD - Get the default Font
-
GetFPS(
) → int - Get current FPS
-
GetFrameTime(
) → double - Get time in seconds for last frame drawn (delta time)
-
GetGamepadAxisCount(
num gamepad) → int - Get gamepad axis count for a gamepad
-
GetGamepadAxisMovement(
num gamepad, GamepadAxis axis) → double - Get axis movement value for a gamepad axis
-
GetGamepadButtonPressed(
) → GamepadButton - Get the last gamepad button pressed
-
GetGamepadName(
num gamepad) → String - Get gamepad internal name id
-
GetGestureDetected(
) → Gesture - Get latest detected gesture
-
GetGestureDragAngle(
) → double - Get gesture drag angle
-
GetGestureDragVector(
) → Vector2D - Get gesture drag vector
-
GetGestureHoldDuration(
) → double - Get gesture hold time in seconds
-
GetGesturePinchAngle(
) → double - Get gesture pinch angle
-
GetGesturePinchVector(
) → Vector2D - Get gesture pinch delta
-
GetGlyphAtlasRec(
FontD font, num codepoint) → RectangleD - Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
-
GetGlyphIndex(
FontD font, num codepoint) → int - Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
-
GetGlyphInfo(
FontD font, num codepoint) → GlyphInfoD - Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
-
GetImageAlphaBorder(
ImageD image, num threshold) → RectangleD - Get image alpha border rectangle
-
GetImageColor(
ImageD image, num x, num y) → ColorD - Get image pixel color at (x, y) position
-
GetKeyName(
KeyboardKey key) → String - Get name of a QWERTY key on the current keyboard layout (eg returns string 'q' for KEY_A on an AZERTY keyboard)
-
GetKeyPressed(
) → int - Get key pressed (keycode), call it multiple times for keys queued, returns 0 when the queue is empty
-
GetMeshBoundingBox(
MeshD mesh) → BoundingBoxD - Compute mesh bounding box limits
-
GetModelBoundingBox(
ModelD model) → BoundingBoxD - Compute model bounding box limits (considers all meshes)
-
GetMonitorCount(
) → int - Get number of connected monitors
-
GetMonitorHeight(
num monitor) → int - Get specified monitor height (current video mode used by monitor)
-
GetMonitorName(
num monitor) → String - Get the human-readable, UTF-8 encoded name of the specified monitor
-
GetMonitorPhysicalHeight(
num monitor) → int - Get specified monitor physical height in millimetres
-
GetMonitorPhysicalWidth(
num monitor) → int - Get specified monitor physical width in millimetres
-
GetMonitorPosition(
num monitor) → Vector2D - Get specified monitor position
-
GetMonitorRefreshRate(
num monitor) → int - Get specified monitor refresh rate
-
GetMonitorWidth(
num monitor) → int - Get specified monitor width (current video mode used by monitor)
-
GetMouseButtonInfo(
MouseButton button) → MouseButtonInfo -
GetMouseDelta(
) → Vector2D - Get mouse delta between frames
-
GetMouseInfo(
) → MouseInfo -
GetMousePosition(
) → Vector2D - Get mouse position XY
-
GetMouseWheelMove(
) → double - Get mouse wheel movement for X or Y, whichever is larger
-
GetMouseWheelMoveV(
) → Vector2D - Get mouse wheel movement for both X and Y
-
GetMouseX(
) → int - Get mouse position X
-
GetMouseY(
) → int - Get mouse position Y
-
GetPixelDataSize(
num width, num height, PixelFormat format) → int - Get pixel data size in bytes for certain format
-
GetPrevDirectoryPath(
String dirPath) → String - Get previous directory path for a given path
-
GetRandomValue(
num min, num max) → int - Get a random value between min and max (both included)
-
GetRayCollisionBox(
RayD ray, BoundingBoxD box) → RayCollisionD - Get collision info between ray and box
-
GetRayCollisionMesh(
RayD ray, MeshD mesh, MatrixD transform) → RayCollisionD - Get collision info between ray and mesh
-
GetRayCollisionQuad(
RayD ray, Vector3D p1, Vector3D p2, Vector3D p3, Vector3D p4) → RayCollisionD - Get collision info between ray and quad
-
GetRayCollisionSphere(
RayD ray, Vector3D center, num radius) → RayCollisionD - Get collision info between ray and sphere
-
GetRayCollisionTriangle(
RayD ray, Vector3D p1, Vector3D p2, Vector3D p3) → RayCollisionD - Get collision info between ray and triangle
-
GetRenderHeight(
) → int - Get current render height (it considers HiDPI)
-
GetRenderWidth(
) → int - Get current render width (it considers HiDPI)
-
GetScreenHeight(
) → int - Get current screen height
-
GetScreenToWorld2D(
Vector2D position, Camera2DD camera) → Vector2D - Get the world space position for a 2d camera screen space position
-
GetScreenToWorldRay(
Vector2D position, Camera3DD camera) → RayD - Get a ray trace from screen position (i.e mouse)
-
GetScreenToWorldRayEx(
Vector2D position, Camera3DD camera, num width, num height) → RayD - Get a ray trace from screen position (i.e mouse) in a viewport
-
GetScreenWidth(
) → int - Get current screen width
-
GetShaderLocation(
ShaderD shader, String uniformName) → int - Get shader uniform location
-
GetShaderLocationAttrib(
ShaderD shader, String attribName) → int - Get shader attribute location
-
GetShapesTexture(
) → TextureD - Get texture that is used for shapes drawing
-
GetShapesTextureRectangle(
) → RectangleD - Get texture source rectangle that is used for shapes drawing
-
GetSplinePointBasis(
Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t) → Vector2D - Get (evaluate) spline point: B-Spline
-
GetSplinePointBezierCubic(
Vector2D p1, Vector2D c2, Vector2D c3, Vector2D p4, num t) → Vector2D - Get (evaluate) spline point: Cubic Bezier
-
GetSplinePointBezierQuad(
Vector2D p1, Vector2D c2, Vector2D p3, num t) → Vector2D - Get (evaluate) spline point: Quadratic Bezier
-
GetSplinePointCatmullRom(
Vector2D p1, Vector2D p2, Vector2D p3, Vector2D p4, num t) → Vector2D - Get (evaluate) spline point: Catmull-Rom
-
GetSplinePointLinear(
Vector2D startPos, Vector2D endPos, num t) → Vector2D - Get (evaluate) spline point: Linear
-
GetTextBetween(
String text, String begin, String end) → String - Get text between two strings
-
GetTime(
) → double - Get elapsed time in seconds since InitWindow()
-
GetTouchPointCount(
) → int - Get number of touch points
-
GetTouchPointId(
num index) → int - Get touch point identifier for given index
-
GetTouchPosition(
num index) → Vector2D - Get touch position XY for a touch point index (relative to screen size)
-
GetTouchX(
) → int - Get touch position X for touch point 0 (relative to screen size)
-
GetTouchY(
) → int - Get touch position Y for touch point 0 (relative to screen size)
-
GetWindowPosition(
) → Vector2D - Get window position XY on monitor
-
GetWindowScaleDPI(
) → Vector2D - Get window scale DPI factor
-
GetWorkingDirectory(
) → String - Get current working directory
-
GetWorldToScreen(
Vector3D position, Camera3DD camera) → Vector2D - Get the screen space position for a 3d world space position
-
GetWorldToScreen2D(
Vector2D position, Camera2DD camera) → Vector2D - Get the screen space position for a 2d camera world space position
-
GetWorldToScreenEx(
Vector3D position, Camera3DD camera, num width, num height) → Vector2D - Get size position for a 3d world space position
-
HideCursor(
) → void - Hides cursor
-
ImageAlphaClear(
ImageD image, ColorD color, num threshold) → void - Clear alpha channel to desired color
-
ImageAlphaCrop(
ImageD image, num threshold) → void - Crop image depending on alpha value
-
ImageAlphaMask(
ImageD image, ImageD alphaMask) → void - Apply alpha mask to image
-
ImageAlphaPremultiply(
ImageD image) → void - Premultiply alpha channel
-
ImageBlurGaussian(
ImageD image, num blurSize) → void - Apply Gaussian blur using a box blur approximation
-
ImageClearBackground(
ImageD dst, ColorD color) → void - Clear image background with given color
-
ImageColorBrightness(
ImageD image, num brightness) → void - Modify image color: brightness (-255 to 255)
-
ImageColorContrast(
ImageD image, num contrast) → void - Modify image color: contrast (-100 to 100)
-
ImageColorGrayscale(
ImageD image) → void - Modify image color: grayscale
-
ImageColorInvert(
ImageD image) → void - Modify image color: invert
-
ImageColorReplace(
ImageD image, ColorD color, ColorD replace) → void - Modify image color: replace color
-
ImageColorTint(
ImageD image, ColorD color) → void - Modify image color: tint
-
ImageCopy(
ImageD image) → ImageD - Create an image duplicate (useful for transformations)
-
ImageCrop(
ImageD image, RectangleD crop) → void - Crop an image to a defined rectangle
-
ImageDither(
ImageD image, num rBpp, num gBpp, num bBpp, num aBpp) → void - Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
-
ImageDraw(
ImageD dst, ImageD src, RectangleD srcRec, RectangleD dstRec, ColorD tint) → void - Draw a source image within a destination image (tint applied to source)
-
ImageDrawCircle(
ImageD dst, num centerX, num centerY, num radius, ColorD color) → void - Draw a filled circle within an image
-
ImageDrawCircleLines(
ImageD dst, num centerX, num centerY, num radius, ColorD color) → void - Draw circle outline within an image
-
ImageDrawCircleLinesV(
ImageD dst, Vector2D center, num radius, ColorD color) → void - Draw circle outline within an image (Vector version)
-
ImageDrawCircleV(
ImageD dst, Vector2D center, num radius, ColorD color) → void - Draw a filled circle within an image (Vector version)
-
ImageDrawLine(
ImageD dst, num startPosX, num startPosY, num endPosX, num endPosY, ColorD color) → void - Draw line within an image
-
ImageDrawLineEx(
ImageD dst, Vector2D start, Vector2D end, num thick, ColorD color) → void - Draw a line defining thickness within an image
-
ImageDrawLineV(
ImageD dst, Vector2D start, Vector2D end, ColorD color) → void - Draw line within an image (Vector version)
-
ImageDrawPixel(
ImageD dst, num posX, num posY, ColorD color) → void - Draw pixel within an image
-
ImageDrawPixelV(
ImageD dst, Vector2D position, ColorD color) → void - Draw pixel within an image (Vector version)
-
ImageDrawRectangle(
ImageD dst, num posX, num posY, num width, num height, ColorD color) → void - Draw rectangle within an image
-
ImageDrawRectangleLines(
ImageD dst, RectangleD rec, num thick, ColorD color) → void - Draw rectangle lines within an image
-
ImageDrawRectangleRec(
ImageD dst, RectangleD rec, ColorD color) → void - Draw rectangle within an image
-
ImageDrawRectangleV(
ImageD dst, Vector2D position, Vector2D size, ColorD color) → void - Draw rectangle within an image (Vector version)
-
ImageDrawText(
ImageD dst, String text, num posX, num posY, num fontSize, ColorD color) → void - Draw text (using default font) within an image (destination)
-
ImageDrawTextEx(
ImageD dst, FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void - Draw text (custom sprite font) within an image (destination)
-
ImageDrawTriangle(
ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void - Draw triangle within an image
-
ImageDrawTriangleEx(
ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD c1, ColorD c2, ColorD c3) → void - Draw triangle with interpolated colors within an image
-
ImageDrawTriangleFan(
ImageD dst, List< Vector2D> points, ColorD color) → void - Draw a triangle fan defined by points within an image (first vertex is the center)
-
ImageDrawTriangleLines(
ImageD dst, Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void - Draw triangle outline within an image
-
ImageDrawTriangleStrip(
ImageD dst, List< Vector2D> points, ColorD color) → void - Draw a triangle strip defined by points within an image
-
ImageFlipHorizontal(
ImageD image) → void - Flip image horizontally
-
ImageFlipVertical(
ImageD image) → void - Flip image vertically
-
ImageFormat(
ImageD image, PixelFormat newFormat) → void - Convert image data to desired format
-
ImageFromChannel(
ImageD image, num selectedChannel) → ImageD - Create an image from a selected channel of another image (GRAYSCALE)
-
ImageFromImage(
ImageD image, RectangleD rec) → ImageD - Create an image from another image piece
-
ImageKernelConvolution(
ImageD image, List< double> kernel) → void - Apply custom square convolution kernel to image
-
ImageMipmaps(
ImageD image) → void - Compute all mipmap levels for a provided image
-
ImageResize(
ImageD image, num newWidth, num newHeight) → void - Resize image (Bicubic scaling algorithm)
-
ImageResizeCanvas(
ImageD image, num newWidth, num newHeight, num offsetX, num offsetY, ColorD fill) → void - Resize canvas and fill with color
-
ImageResizeNN(
ImageD image, num newWidth, num newHeight) → void - Resize image (Nearest-Neighbor scaling algorithm)
-
ImageRotate(
ImageD image, num degrees) → void - Rotate image by input angle in degrees (-359 to 359)
-
ImageRotateCCW(
ImageD image) → void - Rotate image counter-clockwise 90deg
-
ImageRotateCW(
ImageD image) → void - Rotate image clockwise 90deg
-
ImageText(
String text, num fontSize, ColorD color) → ImageD - Create an image from text (default font)
-
ImageTextEx(
FontD font, String text, num fontSize, num spacing, ColorD tint) → ImageD - Create an image from text (custom sprite font)
-
ImageToPOT(
ImageD image, ColorD fill) → void - Convert image to POT (power-of-two)
-
InitWindow(
num width, num height, String title) → void - Initialize window and OpenGL context
-
IsCursorHidden(
) → bool - Check if cursor is not visible
-
IsCursorOnScreen(
) → bool - Check if cursor is on the screen
-
IsFileDropped(
) → bool - Check if a file has been dropped into window
-
IsFileExtension(
String fileName, String ext) → bool - Check file extension (including point: .png, .wav)
-
IsFileNameValid(
String fileName) → bool - Check if fileName is valid for the platform/OS
-
IsFontValid(
FontD font) → bool - Check if a font is valid (font data loaded, WARNING: GPU texture not checked)
-
IsGamepadAvailable(
num gamepad) → bool - Check if a gamepad is available
-
IsGamepadButtonDown(
num gamepad, GamepadButton button) → bool - Check if a gamepad button is being pressed
-
IsGamepadButtonPressed(
num gamepad, GamepadButton button) → bool - Check if a gamepad button has been pressed once
-
IsGamepadButtonReleased(
num gamepad, GamepadButton button) → bool - Check if a gamepad button has been released once
-
IsGamepadButtonUp(
num gamepad, GamepadButton button) → bool - Check if a gamepad button is NOT being pressed
-
IsGestureDetected(
Gesture key) → bool - Check if a gesture have been detected
-
IsImageValid(
ImageD image) → bool - Check if an image is valid (data and parameters)
-
IsKeyDown(
KeyboardKey key) → bool - Check if a key is being pressed
-
IsKeyPressed(
KeyboardKey key) → bool - Check if a key has been pressed once
-
IsKeyPressedRepeat(
KeyboardKey key) → bool - Check if a key has been pressed again
-
IsKeyReleased(
KeyboardKey key) → bool - Check if a key has been released once
-
IsKeyUp(
KeyboardKey key) → bool - Check if a key is NOT being pressed
-
IsMaterialValid(
MaterialD material) → bool - Check if a material is valid (shader assigned, map textures loaded in GPU)
-
IsModelAnimationValid(
ModelD model, ModelAnimationD anim) → bool - Check model animation skeleton match
-
IsModelValid(
ModelD model) → bool - Check if a model is valid (loaded in GPU, VAO/VBOs)
-
IsMouseButtonDown(
MouseButton button) → bool - Check if a mouse button is being pressed
-
IsMouseButtonPressed(
MouseButton button) → bool - Check if a mouse button has been pressed once
-
IsMouseButtonReleased(
MouseButton button) → bool - Check if a mouse button has been released once
-
IsMouseButtonUp(
MouseButton button) → bool - Check if a mouse button is NOT being pressed
-
IsPathFile(
String path) → bool - Check if a given path is a file or a directory
-
IsRenderTextureValid(
RenderTextureD target) → bool - Check if a render texture is valid (loaded in GPU)
-
IsShaderValid(
ShaderD shader) → bool - Check if a shader is valid (loaded on GPU)
-
IsTextureValid(
TextureD texture) → bool - Check if a texture is valid (loaded in GPU)
-
IsWindowFocused(
) → bool - Check if window is currently focused
-
IsWindowFullscreen(
) → bool - Check if window is currently fullscreen
-
IsWindowHidden(
) → bool - Check if window is currently hidden
-
IsWindowMaximized(
) → bool - Check if window is currently maximized
-
IsWindowMinimized(
) → bool - Check if window is currently minimized
-
IsWindowReady(
) → bool - Check if window has been initialized successfully
-
IsWindowResized(
) → bool - Check if window has been resized last frame
-
IsWindowState(
ConfigFlags flag) → bool - Check if one specific window flag is enabled
-
load(
) → void -
Override to perform one-time module initialization.
inherited
-
LoadAutomationEventList(
String? fileName) → AutomationEventListD - Load automation events list from file, NULL for empty list
-
LoadCodepoints(
String text) → Int32List - Load all codepoints from a UTF-8 text string, codepoints count returned by parameter
-
LoadDirectoryFiles(
String dirPath) → FilePathListD - Load directory filepaths
-
LoadDirectoryFilesEx(
String basePath, String filter, bool scanSubdirs) → FilePathListD - Load directory filepaths with extension filtering and recursive directory scan.
-
LoadDroppedFiles(
) → FilePathListD - Load dropped filepaths
-
LoadFileData(
String fileName) → Uint8List - Load file data as byte array (read)
-
LoadFileText(
String fileName) → String - Load text data from file (read)
-
LoadFont(
String fileName) → FontD - Load font from file into GPU memory (VRAM)
-
LoadFontData(
Uint8List fileData, num fontSize, Int32List? codepoints, num? codepointCount, FontType type) → List< GlyphInfoD> - Load font data for further use
-
LoadFontEx(
String fileName, num fontSize, [Int32List? codepoints, num? codepointCount]) → FontD - Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height
-
LoadFontFromImage(
ImageD image, ColorD key, num firstChar) → FontD - Load font from Image (XNA style)
-
LoadFontFromMemory(
String fileType, Uint8List fileData, num fontSize, Int32List codepoints) → FontD - Load font from memory buffer, fileType refers to extension: i.e. '.ttf'
-
LoadImage(
String fileName) → ImageD - Load image from file into CPU memory (RAM)
-
LoadImageAnim(
String fileName) → ImageD - Load image sequence from file (frames appended to image.data)
-
LoadImageAnimFromMemory(
String fileType, Uint8List fileData) → ImageD - Load image sequence from memory buffer
-
LoadImageColors(
ImageD image) → List< ColorD> - Load color data from image as a Color array (RGBA - 32bit)
-
LoadImageFromMemory(
String fileType, Uint8List fileData) → ImageD - Load image from memory buffer, fileType refers to extension: i.e. '.png'
-
LoadImageFromScreen(
) → ImageD - Load image from screen buffer and (screenshot)
-
LoadImageFromTexture(
TextureD texture) → ImageD - Load image from GPU texture data
-
LoadImagePalette(
ImageD image, num maxPaletteSize) → List< ColorD> - Load colors palette from image as a Color array (RGBA - 32bit)
-
LoadImageRaw(
String fileName, num width, num height, PixelFormat format, num headerSize) → ImageD - Load image from RAW file data
-
LoadMaterialDefault(
) → MaterialD - Load default material (Supports: DIFFUSE, SPECULAR, NORMAL maps)
-
LoadMaterials(
String fileName) → List< MaterialD> - Load materials from model file
-
LoadModel(
String fileName) → ModelD - Load model from files (meshes and materials)
-
LoadModelAnimations(
String fileName) → List< ModelAnimationD> - Load model animations from file
-
LoadModelFromMesh(
MeshD mesh) → ModelD - Load model from generated mesh (default material)
-
LoadRandomSequence(
num count, num min, num max) → List< int> - Load random values sequence, no values repeated, min and max included
-
LoadRenderTexture(
num width, num height) → RenderTextureD - Load texture for rendering (framebuffer)
-
LoadShader(
String? vsFileName, String? fsFileName) → ShaderD - Load shader from files and bind default locations
-
LoadShaderFromMemory(
String? vsCode, String? fsCode) → ShaderD - Load shader from code strings and bind default locations
-
LoadTextLines(
String text) → List< String> - Load text as separate lines ('\n')
-
LoadTexture(
String fileName) → TextureD - Load texture from file into GPU memory (VRAM)
-
LoadTextureCubemap(
ImageD image, CubemapLayout layout) → TextureD - Load cubemap from image, multiple image cubemap layouts supported
-
LoadTextureFromImage(
ImageD image) → TextureD - Load texture from image data
-
LoadUTF8(
Int32List codepoints) → String - Load UTF-8 text encoded from codepoints array
-
LoadVrStereoConfig(
VrDeviceInfoD device) → VrStereoConfigD - Load VR stereo config for VR simulator device parameters
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
MakeDirectory(
String dirPath) → int - Create directories (including full path requested), returns 0 on success
-
MaximizeWindow(
) → void - Set window state: maximized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
-
MeasureText(
String text, num fontSize) → int - Measure string width for default font
-
MeasureTextCodepoints(
FontD font, Int32List codepoints, num fontSize, num spacing) → Vector2D - Measure string size for an existing array of codepoints for Font
-
MeasureTextEx(
FontD font, String text, num fontSize, num spacing) → Vector2D - Measure string size for Font
-
MinimizeWindow(
) → void - Set window state: minimized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
OpenURL(
String url) → void - Open URL with default system browser (if available)
-
PlayAutomationEvent(
AutomationEventD event) → void - Play a recorded automation event
-
PollInputEvents(
) → void - Register all input events
-
ProcessGestureEvent(
GestureEventD event) → void - Process gesture event and translate it into gestures
-
RestoreWindow(
) → void - Set window state: not minimized/maximized
-
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
SaveFileData(
String fileName, Uint8List data) → bool - Save data to file from byte array (write), returns true on success
-
SaveFileText(
String fileName, String text) → bool - Save text data to file (write), returns true on success
-
SetAutomationEventBaseFrame(
int frame) → void - Set automation event internal base frame to start recording
-
SetAutomationEventList(
AutomationEventListD list) → void - Set automation event list to record to
-
SetClipboardText(
String text) → void - Set clipboard text content
-
SetConfigFlags(
Iterable< ConfigFlags> flags) → void - Setup init configuration flags (view ConfigFlags)
-
SetExitKey(
KeyboardKey key) → void - Set a custom key to exit program (default is ESC)
-
SetGamepadMappings(
String mappings) → int - Set internal gamepad mappings (SDL_GameControllerDB)
-
SetGamepadVibration(
num gamepad, num leftMotor, num rightMotor, num duration) → void - Set gamepad vibration for both motors (duration in seconds)
-
SetGesturesEnabled(
Iterable< Gesture> flags) → void - Enable a set of gestures using flags Gesture
-
SetLoadFileDataCallback(
covariant LoadFileDataCallbackBase? callback) → void - Set custom file binary data loader
-
SetLoadFileTextCallback(
covariant LoadFileTextCallbackBase? callback) → void - Set custom file text data loader
-
SetMaterialTexture(
MaterialD material, MaterialMapIndex mapType, TextureD texture) → void - Set texture for a material map type (MATERIAL_MAP_DIFFUSE, MATERIAL_MAP_SPECULAR...)
-
SetModelMeshMaterial(
ModelD model, num meshId, num materialId) → void - Set material for a mesh
-
SetMouseCursor(
MouseCursor cursor) → void - Set mouse cursor
-
SetMouseOffset(
num offsetX, num offsetY) → void - Set mouse offset
-
SetMousePosition(
num x, num y) → void - Set mouse position XY
-
SetMouseScale(
num scaleX, num scaleY) → void - Set mouse scaling
-
SetRandomSeed(
num seed) → void - Set the seed for the random number generator
-
SetSaveFileDataCallback(
covariant SaveFileDataCallbackBase? callback) → void - Set custom file binary data saver
-
SetSaveFileTextCallback(
covariant SaveFileTextCallbackBase? callback) → void - Set custom file text data saver
-
SetShaderValue(
ShaderD shader, num locIndex, List< num> value, ShaderUniformDataType uniformType) → void - Set shader uniform value
-
SetShaderValueMatrix(
ShaderD shader, num locIndex, MatrixD mat) → void - Set shader uniform value (matrix 4x4)
-
SetShaderValueTexture(
ShaderD shader, num locIndex, TextureD texture) → void - Set shader uniform value for texture (sampler2d)
-
SetShaderValueV(
ShaderD shader, num locIndex, List< num> value, ShaderUniformDataType uniformType, num count) → void - Set shader uniform value vector
-
SetShapesTexture(
TextureD texture, RectangleD source) → void - Set texture and rectangle to be used on shapes drawing
-
SetTargetFPS(
num fps) → void - Set target FPS (maximum)
-
SetTextLineSpacing(
num spacing) → void - Set vertical line spacing when drawing with line-breaks
-
SetTextureFilter(
TextureD texture, TextureFilter filter) → void - Set texture scaling filter mode
-
SetTextureWrap(
TextureD texture, TextureWrap wrap) → void - Set texture wrapping mode
-
SetTraceLogCallback(
covariant TraceLogCallbackBase? callback) → void - Set custom trace log
-
SetTraceLogLevel(
TraceLogLevel logLevel) → void - Set the current threshold (minimum) log level
-
SetWindowFocused(
) → void - Set window focused
-
SetWindowIcon(
ImageD image) → void - Set icon for window (single image, RGBA 32bit)
-
SetWindowIcons(
List< ImageD> images) → void - Set icon for window (multiple images, RGBA 32bit)
-
SetWindowMaxSize(
num width, num height) → void - Set window maximum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
-
SetWindowMinSize(
num width, num height) → void - Set window minimum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
-
SetWindowMonitor(
num monitor) → void - Set monitor for the current window
-
SetWindowOpacity(
num opacity) → void -
Set window opacity
0.0..1.0 -
SetWindowPosition(
num x, num y) → void - Set window position on screen
-
SetWindowSize(
num width, num height) → void - Set window dimensions
-
SetWindowState(
Iterable< ConfigFlags> flags) → void - Set window configuration state using flags
-
SetWindowTitle(
String title) → void - Set title for window
-
ShowCursor(
) → void - Shows cursor
-
StartAutomationEventRecording(
) → void - Start recording automation events (AutomationEventList must be set)
-
StopAutomationEventRecording(
) → void - Stop recording automation events
-
SwapScreenBuffer(
) → void - Swap back buffer with front buffer (screen drawing)
-
TakeScreenshot(
String fileName) → void - Takes a screenshot of current screen (filename extension defines format)
-
TextAppend(
String text, String append) → String - Append text at specific position and move cursor
-
TextFindIndex(
String text, String search) → int - Find first text occurrence within a string, -1 if not found
-
TextFormat(
String text, [List< Object?> args = const []]) → String - Text formatting with variables (sprintf() style)
-
TextInsert(
String text, String insert, int position) → String - Insert text in a defined byte position
-
TextIsEqual(
String text1, String text2) → bool - Check if two text string are equal
-
TextJoin(
List< String> textList, String delimiter) → String -
Join text strings with delimiter (
delimiteris expected to be length of 1) -
TextLength(
String text) → int - Get text length
-
TextRemoveSpaces(
String text) → String - Remove text spaces, concat words
-
TextReplace(
String text, String search, String replacement) → String - Replace text string with new string
-
TextReplaceBetween(
String text, String begin, String end, String replacement) → String - Replace text between two specific strings
-
TextSplit(
String text, String delimiter) → List< String> - Split text into multiple strings
-
TextSubtext(
String text, int position, int length) → String - Get a piece of a text string
-
TextToCamel(
String text) → String - Get Camel case notation version of provided string
-
TextToFloat(
String text) → double - Get float value from text
-
TextToInteger(
String text) → int - Get integer value from text
-
TextToLower(
String text) → String - Get lower case version of provided string
-
TextToPascal(
String text) → String - Get Pascal case notation version of provided string
-
TextToSnake(
String text) → String - Get Snake case notation version of provided string
-
TextToUpper(
String text) → String - Get upper case version of provided string
-
ToggleBorderlessWindowed(
) → void - Toggle window state: borderless windowed, resizes window to match monitor resolution
-
ToggleFullscreen(
) → void - Toggle window state: fullscreen/windowed, resizes monitor to match window resolution
-
toString(
) → String -
A string representation of this object.
inherited
-
TraceLog(
TraceLogLevel logLevel, String text, [List< Object?> args = const []]) → void - Show trace log messages (LOG_DEBUG, LOG_INFO, LOG_WARNING, LOG_ERROR...)
-
UnloadAutomationEventList(
AutomationEventListD list) → void - Unload automation events list from file
-
UnloadDirectoryFiles(
FilePathListD files) → void - Unload filepaths
-
UnloadDroppedFiles(
FilePathListD files) → void - Unload dropped filepaths
-
UnloadFont(
FontD font) → void - Unload font from GPU memory (VRAM)
-
UnloadFontData(
List< GlyphInfoD> glyphs) → void - Unload font chars info data (RAM)
-
UnloadImage(
ImageD image) → void - Unload image from CPU memory (RAM)
-
UnloadMaterial(
MaterialD material) → void - Unload material from GPU memory (VRAM)
-
UnloadMesh(
MeshD mesh) → void - Unload mesh data from CPU and GPU
-
UnloadModel(
ModelD model) → void - Unload model (including meshes) from memory (RAM and/or VRAM)
-
UnloadModelAnimations(
List< ModelAnimationD> animations) → void - Unload animation array data
-
UnloadRenderTexture(
RenderTextureD target) → void - Unload render texture from GPU memory (VRAM)
-
UnloadShader(
ShaderD shader) → void - Unload shader from GPU memory (VRAM)
-
UnloadTexture(
TextureD texture) → void - Unload texture from GPU memory (VRAM)
-
UnloadVrStereoConfig(
VrStereoConfigD config) → void - Unload VR stereo config
-
UpdateCamera(
Camera3DD camera, CameraMode mode) → void - Update camera position for selected mode
-
UpdateCameraPro(
Camera3DD camera, Vector3D movement, Vector3D rotation, num zoom) → void - Update camera movement/rotation
-
UpdateGestures(
) → void - Update gestures detected (must be called every frame)
-
UpdateMeshBuffer(
MeshD mesh, num index, TypedDataList data, num offset) → void - Update mesh vertex data in GPU for a specific buffer index
-
UpdateModelAnimation(
ModelD model, ModelAnimationD anim, num frame) → void - Update model animation pose (CPU)
-
UpdateModelAnimationEx(
ModelD model, ModelAnimationD animA, num frameA, ModelAnimationD animB, num frameB, num blend) → void - Update model animation data (vertex buffers / bone matrices) for a specific pose, defined by two different animations at specific frames blended together
-
UpdateTexture(
TextureD texture, Uint8List pixels) → void - Update GPU texture with new data
-
UpdateTextureRec(
TextureD texture, RectangleD rec, Uint8List pixels) → void - Update GPU texture rectangle with new data
-
UploadMesh(
MeshD mesh, bool dynamic) → void - Upload mesh vertex data in GPU and provide VAO/VBO ids
-
WaitTime(
num seconds) → void - Wait for some time (halt program execution)
-
WindowShouldClose(
) → bool - Check if application should close (KeyboardKey.KEY_ESCAPE pressed or windows close icon clicked)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited