RaylibGuiDart<R extends RaylibBase> class
final
Backend-agnostic Raygui module.
- Inheritance
-
- Object
- RaylibModule<
R> - RaylibGuiDart
- Mixed-in types
Constructors
- RaylibGuiDart(R rl)
Properties
-
$
→ RaylibTemp<
RaylibBase> -
See RaylibTemp.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- RAYGUI_COLORBARALPHA_CHECKED_SIZE → int
-
See RaylibGuiConstants.RAYGUI_COLORBARALPHA_CHECKED_SIZE.
no setterinherited
- RAYGUI_GRID_ALPHA → double
-
See RaylibGuiConstants.RAYGUI_GRID_ALPHA.
no setterinherited
- RAYGUI_GROUPBOX_LINE_THICK → int
-
See RaylibGuiConstants.RAYGUI_GROUPBOX_LINE_THICK.
no setterinherited
- RAYGUI_ICON_DATA_ELEMENTS → int
-
See RaylibGuiConstants.RAYGUI_ICON_DATA_ELEMENTS.
no setterinherited
- RAYGUI_ICON_FONT_ATLAS_PADDING → int
-
See RaylibGuiConstants.RAYGUI_ICON_FONT_ATLAS_PADDING.
no setterinherited
- RAYGUI_ICON_MAX_FONT_BACKED → int
-
See RaylibGuiConstants.RAYGUI_ICON_MAX_FONT_BACKED.
no setterinherited
- RAYGUI_ICON_MAX_ICONS → int
-
See RaylibGuiConstants.RAYGUI_ICON_MAX_ICONS.
no setterinherited
- RAYGUI_ICON_MAX_NAME_LENGTH → int
-
See RaylibGuiConstants.RAYGUI_ICON_MAX_NAME_LENGTH.
no setterinherited
- RAYGUI_ICON_SIZE → int
-
See RaylibGuiConstants.RAYGUI_ICON_SIZE.
no setterinherited
- RAYGUI_ICON_TEXT_PADDING → int
-
See RaylibGuiConstants.RAYGUI_ICON_TEXT_PADDING.
no setterinherited
-
RAYGUI_ICONS
→ List<
int> -
See RaylibGuiConstants.RAYGUI_ICONS.
no setterinherited
- RAYGUI_LINE_MARGIN_TEXT → int
-
See RaylibGuiConstants.RAYGUI_LINE_MARGIN_TEXT.
no setterinherited
- RAYGUI_LINE_TEXT_PADDING → int
-
See RaylibGuiConstants.RAYGUI_LINE_TEXT_PADDING.
no setterinherited
- RAYGUI_MAX_CONTROLS → int
-
See RaylibGuiConstants.RAYGUI_MAX_CONTROLS.
no setterinherited
- RAYGUI_MAX_PROPS_BASE → int
-
See RaylibGuiConstants.RAYGUI_MAX_PROPS_BASE.
no setterinherited
- RAYGUI_MAX_PROPS_EXTENDED → int
-
See RaylibGuiConstants.RAYGUI_MAX_PROPS_EXTENDED.
no setterinherited
- RAYGUI_MAX_TEXT_LINES → int
-
See RaylibGuiConstants.RAYGUI_MAX_TEXT_LINES.
no setterinherited
- RAYGUI_MESSAGEBOX_BUTTON_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_HEIGHT.
no setterinherited
- RAYGUI_MESSAGEBOX_BUTTON_PADDING → int
-
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_PADDING.
no setterinherited
- RAYGUI_MIN_MOUSE_WHEEL_SPEED → int
-
See RaylibGuiConstants.RAYGUI_MIN_MOUSE_WHEEL_SPEED.
no setterinherited
- RAYGUI_MIN_SCROLLBAR_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_HEIGHT.
no setterinherited
- RAYGUI_MIN_SCROLLBAR_WIDTH → int
-
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_WIDTH.
no setterinherited
- RAYGUI_PANEL_BORDER_WIDTH → int
-
See RaylibGuiConstants.RAYGUI_PANEL_BORDER_WIDTH.
no setterinherited
- RAYGUI_SCROLLBAR_LEFT_SIDE → int
-
See RaylibGuiConstants.RAYGUI_SCROLLBAR_LEFT_SIDE.
no setterinherited
- RAYGUI_SCROLLBAR_RIGHT_SIDE → int
-
See RaylibGuiConstants.RAYGUI_SCROLLBAR_RIGHT_SIDE.
no setterinherited
- RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN → int
-
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN.
no setterinherited
- RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY → int
-
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY.
no setterinherited
- RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT.
no setterinherited
- RAYGUI_TEXTINPUTBOX_BUTTON_PADDING → int
-
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_PADDING.
no setterinherited
- RAYGUI_TEXTINPUTBOX_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_HEIGHT.
no setterinherited
- RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE → int
-
See RaylibGuiConstants.RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE.
no setterinherited
- RAYGUI_VALUEBOX_MAX_CHARS → int
-
See RaylibGuiConstants.RAYGUI_VALUEBOX_MAX_CHARS.
no setterinherited
- RAYGUI_VERSION → String
-
See RaylibGuiConstants.RAYGUI_VERSION.
no setterinherited
- RAYGUI_VERSION_MAJOR → int
-
See RaylibGuiConstants.RAYGUI_VERSION_MAJOR.
no setterinherited
- RAYGUI_VERSION_MINOR → int
-
See RaylibGuiConstants.RAYGUI_VERSION_MINOR.
no setterinherited
- RAYGUI_VERSION_PATCH → int
-
See RaylibGuiConstants.RAYGUI_VERSION_PATCH.
no setterinherited
- RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT.
no setterinherited
- RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT → int
-
See RaylibGuiConstants.RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT.
no setterinherited
- rl → R
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
disposeStructWithOpFreed<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then frees the temporary allocation backing the pointer, if any.inherited -
disposeStructWithOpUnslotted<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.inherited -
GuiButton(
RectangleD bounds, String? text) → GuiResult - Button control, returns true when clicked
-
GuiCheckBox(
RectangleD bounds, String? text, bool checked) → (GuiResult, bool) - Check Box control, returns true when active
-
GuiColorBarAlpha(
RectangleD bounds, num alpha) → (GuiResult, double) - Color Bar Alpha control
-
GuiColorBarHue(
RectangleD bounds, num value) → (GuiResult, double) - Color Bar Hue control
-
GuiColorPanel(
RectangleD bounds, ColorD color) → (GuiResult, ColorD) - Color Panel control
-
GuiColorPanelHSV(
RectangleD bounds, [Vector3D? colorHsv]) → (GuiResult, Vector3D) - Color Panel control, using Hue-Saturation-Value color data
-
GuiColorPicker(
RectangleD bounds, ColorD? color) → (GuiResult, ColorD) - Color Picker control, includes Color bar controls
-
GuiColorPickerHSV(
RectangleD bounds, [Vector3D? colorHsv]) → (GuiResult, Vector3D) - Color Picker control, using Hue-Saturation-Value color data, includes Color bar controls
-
GuiComboBox(
RectangleD bounds, String? text, num active) → (GuiResult, int) - Combo Box control
-
GuiDisable(
) → void - Disable gui controls (global state)
-
GuiDisableTooltip(
) → void - Disable gui tooltips (global state)
-
GuiDrawIcon(
GuiIconName iconId, num posX, num posY, num pixelSize, ColorD color) → void - Draw icon using pixel size at specified position
-
GuiDropdownBox(
RectangleD bounds, String? text, num active, bool editMode) → (GuiResult, int) - Dropdown Box control
-
GuiDummyRec(
RectangleD bounds, String? text) → GuiResult - Dummy control for placeholders
-
GuiEnable(
) → void - Enable gui controls (global state)
-
GuiEnableTooltip(
) → void - Enable gui tooltips (global state)
-
GuiGetFont(
) → FontD - Get gui custom font (global state)
-
GuiGetIcons(
) → List< int> - Get raygui icons data
-
GuiGetState(
) → int - Get gui state (global state)
-
GuiGetStyle(
GuiControl control, GuiProperty property) → int - Get one style property
-
GuiGetTextWidth(
String? text) → int - Get text width considering gui style and icon size (if required)
-
GuiGrid(
RectangleD bounds, num spacing, num subdivs, {Vector2D? mouseCell}) → GuiResult - Grid control
-
GuiGroupBox(
RectangleD bounds, String? text) → GuiResult - Group Box control with text name
-
GuiIconText(
GuiIconName iconId, String? text) → String - Get text with icon id prepended (if supported)
-
GuiIsLocked(
) → bool - Check if gui is locked (global state)
-
GuiLabel(
RectangleD bounds, String? text) → GuiResult - Label control
-
GuiLabelButton(
RectangleD bounds, String? text) → GuiResult - Label button control, returns true when clicked
-
GuiLine(
RectangleD bounds, String? text) → GuiResult - Line separator control, could contain text
-
GuiListView(
RectangleD bounds, String? text, {int? scrollIndex, int? active}) → (GuiResult, int?, int?) - List View control
-
GuiListViewEx(
RectangleD bounds, List< String> ? text, {int? scrollIndex, int? active, int? focus}) → (GuiResult, int?, int?, int?) - List View control, using text entries list and returning focus entry
-
GuiLoadIcons(
String fileName, bool loadIconsName) → List< String> - Load raygui icons file (.rgi) into internal icons data
-
GuiLoadIconsFromMemory(
Uint8List fileData, bool loadIconsName) → List< String> - Load raygui icons file (.rgi) from memory into internal icons data
-
GuiLoadStyle(
String fileName) → void - Load style file over global style variable (.rgs)
-
GuiLoadStyleDefault(
) → void - Load style default over global style
-
GuiLoadStyleFromMemory(
Uint8List fileData) → void - Load style from memory (binary only)
-
GuiLock(
) → void - Lock gui controls (global state)
-
GuiMessageBox(
RectangleD bounds, String? title, String message, String btnText) → (GuiResult, int) - Message Box control, displays a message
-
GuiPanel(
RectangleD bounds, String? text) → GuiResult - Panel control, useful to group controls
-
GuiProgressBar(
RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (GuiResult, double) - Progress Bar control
-
GuiScrollPanel(
RectangleD bounds, String? text, RectangleD content, {Vector2D? scroll, RectangleD? view}) → GuiResult - Scroll Panel control
-
GuiSetAlpha(
num alpha) → void - Set gui controls alpha (global state), alpha goes from 0.0 to 1.0
-
GuiSetFont(
FontD font) → void - Set gui custom font (global state)
-
GuiSetIconScale(
num scale) → void - Set default icon drawing size
-
GuiSetState(
GuiState state) → void - Set gui state (global state)
-
GuiSetStyle(
GuiControl control, GuiProperty property, num value) → void - Set one style property
-
GuiSetTooltip(
String? tooltip) → void - Set tooltip string
-
GuiSlider(
RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (GuiResult, double) - Slider control
-
GuiSliderBar(
RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (GuiResult, double) - Slider Bar control
-
GuiSpinner(
RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (GuiResult, int) - Spinner control
-
GuiStatusBar(
RectangleD bounds, String? text) → GuiResult - Status Bar control, shows info text
-
GuiTabBar(
RectangleD bounds, String? text, int active) → (GuiResult, int) - Tab Bar control
-
GuiTabBarEx(
RectangleD bounds, List< String> ? text, {int? active}) → (GuiResult, int) - Tab Bar control, using text entries list and returning focus entry
-
GuiTextBox(
RectangleD bounds, String? text, num textSize, bool editMode) → (GuiResult, String) - Text Box control, updates input text
-
GuiTextInputBox(
RectangleD bounds, String? title, String? message, String? text, num textSize, String btnText, [bool? secretViewActive]) → (GuiResult, String, int, bool?) - Text Input Box control, ask for text, supports secret
-
GuiToggle(
RectangleD bounds, String? text, bool active) → (GuiResult, bool) - Toggle Button control
-
GuiToggleGroup(
RectangleD bounds, String? text, num active) → (GuiResult, int) - Toggle Group control
-
GuiToggleSlider(
RectangleD bounds, String? text, num active) → (GuiResult, int) - Toggle Slider control
-
GuiUnlock(
) → void - Unlock gui controls (global state)
-
GuiValueBox(
RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (GuiResult, int) - Value Box control, updates input text with numbers
-
GuiValueBoxFloat(
RectangleD bounds, String? text, String textValue, num value, bool editMode) → (GuiResult, double) - Value box control for float values
-
GuiWindowBox(
RectangleD bounds, String? title) → GuiResult - Window Box control, shows a window that can be closed
-
load(
) → void -
Override to perform one-time module initialization.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited