RaylibGuiModuleDebugLabels class
Produces human-readable debug strings for each Gui module function call, logged to the console when debug output is enabled.
- Inheritance
-
- Object
- RaylibDebugLabelsBase
- RaylibGuiModuleDebugLabels
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
EnumsAsFlagsOr(
Iterable< RaylibEnum> flags) → String -
Formats
flagsas a|-separated string of enum names, mirroring C bitflag notation.inherited -
GuiButton(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiButton.
-
GuiCheckBox(
RectangleBase< RectangleBase> bounds, String? text, bool checked) → String - Label for RaylibGuiModuleBase.GuiCheckBox.
-
GuiColorBarAlpha(
RectangleBase< RectangleBase> bounds, num alpha) → String - Label for RaylibGuiModuleBase.GuiColorBarAlpha.
-
GuiColorBarHue(
RectangleBase< RectangleBase> bounds, num value) → String - Label for RaylibGuiModuleBase.GuiColorBarHue.
-
GuiColorPanel(
RectangleBase< RectangleBase> bounds, ColorBase<ColorBase> color) → String - Label for RaylibGuiModuleBase.GuiColorPanel.
-
GuiColorPanelHSV(
RectangleBase< RectangleBase> bounds, [Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> ? colorHsv]) → String - Label for RaylibGuiModuleBase.GuiColorPanelHSV.
-
GuiColorPicker(
RectangleBase< RectangleBase> bounds, ColorBase<ColorBase> ? color) → String - Label for RaylibGuiModuleBase.GuiColorPicker.
-
GuiColorPickerHSV(
RectangleBase< RectangleBase> bounds, [Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> ? colorHsv]) → String - Label for RaylibGuiModuleBase.GuiColorPickerHSV.
-
GuiComboBox(
RectangleBase< RectangleBase> bounds, String? text, num active) → String - Label for RaylibGuiModuleBase.GuiComboBox.
-
GuiDisable(
) → String - Label for RaylibGuiModuleBase.GuiDisable.
-
GuiDisableTooltip(
) → String - Label for RaylibGuiModuleBase.GuiDisableTooltip.
-
GuiDrawIcon(
GuiIconName iconId, num posX, num posY, num pixelSize, ColorBase< ColorBase> color) → String - Label for RaylibGuiModuleBase.GuiDrawIcon.
-
GuiDropdownBox(
RectangleBase< RectangleBase> bounds, String? text, num active, bool editMode) → String - Label for RaylibGuiModuleBase.GuiDropdownBox.
-
GuiDummyRec(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiDummyRec.
-
GuiEnable(
) → String - Label for RaylibGuiModuleBase.GuiEnable.
-
GuiEnableTooltip(
) → String - Label for RaylibGuiModuleBase.GuiEnableTooltip.
-
GuiGetFont(
) → String - Label for RaylibGuiModuleBase.GuiGetFont.
-
GuiGetIcons(
) → String - Label for RaylibGuiModuleBase.GuiGetIcons.
-
GuiGetState(
) → String - Label for RaylibGuiModuleBase.GuiGetState.
-
GuiGetStyle(
GuiControl control, GuiProperty property) → String - Label for RaylibGuiModuleBase.GuiGetStyle.
-
GuiGetTextWidth(
String? text) → String - Label for RaylibGuiModuleBase.GuiGetTextWidth.
-
GuiGrid(
RectangleBase< RectangleBase> bounds, num spacing, num subdivs, [Vector2Base<Vector2Base< ? mouseCell]) → Stringdynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> , MatrixBase, Vector3Base, QuaternionBase, Vector4Base> - Label for RaylibGuiModuleBase.GuiGrid.
-
GuiGroupBox(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiGroupBox.
-
GuiIconText(
GuiIconName iconId, String? text) → String - Label for RaylibGuiModuleBase.GuiIconText.
-
GuiIsLocked(
) → String - Label for RaylibGuiModuleBase.GuiIsLocked.
-
GuiLabel(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiLabel.
-
GuiLabelButton(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiLabelButton.
-
GuiLine(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiLine.
-
GuiListView(
RectangleBase< RectangleBase> bounds, String? text, {int? scrollIndex, int? active}) → String - Label for RaylibGuiModuleBase.GuiListView.
-
GuiListViewEx(
RectangleBase< RectangleBase> bounds, List<String> ? text, {int? scrollIndex, int? active, int? focus}) → String - Label for RaylibGuiModuleBase.GuiListViewEx.
-
GuiLoadIcons(
String fileName, bool loadIconsName) → String - Label for RaylibGuiModuleBase.GuiLoadIcons.
-
GuiLoadStyle(
String fileName) → String - Label for RaylibGuiModuleBase.GuiLoadStyle.
-
GuiLoadStyleDefault(
) → String - Label for RaylibGuiModuleBase.GuiLoadStyleDefault.
-
GuiLock(
) → String - Label for RaylibGuiModuleBase.GuiLock.
-
GuiMessageBox(
RectangleBase< RectangleBase> bounds, String? title, String message, String buttons) → String - Label for RaylibGuiModuleBase.GuiMessageBox.
-
GuiPanel(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiPanel.
-
GuiProgressBar(
RectangleBase< RectangleBase> bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → String - Label for RaylibGuiModuleBase.GuiProgressBar.
-
GuiScrollPanel(
RectangleBase< RectangleBase> bounds, String? text, RectangleBase<RectangleBase> content, Vector2Base<Vector2Base< scroll, [RectangleBase<dynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> , MatrixBase, Vector3Base, QuaternionBase, Vector4Base>RectangleBase> ? view]) → String - Label for RaylibGuiModuleBase.GuiScrollPanel.
-
GuiSetAlpha(
num alpha) → String - Label for RaylibGuiModuleBase.GuiSetAlpha.
-
GuiSetFont(
FontBase< FontBase< font) → Stringdynamic, TextureBase, RectangleBase, GlyphInfoBase< , TextureBase, RectangleBase, GlyphInfoBase<dynamic, ImageBase> , ImageBase>dynamic, ImageBase> , ImageBase> - Label for RaylibGuiModuleBase.GuiSetFont.
-
GuiSetIconScale(
num scale) → String - Label for RaylibGuiModuleBase.GuiSetIconScale.
-
GuiSetState(
GuiState state) → String - Label for RaylibGuiModuleBase.GuiSetState.
-
GuiSetStyle(
GuiControl control, GuiProperty property, num value) → String - Label for RaylibGuiModuleBase.GuiSetStyle.
-
GuiSetTooltip(
String? tooltip) → String - Label for RaylibGuiModuleBase.GuiSetTooltip.
-
GuiSlider(
RectangleBase< RectangleBase> bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → String - Label for RaylibGuiModuleBase.GuiSlider.
-
GuiSliderBar(
RectangleBase< RectangleBase> bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → String - Label for RaylibGuiModuleBase.GuiSliderBar.
-
GuiSpinner(
RectangleBase< RectangleBase> bounds, String? text, num value, num minValue, num maxValue, bool editMode) → String - Label for RaylibGuiModuleBase.GuiSpinner.
-
GuiStatusBar(
RectangleBase< RectangleBase> bounds, String? text) → String - Label for RaylibGuiModuleBase.GuiStatusBar.
-
GuiTabBar(
RectangleBase< RectangleBase> bounds, List<String> text) → String - Label for RaylibGuiModuleBase.GuiTabBar.
-
GuiTextBox(
RectangleBase< RectangleBase> bounds, String? text, num textSize, bool editMode) → String - Label for RaylibGuiModuleBase.GuiTextBox.
-
GuiTextInputBox(
RectangleBase< RectangleBase> bounds, String? title, String? message, String buttons, String? text, num textMaxSize, bool? secretViewActive) → String - Label for RaylibGuiModuleBase.GuiTextInputBox.
-
GuiToggle(
RectangleBase< RectangleBase> bounds, String? text, bool active) → String - Label for RaylibGuiModuleBase.GuiToggle.
-
GuiToggleGroup(
RectangleBase< RectangleBase> bounds, String? text, num active) → String - Label for RaylibGuiModuleBase.GuiToggleGroup.
-
GuiToggleSlider(
RectangleBase< RectangleBase> bounds, String? text, num active) → String - Label for RaylibGuiModuleBase.GuiToggleSlider.
-
GuiUnlock(
) → String - Label for RaylibGuiModuleBase.GuiUnlock.
-
GuiValueBox(
RectangleBase< RectangleBase> bounds, String? text, num value, num minValue, num maxValue, bool editMode) → String - Label for RaylibGuiModuleBase.GuiValueBox.
-
GuiValueBoxFloat(
RectangleBase< RectangleBase> bounds, String? text, String textValue, num value, bool editMode) → String - Label for RaylibGuiModuleBase.GuiValueBoxFloat.
-
GuiWindowBox(
RectangleBase< RectangleBase> bounds, String? title) → String - Label for RaylibGuiModuleBase.GuiWindowBox.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited