RaylibRlglConstants class
Dart-side mirror of Rlgl's compile-time constants (RLGL_VERSION, RL_DEFAULT_BATCH_BUFFER_ELEMENTS, etc.),
kept in the base package so all backends share a single source of truth.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- RL_BLEND_COLOR → int
-
Predefined constant
RL_BLEND_COLOR.final - RL_BLEND_DST_ALPHA → int
-
Predefined constant
RL_BLEND_DST_ALPHA.final - RL_BLEND_DST_RGB → int
-
Predefined constant
RL_BLEND_DST_RGB.final - RL_BLEND_EQUATION → int
-
Predefined constant
RL_BLEND_EQUATION.final - RL_BLEND_EQUATION_ALPHA → int
-
Predefined constant
RL_BLEND_EQUATION_ALPHA.final - RL_BLEND_EQUATION_RGB → int
-
Predefined constant
RL_BLEND_EQUATION_RGB.final - RL_BLEND_SRC_ALPHA → int
-
Predefined constant
RL_BLEND_SRC_ALPHA.final - RL_BLEND_SRC_RGB → int
-
Predefined constant
RL_BLEND_SRC_RGB.final - RL_COMPUTE_SHADER → int
-
Predefined constant
RL_COMPUTE_SHADER.final - RL_CONSTANT_ALPHA → int
-
Predefined constant
RL_CONSTANT_ALPHA.final - RL_CONSTANT_COLOR → int
-
Predefined constant
RL_CONSTANT_COLOR.final - RL_CULL_DISTANCE_FAR → double
-
Predefined constant
RL_CULL_DISTANCE_FAR.final - RL_CULL_DISTANCE_NEAR → double
-
Predefined constant
RL_CULL_DISTANCE_NEAR.final - RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
-
Predefined constant
RL_DEFAULT_BATCH_BUFFER_ELEMENTS.final - RL_DEFAULT_BATCH_BUFFERS → int
-
Predefined constant
RL_DEFAULT_BATCH_BUFFERS.final - RL_DEFAULT_BATCH_DRAWCALLS → int
-
Predefined constant
RL_DEFAULT_BATCH_DRAWCALLS.final - RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
-
Predefined constant
RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEIDS → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEIDS.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD.final - RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2 → int
-
Predefined constant
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2.final - RL_DRAW_FRAMEBUFFER → int
-
Predefined constant
RL_DRAW_FRAMEBUFFER.final - RL_DST_ALPHA → int
-
Predefined constant
RL_DST_ALPHA.final - RL_DST_COLOR → int
-
Predefined constant
RL_DST_COLOR.final - RL_DYNAMIC_COPY → int
-
Predefined constant
RL_DYNAMIC_COPY.final - RL_DYNAMIC_DRAW → int
-
Predefined constant
RL_DYNAMIC_DRAW.final - RL_DYNAMIC_READ → int
-
Predefined constant
RL_DYNAMIC_READ.final - RL_FLOAT → int
-
Predefined constant
RL_FLOAT.final - RL_FRAGMENT_SHADER → int
-
Predefined constant
RL_FRAGMENT_SHADER.final - RL_FUNC_ADD → int
-
Predefined constant
RL_FUNC_ADD.final - RL_FUNC_REVERSE_SUBTRACT → int
-
Predefined constant
RL_FUNC_REVERSE_SUBTRACT.final - RL_FUNC_SUBTRACT → int
-
Predefined constant
RL_FUNC_SUBTRACT.final - RL_LINES → int
-
Predefined constant
RL_LINES.final - RL_MAX → int
-
Predefined constant
RL_MAX.final - RL_MAX_MATRIX_STACK_SIZE → int
-
Predefined constant
RL_MAX_MATRIX_STACK_SIZE.final - RL_MAX_SHADER_LOCATIONS → int
-
Predefined constant
RL_MAX_SHADER_LOCATIONS.final - RL_MIN → int
-
Predefined constant
RL_MIN.final - RL_MODELVIEW → int
-
Predefined constant
RL_MODELVIEW.final - RL_ONE → int
-
Predefined constant
RL_ONE.final - RL_ONE_MINUS_CONSTANT_ALPHA → int
-
Predefined constant
RL_ONE_MINUS_CONSTANT_ALPHA.final - RL_ONE_MINUS_CONSTANT_COLOR → int
-
Predefined constant
RL_ONE_MINUS_CONSTANT_COLOR.final - RL_ONE_MINUS_DST_ALPHA → int
-
Predefined constant
RL_ONE_MINUS_DST_ALPHA.final - RL_ONE_MINUS_DST_COLOR → int
-
Predefined constant
RL_ONE_MINUS_DST_COLOR.final - RL_ONE_MINUS_SRC_ALPHA → int
-
Predefined constant
RL_ONE_MINUS_SRC_ALPHA.final - RL_ONE_MINUS_SRC_COLOR → int
-
Predefined constant
RL_ONE_MINUS_SRC_COLOR.final - RL_PROJECTION → int
-
Predefined constant
RL_PROJECTION.final - RL_QUADS → int
-
Predefined constant
RL_QUADS.final - RL_READ_FRAMEBUFFER → int
-
Predefined constant
RL_READ_FRAMEBUFFER.final - RL_SHADER_LOC_MAP_DIFFUSE → int
-
Predefined constant
RL_SHADER_LOC_MAP_DIFFUSE.final - RL_SHADER_LOC_MAP_SPECULAR → int
-
Predefined constant
RL_SHADER_LOC_MAP_SPECULAR.final - RL_SRC_ALPHA → int
-
Predefined constant
RL_SRC_ALPHA.final - RL_SRC_ALPHA_SATURATE → int
-
Predefined constant
RL_SRC_ALPHA_SATURATE.final - RL_SRC_COLOR → int
-
Predefined constant
RL_SRC_COLOR.final - RL_STATIC_COPY → int
-
Predefined constant
RL_STATIC_COPY.final - RL_STATIC_DRAW → int
-
Predefined constant
RL_STATIC_DRAW.final - RL_STATIC_READ → int
-
Predefined constant
RL_STATIC_READ.final - RL_STREAM_COPY → int
-
Predefined constant
RL_STREAM_COPY.final - RL_STREAM_DRAW → int
-
Predefined constant
RL_STREAM_DRAW.final - RL_STREAM_READ → int
-
Predefined constant
RL_STREAM_READ.final - RL_TEXTURE → int
-
Predefined constant
RL_TEXTURE.final - RL_TEXTURE_FILTER_ANISOTROPIC → int
-
Predefined constant
RL_TEXTURE_FILTER_ANISOTROPIC.final - RL_TEXTURE_FILTER_LINEAR → int
-
Predefined constant
RL_TEXTURE_FILTER_LINEAR.final - RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
-
Predefined constant
RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST.final - RL_TEXTURE_FILTER_MIP_LINEAR → int
-
Predefined constant
RL_TEXTURE_FILTER_MIP_LINEAR.final - RL_TEXTURE_FILTER_MIP_NEAREST → int
-
Predefined constant
RL_TEXTURE_FILTER_MIP_NEAREST.final - RL_TEXTURE_FILTER_NEAREST → int
-
Predefined constant
RL_TEXTURE_FILTER_NEAREST.final - RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
-
Predefined constant
RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR.final - RL_TEXTURE_MAG_FILTER → int
-
Predefined constant
RL_TEXTURE_MAG_FILTER.final - RL_TEXTURE_MIN_FILTER → int
-
Predefined constant
RL_TEXTURE_MIN_FILTER.final - RL_TEXTURE_MIPMAP_BIAS_RATIO → int
-
Predefined constant
RL_TEXTURE_MIPMAP_BIAS_RATIO.final - RL_TEXTURE_WRAP_CLAMP → int
-
Predefined constant
RL_TEXTURE_WRAP_CLAMP.final - RL_TEXTURE_WRAP_MIRROR_CLAMP → int
-
Predefined constant
RL_TEXTURE_WRAP_MIRROR_CLAMP.final - RL_TEXTURE_WRAP_MIRROR_REPEAT → int
-
Predefined constant
RL_TEXTURE_WRAP_MIRROR_REPEAT.final - RL_TEXTURE_WRAP_REPEAT → int
-
Predefined constant
RL_TEXTURE_WRAP_REPEAT.final - RL_TEXTURE_WRAP_S → int
-
Predefined constant
RL_TEXTURE_WRAP_S.final - RL_TEXTURE_WRAP_T → int
-
Predefined constant
RL_TEXTURE_WRAP_T.final - RL_TRIANGLES → int
-
Predefined constant
RL_TRIANGLES.final - RL_UNSIGNED_BYTE → int
-
Predefined constant
RL_UNSIGNED_BYTE.final - RL_VERTEX_SHADER → int
-
Predefined constant
RL_VERTEX_SHADER.final - RL_ZERO → int
-
Predefined constant
RL_ZERO.final - RLGL_VERSION → String
-
Predefined constant
RLGL_VERSION.final