RaylibRlglModuleDebugLabels class

Produces human-readable debug strings for each Rlgl module function call, logged to the console when debug output is enabled.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

EnumsAsFlagsOr(Iterable<RaylibEnum> flags) String
Formats flags as a |-separated string of enum names, mirroring C bitflag notation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rlActiveDrawBuffers(num count) String
rlActiveTextureSlot(num slot) String
rlBegin(RlDrawMode mode) String
rlBindFramebuffer(num target, num framebuffer) String
rlBindImageTexture(num id, num index, PixelFormat format, bool readonly) String
rlBindShaderBuffer(num id, num index) String
rlBlitFramebuffer(num srcX, num srcY, num srcWidth, num srcHeight, num dstX, num dstY, num dstWidth, num dstHeight, num bufferMask) String
rlCheckErrors() String
rlCheckRenderBatchLimit(num vCount) String
rlClearColor(num r, num g, num b, num a) String
rlClearScreenBuffers() String
rlColor3f(num x, num y, num z) String
rlColor4f(num x, num y, num z, num w) String
rlColor4ub(num r, num g, num b, num a) String
rlColorMask(bool r, bool g, bool b, bool a) String
rlCompileShader(String shaderCode, RlShaderType type) String
rlComputeShaderDispatch(num groupX, num groupY, num groupZ) String
rlCopyShaderBuffer(num destId, num srcId, num destOffset, num srcOffset, num count) String
rlCubemapParameters(num id, num param, num value) String
rlDisableBackfaceCulling() String
rlDisableColorBlend() String
rlDisableDepthMask() String
rlDisableDepthTest() String
rlDisableFramebuffer() String
rlDisableScissorTest() String
rlDisableShader() String
rlDisableSmoothLines() String
rlDisableStereoRender() String
rlDisableTexture() String
rlDisableTextureCubemap() String
rlDisableVertexArray() String
rlDisableVertexAttribute(num index) String
rlDisableVertexBuffer() String
rlDisableVertexBufferElement() String
rlDisableWireMode() String
rlDrawRenderBatch(RlRenderBatchBase<RlRenderBatchBase<dynamic, RlVertexBufferBase, RlDrawCallBase>, RlVertexBufferBase, RlDrawCallBase> batch) String
rlDrawRenderBatchActive() String
rlDrawVertexArray(num offset, num count) String
rlDrawVertexArrayElements(num offset, num count, Uint16List buffer) String
rlDrawVertexArrayElementsInstanced(num offset, num count, Uint16List buffer, num instances) String
rlDrawVertexArrayInstanced(num offset, num count, num instances) String
rlEnableBackfaceCulling() String
rlEnableColorBlend() String
rlEnableDepthMask() String
rlEnableDepthTest() String
rlEnableFramebuffer(num id) String
rlEnablePointMode() String
rlEnableScissorTest() String
rlEnableShader(num id) String
rlEnableSmoothLines() String
rlEnableStereoRender() String
rlEnableTexture(num id) String
rlEnableTextureCubemap(num id) String
rlEnableVertexArray(num vaoId) String
rlEnableVertexAttribute(num index) String
rlEnableVertexBuffer(num id) String
rlEnableVertexBufferElement(num id) String
rlEnableWireMode() String
rlEnd() String
rlFramebufferAttach(num fboId, num texId, RlFramebufferAttachType attachType, RlFramebufferAttachTextureType texType, num mipLevel) String
rlFramebufferComplete(num id) String
rlFrustum(num left, num right, num bottom, num top, num znear, num zfar) String
rlGenTextureMipmaps(num id, num width, num height, PixelFormat format) String
rlGetActiveFramebuffer() String
rlGetCullDistanceFar() String
rlGetCullDistanceNear() String
rlGetFramebufferHeight() String
rlGetFramebufferWidth() String
rlGetGlTextureFormats(PixelFormat format) String
rlGetLineWidth() String
rlGetLocationAttrib(num shaderId, String attribName) String
rlGetLocationUniform(num shaderId, String uniformName) String
rlGetMatrixModelview() String
rlGetMatrixProjection() String
rlGetMatrixProjectionStereo(num eye) String
rlGetMatrixTransform() String
rlGetMatrixViewOffsetStereo(num eye) String
rlGetPixelFormatName(PixelFormat format) String
rlGetShaderBufferSize(num id) String
rlGetShaderIdDefault() String
rlGetShaderLocsDefault() String
rlGetTextureIdDefault() String
rlGetVersion() String
rlglClose() String
rlglInit(num width, num height) String
rlIsStereoRenderEnabled() String
rlLoadComputeShaderProgram(num shaderId) String
rlLoadDrawCube() String
rlLoadDrawQuad() String
rlLoadFramebuffer() String
rlLoadIdentity() String
rlLoadRenderBatch(num numBuffers, num bufferElements) String
rlLoadShaderBuffer(num size, TypedDataList? data, RlUsageHint? usageHint) String
rlLoadShaderCode(String? vsCode, String? fsCode) String
rlLoadShaderProgram(num vShaderId, num fShaderId) String
rlLoadTexture(Uint8List? data, num width, num height, PixelFormat format, num mipmapCount) String
rlLoadTextureCubemap(Uint8List? data, num size, PixelFormat format, num mipmapCount) String
rlLoadTextureDepth(num width, num height, bool useRenderBuffer) String
rlLoadVertexArray() String
rlLoadVertexBuffer(TypedDataList buffer, bool dynamic) String
rlLoadVertexBufferElement(TypedDataList buffer, bool dynamic) String
rlMatrixMode(RlMatrixMode mode) String
rlMultMatrixf(List<double> matf) String
rlNormal3f(num x, num y, num z) String
rlOrtho(num left, num right, num bottom, num top, num znear, num zfar) String
rlPopMatrix() String
rlPushMatrix() String
rlReadScreenPixels(num width, num height) String
rlReadShaderBuffer(num id, num count, num offset) String
rlReadTexturePixels(num id, num width, num height, PixelFormat format) String
rlRotatef(num angle, num x, num y, num z) String
rlScalef(num x, num y, num z) String
rlScissor(num x, num y, num width, num height) String
rlSetBlendFactors(num glSrcFactor, num glDstFactor, num glEquation) String
rlSetBlendFactorsSeparate(num glSrcRGB, num glDstRGB, num glSrcAlpha, num glDstAlpha, num glEqRGB, num glEqAlpha) String
rlSetBlendMode(BlendMode mode) String
rlSetClipPlanes(num nearPlane, num farPlane) String
rlSetCullFace(RlCullMode mode) String
rlSetFramebufferHeight(num height) String
rlSetFramebufferWidth(num width) String
rlSetLineWidth(num width) String
rlSetMatrixModelview(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> view) String
rlSetMatrixProjection(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> proj) String
rlSetMatrixProjectionStereo(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> right, MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> left) String
rlSetMatrixViewOffsetStereo(MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> right, MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> left) String
rlSetRenderBatchActive(RlRenderBatchBase<RlRenderBatchBase<dynamic, RlVertexBufferBase, RlDrawCallBase>, RlVertexBufferBase, RlDrawCallBase> batch) String
rlSetShader(num id, List<int> locs) String
rlSetTexture(num id) String
rlSetUniform(num locIndex, TypedDataList value, RlShaderUniformDataType uniformType, num count) String
rlSetUniformMatrices(num locIndex, List<MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base>> mat) String
rlSetUniformMatrix(num locIndex, MatrixBase<MatrixBase, Vector3Base, QuaternionBase, Vector4Base> mat) String
rlSetUniformSampler(num locIndex, num textureId) String
rlSetVertexAttribute(num index, num compSize, num type, bool normalized, num stride, num offset) String
rlSetVertexAttributeDefault(num locIndex, Float32List value, RlShaderAttributeDataType attribType) String
rlSetVertexAttributeDivisor(num index, num divisor) String
rlTexCoord2f(num x, num y) String
rlTextureParameters(num id, num param, num value) String
rlTranslatef(num x, num y, num z) String
rlUnloadFramebuffer(num id) String
rlUnloadRenderBatch(RlRenderBatchBase<RlRenderBatchBase<dynamic, RlVertexBufferBase, RlDrawCallBase>, RlVertexBufferBase, RlDrawCallBase> batch) String
rlUnloadShaderBuffer(num ssboId) String
rlUnloadShaderProgram(num id) String
rlUnloadTexture(num id) String
rlUnloadVertexArray(num vaoId) String
rlUnloadVertexBuffer(num vboId) String
rlUpdateShaderBuffer(num id, TypedDataList data, num offset) String
rlUpdateTexture(num id, num offsetX, num offsetY, num width, num height, PixelFormat format, Uint8List data) String
rlUpdateVertexBuffer(num bufferId, TypedDataList data, num offset) String
rlUpdateVertexBufferElements(num id, TypedDataList data, num offset) String
rlVertex2f(num x, num y) String
rlVertex2i(num x, num y) String
rlVertex3f(num x, num y, num z) String
rlViewport(num x, num y, num width, num height) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited