RlDrawMode enum

Rlgl DrawMode enum.

Inheritance
Available extensions

Values

RL_NONE → const RlDrawMode

RL_NONE (for uninitialized RlDrawCallBase slots only)

const RlDrawMode(0)
RL_LINES → const RlDrawMode

RL_LINES

const RlDrawMode(0x0001)
RL_TRIANGLES → const RlDrawMode

RL_TRIANGLES

const RlDrawMode(0x0004)
RL_QUADS → const RlDrawMode

RL_QUADS

const RlDrawMode(0x0007)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) RlDrawMode
Returns the RlDrawMode for the given native value.

Constants

values → const List<RlDrawMode>
A constant List of the values in this enum, in order of their declaration.