RlVertexBufferD class
RLGL Vertex buffer
- Inheritance
-
- Object
- RaylibStruct<
RlVertexBufferD> - RlVertexBufferD
Constructors
-
RlVertexBufferD({StructPointer<
RlVertexBufferD> ? op, int elementCount = 0, List<double> ? vertices, List<double> ? texcoords, List<double> ? normals, List<int> ? colors, List<int> ? indices, int vaoId = 0, List<int> ? vboId}) - RlVertexBufferD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
colors
↔ StructLiveList<
int, RUnsignedChar> -
Vertex colors (RGBA - 4 components per vertex) (shader-location = 3)
getter/setter pair
- colorsCount → int
-
Number of components in the colors buffer.
no setter
- elementCount ↔ int
-
Number of elements in the buffer (QUADS)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ StructLiveList<
int, RTypeIntLike> -
Vertex indices (in case vertex data comes indexed) (6 indices per quad)
getter/setter pair
- indicesCount → int
-
Number of components in the indices buffer.
no setter
-
normals
↔ StructLiveList<
double, RFloat> -
Vertex normal (XYZ - 3 components per vertex) (shader-location = 2)
getter/setter pair
- normalsCount → int
-
Number of components in the normals buffer.
no setter
-
op
↔ StructPointer<
RlVertexBufferD> ? -
The C-owned or RaylibTemp-owned typed pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
-
texcoords
↔ StructLiveList<
double, RFloat> -
Vertex texture coordinates (UV - 2 components per vertex) (shader-location = 1)
getter/setter pair
- texcoordsCount → int
-
Number of components in the texcoords buffer.
no setter
- vaoId ↔ int
-
OpenGL Vertex Array Object id
getter/setter pair
-
vboId
↔ StructLiveList<
int, RUnsignedInt> -
OpenGL Vertex Buffer Objects id (5 types of vertex data)
getter/setter pair
- vboIdCount → int
-
Number of components in the vboId array.
no setter
-
vertices
↔ StructLiveList<
double, RFloat> -
Vertex position (XYZ - 3 components per vertex) (shader-location = 0)
getter/setter pair
- verticesCount → int
-
Number of components in the vertices buffer.
no setter
Methods
-
clone(
) → RlVertexBufferD -
Returns a deep copy of this instance, preserving op if present.
override
-
copy(
) → RlVertexBufferD -
Returns a deep copy of this instance without op.
inherited
-
getOp(
) → StructPointer< RlVertexBufferD> -
Returns op, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOpAndDispose(
) → StructPointer< RlVertexBufferD> -
Returns op and immediately disposes this struct.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDart(
RlVertexBufferD o) → RlVertexBufferD -
Copies the fields of
ointo this instance.override -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
structAllocateInto(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.override -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears op.
inherited
-
structOnOp(
void callback(StructPointer< RlVertexBufferD> p)) → void -
Calls
callbackwith op if it is set, otherwise no-ops.inherited -
structReadFrom(
MemoryPointer< RType> p) → void -
override
-
structSetTag(
String newTag) → RlVertexBufferD -
Sets RaylibTempStructState.tag to
newTag.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires op.
inherited
-
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires op.
inherited
-
structWriteInto(
MemoryPointer< RType> p) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_vboIdCount → int
-
Number of components in the vboId array.
no setter
-
field_colors
→ StructPointerArrayField<
int, RUnsignedChar> -
Field descriptor for colors.
final
-
field_elementCount
→ StructValueField<
int, RInt> -
Field descriptor for elementCount.
final
-
field_indices
→ StructPointerArrayField<
int, RTypeIntLike> -
Field descriptor for indices.
final
-
field_normals
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for normals.
final
-
field_texcoords
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for texcoords.
final
-
field_vaoId
→ StructValueField<
int, RUnsignedInt> -
Field descriptor for vaoId.
final
-
field_vboId
→ StructValueField<
List< int> , RArray<RUnsignedInt> > -
Field descriptor for vboId.
final
-
field_vertices
→ StructPointerArrayField<
double, RFloat> -
Field descriptor for vertices.
final
-
struct
→ StructType<
RlVertexBufferD> -
Describes the raw memory layout, construction, and pointer representation
of this struct type.
final
-
structLayout
→ StructLayout<
RlVertexBufferField> -
Raw memory layout of this object.
final
Static Methods
-
BASE_colorsCount(
int elementCount) → int - Number of components in the colors buffer.
-
BASE_indicesCount(
int elementCount) → int - Number of components in the indices buffer.
-
BASE_normalsCount(
int elementCount) → int - Number of components in the normals buffer.
-
BASE_texcoordsCount(
int elementCount) → int - Number of components in the texcoords buffer.
-
BASE_verticesCount(
int elementCount) → int - Number of components in the vertices buffer.