ShaderLocationIndex enum
Raylib ShaderLocationIndex enum.
Values
- SHADER_LOC_VERTEX_POSITION → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_POSITIONconst ShaderLocationIndex(0) - SHADER_LOC_VERTEX_TEXCOORD01 → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_TEXCOORD01const ShaderLocationIndex(1) - SHADER_LOC_VERTEX_TEXCOORD02 → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_TEXCOORD02const ShaderLocationIndex(2) - SHADER_LOC_VERTEX_NORMAL → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_NORMALconst ShaderLocationIndex(3) - SHADER_LOC_VERTEX_TANGENT → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_TANGENTconst ShaderLocationIndex(4) - SHADER_LOC_VERTEX_COLOR → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_COLORconst ShaderLocationIndex(5) - SHADER_LOC_MATRIX_MVP → const ShaderLocationIndex
-
SHADER_LOC_MATRIX_MVPconst ShaderLocationIndex(6) - SHADER_LOC_MATRIX_VIEW → const ShaderLocationIndex
-
SHADER_LOC_MATRIX_VIEWconst ShaderLocationIndex(7) - SHADER_LOC_MATRIX_PROJECTION → const ShaderLocationIndex
-
SHADER_LOC_MATRIX_PROJECTIONconst ShaderLocationIndex(8) - SHADER_LOC_MATRIX_MODEL → const ShaderLocationIndex
-
SHADER_LOC_MATRIX_MODELconst ShaderLocationIndex(9) - SHADER_LOC_MATRIX_NORMAL → const ShaderLocationIndex
-
SHADER_LOC_MATRIX_NORMALconst ShaderLocationIndex(10) - SHADER_LOC_VECTOR_VIEW → const ShaderLocationIndex
-
SHADER_LOC_VECTOR_VIEWconst ShaderLocationIndex(11) - SHADER_LOC_COLOR_DIFFUSE → const ShaderLocationIndex
-
SHADER_LOC_COLOR_DIFFUSEconst ShaderLocationIndex(12) - SHADER_LOC_COLOR_SPECULAR → const ShaderLocationIndex
-
SHADER_LOC_COLOR_SPECULARconst ShaderLocationIndex(13) - SHADER_LOC_COLOR_AMBIENT → const ShaderLocationIndex
-
SHADER_LOC_COLOR_AMBIENTconst ShaderLocationIndex(14) - SHADER_LOC_MAP_ALBEDO → const ShaderLocationIndex
-
SHADER_LOC_MAP_ALBEDOconst ShaderLocationIndex(15) - SHADER_LOC_MAP_METALNESS → const ShaderLocationIndex
-
SHADER_LOC_MAP_METALNESSconst ShaderLocationIndex(16) - SHADER_LOC_MAP_NORMAL → const ShaderLocationIndex
-
SHADER_LOC_MAP_NORMALconst ShaderLocationIndex(17) - SHADER_LOC_MAP_ROUGHNESS → const ShaderLocationIndex
-
SHADER_LOC_MAP_ROUGHNESSconst ShaderLocationIndex(18) - SHADER_LOC_MAP_OCCLUSION → const ShaderLocationIndex
-
SHADER_LOC_MAP_OCCLUSIONconst ShaderLocationIndex(19) - SHADER_LOC_MAP_EMISSION → const ShaderLocationIndex
-
SHADER_LOC_MAP_EMISSIONconst ShaderLocationIndex(20) - SHADER_LOC_MAP_HEIGHT → const ShaderLocationIndex
-
SHADER_LOC_MAP_HEIGHTconst ShaderLocationIndex(21) - SHADER_LOC_MAP_CUBEMAP → const ShaderLocationIndex
-
SHADER_LOC_MAP_CUBEMAPconst ShaderLocationIndex(22) - SHADER_LOC_MAP_IRRADIANCE → const ShaderLocationIndex
-
SHADER_LOC_MAP_IRRADIANCEconst ShaderLocationIndex(23) - SHADER_LOC_MAP_PREFILTER → const ShaderLocationIndex
-
SHADER_LOC_MAP_PREFILTERconst ShaderLocationIndex(24) - SHADER_LOC_MAP_BRDF → const ShaderLocationIndex
-
SHADER_LOC_MAP_BRDFconst ShaderLocationIndex(25) - SHADER_LOC_VERTEX_BONEIDS → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_BONEIDSconst ShaderLocationIndex(26) - SHADER_LOC_VERTEX_BONEWEIGHTS → const ShaderLocationIndex
-
SHADER_LOC_VERTEX_BONEWEIGHTSconst ShaderLocationIndex(27) - SHADER_LOC_BONE_MATRICES → const ShaderLocationIndex
-
SHADER_LOC_BONE_MATRICESconst ShaderLocationIndex(28)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → ShaderLocationIndex -
Returns the ShaderLocationIndex for the given native
value.
Constants
-
values
→ const List<
ShaderLocationIndex> - A constant List of the values in this enum, in order of their declaration.