ref property
D
get
ref
Returns a live view of the struct backed by this memory.
The returned struct always retains its memory reference. Field mutations are therefore written through to the underlying memory immediately.
Implementation
D get ref => structType.factory(op: this);
set
ref
(D v)
Copies v's current field values into this memory.
The identity and memory reference of ref are not changed.
Implementation
set ref(D v) => _copyOrWrite(ptr, v);