StructPointerArrayField<E, R extends RType> class
A pointer to a variable-length run of E, length is runtime-only, so
there's no plain read/write; callers must supply the count they know
about externally via readCount/writeCount.
- Inheritance
-
- Object
- StructFieldBase<
List< E> > - StructPointerArrayField
- Available extensions
Constructors
-
StructPointerArrayField(int offset, PointerCodec<
E, R> codec) -
const
Properties
-
codec
→ PointerCodec<
E, R> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocate(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key, {int count = 1, bool raw = false}) → void -
override
-
live(
MemoryPointer< RType> ? ptrOf(), List<E> initial) → StructLiveList<E, R> -
Available on StructPointerArrayField<
E, R> , provided by the LivePointerArrayFieldX extension -
liveNested(
MemoryPointer< RType> ? ptrOf(), List<List< initial) → StructLiveList<E> >StructLiveList< E, R> , RPointer<R> > -
Available on StructPointerArrayField<
E, RPointer< , provided by the LivePointerPointerArrayFieldX extensionR> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
MemoryPointer< RType> p) → List<E> -
override
-
readCount(
MemoryPointer< RType> p, int count, [List<E> ? fallback]) → List<E> -
readCountOr(
MemoryPointer< RType> ? p, int count, [List<E> ? fallback]) → List<E> -
readOr(
MemoryPointer< RType> ? p, List<E> fallback) → List<E> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
MemoryPointer< RType> p, List<E> value) → List<E> -
override
-
writeCount(
MemoryPointer< RType> p, List<E> values) → List<E> -
writeCountIf(
MemoryPointer< RType> ? p, List<E> fallback) → List<E> -
writeOr(
MemoryPointer< RType> ? p, List<E> value) → List<E> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited