VrDeviceInfoD class
VrDeviceInfo, Head-Mounted-Display device parameters
- Inheritance
-
- Object
- RaylibStruct<
VrDeviceInfoD> - VrDeviceInfoD
Constructors
-
VrDeviceInfoD({StructPointer<
VrDeviceInfoD> ? op, int hResolution = 0, int vResolution = 0, double hScreenSize = 0, double vScreenSize = 0, double eyeToScreenDistance = 0, double lensSeparationDistance = 0, double interpupillaryDistance = 0, List<double> ? lensDistortionValues, List<double> ? chromaAbCorrection}) - VrDeviceInfoD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
chromaAbCorrection
↔ StructLiveList<
double, RFloat> -
Chromatic aberration correction parameters
getter/setter pair
- eyeToScreenDistance ↔ double
-
Distance between eye and display in meters
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hResolution ↔ int
-
Horizontal resolution in pixels
getter/setter pair
- hScreenSize ↔ double
-
Horizontal size in meters
getter/setter pair
- interpupillaryDistance ↔ double
-
IPD (distance between pupils) in meters
getter/setter pair
-
lensDistortionValues
↔ StructLiveList<
double, RFloat> -
Lens distortion constant parameters
getter/setter pair
- lensSeparationDistance ↔ double
-
Lens separation distance in meters
getter/setter pair
-
op
↔ StructPointer<
VrDeviceInfoD> ? -
The C-owned or RaylibTemp-owned typed pointer for this struct, if any.
getter/setter pairinherited
- paramsCount → int
-
Number of components in the lensDistortionValues and chromaAbCorrection arrays.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- vResolution ↔ int
-
Vertical resolution in pixels
getter/setter pair
- vScreenSize ↔ double
-
Vertical size in meters
getter/setter pair
Methods
-
clone(
) → VrDeviceInfoD -
Returns a deep copy of this instance, preserving op if present.
override
-
copy(
) → VrDeviceInfoD -
Returns a deep copy of this instance without op.
inherited
-
getOp(
) → StructPointer< VrDeviceInfoD> -
Returns op, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOpAndDispose(
) → StructPointer< VrDeviceInfoD> -
Returns op and immediately disposes this struct.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDart(
VrDeviceInfoD o) → VrDeviceInfoD -
Copies the fields of
ointo this instance.override -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
structAllocateInto(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.inherited -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears op.
inherited
-
structOnOp(
void callback(StructPointer< VrDeviceInfoD> p)) → void -
Calls
callbackwith op if it is set, otherwise no-ops.inherited -
structReadFrom(
MemoryPointer< RType> p) → void -
override
-
structSetTag(
String newTag) → VrDeviceInfoD -
Sets RaylibTempStructState.tag to
newTag.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires op.
inherited
-
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires op.
inherited
-
structWriteInto(
MemoryPointer< RType> p) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_paramsCount → int
-
Number of components in the lensDistortionValues and chromaAbCorrection arrays.
no setter
-
field_chromaAbCorrection
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for chromaAbCorrection.
final
-
field_eyeToScreenDistance
→ StructValueField<
double, RFloat> -
Field descriptor for eyeToScreenDistance.
final
-
field_hResolution
→ StructValueField<
int, RInt> -
Field descriptor for hResolution.
final
-
field_hScreenSize
→ StructValueField<
double, RFloat> -
Field descriptor for hScreenSize.
final
-
field_interpupillaryDistance
→ StructValueField<
double, RFloat> -
Field descriptor for interpupillaryDistance.
final
-
field_lensDistortionValues
→ StructValueField<
List< double> , RArray<RFloat> > -
Field descriptor for lensDistortionValues.
final
-
field_lensSeparationDistance
→ StructValueField<
double, RFloat> -
Field descriptor for lensSeparationDistance.
final
-
field_vResolution
→ StructValueField<
int, RInt> -
Field descriptor for vResolution.
final
-
field_vScreenSize
→ StructValueField<
double, RFloat> -
Field descriptor for vScreenSize.
final
-
struct
→ StructType<
VrDeviceInfoD> -
Describes the raw memory layout, construction, and pointer representation
of this struct type.
final
-
structLayout
→ StructLayout<
VrDeviceInfoField> -
Raw memory layout of this object.
final